@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2025 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -45,7 +45,8 @@ $var_pag[17] = 'valore_xml';
 $var_pag[18] = 'token';
 $var_pag[19] = 'ord_ic';
 $var_pag[20] = 'tweb';
-$n_var_pag = 21;
+$var_pag[21] = 'del';
+$n_var_pag = 22;
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -102,9 +103,9 @@ $login_sbagliati = numlin_query($login_sbagliati);
 if ($login_sbagliati >= $max_log_sbagliati) echo "Excessive number of failed logins";
 else {
 
-if (@get_magic_quotes_gpc()) $pass = stripslashes($pass);
+if (@get_magic_quotes_gpc()) $pass = stripslashes(fixstr($pass));
 $pass_api = substr($pass_api,(strlen($id_utente) + strlen($indirizzi_ip_api) + 2));
-if ($pass == $pass_api) {
+if (fixset($pass) == $pass_api) {
 
 $raggiunto_limite = 0;
 if (defined('C_LIMITE_CHIAMATE_API_AL_MINUTO') and C_LIMITE_CHIAMATE_API_AL_MINUTO > 0) {
@@ -145,6 +146,12 @@ if (@is_file(C_DATI_PATH."/selectperiodi$anno_prec.1.php")) $anno = $anno_prec;
 else $anno_esist = 0;
 } # fine if (!@is_file(C_DATI_PATH."/selectperiodi$anno.1.php"))
 if ($anno_esist) {
+$tariffe_consentite_vett = array();
+
+$tablebeniinventario = $PHPR_TAB_PRE."beniinventario";
+$tablerelinventario = $PHPR_TAB_PRE."relinventario";
+$tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
+$tableregole = $PHPR_TAB_PRE."regole".$anno;
 
 
 if ($id_utente != 1) {
@@ -158,16 +165,26 @@ $anno_utente_attivato = "SI";
 $privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
 $priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
 if (substr($priv_mod_pers,0,1) != "s") $modifica_pers = "NO";
+$priv_inventario = risul_query($privilegi_globali_utente,0,'priv_inventario');
+$priv_vedi_beni_inv = substr($priv_inventario,0,1);
+$priv_vedi_inv_app = substr($priv_inventario,6,1);
+if ($priv_vedi_beni_inv == "g" or $priv_vedi_inv_app == "g") $prendi_gruppi = "SI";
 $priv_vedi_tab = risul_query($privilegi_annuali_utente,0,'priv_vedi_tab');
 $priv_vedi_tab_mesi = substr($priv_vedi_tab,0,1);
-if ($priv_vedi_tab_mesi == "q" or $priv_vedi_tab_mesi == "g") $prendi_gruppi = "SI";
+if ($priv_vedi_tab_mesi == "q" or $priv_vedi_tab_mesi == "r" or $priv_vedi_tab_mesi == "g") $prendi_gruppi = "SI";
 $priv_vedi_tab_costi = substr($priv_vedi_tab,2,1);
 $priv_vedi_tab_prenotazioni = substr($priv_vedi_tab,1,1);
 if ($priv_vedi_tab_prenotazioni == "g") $prendi_gruppi = "SI";
+$priv_vedi_tab_appartamenti = substr($priv_vedi_tab,5,1);
+if ($priv_vedi_tab_appartamenti == "g") $prendi_gruppi = "SI";
 $priv_vedi_tab_doc = substr($priv_vedi_tab,7,1);
+$priv_ins_prenota = risul_query($privilegi_annuali_utente,0,'priv_ins_prenota');
+$priv_ins_nuove_prenota = substr($priv_ins_prenota,0,1);
+$priv_ins_assegnazione_app = substr($priv_ins_prenota,1,1);
 $priv_mod_prenota = risul_query($privilegi_annuali_utente,0,'priv_mod_prenota');
 $priv_mod_prenotazioni = substr($priv_mod_prenota,0,1);
 if ($priv_mod_prenotazioni == "g") $prendi_gruppi = "SI";
+$priv_mod_assegnazione_app = substr($priv_mod_prenota,2,1);
 $priv_mod_tariffa = substr($priv_mod_prenota,3,1);
 $priv_mod_sconto = substr($priv_mod_prenota,6,1);
 $priv_mod_caparra = substr($priv_mod_prenota,7,1);
@@ -184,6 +201,16 @@ if (substr($priv_ins_clienti,2,1) == "p") $vedi_clienti = "PROPRI";
 if (substr($priv_ins_clienti,2,1) == "g") { $vedi_clienti = "GRUPPI"; $prendi_gruppi = "SI"; }
 $priv_vedi_telefoni = substr($priv_ins_clienti,3,1);
 $priv_vedi_indirizzo = substr($priv_ins_clienti,4,1);
+$regole1_consentite = risul_query($privilegi_annuali_utente,0,'regole1_consentite');
+$attiva_regole1_consentite = substr($regole1_consentite,0,1);
+if ($attiva_regole1_consentite != "n") $regole1_consentite = explode("#@^",substr($regole1_consentite,3));
+$tariffe_consentite = risul_query($privilegi_annuali_utente,0,'tariffe_consentite');
+$attiva_tariffe_consentite = substr($tariffe_consentite,0,1);
+if ($attiva_tariffe_consentite == "s") {
+$tariffe_consentite = explode(",",substr($tariffe_consentite,2));
+for ($num1 = 0 ; $num1 < count($tariffe_consentite) ; $num1++) if ($tariffe_consentite[$num1]) $tariffe_consentite_vett[$tariffe_consentite[$num1]] = "SI";
+} # fine if ($attiva_tariffe_consentite == "s")
+unset($tariffe_consentite);
 $casse_consentite = risul_query($privilegi_globali_utente,0,'casse_consentite');
 $attiva_casse_consentite = substr($casse_consentite,0,1);
 if ($attiva_casse_consentite == "s") {
@@ -200,8 +227,20 @@ for ($num1 = 1 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_
 if ($contratti_consentiti_vett[$numero_contratto] != "SI") $anno_utente_attivato = "NO";
 } # fine if ($attiva_contratti_consentiti == "s")
 } # fine else if (numlin_query($privilegi_annuali_utente) == 0)
-unset($utenti_gruppi);
-$utenti_gruppi[$id_utente] = 1;
+
+if ($priv_vedi_tab_appartamenti == "g" or $priv_vedi_tab_mesi == "r" or $priv_vedi_tab_mesi == "g" or $priv_vedi_inv_app == "g") {
+$priv_app_gruppi = "SI";
+$attiva_regole1_consentite_gr = array($id_utente => $attiva_regole1_consentite);
+$regole1_consentite_gr = array($id_utente => $regole1_consentite);
+$attiva_tariffe_consentite_gr = array($id_utente => $attiva_tariffe_consentite);
+$tariffe_consentite_vett_gr = array($id_utente => $tariffe_consentite_vett);
+$priv_ins_nuove_prenota_gr = array($id_utente => $priv_ins_nuove_prenota);
+$priv_ins_assegnazione_app_gr = array($id_utente => $priv_ins_assegnazione_app);
+$priv_mod_prenotazioni_gr = array($id_utente => $priv_mod_prenotazioni);
+$priv_mod_assegnazione_app_gr = array($id_utente => $priv_mod_assegnazione_app);
+} # fine if ($priv_vedi_tab_appartamenti == "g" or $priv_vedi_tab_mesi == "r" or $priv_vedi_tab_mesi == "g" or $priv_vedi_inv_app == "g")
+else $priv_app_gruppi = "NO";
+$utenti_gruppi = array($id_utente => 1);
 if ($prendi_gruppi == "SI") {
 $gruppi_utente = esegui_query("select idgruppo from $tablerelgruppi where idutente = '$id_utente' and idgruppo is not NULL ");
 $num_gruppi_utente = numlin_query($gruppi_utente);
@@ -209,18 +248,60 @@ for ($num1 = 0 ; $num1 < $num_gruppi_utente ; $num1++) {
 $idgruppo = risul_query($gruppi_utente,$num1,'idgruppo');
 $utenti_gruppo = esegui_query("select idutente from $tablerelgruppi where idgruppo = '$idgruppo' ");
 $num_utenti_gruppo = numlin_query($utenti_gruppo);
-for ($num2 = 0 ; $num2 < $num_utenti_gruppo ; $num2++) $utenti_gruppi[risul_query($utenti_gruppo,$num2,'idutente')] = 1;
+for ($num2 = 0 ; $num2 < $num_utenti_gruppo ; $num2++) {
+$idutente_gruppo = risul_query($utenti_gruppo,$num2,'idutente');
+if ($idutente_gruppo != $id_utente and !isset($utenti_gruppi[$idutente_gruppo])) {
+$utenti_gruppi[$idutente_gruppo] = 1;
+
+if ($priv_app_gruppi == "SI") {
+$priv_anno_ut_gr = esegui_query("select * from $tableprivilegi where idutente = '$idutente_gruppo' and anno = '$anno'");
+if (numlin_query($priv_anno_ut_gr) == 1) {
+$regole1_consentite_gr[$idutente_gruppo] = risul_query($priv_anno_ut_gr,0,'regole1_consentite');
+$attiva_regole1_consentite_gr[$idutente_gruppo] = substr($regole1_consentite_gr[$idutente_gruppo],0,1);
+if ($attiva_regole1_consentite_gr[$idutente_gruppo] != "n") $regole1_consentite_gr[$idutente_gruppo] = explode("#@^",substr($regole1_consentite_gr[$idutente_gruppo],3));
+$tariffe_consentite_tmp = risul_query($priv_anno_ut_gr,0,'tariffe_consentite');
+$attiva_tariffe_consentite_gr[$idutente_gruppo] = substr($tariffe_consentite_tmp,0,1);
+if ($attiva_tariffe_consentite_gr[$idutente_gruppo] == "s") {
+$tariffe_consentite_tmp = explode(",",substr($tariffe_consentite_tmp,2));
+$tariffe_consentite_vett_gr[$idutente_gruppo] = array();
+for ($num3 = 0 ; $num3 < count($tariffe_consentite_tmp) ; $num3++) if ($tariffe_consentite_tmp[$num3]) $tariffe_consentite_vett_gr[$idutente_gruppo][$tariffe_consentite_tmp[$num3]] = "SI";
+} # fine if ($attiva_tariffe_consentite_gr[$idutente_gruppo] == "s")
+$priv_ins_prenota_tmp = risul_query($priv_anno_ut_gr,0,'priv_ins_prenota');
+$priv_ins_nuove_prenota_gr[$idutente_gruppo] = substr($priv_ins_prenota_tmp,0,1);
+$priv_ins_assegnazione_app_gr[$idutente_gruppo] = substr($priv_ins_prenota_tmp,1,1);
+$priv_mod_prenota_tmp = risul_query($priv_anno_ut_gr,0,'priv_mod_prenota');
+$priv_mod_prenotazioni_gr[$idutente_gruppo] = substr($priv_mod_prenota_tmp,0,1);
+$priv_mod_assegnazione_app_gr[$idutente_gruppo] = substr($priv_mod_prenota_tmp,2,1);
+unset($tariffe_consentite_tmp);
+unset($priv_ins_prenota_tmp);
+unset($priv_mod_prenota_tmp);
+} # fine if (numlin_query($priv_anno_ut_gr) == 1)
+else {
+$priv_ins_nuove_prenota_gr[$idutente_gruppo] = "n";
+$priv_mod_prenotazioni_gr[$idutente_gruppo] = "n";
+} # fine else if (numlin_query($priv_anno_ut_gr) == 1)
+chiudi_query($priv_anno_ut_gr);
+} # fine if ($priv_app_gruppi == "SI")
+
+} # fine if ($idutente_gruppo != $id_utente and !isset($utenti_gruppi[$idutente_gruppo]))
+} # fine for $num2
 } # fine for $num1
 } # fine if ($prendi_gruppi == "SI")
 } # fine if ($id_utente != 1)
 else {
 $anno_utente_attivato = "SI";
 $modifica_pers = "SI";
+$priv_vedi_beni_inv = "s";
+$priv_vedi_inv_app = "s";
 $priv_vedi_tab_mesi = "s";
 $priv_vedi_tab_costi = "s";
 $priv_vedi_tab_prenotazioni = "s";
+$priv_vedi_tab_appartamenti = "s";
 $priv_vedi_tab_doc = "s";
+$priv_ins_nuove_prenota = "s";
+$priv_ins_assegnazione_app = "s";
 $priv_mod_prenotazioni = "s";
+$priv_mod_assegnazione_app = "s";
 $priv_mod_tariffa = "s";
 $priv_mod_sconto = "s";
 $priv_mod_caparra = "s";
@@ -231,6 +312,8 @@ $priv_mod_codice = "s";
 $vedi_clienti = "SI";
 $priv_vedi_telefoni = "s";
 $priv_vedi_indirizzo = "s";
+$attiva_regole1_consentite = "n";
+$attiva_tariffe_consentite = "n";
 $attiva_casse_consentite = "n";
 $attiva_contratti_consentiti = "n";
 } # fine else if ($id_utente != 1)
@@ -240,7 +323,8 @@ include("./includes/funzioni_contratti.php");
 include("./includes/funzioni_testo.php");
 $priv_cancella_contratti = "n";
 @include(C_DATI_PATH."/lingua.php");
-$lingua_mex = $lingua[$id_utente];
+$locale_mex = substr(strstr($lingua[1],"-"),1);
+$lingua_mex = str_replace("-$locale_mex","",$lingua[1]);
 $pag_orig = $pag;
 $pag = "visualizza_contratto.php";
 $nomi_contratti = trova_nomi_contratti($max_contr,$id_utente,$tablecontratti,$tablepersonalizza,$LIKE,$pag);
@@ -263,7 +347,7 @@ $num_campi_pers_cliente = count($campi_pers_cliente);
 else $num_campi_pers_cliente = 0;
 include_once("./includes/funzioni_tariffe.php");
 $dati_cat_pers = dati_cat_pers($id_utente,$tablepersonalizza,$lingua_mex,"v",0,1);
-$dati_allegato = array('num' => 0);
+$dati_allegato = array('num' => 0, 'num_iim' => 0);
 /*# PER ORA IL FORMATO EMAIL NON PUÒ ESSERE API (poi sostituire con nuova funzione dati_allegato($num_contr), da sostituire anche in visualizza_contratto, in funzioni_contratti?)
 $allegati_email = esegui_query("select * from $tablecontratti where numero = '$numero_contratto' and tipo = 'allegato'");
 if (numlin_query($allegati_email)) {
@@ -307,7 +391,9 @@ $num_persone_tipo_ = "num_persone_tipo_";
 $allegato_ = "allegato";
 include("./includes/variabili_contratto.php");
 
-$tableprenota = $PHPR_TAB_PRE."prenota".$anno;
+$tableprenotacanc = $PHPR_TAB_PRE."prenotacanc".$anno;
+if (isset($del) and $del == 1) $tableprenota = $tableprenotacanc;
+else $tableprenota = $PHPR_TAB_PRE."prenota".$anno;
 $tablecostiprenota = $PHPR_TAB_PRE."costiprenota".$anno;
 $tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
 $tablesoldi = $PHPR_TAB_PRE."soldi".$anno;
@@ -322,6 +408,8 @@ $sec_oggi = time() + (C_DIFF_ORE * 3600);
 
 
 if (!empty($res_from) or !empty($res_to)) {
+$res_from = fixset($res_from);
+$res_to = fixset($res_to);
 if ($res_from == "today") $res_from = date("Y-m-d",$sec_oggi);
 if ($res_from == "tomorrow") $res_from = date("Y-m-d",($sec_oggi + 86400));
 if ($res_from == "yesterday") $res_from = date("Y-m-d",($sec_oggi - 86400));
@@ -356,41 +444,81 @@ if (!$query_prenota) $query_prenota = "select idprenota from $tableprenota where
 
 if (!empty($res_num) and !$query_prenota) {
 $prenota_in_lista = array();
-$res_num = explode(",",$res_num);
+$anno_num_pren = 0;
+$res_num = explode(",",togli_acapo($res_num));
 $num_res = count($res_num);
 for ($num1 = 0 ; $num1 < $num_res ; $num1++) {
 $num_pren = $res_num[$num1];
 if (str_replace("-","",$num_pren) != $num_pren) {
+$anno_pren = "";
 $num_pren = explode("-",$num_pren);
-if (preg_match("/[0-9]+/",$num_pren[0])) $res_ini = $num_pren[0];
+if (preg_match("/^([0-9]{4,4}\.)?[0-9]+$/",$num_pren[0])) $res_ini = $num_pren[0];
 else $res_ini = "";
-if (preg_match("/[0-9]+/",$num_pren[1])) $res_fine = $num_pren[1];
+if (preg_match("/^([0-9]{4,4}\.)?[0-9]+$/",$num_pren[1])) $res_fine = $num_pren[1];
 else $res_fine = "";
-if (!$res_ini or !$res_fine or $res_fine >= $res_ini) {
+if ($res_ini or (!$res_ini and $res_fine)) {
 if (!$res_ini) $ini_for = 1;
+else {
+if (strstr($res_ini,".")) {
+$anno_pren = substr($res_ini,0,4);
+if ($anno_pren >= $anno) $anno_pren = "";
+$ini_for = substr($res_ini,5);
+} # fine if (strstr($res_ini,"."))
 else $ini_for = $res_ini;
+} # fine else if (!$res_ini)
 if (!$res_fine) {
 $fine_for = esegui_query("select max(idprenota) from $tableprenota ");
 if (numlin_query($fine_for)) $fine_for = risul_query($fine_for,0,0);
 else $fine_for = 0;
+if (isset($del) and $del == "2") {
+$fine_for2 = esegui_query("select max(idprenota) from $tableprenotacanc ");
+if (numlin_query($fine_for2)) $fine_for2 = risul_query($fine_for,0,0);
+else $fine_for2 = 0;
+if ($fine_for2 > $fine_for) $fine_for = $fine_for2;
+} # fine if (isset($del) and $del == "2")
 } # fine if (!$res_fine)
-else $fine_for = $res_fine;
-for ($num2 = $ini_for ; $num2 <= $fine_for ; $num2++) {
-if (empty($prenota_in_lista[$num2])) {
-$prenota_in_lista[$num2] = 1;
-$query_prenota .= ",$num2";
-} # fine if (empty($prenota_in_lista[$num2]))
-} # fine for $num2
-} # fine if (!$res_ini or !$res_fine or $res_fine >= $res_ini)
-} # fine if (str_replace("-","",$num_pren) != $num_pren)
 else {
-if (preg_match("/[0-9]*/",$num_pren) and empty($prenota_in_lista[$num_pren])) {
+if (strstr($res_fine,".")) {
+if ($anno_pren and $anno_pren != substr($res_fine,0,4)) $fine_for = 0;
+else $fine_for = substr($res_fine,5);
+if (!$anno_pren) {
+$anno_pren = substr($res_fine,0,4);
+if ($anno_pren >= $anno) $anno_pren = "";
+} # fine if (!$anno_pren)
+} # fine if (strstr($res_fine,"."))
+else $fine_for = $res_fine;
+} # fine else if (!$res_fine)
+for ($num2 = $ini_for ; $num2 <= $fine_for ; $num2++) {
+if ($anno_pren) $num_pren = "$anno_pren.$num2";
+else $num_pren = $num2;
+if (empty($prenota_in_lista[$num_pren])) {
 $prenota_in_lista[$num_pren] = 1;
 $query_prenota .= ",$num_pren";
-} # fine if (preg_match("/[0-9]*/",$num_pren) and empty($prenota_in_lista[$num_pren]))
+} # fine if (empty($prenota_in_lista[$num_pren]))
+} # fine for $num2
+} # fine if ($res_ini or (!$res_ini and $res_fine))
+} # fine if (str_replace("-","",$num_pren) != $num_pren)
+else {
+if (preg_match("/^([0-9]{4,4}\.)?[0-9]+$/",$num_pren) and empty($prenota_in_lista[$num_pren])) {
+if (strstr($num_pren,".") and (substr($num_pren,0,4) >= $anno)) $num_pren = substr($num_pren,5);
+$prenota_in_lista[$num_pren] = 1;
+$query_prenota .= ",$num_pren";
+} # fine if (preg_match("/[0-9]*/",$num_pren) or preg_match("/[0-9]{4,4}\+[0-9]*/",$num_pren)) and...
 } # fine else if (str_replace("-","",$num_pren) != $num_pren)
 } # fine for $num1
-if ($query_prenota) $lista_prenota = 1;
+if ($query_prenota) {
+if (strstr($query_prenota,".")) {
+$num_pren = explode(",",$query_prenota);
+$num_p = count($num_pren);
+$query_prenota = "select idprenota from $tableprenota where ";
+for ($num1 = 1 ; $num1 < $num_p ; $num1++) {
+if (strstr($num_pren[$num1],".")) $query_prenota .= "id_anni_prec $LIKE '%;".str_replace(".",",",$num_pren[$num1]).";%' or ";
+else $query_prenota .= "idprenota = '".$num_pren[$num1]."' or ";
+} # fine for $num1
+$query_prenota = substr($query_prenota,0,-3)."order by iddatainizio";
+} # fine if (strstr($query_prenota,"."))
+else $lista_prenota = 1;
+} # fine if ($query_prenota)
 else $query_prenota = "select idprenota from $tableprenota where iddatainizio < '-3' ";
 } # fine if (!empty($res_num) and !$query_prenota)
 
@@ -407,7 +535,11 @@ if ($res_ins_from or $res_ins_to) {
 if (!$res_ins_from) $res_ins_from = "1980-01-01";
 if (!$res_ins_to) $res_ins_to = date("Y-m-d",mktime(0,0,0,date("m"),(date("d") + 2),date("Y")));
 if ($res_ins_from <= $res_ins_to) {
-$query_prenota = "select idprenota from $tableprenota where datainserimento >= '$res_ins_from 00:00:00' and datainserimento <= '$res_ins_to 23:59:59' order by iddatainizio";
+if (isset($del) and $del == "2") $query_prenota = "(select idprenota,iddatainizio from $tableprenota where datainserimento >= '$res_ins_from 00:00:00' and datainserimento <= '$res_ins_to 23:59:59') union (select idprenota,iddatainizio from $tableprenotacanc where (datainserimento >= '$res_ins_from 00:00:00' and datainserimento <= '$res_ins_to 23:59:59') or (data_modifica >= '$res_ins_from 00:00:00' and data_modifica <= '$res_ins_to 23:59:59')) order by iddatainizio";
+else {
+if (isset($del) and $del == "1") $query_prenota = "select idprenota from $tableprenota where (datainserimento >= '$res_ins_from 00:00:00' and datainserimento <= '$res_ins_to 23:59:59') or (data_modifica >= '$res_ins_from 00:00:00' and data_modifica <= '$res_ins_to 23:59:59') order by iddatainizio";
+else $query_prenota = "select idprenota from $tableprenota where datainserimento >= '$res_ins_from 00:00:00' and datainserimento <= '$res_ins_to 23:59:59' order by iddatainizio";
+} # fine else if (isset($del) and $del == "2")
 } # fine if ($res_ins_from <= $res_ins_to)
 } # fine if ($res_ins_from or $res_ins_to)
 if (!$query_prenota) $query_prenota = "select idprenota from $tableprenota where iddatainizio < '-3' ";
@@ -423,7 +555,7 @@ if (numlin_query($arrivo)) {
 $data_inizio_selezione = $res_arr;
 $data_fine_selezione = date("Y-m-d",mktime(0,0,0,substr($res_arr,5,2),(substr($res_arr,8,2) + 1),substr($res_arr,0,4)));
 $arrivo = risul_query($arrivo,0,'idperiodi');
-$query_prenota = "select idprenota from $tableprenota where iddatainizio = '$arrivo' ";
+$query_prenota = "select idprenota from $tableprenota where iddatainizio = '$arrivo' order by iddatainizio";
 } # fine if (numlin_query($arrivo))
 } # fine if (preg_match("/[0-9]{4,4}-[0-9]{2,2}-[0-9]{2,2}/",$res_arr))
 if (!$query_prenota) $query_prenota = "select idprenota from $tableprenota where iddatainizio < '-3' ";
@@ -439,7 +571,7 @@ if (numlin_query($partenza)) {
 $data_inizio_selezione = $res_dep;
 $data_fine_selezione = date("Y-m-d",mktime(0,0,0,substr($res_dep,5,2),(substr($res_dep,8,2) + 1),substr($res_dep,0,4)));
 $partenza = risul_query($partenza,0,'idperiodi');
-$query_prenota = "select idprenota from $tableprenota where iddatafine = '$partenza' ";
+$query_prenota = "select idprenota from $tableprenota where iddatafine = '$partenza' order by iddatainizio";
 } # fine if (numlin_query())
 } # fine if (preg_match("/[0-9]{4,4}-[0-9]{2,2}-[0-9]{2,2}/",$res_dep))
 if (!$query_prenota) $query_prenota = "select idprenota from $tableprenota where iddatainizio < '-3' ";
@@ -476,13 +608,18 @@ $lista_prenota = explode(",",$query_prenota);
 $num_ripeti = count($lista_prenota) - 1;
 } # fine if ($lista_prenota)
 else {
+if (isset($del) and $del == "2" and substr($query_prenota,-21) == "order by iddatainizio" and substr($query_prenota,0,(strlen($tableprenota) + 29)) == "select idprenota from $tableprenota where ") {
+$query_prenota = substr($query_prenota,0,-21);
+$query_prenota = "(select idprenota,iddatainizio".substr($query_prenota,16).") union (select idprenota,iddatainizio from $tableprenotacanc where ".substr($query_prenota,(strlen($tableprenota) + 29)).") order by iddatainizio";
+} # fine if (isset($del) and $del == "2" and substr($query_prenota,-21) == "order by iddatainizio" and...
 $prenotazioni = esegui_query($query_prenota);
 $num_ripeti = numlin_query($prenotazioni);
 $lista_prenota = array();
 for ($num1 = 1 ; $num1 <= $num_ripeti ; $num1++) $lista_prenota[$num1] = risul_query($prenotazioni,($num1 - 1),'idprenota');
 chiudi_query($prenotazioni);
 } # fine else if ($lista_prenota)
-$pcanc = "";
+if (isset($del) and $del == "2") $pcanc = "+";
+else $pcanc = "";
 include("./includes/dati_lista_prenota.php");
 } # fine if ($query_prenota and ($priv_vedi_tab_prenotazioni != "n" or...
 
@@ -526,8 +663,12 @@ $messaggio_di_errore
 if ($dir_salva and !$num_contr_esist) $mostra_headers = "NO";
 $foothtm = "";
 
+$dati_download = "";
 if (!empty($nome_file_contr['downl']['datdownl'])) $dati_download = explode(">",$nome_file_contr['downl']['datdownl']);
-else $dati_download = "";
+else {
+$risul = esegui_query("select testo from $tablecontratti where numero = '$numero_contratto' and tipo = 'datdownl'");
+if (numlin_query($risul)) $dati_download = explode(">",(string) risul_query($risul,0,'testo'));
+} # fine else if (!empty($nome_file_contr['downl']['datdownl']))
 if ($tipo_contratto == "contrhtm") {
 $show_bar = "NO";
 $headhtm = esegui_query("select testo from $tablecontratti where numero = '$numero_contratto' and tipo = 'headhtm'");
@@ -597,12 +738,12 @@ $pag = $pag_orig;
 } # fine if ($anno_utente_attivato == "SI")
 } # fine if ($anno_esist)
 } # fine else if ($raggiunto_limite)
-} # fine if ($pass == $pass_api)
+} # fine if (fixset($pass) == $pass_api)
 else {
 $id_transazione = crea_id_sessione("",$tabletransazioniweb,16,0,"idtransazioni","anno");
 $ultimo_accesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 esegui_query("insert into $tabletransazioniweb (idtransazioni,tipo_transazione,dati_transazione1,dati_transazione2,ultimo_accesso) values ('$id_transazione','api_l','doc$numero_contratto','$REMOTE_ADDR','$ultimo_accesso')");
-} # fine else if ($pass == $pass_api)
+} # fine else if (fixset($pass) == $pass_api)
 
 } # fine else if ($login_sbagliati >= $max_log_sbagliati)
 } # fine if (!$indirizzi_ip_api or strstr(",$indirizzi_ip_api,",",$REMOTE_ADDR,"))
@@ -615,7 +756,7 @@ else echo "$REMOTE_ADDR not allowed.";
 
 
 # Conferma sessione da modulo carte di credito
-if ($session_data and $id_sessione and defined('C_IP_MOD_EXT_CARTE_CREDITO') and C_IP_MOD_EXT_CARTE_CREDITO != "") {
+if (!empty($session_data) and $id_sessione and defined('C_IP_MOD_EXT_CARTE_CREDITO') and C_IP_MOD_EXT_CARTE_CREDITO != "") {
 if ($_SERVER['REMOTE_ADDR']) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
 if ($REMOTE_ADDR == C_IP_MOD_EXT_CARTE_CREDITO or ($REMOTE_ADDR == "::1" and C_IP_MOD_EXT_CARTE_CREDITO == "127.0.0.1")) {
 $cli_pass = 0;
@@ -763,10 +904,10 @@ else $condizione_utente_canc = "";
 
 if ($cli_id and $id_utente != 1) {
 $cli_priv = 0;
-if ($tweb) {
+if (!empty($tweb)) {
 $idclienti_tweb = risul_query($sessione,0,'dati_transazione14');
 if ($idclienti_tweb == $idclienti) $cli_priv = 1;
-} # fine if ($tweb)
+} # fine if (!empty($tweb))
 else {
 if (strstr($idclienti,",")) {
 $limite_transazioni_vecchie = date("Y-m-d H:i:s",(time() - (15 * 60) + (C_DIFF_ORE * 3600)));
@@ -790,7 +931,7 @@ if (!$utenti_gruppi[$utente_inserimento]) $modifica_clienti = "NO";
 } # fine elseif ($modifica_clienti == "GRUPPI" or $vedi_clienti == "GRUPPI")
 if ($anno_utente_attivato == "SI" and $modifica_clienti != "NO" and $vedi_clienti != "NO" and $idclienti and controlla_num_pos($idclienti) == "SI") $cli_priv = 1;
 } # fine else if (strstr($idclienti,","))
-} # fine else if ($tweb)
+} # fine else if (!empty($tweb))
 echo "<cli_priv>$cli_priv</cli_priv>";
 } # fine if ($cli_id and $id_utente != 1)
 
@@ -852,7 +993,7 @@ if ($val_priv_r) echo "<privr_$priv_r>$val_priv_r</privr_$priv_r>";
 unlock_tabelle($tabelle_lock);
 } # fine if ($REMOTE_ADDR == C_IP_MOD_EXT_CARTE_CREDITO or ($REMOTE_ADDR == "::1" and C_IP_MOD_EXT_CARTE_CREDITO == "127.0.0.1"))
 exit();
-} # fine if ($session_data and $id_sessione and defined('C_IP_MOD_EXT_CARTE_CREDITO') and C_IP_MOD_EXT_CARTE_CREDITO != "")
+} # fine if (!empty($session_data) and $id_sessione and defined('C_IP_MOD_EXT_CARTE_CREDITO') and C_IP_MOD_EXT_CARTE_CREDITO != "")
 
 
 
@@ -864,7 +1005,7 @@ if ($_SERVER['REMOTE_ADDR']) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
 if ($REMOTE_ADDR == C_IP_MOD_EXT_CARTE_CREDITO or ($REMOTE_ADDR == "::1" and C_IP_MOD_EXT_CARTE_CREDITO == "127.0.0.1")) {
 
 
-if ($azione == "pull_xml" and isset($tipo_ic) and $tipo_ic == "boo" and !empty($valore_xml) and !empty($token)) {
+if ($azione == "pull_xml" and isset($tipo_ic) and ($tipo_ic == "boo" or $tipo_ic == "eqc" or $tipo_ic == "oct") and !empty($valore_xml) and !empty($token)) {
 
 $file_interconnessioni = C_DATI_PATH."/dati_interconnessioni.php";
 if (@is_file($file_interconnessioni)) {
@@ -877,10 +1018,10 @@ $interconn_dir = opendir("./includes/interconnect/");
 while ($mod_ext = readdir($interconn_dir)) {
 if ($mod_ext != "." and $mod_ext != ".." and $mod_ext == $tipo_ic.fixset($ord_ic) and @is_dir("./includes/interconnect/$mod_ext")) {
 include("./includes/interconnect/$mod_ext/name.php");
-if ($ic_present[$interconnection_name] == "SI") {
+if (isset($ic_present[$interconnection_name]) and $ic_present[$interconnection_name] == "SI") {
 include("./includes/interconnect/$mod_ext/functions_import.php");
 $funz_import_reservations = "import_reservations_".$interconnection_func_name;
-} # fine if ($ic_present[$interconnection_name] == "SI")
+} # fine if (isset($ic_present[$interconnection_name]) and $ic_present[$interconnection_name] == "SI")
 break;
 } # fine if ($mod_ext != "." and $mod_ext != ".." and $mod_ext == $tipo_ic.fixset($ord_ic) and...
 } # fine while ($mod_ext = readdir($interconn_dir))
@@ -896,25 +1037,30 @@ else $anno_esist = 0;
 } # fine if (!@is_file(C_DATI_PATH."/selectperiodi$anno.1.php"))
 if ($anno_esist) {
 
-if (substr(C_URL_PULL_TOKEN,0,17) == "https://localhost") $token_res_id = file(C_URL_PULL_TOKEN."boo$token.php",false,stream_context_create(array("ssl" => array("verify_peer" => true,"allow_self_signed" => true))));
-else $token_res_id = @file(C_URL_PULL_TOKEN."boo$token.php");
+if (substr(C_URL_PULL_TOKEN,0,17) == "https://localhost") $token_res_id = file(C_URL_PULL_TOKEN."$tipo_ic$token.php",false,stream_context_create(array("ssl" => array("verify_peer" => true,"allow_self_signed" => true))));
+else $token_res_id = @file(C_URL_PULL_TOKEN."$tipo_ic$token.php");
 if (is_array($token_res_id)) $token_res_id = trim(implode("",$token_res_id));
 else $token_res_id = "";
-if (stristr($valore_xml,"<id>$token_res_id<")) {
+$res_id = 0;
+if ($tipo_ic == "boo" and stristr($valore_xml,"<id>$token_res_id<")) $res_id = 1;
+if ($tipo_ic == "eqc" and stristr($valore_xml," id=\"$token_res_id\"")) $res_id = 1;
+if ($tipo_ic == "oct" and stristr($valore_xml,"<ResId>$token_res_id<")) $res_id = 1;
+if ($res_id) {
 
 @include(C_DATI_PATH."/lingua.php");
-$lingua_mex = $lingua[1];
+$locale_mex = substr(strstr($lingua[1],"-"),1);
+$lingua_mex = str_replace("-$locale_mex","",$lingua[1]);
 $id_utente_sessione = "-1";
 $id_sessione = crea_id_sessione($anno,$tableversioni);
 if (C_VERSIONE_ATTUALE < 3.04) $id_sessione = substr($id_sessione,0,20).substr($id_sessione,30);
 $ultimo_accesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
-if ($_SERVER['REMOTE_ADDR']) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
-$REMOTE_ADDR = aggslashdb($REMOTE_ADDR);
-if ($_SERVER['REMOTE_PORT']) $REMOTE_PORT = $_SERVER['REMOTE_PORT'];
-$REMOTE_PORT = aggslashdb($REMOTE_PORT);
-if ($_SERVER['HTTP_USER_AGENT']) $HTTP_USER_AGENT = $_SERVER['HTTP_USER_AGENT'];
-$HTTP_USER_AGENT = aggslashdb($HTTP_USER_AGENT);
-if ($_SERVER['HTTPS'] == "on" or $_SERVER['SERVER_PORT'] == "443") $tipo_conn = "HTTPS";
+if (!empty($_SERVER['REMOTE_ADDR'])) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
+$REMOTE_ADDR = aggslashdb(fixstr($REMOTE_ADDR));
+if (!empty($_SERVER['REMOTE_PORT'])) $REMOTE_PORT = $_SERVER['REMOTE_PORT'];
+$REMOTE_PORT = aggslashdb(fixstr($REMOTE_PORT));
+if (!empty($_SERVER['HTTP_USER_AGENT'])) $HTTP_USER_AGENT = $_SERVER['HTTP_USER_AGENT'];
+$HTTP_USER_AGENT = aggslashdb(fixstr($HTTP_USER_AGENT));
+if (fixset($_SERVER['HTTPS']) == "on" or fixset($_SERVER['SERVER_PORT']) == "443") $tipo_conn = "HTTPS";
 else $tipo_conn = "HTTP";
 esegui_query("insert into $tablesessioni (idsessioni,idutente,indirizzo_ip,tipo_conn,user_agent,ultimo_accesso) values ('$id_sessione','$id_utente_sessione','$REMOTE_ADDR','$tipo_conn','$HTTP_USER_AGENT','$ultimo_accesso')","",1);
 $id_utente_origi = $id_utente;
@@ -922,13 +1068,13 @@ $id_utente = 1;
 $testo = $funz_import_reservations("","",$file_interconnessioni,$anno,$PHPR_TAB_PRE,2,$id_utente,$HOSTNAME,$valore_xml);
 $id_utente = $id_utente_origi;
 
-} # fine if (stristr($valore_xml,"<id>$token_res_id<"))
+} # fine if ($res_id)
 
 } # fine if ($anno_esist)
 } # fine if ($funz_import_reservations)
 } # fine if (@is_array($ic_present))
 } # fine if (@is_file($file_interconnessioni))
-} # fine if ($azione == "pull_xml" and isset($tipo_ic) and $tipo_ic == "boo" and !empty($valore_xml) and !empty($token))
+} # fine if ($azione == "pull_xml" and isset($tipo_ic) and ($tipo_ic == "boo" or $tipo_ic == "eqc" or $tipo_ic == "oct") and...
 
 
 } # fine if ($REMOTE_ADDR == C_IP_MOD_EXT_CARTE_CREDITO or ($REMOTE_ADDR == "::1" and C_IP_MOD_EXT_CARTE_CREDITO == "127.0.0.1"))
