@@ -120,10 +120,10 @@ $altre_tab_lock = array($tablepersonalizza,$tablecasse);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 
 if (@get_magic_quotes_gpc()) $nome_costo = stripslashes($nome_costo);
-$nome_costo = htmlspecialchars(fixstr($nome_costo));
+$nome_costo = htmlspecialchars(fixstr($nome_costo),ENT_COMPAT);
 $nome_costo = aggslashdb($nome_costo);
 if (@get_magic_quotes_gpc()) $persona_costo = stripslashes($persona_costo);
-$persona_costo = htmlspecialchars($persona_costo);
+$persona_costo = htmlspecialchars(fixstr($persona_costo),ENT_COMPAT);
 $persona_costo = aggslashdb($persona_costo);
 if (!$nome_costo) {
 if (!empty($inserisci_entrata)) echo mex("Si deve inserire un nome per l' entrata",$pag).".<br>";
@@ -157,7 +157,7 @@ elseif ($id_cassa != 1) $nome_cassa = risul_query($cassa_esistente,0,'nome_cassa
 } # fine else if (!$id_cassa or controlla_num_pos($id_cassa) != "SI")
 
 if (@get_magic_quotes_gpc()) $metodo_pagamento = stripslashes($metodo_pagamento);
-$metodo_pagamento = htmlspecialchars(fixstr($metodo_pagamento));
+$metodo_pagamento = htmlspecialchars(fixstr($metodo_pagamento),ENT_COMPAT);
 if (strcmp($metodo_pagamento,"")) {
 $metodi_pagamento = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'metodi_pagamento' and idutente = '$id_utente'");
 $metodi_pagamento = risul_query($metodi_pagamento,0,'valpersonalizza');
@@ -172,10 +172,10 @@ else {
 $costo_valuta = $val_costo;
 $arrotond_tasse = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'arrotond_tasse' and idutente = '$id_utente'");
 $arrotond_tasse = risul_query($arrotond_tasse,0,'valpersonalizza');
-$val_costo = (double) $val_costo / (double) $altre_valute[$n_valuta]['cambio'];
-$val_costo = $val_costo / (double) $arrotond_tasse;
+$val_costo = (float) $val_costo / (float) $altre_valute[$n_valuta]['cambio'];
+$val_costo = $val_costo / (float) $arrotond_tasse;
 $val_costo = round($val_costo);
-$val_costo = $val_costo * (double) $arrotond_tasse;
+$val_costo = $val_costo * (float) $arrotond_tasse;
 $valuta = $altre_valute[$n_valuta]['nome'].">".$altre_valute[$n_valuta]['cambio'].">".$altre_valute[$n_valuta]['arrotond'];
 } # fine else if ($n_valuta == "-1")
 } # fine if (strcmp(fixstr($valuta),""))
@@ -190,7 +190,7 @@ $anno_corr = date('Y',(time() + (C_DIFF_ORE * 3600)));
 if ($anno_pagamento >= ($anno_corr - 2) and $anno_pagamento <= ($anno_corr + 1)) $datatransazione = date("Y-m-d H:i:s",mktime(0,0,0,(int) $mese_pagamento,(int) $giorno_pagamento,(int) $anno_pagamento));
 } # fine if ($giorno_pagamento >= 1 and $giorno_pagamento <= 31 and $mese_pagamento >= 1 and...
 } # fine if (isset($giorno_pagamento) and isset($mese_pagamento) and isset($anno_pagamento))
-if ($priv_persona_ins_costi != "c") unset($persona_costo);
+if ($priv_persona_ins_costi != "c") $persona_costo = "";
 if ($priv_persona_ins_costi == "u") $persona_costo = $nome_utente;
 if ($priv_entrate_da_prenota != "c") unset($entrata_da_prenota);
 if ($priv_entrate_da_prenota == "s") $entrata_da_prenota = "SI";
@@ -210,7 +210,7 @@ $tipo_costo = "e";
 if ($inserisci_spesa) $tipo_costo = "s";
 esegui_query("insert into $tablecosti (idcosti,nome_costo,val_costo,tipo_costo,nome_cassa,persona_costo,provenienza_costo,metodo_pagamento,data_transazione,datainserimento,hostinserimento,utente_inserimento) values ('$idcosti','$nome_costo','$val_costo','$tipo_costo','".aggslashdb($nome_cassa)."','$persona_costo','$provenienza_costo','$metodo_pagamento','$datatransazione','$datainserimento','$HOSTNAME','$id_utente') ");
 if ($valuta) esegui_query("update $tablecosti set valuta = '".aggslashdb($valuta)."', costo_valuta = '".aggslashdb($costo_valuta)."' where idcosti = '$idcosti' ");
-if (!empty($id_pagamento)) esegui_query("update $tablecosti set id_pagamento = '".aggslashdb(htmlspecialchars($id_pagamento))."' where idcosti = '$idcosti' ");
+if (!empty($id_pagamento)) esegui_query("update $tablecosti set id_pagamento = '".aggslashdb(htmlspecialchars($id_pagamento),ENT_COMPAT)."' where idcosti = '$idcosti' ");
 if (!empty($inserisci_entrata)) echo mex("L'entrata è stata inserita",$pag);
 if (!empty($inserisci_spesa)) echo mex("La spesa è stata inserita",$pag);
 echo " (".punti_in_num($val_costo,$stile_soldi)." $Euro";
@@ -239,7 +239,7 @@ $opt_casse = "";
 $num_casse_attive = 0;
 for ($num1 = 0 ; $num1 < $num_casse ; $num1++) {
 $id_cassa = risul_query($casse,$num1,'idcasse');
-if ($attiva_casse_consentite == "n" or $casse_consentite_vett[$id_cassa] == "SI") {
+if ($attiva_casse_consentite == "n" or (isset($casse_consentite_vett[$id_cassa]) and $casse_consentite_vett[$id_cassa] == "SI")) {
 if ($id_cassa == 1) $nome_cassa = mex("cassa principale",$pag);
 else $nome_cassa = risul_query($casse,$num1,'nome_cassa');
 $opt_casse .= "<option value=\"$id_cassa\">$nome_cassa</option>";
