@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2025 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -46,6 +46,10 @@ $n_var_pag = 16;
 $num2 = 0;
 if (isset($_POST['numappartamenti'])) $num2 = (int) $_POST['numappartamenti'];
 elseif (isset($_GET['numappartamenti'])) $num2 = (int) $_GET['numappartamenti'];
+$num3 = 0;
+if (isset($_POST['numletti'])) $num3 = (int) $_POST['numletti'];
+elseif (isset($_GET['numletti'])) $num3 = (int) $_GET['numletti'];
+$num2 += $num3;
 for ($num1 = 1 ; $num1 <= $num2 ; $num1++) {
 $var_pag[$n_var_pag++] = "numapp$num1";
 $var_pag[$n_var_pag++] = "maxoccupanti$num1";
@@ -59,6 +63,7 @@ include("./includes/funzioni.php");
 if (!defined('C_CREADB_TIPODB')) include("./includes/costanti.php");
 if (function_exists('ini_set')) @ini_set('opcache.enable',0);
 
+if (defined('C_CREA_ULTIMO_ACCESSO') and C_CREA_ULTIMO_ACCESSO == "SI") $filelock_ua = crea_lock_file(C_DATI_PATH."/ultimo_accesso");
 if (!defined('C_CREA_ULTIMO_ACCESSO') or C_CREA_ULTIMO_ACCESSO != "SI" or !@is_file(C_DATI_PATH."/ultimo_accesso")) {
 
 unset($numconnessione);
@@ -83,8 +88,27 @@ return $messaggio;
 } # fine function mex2
 
 
+$lingua = fixstr($lingua);
+$locale_lingua = "";
+if (strstr($lingua,"-")) {
+$lingua = explode("-",$lingua);
+if ($lingua[1] and preg_replace("/[a-z]*/i","",$lingua[1]) == "" and strlen($lingua[1]) < 4) $locale_lingua = $lingua[1];
+$lingua = $lingua[0];
+} # fine if (strstr($lingua,"-"))
+if (!$lingua or preg_replace("/[a-z]*/i","",$lingua) != "" or strlen($lingua) > 3) $lingua = "en";
+if (!is_dir("./includes/lang/$lingua")) $lingua = "ita";
+if ($locale_lingua and ($lingua == "ita" or !is_file("./includes/lang/$lingua/locales/$locale_lingua/l_n"))) $locale_lingua = "";
+if ($locale_lingua) $lingua_locale = "$lingua-$locale_lingua";
+else $lingua_locale = $lingua;
+if ($lingua == "ita") include("./includes/locale.php");
+else {
+if ($locale_lingua and is_file("./includes/lang/$lingua/locales/$locale_lingua/locale.php")) include("./includes/lang/$lingua/locales/$locale_lingua/locale.php");
+else include("./includes/lang/$lingua/locale.php");
+} # fine else if ($lingua == "ita")
+
+
 $show_bar = "NO";
-$titolo = "HotelDruid: ".mex2("Crea Database",$pag,fixset($lingua));
+$titolo = "HotelDruid: ".mex2("Crea Database",$pag,$lingua);
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 
@@ -101,6 +125,8 @@ $permessi_scrittura_controllati = "";
 $torna_indietro = "";
 
 allunga_tempo_limite();
+if (!isset($tipo_db)) $tipo_db = "";
+if ($tipo_db and $tipo_db != "mysqli" and $tipo_db != "postgresql" and $tipo_db != "sqlite") $tipo_db = "mysql";
 if ($tipo_db == "mysql" and @function_exists('mysqli_connect')) $tipo_db = "mysqli";
 $carica_estensione = "NO";
 if (($tipo_db == "postgresql" and !@function_exists('pg_connect')) or ($tipo_db == "mysql" and !@function_exists('mysql_connect'))) $carica_estensione = "SI";
@@ -122,10 +148,10 @@ $prefisso_tab = C_CREADB_PREFISSO_TAB;
 } # fine if (defined('C_UTILIZZA_SEMPRE_DEFAULTS') and (C_UTILIZZA_SEMPRE_DEFAULTS == "SI" or C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO"))
 if (!controlla_num_pos($numletti) == "NO") $numletti = 0;
 $numapp_default = 0;
-if ((!$numappartamenti and !$numletti) or controlla_num_pos($numappartamenti) == "NO") {
+if ((empty($numappartamenti) and empty($numletti)) or controlla_num_pos($numappartamenti) == "NO") {
 $numappartamenti = 5;
 $numapp_default = 1;
-} # fine if ((!$numappartamenti and !$numletti) or controlla_num_pos($numappartamenti) == "NO")
+} # fine if ((empty($numappartamenti) and empty($numletti)) or controlla_num_pos($numappartamenti) == "NO")
 
 if (defined('C_EXT_DB_DATA_PATH') and C_EXT_DB_DATA_PATH) {
 $HOTELD_DB_TYPE = "";
@@ -148,11 +174,21 @@ if (strcmp((string) $HOTELD_DB_PASS,"")) $password_phprdb = $HOTELD_DB_PASS;
 if ($HOTELD_TAB_PRE) $prefisso_tab = $HOTELD_TAB_PRE;
 } # fine if (defined('C_EXT_DB_DATA_PATH') and C_EXT_DB_DATA_PATH)
 
-if (!$prefisso_tab or preg_match('/^[_a-z][_0-9a-z]*$/',$prefisso_tab)) {
+$prefisso_tab = trim(fixstr($prefisso_tab));
+if (!$prefisso_tab or (preg_match('/^[a-z][_0-9a-z]*$/',$prefisso_tab) and strlen($prefisso_tab) <= 12)) {
+$numconnessione = "";
+$host_phprdb = substr(preg_replace("/[^a-z0-9-.]/i","",fixstr($host_phprdb)),0,253);
+$port_phprdb = trim(fixstr($port_phprdb));
+if ($port_phprdb and (controlla_num_pos($port_phprdb) != "SI" or $port_phprdb > "65535")) $port_phprdb = "";
+$user_phprdb = substr(trim(str_replace(" ","",fixstr($user_phprdb))),0,128);
+$password_phprdb = substr(trim(str_replace(" ","",fixstr($password_phprdb))),0,128);
+
 if ($tipo_db == "postgresql") {
 if ($carica_estensione == "SI") dl("pgsql.so");
+$tempdatabase = preg_replace("/[^a-z0-9_]/i","",fixstr($tempdatabase));
 if ($database_esistente == "SI") $tempdatabase = $database_phprdb;
-$numconnessione = pg_connect("dbname=$tempdatabase host=$host_phprdb port=$port_phprdb user=$user_phprdb password=$password_phprdb ");
+if ($tempdatabase) $numconnessione = pg_connect("dbname=$tempdatabase host=$host_phprdb port=$port_phprdb user=$user_phprdb password=$password_phprdb ");
+$link_pgsql = $numconnessione;
 $encoding = " with encoding = 'SQL_ASCII'";
 $encoding = "";
 } # fine if ($tipo_db == "postgresql")
@@ -170,6 +206,7 @@ $encoding = "";
 if ($tipo_db == "mysqli") {
 if ($carica_estensione == "SI") dl("mysqli.so");
 $numconnessione = mysqli_connect($host_phprdb,$user_phprdb,$password_phprdb,"",$port_phprdb);
+$link_mysqli = $numconnessione;
 @mysqli_query($numconnessione,"SET NAMES 'utf8mb4'");
 $risul = @mysqli_query($numconnessione,"SET default_storage_engine=MYISAM");
 if (!$risul) {
@@ -194,7 +231,7 @@ if ($numconnessione) {
 $PHPR_LOG = "";
 include("./includes/funzioni_$tipo_db.php");
 if ($database_esistente == "NO") {
-$link_mysqli = $numconnessione;
+if ($tipo_db == "mysqli") $link_mysqli = $numconnessione;
 $query = esegui_query("create database $database_phprdb $encoding");
 if ($query) echo mex2("Database creato",$pag,$lingua)."!<br>";
 } # fine if ($database_esistente == "NO")
@@ -208,6 +245,7 @@ $character_set_db = "";
 $collation_db = "";
 if ($tipo_db == "postgresql") {
 $numconnessione = pg_connect("dbname=$database_phprdb host=$host_phprdb port=$port_phprdb user=$user_phprdb password=$password_phprdb ");
+$link_pgsql = $numconnessione;
 } # fine if ($tipo_db == "postgresql")
 if ($tipo_db == "mysql" or $tipo_db == "mysqli") {
 if ($tipo_db == "mysql") {
@@ -250,10 +288,10 @@ $numconnessione->busyTimeout(60000);
 
 # creo la tabella appartamenti.
 $tableappartamenti = $prefisso_tab."appartamenti";
-esegui_query("create table $tableappartamenti ( idappartamenti varchar(100) primary key, numpiano text, maxoccupanti integer, numcasa text, app_vicini text, priorita integer, priorita2 integer, letto varchar(1), commento text )");
+esegui_query("create table $tableappartamenti (idappartamenti varchar(100) primary key, numpiano text, maxoccupanti integer, numcasa text, app_vicini text, priorita integer, priorita2 integer, letto varchar(1), commento text )");
 # creo la tabella clienti.
 $tableclienti = $prefisso_tab."clienti";
-esegui_query("create table $tableclienti (idclienti integer primary key, cognome varchar(70) not null, nome varchar(70), soprannome varchar(70), sesso char, titolo varchar(30), lingua varchar(14), datanascita date, cittanascita varchar(70), regionenascita varchar(70), nazionenascita varchar(70), documento varchar(70), scadenzadoc date, tipodoc varchar(70), cittadoc varchar(70), regionedoc varchar(70), nazionedoc  varchar(70), nazionalita varchar(70), nazione varchar(70), regione varchar(70), citta varchar(70), via varchar(70), numcivico varchar(30), cap varchar(30), telefono varchar(50), telefono2 varchar(50), telefono3 varchar(50), fax varchar(50), email text, email2 text, email3 text, cod_fiscale varchar(50), partita_iva varchar(50), commento text, max_num_ordine integer, idclienti_compagni text, doc_inviati text, datainserimento $DATETIME, hostinserimento varchar(50), utente_inserimento integer )");
+esegui_query("create table $tableclienti (idclienti integer primary key, cognome varchar(70) not null, cognome2 varchar(70), nome varchar(70), soprannome varchar(70), sesso char, titolo varchar(30), lingua varchar(14), datanascita date, cittanascita varchar(70), regionenascita varchar(70), nazionenascita varchar(70), documento varchar(70), scadenzadoc date, tipodoc varchar(70), cittadoc varchar(70), regionedoc varchar(70), nazionedoc  varchar(70), nazionalita varchar(70), nazione varchar(70), regione varchar(70), citta varchar(70), via varchar(70), numcivico varchar(30), cap varchar(30), telefono varchar(50), telefono2 varchar(50), telefono3 varchar(50), fax varchar(50), email text, email2 text, email3 text, cod_fiscale varchar(50), partita_iva varchar(50), commento text, max_num_ordine integer, idclienti_compagni text, doc_inviati text, datainserimento $DATETIME, hostinserimento varchar(50), utente_inserimento integer )");
 # creo la tabella di relazione tra clienti e dati vari.
 $tablerelclienti = $prefisso_tab."relclienti";
 esegui_query("create table $tablerelclienti (idclienti integer, numero integer, tipo varchar(12), testo1 text, testo2 text, testo3 text, testo4 text, testo5 text, testo6 text, testo7 text, testo8 text, datainserimento $DATETIME, hostinserimento varchar(50), utente_inserimento integer )");
@@ -291,11 +329,20 @@ if (defined("C_MASCHERA_EMAIL") and C_MASCHERA_EMAIL == "SI") $maschera_email =
 else $maschera_email = "NO";
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('maschera_email','1','$maschera_email')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('dati_struttura','1','#@&#@&#@&#@&#@&#@&#@&#@&#@&#@&#@&#@&')");
-esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('valuta','1','".aggslashdb(mex2("Euro",$pag,$lingua))."')");
-esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('arrotond_predef','1','1')");
-esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('arrotond_tasse','1','0.01')");
+if (isset($locale['currency_name']) and (string) $locale['currency_name'] != "") $Euro = $locale['currency_name'];
+else $Euro = mex2("Euro",$pag,$lingua);
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('valuta','1','".aggslashdb($Euro)."')");
+$arrotond_predef = formatta_soldi(fixset($locale['prices_percentage_rounding']));
+if ((float) $arrotond_predef == 0 or controlla_soldi($arrotond_predef) != "SI")  $arrotond_predef = "1";
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('arrotond_predef','1','".aggslashdb($arrotond_predef)."')");
+$arrotond_tasse = formatta_soldi(fixset($locale['taxes_rounding']));
+if ((float) $arrotond_tasse == 0 or controlla_soldi($arrotond_tasse) != "SI") $arrotond_tasse = "0.01";
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('arrotond_tasse','1','".aggslashdb($arrotond_tasse)."')");
+if (isset($locale['money_format']) and ($locale['money_format'] == "usa" or $locale['money_format'] == "europa")) $stile_soldi = $locale['money_format'];
+else {
 if ($lingua == "ita" or $lingua == "es" or $lingua == "fr" or $lingua == "de" or $lingua == "pt") $stile_soldi = "europa";
 else $stile_soldi = "usa";
+} # fine else if (isset($locale['money_format']) and ($locale['money_format'] == "usa" or...
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('stile_soldi','1','$stile_soldi')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('costi_agg_in_tab_prenota','1','')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('aggiunta_tronca_nomi_tab1','1','-2')");
@@ -312,7 +359,9 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersona
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_messaggi','1','80')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_doc_salvati','1','100')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_storia_soldi','1','200')");
-esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('stile_data','1','europa')");
+if (isset($locale['date_format']) and ($locale['date_format'] == "usa" or $locale['date_format'] == "europa")) $stile_data = $locale['date_format'];
+else $stile_data = "europa";
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('stile_data','1','$stile_data')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('stile_nomi','1','ma1or')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_categorie_persone','1','1')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('minuti_durata_sessione','1','90')");
@@ -323,7 +372,9 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersona
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('auto_crea_anno','1','SI')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('metodi_pagamento','1','')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('origini_prenota','1','')");
-esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('attiva_checkin','1','NO')");
+if ($numappartamenti > 12) $attiva_checkin = "SI";
+else $attiva_checkin = "NO";
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('attiva_checkin','1','$attiva_checkin')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('mostra_quadro_disp','1','reg2')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('ultime_sel_ins_prezzi','1','')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('subordinazione','1','NO')");
@@ -391,11 +442,14 @@ if (defined("C_CARTELLA_FILES_REALI")) $f_pre = C_CARTELLA_FILES_REALI;
 else $f_pre = "";
 if ($lingua == "ita") $file_contr_backup = $f_pre."./includes/hoteld_doc_backup.php";
 else {
+if ($locale_lingua and is_file($f_pre."./includes/lang/$lingua/locales/$locale_lingua/hoteld_doc_backup.php")) $file_contr_backup = $f_pre."./includes/lang/$lingua/locales/$locale_lingua/hoteld_doc_backup.php";
+else {
 if (@is_file($f_pre."./includes/lang/$lingua/hoteld_doc_backup.php")) $file_contr_backup = $f_pre."./includes/lang/$lingua/hoteld_doc_backup.php";
 else {
 if (@is_file($f_pre."./includes/lang/en/hoteld_doc_backup.php")) $file_contr_backup = $f_pre."./includes/lang/en/hoteld_doc_backup.php";
 else $file_contr_backup = $f_pre."./includes/hoteld_doc_backup.php";
 } # fine else if (@is_file($f_pre."./includes/lang/$lingua/hoteld_doc_backup.php"))
+} # fine else if ($locale_lingua and is_file($f_pre."./includes/lang/$lingua/locales/$locale_lingua/hoteld_doc_backup.php"))
 } # fine else if ($lingua == "ita")
 if ($linee_backup = @file($file_contr_backup)) {
 ripristina_backup_contr($linee_backup,"SI","crea_backup.php",$prefisso_tab,"rimpiazza");
@@ -451,13 +505,13 @@ if (\$HOTELD_TAB_PRE) \$PHPR_TAB_PRE = \$HOTELD_TAB_PRE;
 fwrite($fileaperto,"?>");
 fclose($fileaperto);
 @chmod(C_DATI_PATH."/dati_connessione.php", 0640);
-if ($lingua != "ita" and (!@is_dir("./includes/lang/".$lingua) or strlen($lingua) > 3)) $lingua = "en";
+#if ($lingua != "ita" and (!@is_dir("./includes/lang/".$lingua) or strlen($lingua) > 3)) $lingua = "en";
 $fileaperto = fopen(C_DATI_PATH."/lingua.php","w+");
 fwrite($fileaperto,"<?php
-\$lingua[1] = \"$lingua\";
+\$lingua[1] = \"$lingua_locale\";
 ?>");
 fclose($fileaperto);
-if ($nomeappartamenti != "appartamenti") $nomeappartamenti = "camere";
+if (!isset($nomeappartamenti) or $nomeappartamenti != "appartamenti") $nomeappartamenti = "camere";
 $fileaperto = fopen(C_DATI_PATH."/unit.php","w+");
 fwrite($fileaperto,"<?php
 ");
@@ -495,10 +549,19 @@ fwrite($fileaperto,"<?php
 ?>");
 fclose($fileaperto);
 $fileaperto = fopen(C_DATI_PATH."/versione.php","w+");
+$diff_tz = "";
+if (!empty($locale['timezone']) and function_exists('timezone_identifiers_list') and function_exists('date_default_timezone_set')) {
+$tzlist = timezone_identifiers_list();
+foreach ($tzlist as $id => $val) if ($val == $locale['timezone']) $diff_tz = $locale['timezone'];
+unset($tzlist);
+} # fine if (!empty($locale['timezone']) and function_exists('timezone_identifiers_list') and...
 fwrite($fileaperto,"<?php
 define('C_VERSIONE_ATTUALE',".C_PHPR_VERSIONE_NUM.");
 define('C_DIFF_ORE',0);
-define('C_MIN_SESSIONE',90);
+");
+if ($diff_tz) fwrite($fileaperto,"define('C_DIFF_TZ','$diff_tz');
+");
+fwrite($fileaperto,"define('C_MIN_SESSIONE',90);
 define('C_USA_COOKIES',0);
 ?>");
 fclose($fileaperto);
@@ -527,7 +590,7 @@ if (!$numletti) {
 if ($numapp_default) $num_app_max = "10";
 else $num_app_max = $numappartamenti;
 } # fine if (!$numletti)
-else $num_app_max = $numappartamenti + ceil((double) $numletti / 26);
+else $num_app_max = $numappartamenti + ceil((float) $numletti / 26);
 for ( $num = 1; $num <= ($numappartamenti + $numletti) ; $num = $num + 1) {
 $numapp = "numapp" . $num;
 $piano = "piano" . $num;
@@ -632,11 +695,11 @@ if ($tipo_db == "postgresql") echo " (".mex2("se postgres assicurarsi che venga
 echo ".<br>";
 $torna_indietro = "SI";
 } # fine else if ($numconnessione)
-} # fine if (!$prefisso_tab or preg_match('/^[_a-z][_0-9a-z]*$/',$prefisso_tab))
+} # fine if (!$prefisso_tab or (preg_match('/^[_a-z][_0-9a-z]*$/',$prefisso_tab) and...
 else {
 echo "<br>".mex2("Il prefisso del nome delle tabelle è sbagliato (accettate solo lettere minuscole, numeri e _ , primo carattere lettera)",$pag,$lingua).".<br>";
 $torna_indietro = "SI";
-} # fine else if (!$prefisso_tab or preg_match('/^[_a-z][_0-9a-z]*$/',$prefisso_tab))
+} # fine else if (!$prefisso_tab or (preg_match('/^[_a-z][_0-9a-z]*$/',$prefisso_tab) and...
 if ($permessi_scrittura_controllati != "SI") {
 $fileaperto = @fopen(C_DATI_PATH."/prova.tmp","a+");
 if (!$fileaperto) echo "<br>".mex2("Non ho i permessi di scrittura sulla directory dati, cambiarli e reiniziare l'installazione",$pag,$lingua).".<br>";
@@ -647,7 +710,7 @@ unlink(C_DATI_PATH."/prova.tmp");
 } # fine if ($permessi_scrittura_controllati != "SI")
 if ($torna_indietro == "SI") {
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"creadb.php\"><div>
-<input type=\"hidden\" name=\"lingua\" value=\"$lingua\">
+<input type=\"hidden\" name=\"lingua\" value=\"$lingua_locale\">
 <input class=\"sbutton\" type=\"submit\" name=\"torna\" value=\"".mex2("Torna indietro",$pag,$lingua)."\"><br>
 </div></form>";
 } # fine if ($torna_indietro == "SI")
@@ -663,7 +726,8 @@ if (!controlla_num_pos($numletti) == "NO") $numletti = 0;
 if ((!$numappartamenti and !$numletti) or controlla_num_pos($numappartamenti) == "NO") $numappartamenti = 5;
 unset($lingua);
 include(C_DATI_PATH."/lingua.php");
-$lingua_mex = $lingua[1];
+$locale_mex = substr(strstr($lingua[1],"-"),1);
+$lingua_mex = str_replace("-$locale_mex","",$lingua[1]);
 include(C_DATI_PATH."/dati_connessione.php");
 include_once("./includes/funzioni_$PHPR_DB_TYPE.php");
 $numconnessione = connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
@@ -682,16 +746,17 @@ $num_camera_l = 1;
 } # fine if (!empty($lista_camere_letti))
 else $num_camera_l = 0;
 $app_vicini_vett = array();
+$numapp_esist = array();
 if (!$numletti) $num_app_max = $numappartamenti;
 else {
 if ($num_camera_l) $num_app_max = $numappartamenti + count($lista_camere_letti) - 1;
-else $num_app_max = $numappartamenti + ceil((double) $numletti / 26);
+else $num_app_max = $numappartamenti + ceil((float) $numletti / 26);
 } # fine else if (!$numletti)
 if (defined('C_UTILIZZA_SEMPRE_DEFAULTS') and C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO" and $num_app_max < 10) $num_app_max = 10;
 
 for ($num = 1 ; $num <= ($numappartamenti + $numletti) ; $num = $num + 1) {
 $numapp = "numapp" . $num;
-$numapp = $$numapp;
+$numapp = fixstr($$numapp);
 if (defined('C_UTILIZZA_SEMPRE_DEFAULTS') and (C_UTILIZZA_SEMPRE_DEFAULTS == "SI" or C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO")) {
 if ($num <= $numappartamenti) $numapp = (string) substr($zeri,0,(strlen($num_app_max) - strlen($num))).$num;
 else {
@@ -704,6 +769,8 @@ $numapp = $num_dorm.$suff_lettera.substr($lettere,$pos_lettera,1);
 if ($num_camera_l) {
 $app_vicini_vett['pos'][$num] = $numapp;
 if ($pos_lettera > 0) {
+if (!isset($app_vicini_vett[$num])) $app_vicini_vett[$num] = "";
+if (!isset($app_vicini_vett[($num - 1)])) $app_vicini_vett[($num - 1)] = "";
 if ($pos_lettera > 1) {
 $app_vicini_vett[($num - 2)] .= ",$numapp";
 $app_vicini_vett[$num] .= ",".$app_vicini_vett['pos'][($num - 2)];
@@ -730,19 +797,22 @@ else $suff_lettera = substr(strstr($lettere,$suff_lettera),1,1);
 $numapp = str_replace (",","",$numapp);
 if (str_replace (" ","",$numapp) == "") $numapp = str_replace (" ","_",$numapp);
 $numapp = trim($numapp);
-$numapp_file = htmlspecialchars(elimina_caratteri_slash($numapp));
+if ($numapp == "") $numapp = "_";
+$numapp_file = htmlspecialchars(elimina_caratteri_slash($numapp),ENT_COMPAT);
 $numapp = aggslashdb($numapp_file);
+while (!empty($numapp_esist[$numapp])) $numapp .= "_";
+$numapp_esist[$numapp] = 1;
 $piano = "piano" . $num;
-$piano = aggslashdb(htmlspecialchars(elimina_caratteri_slash($$piano)));
+$piano = aggslashdb(htmlspecialchars(elimina_caratteri_slash($$piano),ENT_COMPAT));
 $maxoccupanti = "maxoccupanti" . $num;
-$maxoccupanti = $$maxoccupanti;
+$maxoccupanti = fixset($$maxoccupanti);
 if ($num > $numappartamenti) $maxoccupanti = 1;
 $numcasa = "numcasa" . $num;
-$numcasa = aggslashdb(htmlspecialchars(elimina_caratteri_slash($$numcasa)));
+$numcasa = aggslashdb(htmlspecialchars(elimina_caratteri_slash($$numcasa),ENT_COMPAT));
 $priorita = "priorita" . $num;
-$priorita = $$priorita;
+$priorita = fixset($$priorita);
 $app_vicini = "app_vicini" . $num;
-$app_vicini = aggslashdb(htmlspecialchars(fixstr($$app_vicini)));
+$app_vicini = aggslashdb(htmlspecialchars(fixstr($$app_vicini),ENT_COMPAT));
 if (controlla_num($maxoccupanti) != "SI") unset($maxoccupanti);
 if (controlla_num($priorita) != "SI") unset($priorita);
 esegui_query("insert into $tableappartamenti ( idappartamenti ) values ( '$numapp' )");
@@ -791,20 +861,22 @@ esegui_query("update $tableappartamenti set app_vicini = '$app_vicini' where ida
 } # fine if (isset($assegna_vicini_nc) and $assegna_vicini_nc == "SI")
 if ($num_camera_l) {
 for ($num = 1 ; $num <= ($numappartamenti + $numletti) ; $num = $num + 1) {
-if ($app_vicini_vett[$num]) {
+if (!empty($app_vicini_vett[$num])) {
 $app_vicini = substr($app_vicini_vett[$num],1);
 esegui_query("update $tableappartamenti set app_vicini = '$app_vicini' where idappartamenti = '".$app_vicini_vett['pos'][$num]."'");
-} # fine if ($app_vicini_vett[$num])
+} # fine if (!empty($app_vicini_vett[$num]))
 } # fine for $num
 } # fine if ($num_camera_l)
 
 if (defined('C_UTILIZZA_SEMPRE_DEFAULTS') and C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO" and @is_file(C_DATI_PATH."/ini.php")) {
+$filelock = crea_lock_file(C_DATI_PATH."/ini.php");
+if (@is_file(C_DATI_PATH."/ini.php")) {
 include(C_DATI_PATH."/ini.php");
 $admin = "";
 if (defined('C_ADMIN_NAME')) $admin = C_ADMIN_NAME;
 if (htmlspecialchars($admin) != $admin) $admin = "";
 if (strcmp((string) $admin,"")) {
-esegui_query("update $tableutenti set nome_utente = '".aggslashdb($admin)."' where idutenti = '1'");
+esegui_query("update $tableutenti set nome_utente = '".aggslashdb($admin)."' where idutenti = '1'",1);
 $passw = "";
 if (defined('C_ADMIN_PASS')) $passw = C_ADMIN_PASS;
 if ($passw != str_replace("&","",$passw)) $passw = "";
@@ -815,19 +887,21 @@ if (defined('C_ADMIN_SALT')) $salt = C_ADMIN_SALT;
 else {
 if ($md5p) $salt = "";
 else {
-srand((double) microtime() * 1000000);
+srand((float) microtime() * 1000000);
 $valori = "=?#@%abcdefghijkmnpqrstuvwxzABCDEFGHJKLMNPQRSTUVWXZ1234567890";
 $salt = substr($valori,rand(0,4),1);
 for ($num1 = 0 ; $num1 < 19 ; $num1++) $salt .= substr($valori,rand(0,60),1);
 } # fine else if ($md5p)
 } # fine else if (defined('C_ADMIN_SALT'))
 for ($num1 = $md5p ; $num1 < 15 ; $num1++) $passw = md5($passw.substr($salt,0,(20 - $num1)));
-esegui_query("update $tableutenti set password = '$passw', salt = '$salt', tipo_pass = '5' where idutenti = '1'");
+esegui_query("update $tableutenti set password = '$passw', salt = '$salt', tipo_pass = '5' where idutenti = '1'",1);
 $fileaperto = fopen(C_DATI_PATH."/abilita_login","w+");
 fclose($fileaperto);
 } # fine if (strcmp((string) $passw,""))
 } # fine if (strcmp((string) $admin,""))
 @unlink(C_DATI_PATH."/ini.php");
+} # fine if (@is_file(C_DATI_PATH."/ini.php"))
+distruggi_lock_file($filelock,C_DATI_PATH."/ini.php");
 } # fine if (defined('C_UTILIZZA_SEMPRE_DEFAULTS') and C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO" and @is_file(C_DATI_PATH."/ini.php"))
 
 $tablemessaggi = $PHPR_TAB_PRE."messaggi";
@@ -939,7 +1013,7 @@ echo "".mex2("Nome del database a cui collegarsi temporaneamente",$pag,$lingua).
 ".mex2("Numero di unità singole da gestire",$pag,$lingua).": 
 <input type=\"text\" name=\"numletti\" value=\"0\" size=\"5\"><br>
 <div style=\"text-align: center;\"><input class=\"sbutton\" type=\"submit\" name=\"creabase\" value=\"".mex2("Crea il database",$pag,$lingua)."\"></div><br>
-<input type=\"hidden\" name=\"lingua\" value=\"$lingua\">
+<input type=\"hidden\" name=\"lingua\" value=\"$lingua_locale\">
 </div></form>";
 
 } # fine if (!isset($mostra_form_iniziale) or $mostra_form_iniziale != "NO")
@@ -955,6 +1029,7 @@ else include("./includes/foot.php");
 
 
 } # fine if (!defined('C_CREA_ULTIMO_ACCESSO') or CREA_ULTIMO_ACCESSO != "SI" or !@is_file(C_DATI_PATH."/ultimo_accesso"))
+if (defined('C_CREA_ULTIMO_ACCESSO') and C_CREA_ULTIMO_ACCESSO == "SI") distruggi_lock_file($filelock_ua,C_DATI_PATH."/ultimo_accesso");
 
 
 ?>
