@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2025 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -306,7 +306,7 @@ echo mex("Le date sono sbagliate",$pag).".<br>";
 else {
 if ($motivazione == " ") echo mex("Motivazione non valida",$pag).".<br>";
 else {
-$appartamento = htmlspecialchars($appartamento);
+$appartamento = htmlspecialchars($appartamento,ENT_COMPAT);
 $app_esistente = esegui_query("select idappartamenti from $tableappartamenti where idappartamenti = '".aggslashdb($appartamento)."' ");
 if (!numlin_query($app_esistente) or $appartamenti_consentiti[$appartamento] != "SI") echo mex("Non sono stati inseriti tutti i dati necessari",$pag).".<br>";
 else {
@@ -396,7 +396,7 @@ $idregole = $mod_idregola1;
 } # fine if ($mod_idregola1)
 esegui_query("insert into $tableregole (idregole,app_agenzia,iddatainizio,iddatafine) values ($idregole,'".aggslashdb($appartamento)."','$idinizioperiodo','$idfineperiodo')");
 if (@get_magic_quotes_gpc()) $motivazione = stripslashes($motivazione);
-$motivazione = htmlspecialchars($motivazione);
+$motivazione = htmlspecialchars($motivazione,ENT_COMPAT);
 if ($motivazione) esegui_query("update $tableregole set motivazione = '".aggslashdb($motivazione)."' where idregole = '$idregole' ");
 if ($attiva_regole1_consentite != "n") $chiudi_app = 1;
 if ($chiudi_app) {
@@ -570,7 +570,7 @@ $idregole = $mod_idregola1;
 } # fine if ($mod_idregola1)
 esegui_query("insert into $tableregole (idregole,tariffa_chiusa,iddatainizio,iddatafine) values ('$idregole','$tipotariffa','$idinizioperiodo','$idfineperiodo')");
 if (@get_magic_quotes_gpc()) $motivazione = stripslashes($motivazione);
-$motivazione = htmlspecialchars($motivazione);
+$motivazione = htmlspecialchars($motivazione,ENT_COMPAT);
 if ($motivazione) esegui_query("update $tableregole set motivazione = '".aggslashdb($motivazione)."' where idregole = '$idregole' ");
 echo mex("La regola è stata inserita",$pag).".";
 $aggiorna_ic_tar = 1;
@@ -629,6 +629,7 @@ echo mex("Sei sicuro di voler cancellare tutte le regole del tipo 1",$pag)."?
 
 
 if ((!empty($regola_2) or !empty($regola_2b)) and $priv_mod_reg2 == "s") {
+$inserire = "";
 if (substr($tipotariffa,0,7) != "tariffa" or controlla_num_pos(substr($tipotariffa,7)) == "NO" or ($attiva_tariffe_consentite != "n" and !isset($tariffe_consentite_vett[substr($tipotariffa,7)]))) {
 $inserire = "NO";
 echo "<br><span class=\"colwarn\">".mex("Si deve scegliere la tariffa",$pag)."</span>.<br><br>";
@@ -715,7 +716,7 @@ $num_giorni_fine = "'$num_giorni'";
 } # fine if (!empty($regola_2b))
 if (!isset($v_apti) or $v_apti != "v") $v_apti = "";
 
-if (!isset($inserire) or $inserire != "NO") {
+if ($inserire != "NO") {
 if ($num_regole_esistente != 0) {
 if (!empty($regola_2b)) {
 esegui_query("update $tableregole set motivazione2 = '$lista_app', iddatainizio = $num_giorni_ini, iddatafine = $num_giorni_fine where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
@@ -752,11 +753,12 @@ if ($num_apti > 1) esegui_query("update $tableregole set motivazione3 = '$v_apti
 echo "<br>".mex("La regola di assegnazione",$pag)." 2 ".mex("è stata inserita",$pag).".<br><br>";
 } # fine else if ($num_regole_esistente != 0)
 $aggiorna_ic_disp = 1;
-} # fine if (!isset($inserire) or $inserire != "NO")
+} # fine if ($inserire != "NO")
 } # fine if ((!empty($regola_2) or !empty($regola_2b)) and $priv_mod_reg2 == "s")
 
 
 if ((!empty($regola_3) or !empty($regola_3m)) and $priv_mod_reg2 == "s") {
+$inserire = "";
 if (substr($tipotariffa,0,7) != "tariffa" or controlla_num_pos(substr($tipotariffa,7)) == "NO" or ($attiva_tariffe_consentite != "n" and !isset($tariffe_consentite_vett[substr($tipotariffa,7)]))) {
 $inserire = "NO";
 echo mex("Si deve scegliere la tariffa",$pag).".<br>";
@@ -789,7 +791,7 @@ $inserire = "NO";
 echo mex("Il numero di persone minimo",$pag)." ($pers_min) ".mex("è maggiore del numero di persone predefinito",$pag)." ($pers_def).<br>";
 } # fine if ($pers_def and $pers_min > $pers_def)
 } # fine if ((!isset($inserire) or $inserire != "NO") and $num_regole_esistente)
-if (!isset($inserire) or $inserire != "NO") {
+if ($inserire != "NO") {
 $regola2_esistente = esegui_query("select * from $tableregole where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
 if (numlin_query($regola2_esistente)) {
 $lista_app2 = risul_query($regola2_esistente,0,'motivazione');
@@ -838,7 +840,7 @@ esegui_query("insert into $tableregole (idregole,tariffa_per_persone,$campo) val
 echo "<br>".mex("La regola di assegnazione",$pag)." 3 ".mex("è stata inserita",$pag).".<br><br>";
 } # fine else if ($num_regole_esistente != 0)
 $aggiorna_ic_tar = 1;
-} # fine if (!isset($inserire) or $inserire != "NO")
+} # fine if ($inserire != "NO")
 } # fine if ((!empty($regola_3) or !empty($regola_3m)) and $priv_mod_reg2 == "s")
 
 
@@ -858,10 +860,10 @@ echo mex("La tariffa scelta ha già un utente associato, cancella la regola prim
 } # fine if ($num_regole_esistente != 0)
 */
 } # fine else if (substr($tipotariffa,0,7) != "tariffa" or...
-if (!$id_utente_inserimento) {
+if (empty($id_utente_inserimento)) {
 $inserire = "NO";
 echo mex("Si deve inserire l'utente da associare",$pag).".<br>";
-} # fine if (!$id_utente_inserimento)
+} # fine if (empty($id_utente_inserimento))
 else {
 $id_utente_inserimento = aggslashdb($id_utente_inserimento);
 $utente_tariffa = esegui_query("select nome_utente from $tableutenti where idutenti = '$id_utente_inserimento'");
@@ -869,7 +871,7 @@ if (numlin_query($utente_tariffa) != 1) {
 $inserire = "NO";
 echo mex("L'utente ",$pag).$id_utente_inserimento.mex(" non esiste",$pag).".<br>";
 } # fine if ($numlin_query($utente_tariffa) != 1)
-} # fine else if (!$id_utente_inserimento)
+} # fine else if (empty($id_utente_inserimento))
 if ($inserire != "NO") {
 if ($num_regole_esistente != 0) {
 esegui_query("update $tableregole set iddatainizio = '$id_utente_inserimento' where tariffa_per_utente = '".aggslashdb($tipotariffa)."'");
@@ -971,7 +973,7 @@ $transaz_esist_1t = esegui_query("select * from $tabletransazioni where idsessio
 if (!numlin_query($transaz_esist_1a) or !numlin_query($transaz_esist_1t)) {
 $inizio_select = "";
 $fine_select = "";
-$motivazione_orig = htmlspecialchars(fixstr($motivazione));
+$motivazione_orig = htmlspecialchars(fixstr($motivazione),ENT_COMPAT);
 $oggi = date("Y-m-d",(time() + (C_DIFF_ORE * 3600)));
 $date_select = esegui_query("select datainizio,datafine from $PHPR_TAB_PRE"."periodi$anno where datainizio <= '$oggi' and datafine > '$oggi' ");
 if (numlin_query($date_select) != 0) {
