@@ -144,7 +144,7 @@ ${"nome".$id} = trim(elimina_caratteri_slash(${"nome".$id}));
 ${"tipo_pass".$id} = aggslashdb(${"tipo_pass".$id});
 ${"prima_pass".$id} = aggslashdb(fixset(${"prima_pass".$id}));
 $nome = risul_query($lista_utenti,$num1,'nome_utente');
-if (htmlspecialchars(${"nome".$id}) != ${"nome".$id}) ${"nome".$id} = $nome;
+if (htmlspecialchars(${"nome".$id},ENT_COMPAT) != ${"nome".$id}) ${"nome".$id} = $nome;
 $tipo_pass = risul_query($lista_utenti,$num1,'tipo_pass');
 $cambia_nome = 0;
 if ($nome != ${"nome".$id} and str_replace("&","",${"nome".$id}) == ${"nome".$id}) {
@@ -210,12 +210,42 @@ $continua = "NO";
 echo mex("<div style=\"display: inline; color: red;\">Esiste già</div> un utente chiamato",$pag)." ".${"nome".$id}.".<br>";
 } # fine if (numlin_query($nome_esistente) != 0)
 $n_tipo_pass = ${"tipo_pass".$id};
-if ($n_tipo_pass and $tipo_pass != $n_tipo_pass) {
-if ($n_tipo_pass != "n" and (!${"prima_pass".$id} or ${"prima_pass".$id} != ${"seconda_pass".$id} or ${"prima_pass".$id} != str_replace("&","",${"prima_pass".$id}))) {
+if ($n_tipo_pass and $tipo_pass != $n_tipo_pass and $n_tipo_pass != "n") {
+if (!${"prima_pass".$id} or ${"prima_pass".$id} != ${"seconda_pass".$id} or ${"prima_pass".$id} != str_replace("&","",${"prima_pass".$id})) {
 $continua = "NO";
 echo mex("Nuova password dell'utente",$pag)." $id ".mex("<div style=\"display: inline; color: red;\">non</div> inserita correttamente",$pag).".<br>";
-} # fine if ($n_tipo_pass != "n" and (!${"prima_pass".$id} or...
-} # fine if ($n_tipo_pass and $tipo_pass != $n_tipo_pass)
+} # fine if (!${"prima_pass".$id} or ${"prima_pass".$id} != ${"seconda_pass".$id} or...
+else {
+$lung_min = 4;
+if (defined('C_MINIMA_LUNGHEZZA_PASS') and C_MINIMA_LUNGHEZZA_PASS > 0 and controlla_num_pos(C_MINIMA_LUNGHEZZA_PASS) == "SI") $lung_min = C_MINIMA_LUNGHEZZA_PASS;
+$lung_pass = strlen(${"prima_pass".$id});
+if ($lung_pass < $lung_min) {
+$continua = "NO";
+echo "<span style=\"color: red;\">".mex("Password troppo debole",$pag)."</span> (".mex("almeno",$pag)." $lung_min ".mex("caratteri",$pag).").<br>";
+} # fine if ($lung_pass < $lung_min)
+else {
+$pass_debole = 0;
+if (strstr("012345678901234567890",${"prima_pass".$id}) or strstr("098765432109876543210",${"prima_pass".$id})) $pass_debole = 1;
+else {
+$max_lung_ripetizioni = 1;
+$ripetizione_corr = 1;
+$ultimo_car = substr(${"prima_pass".$id},0,1);
+for ($num2 = 1 ; $num2 < $lung_pass ; $num2++) {
+$car_corr = substr(${"prima_pass".$id},$num2,1);
+if ($car_corr == $ultimo_car) $ripetizione_corr++;
+else $ripetizione_corr = 1;
+if ($ripetizione_corr > $max_lung_ripetizioni) $max_lung_ripetizioni = $ripetizione_corr;
+$ultimo_car = $car_corr;
+} # fine for $num2
+if ($max_lung_ripetizioni > ceil($lung_pass / 2) and $max_lung_ripetizioni > ($lung_pass - $lung_min)) $pass_debole = 1;
+} # fine else if (strstr("012345678901234567890",${"prima_pass".$id}) or...
+if ($pass_debole) {
+$continua = "NO";
+echo "<span style=\"color: red;\">".mex("Password troppo debole",$pag)."</span>.<br>";
+} # fine if ($pass_debole)
+} # fine else if ($lung_pass < $lung_min)
+} # fine else if (!${"prima_pass".$id} or ${"prima_pass".$id} != ${"seconda_pass".$id} or...
+} # fine if ($n_tipo_pass and $tipo_pass != $n_tipo_pass and...
 } # fine for $num1
 if ($continua == "NO") {
 echo mex("<b>Non</b> è stato effettuato nessun cambiamento",$pag).".<br>";
@@ -241,7 +271,7 @@ if ($n_tipo_pass != "n") {
 $n_pass = ${"prima_pass".$id};
 $salt = "";
 if ($n_tipo_pass == "5") {
-srand((int) ((double) microtime() * 1000000.0));
+srand((int) ((float) microtime() * 1000000.0));
 $valori = "=?#@%abcdefghijkmnpqrstuvwxzABCDEFGHJKLMNPQRSTUVWXZ1234567890";
 $salt = substr($valori,rand(0,4),1);
 for ($num2 = 0 ; $num2 < 19 ; $num2++) $salt .= substr($valori,rand(0,60),1);
@@ -268,7 +298,7 @@ unlock_tabelle($tabelle_lock);
 
 
 if (!empty($aggiungi_utente) and $id_utente == 1) {
-if (htmlspecialchars($nome) != $nome) $nome = "";
+if (htmlspecialchars($nome,ENT_COMPAT) != $nome) $nome = "";
 if ($nome) {
 $nome = trim(elimina_caratteri_slash($nome));
 $continua = "";
@@ -376,7 +406,7 @@ $linee[$num_lin] = "\$tema[".$nuovo_id."] = \"blu\";
 ";
 $num_lin++;
 $linee[$num_lin] = $file_tema[$num1];
-} # fine if (substr($file_lingua[$num1],0,2) ==..
+} # fine if (substr($file_tema[$num1],0,2) ==..
 else $linee[$num_lin] = $file_tema[$num1];
 $num_lin++;
 } # fine for $num1
@@ -403,10 +433,42 @@ $dati_utente = esegui_query("select * from $tableutenti where idutenti = '".aggs
 if (numlin_query($dati_utente) != 1 or controlla_num_pos($id_utente_pass) != "SI") $continua = "NO";
 else $nome_utente = risul_query($dati_utente,0,'nome_utente');
 if ($id_utente_pass == 1 and defined('C_RESTRIZIONI_DEMO_ADMIN') and C_RESTRIZIONI_DEMO_ADMIN == "SI") $continua = "NO";
-if (isset($continua) and $continua == "SI" and ($prima_pass != $seconda_pass or $prima_pass == "" or $prima_pass != str_replace("&","",$prima_pass))) {
+if (isset($continua)and $continua == "SI") {
+if ($prima_pass != $seconda_pass or $prima_pass == "" or $prima_pass != str_replace("&","",$prima_pass)) {
 unset($continua);
 echo mex("Le nuove password non coincidono",$pag).".<br><br>";
-} # fine if (isset($continua) and $continua == "SI" and ($prima_pass != $seconda_pass or...
+} # fine if ($prima_pass != $seconda_pass or...
+else {
+$lung_min = 4;
+if (defined('C_MINIMA_LUNGHEZZA_PASS') and C_MINIMA_LUNGHEZZA_PASS > 0 and controlla_num_pos(C_MINIMA_LUNGHEZZA_PASS) == "SI") $lung_min = C_MINIMA_LUNGHEZZA_PASS;
+$lung_pass = strlen($prima_pass);
+if ($lung_pass < $lung_min) {
+unset($continua);
+echo "<span style=\"color: red;\">".mex("Password troppo debole",$pag)."</span> (".mex("almeno",$pag)." $lung_min ".mex("caratteri",$pag).").<br><br>";
+} # fine if ($lung_pass < $lung_min)
+else {
+$pass_debole = 0;
+if (strstr("012345678901234567890",$prima_pass) or strstr("098765432109876543210",$prima_pass)) $pass_debole = 1;
+else {
+$max_lung_ripetizioni = 1;
+$ripetizione_corr = 1;
+$ultimo_car = substr($prima_pass,0,1);
+for ($num2 = 1 ; $num2 < $lung_pass ; $num2++) {
+$car_corr = substr($prima_pass,$num2,1);
+if ($car_corr == $ultimo_car) $ripetizione_corr++;
+else $ripetizione_corr = 1;
+if ($ripetizione_corr > $max_lung_ripetizioni) $max_lung_ripetizioni = $ripetizione_corr;
+$ultimo_car = $car_corr;
+} # fine for $num2
+if ($max_lung_ripetizioni > ceil($lung_pass / 2) and $max_lung_ripetizioni > ($lung_pass - $lung_min)) $pass_debole = 1;
+} # fine else if (strstr("012345678901234567890",$prima_pass) or...
+if ($pass_debole) {
+unset($continua);
+echo "<span style=\"color: red;\">".mex("Password troppo debole",$pag)."</span>.<br><br>";
+} # fine if ($pass_debole)
+} # fine else if ($lung_pass < $lung_min)
+} # fine else if (prima_pass != $seconda_pass or...
+} # fine if (isset($continua) and $continua == "SI")
 if (empty($continua)) {
 $mostra_tabella_iniziale = "NO";
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"gestione_utenti.php\"><div>
@@ -433,7 +495,7 @@ $tipo_pass = risul_query($dati_utente,0,'tipo_pass');
 if ($tipo_pass != "n") {
 $salt = "";
 if ($tipo_pass == "5") {
-srand((double) microtime() * 1000000);
+srand((float) microtime() * 1000000);
 $valori = "=?#@%abcdefghijkmnpqrstuvwxzABCDEFGHJKLMNPQRSTUVWXZ1234567890";
 $salt = substr($valori,rand(0,4),1);
 for ($num1 = 0 ; $num1 < 19 ; $num1++) $salt .= substr($valori,rand(0,60),1);
@@ -450,7 +512,7 @@ unlock_tabelle($tabelle_lock);
 if (!empty($modifica_gruppi) and $id_utente == 1) {
 $continua = fixset($continua);
 $nuovo_gruppo = fixstr($nuovo_gruppo);
-if (htmlspecialchars($nuovo_gruppo) != $nuovo_gruppo) $nuovo_gruppo = "";
+if (htmlspecialchars($nuovo_gruppo,ENT_COMPAT) != $nuovo_gruppo) $nuovo_gruppo = "";
 $nuovo_gruppo = trim(elimina_caratteri_slash($nuovo_gruppo));
 $tabelle_lock = array("$tableutenti","$tablegruppi","$tablerelgruppi");
 $altre_tab_lock = "";
@@ -482,7 +544,7 @@ echo mex("Esiste già un gruppo chiamato",$pag)." $nuovo_gruppo.<br>";
 if ($nuovo_gruppo != str_replace("&","",$nuovo_gruppo)) $continua = "NO";
 } # fine if ($nuovo_gruppo)
 if ($continua != "NO") {
-unset($gruppi_utente);
+$gruppi_utente = array();
 $gruppi = esegui_query("select idgruppo from $tablerelgruppi where idutente = '$id_utente_mod' and idgruppo is not NULL ");
 $num_gruppi = numlin_query($gruppi);
 for ($num1 = 0 ; $num1 < $num_gruppi ; $num1++) $gruppi_utente[risul_query($gruppi,$num1,'idgruppo')] = "SI";
@@ -500,7 +562,7 @@ $lista_idg_passa = "";
 for ($num1 = 0 ; $num1 < $num_lista_gruppi ; $num1++) {
 $id_gruppo = risul_query($lista_gruppi,$num1,'idgruppi');
 $lista_idg_passa .= ",$id_gruppo";
-if ($gruppi_utente[$id_gruppo] == "SI") { $checked = " checked"; $tag_b = "<b>"; $slash_b = "</b>"; }
+if (isset($gruppi_utente[$id_gruppo]) and $gruppi_utente[$id_gruppo] == "SI") { $checked = " checked"; $tag_b = "<b>"; $slash_b = "</b>"; }
 else { $checked = ""; $tag_b = ""; $slash_b = ""; }
 echo "<label><input type=\"checkbox\" name=\"gruppo$id_gruppo\" value=\"SI\"$checked> $tag_b".$nome_gruppo[$id_gruppo]."$slash_b</label><br>";
 } # fine for $num1
@@ -518,11 +580,11 @@ $gruppo_log = $gruppo_log[0];
 } # fine if (substr($PHPR_LOG,0,2) == "SI" and $PHPR_LOG != "SI" and substr($PHPR_LOG,2,1) != ",")
 for ($num1 = 0 ; $num1 < $num_lista_gruppi ; $num1++) {
 $id_gruppo = risul_query($lista_gruppi,$num1,'idgruppi');
-if ($gruppi_utente[$id_gruppo] != "SI" and ${"gruppo".$id_gruppo} == "SI") {
+if ((!isset($gruppi_utente[$id_gruppo]) or $gruppi_utente[$id_gruppo] != "SI") and isset(${"gruppo".$id_gruppo}) and ${"gruppo".$id_gruppo} == "SI") {
 esegui_query("insert into $tablerelgruppi (idutente,idgruppo) values ('$id_utente_mod','$id_gruppo')");
 if ($id_gruppo == $gruppo_log) $n_phpr_log = $PHPR_LOG.",$id_utente_mod";
-} # fine if ($gruppi_utente[$id_gruppo] != "SI" and ${"gruppo".$id_gruppo} == "SI")
-if ($gruppi_utente[$id_gruppo] == "SI" and ${"gruppo".$id_gruppo} != "SI") {
+} # fine if ((!isset($gruppi_utente[$id_gruppo]) or $gruppi_utente[$id_gruppo] != "SI") and isset(${"gruppo".$id_gruppo}) and...
+if (isset($gruppi_utente[$id_gruppo]) and $gruppi_utente[$id_gruppo] == "SI" and (!isset(${"gruppo".$id_gruppo}) or ${"gruppo".$id_gruppo} != "SI")) {
 esegui_query("delete from $tablerelgruppi where idutente = '$id_utente_mod' and idgruppo = '$id_gruppo' ");
 $gruppo_presente = esegui_query("select idgruppo from $tablerelgruppi where idgruppo = '$id_gruppo'");
 if (numlin_query($gruppo_presente) == 0) {
@@ -530,7 +592,7 @@ esegui_query("delete from $tablegruppi where idgruppi = '$id_gruppo' ");
 if ($id_gruppo == $gruppo_log) $n_phpr_log = "NO";
 } # fine if (numlin_query($gruppo_presente) == 0)
 elseif ($id_gruppo == $gruppo_log) $n_phpr_log = substr(str_replace(",$id_utente_mod,",",","$PHPR_LOG,"),0,-1);
-} # fine if ($gruppi_utente[$id_gruppo] == "SI" and ${"gruppo".$id_gruppo} != "SI") 
+} # fine if (isset($gruppi_utente[$id_gruppo]) and $gruppi_utente[$id_gruppo] == "SI" and (!isset(${"gruppo".$id_gruppo}) or...
 } # fine for $num1
 if ($nuovo_gruppo) {
 $nuovo_id = esegui_query("select max(idgruppi) from $tablegruppi");
@@ -753,10 +815,12 @@ esegui_query("insert into $tableprivilegi (idutente,anno,regole1_consentite,tari
 if ($e_anno != 1) {
 $tipo_periodi_cambia = esegui_query("select * from $tableanni where idanni = '$e_anno'");
 $tipo_periodi_cambia = risul_query($tipo_periodi_cambia,0,'tipo_periodi');
-$lingua_mex = $lingua[$id_utente_importa];
+$locale_mex = substr(strstr($lingua[$id_utente_importa],"-"),1);
+$lingua_mex = str_replace("-$locale_mex","",$lingua[$id_utente_importa]);
 crea_menu_date(C_DATI_PATH."/selectperiodi$e_anno.$id_utente_esporta.php",C_DATI_PATH."/selectperiodi$e_anno.$id_utente_importa.php",$tipo_periodi_cambia);
 crea_menu_date(C_DATI_PATH."/selperiodimenu$e_anno.$id_utente_esporta.php",C_DATI_PATH."/selperiodimenu$e_anno.$id_utente_importa.php",$tipo_periodi_cambia);
-$lingua_mex = $lingua[$id_utente];
+$locale_mex = substr(strstr($lingua[$id_utente],"-"),1);
+$lingua_mex = str_replace("-$locale_mex","",$lingua[$id_utente]);
 $giorno_vedi_ini_sett = esegui_query("select valpersonalizza_num from $tablepersonalizza where idpersonalizza = 'giorno_vedi_ini_sett$e_anno' and idutente = '$id_utente_esporta'");
 if (numlin_query($giorno_vedi_ini_sett) == 1) {
 $giorno_vedi_ini_sett = risul_query($giorno_vedi_ini_sett,0,'valpersonalizza_num');
