@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2025 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -56,12 +56,13 @@ define('C_BACKUP_E_MODELLI_CON_NUOVI_DATI',"SI");
 define('C_CREA_SUBORDINAZIONI',"SI");
 define('C_CREA_NUOVI_APP',"SI");
 define('C_URL_NUOVI_APP',"");
-define('C_CREA_ANNO_MANUALMENTE',"NO");
+define('C_CREA_ANNO_MANUALMENTE',"NUOVO"); # SI, NO or NUOVO to allow creation of new year only when it has begun
 define('C_CREA_ANNO_NON_ATTUALE',"SI");
 define('C_PRIMO_ANNO_CREATO',2001);
 define('C_CANCELLA_ANNO_ATTUALE',"NO");
 define('C_CAMBIA_TIPO_PERIODI',"SI");
 define('C_DISABILITA_PASS_ADMIN',"SI");
+define('C_MINIMA_LUNGHEZZA_PASS',"4");
 define('C_MOSTRA_COPYRIGHT',"SI"); # You are not authorized to remove the copyright notice. Ask info@digitaldruid.net
 # 0 per nessuna limitazione
 define('C_MASSIMO_NUM_UTENTI',80);
@@ -76,21 +77,25 @@ define('C_MASSIMO_NUM_APP',0);
 define('C_MASSIMO_NUM_BYTE_UPLOAD',12582912);
 define('C_MASSIMO_NUM_EMAIL_GIORNALIERE',200); # NUM + (10%NUM * NUM_APP)
 define('C_CREA_ULTIMO_ACCESSO',"SI");
-if (!defined('C_CARTELLA_CREA_MODELLI')) define('C_CARTELLA_CREA_MODELLI',"./dati");
+#if (!defined('C_CARTELLA_CREA_MODELLI')) define('C_CARTELLA_CREA_MODELLI',"");
 #if (!defined('C_URL_CREA_MODELLI')) define('C_URL_CREA_MODELLI',"");
 #if (!defined('C_PERCORSO_PHPMAILER')) define('C_PERCORSO_PHPMAILER',"");
+#if (!defined('C_NUM_HOSTING')) define('C_NUM_HOSTING',"");
 define('C_DOMINIO_CREA_MODELLI',"");
 define('C_CHMOD_EXEC_MODELLI',"NO");
 define('C_CARTELLA_DOC',"");
 define('C_CARTELLA_FILES_REALI',"");
-define('C_CARTELLA_UPLOAD_IMG',"up_img");
+define('C_CARTELLA_UPLOAD_IMG',"");
+define('C_CARTELLA_VAR',"");
 define('C_UTENTE_AZIONE_IC',"");
 define('C_UTENTE_BACKUP_ESTERNO',"");
+#if (!defined('C_MAX_ANNI_BACKUP_ESTERNO')) define('C_MAX_ANNI_BACKUP_ESTERNO',"5");
 define('C_FILE_SCADENZA_ACCOUNT',"");
 define('C_HTML_PRE_LOGIN',"");
 define('C_HTML_POST_LOGIN',"");
 define('C_URL_LOGO',"");
 define('C_URL_FAVICON',"");
+define('C_URL_MANIFEST',"");
 define('C_SEC_LIMITE_LIBERA_APP',"");
 define('C_LIMITE_BACKUP_GIORNALIERI',0);
 define('C_LIMITE_CHIAMATE_API_AL_MINUTO',0);
@@ -102,7 +107,9 @@ define('C_NASCONDI_MARCA',"");
 define('C_OPZIONI_NASCONDI_MARCA',"n"); # 1: s-n open ext module for credit cards in new window yes-no
 define('C_DISABILITA_COD_EMAIL_MODELLI',"NO");
 define('C_USER_BOOKINGCOM_IC',"");
-define('C_PASSWORD_BOOKINGCOM_IC',"");
+define('C_PASSWORD_BOOKINGCOM_IC',"NOAUTH"); # NOAUTH to don't use old authentication
+define('C_CLIENT_ID_BOOKINGCOM_IC',"");
+define('C_CLIENT_SECRET_BOOKINGCOM_IC',"");
 define('C_USER_EXPEDIA_IC',"");
 define('C_PASSWORD_EXPEDIA_IC',"");
 define('C_API_KEY_BBLIVERATE_IC',"");
@@ -115,6 +122,7 @@ define('C_UTENTE_CANC_CC',"");
 define('C_FILE_TITOLO_PERS',"");
 define('C_FILE_CSS_PERS',"");
 define('C_FILE_MOB_CSS_PERS',"");
+define('C_FILE_JS_PERS',"");
 define('C_FILE_DOMINIO',""); # secure domains file will be searched as C_FILE_DOMINIO.'_https'
 define('C_DOMINIO_ADMIN_DIR',"");
 
