@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2018-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2018-2025 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -31,6 +31,7 @@ $lista_c = array();
 for ($num1 = 1 ; $num1 <= $num_ripeti ; $num1++) {
 $id_clienti = aggslashdb($lista_clienti[$num1]);
 $dati_cliente = esegui_query("select * from $tableclienti where idclienti = '$id_clienti' ");
+if (numlin_query($dati_cliente)) {
 if ($vedi_clienti == "PROPRI" or $vedi_clienti == "GRUPPI") {
 $mostra_cliente = "SI";
 $utente_inserimento = risul_query($dati_cliente,0,'utente_inserimento');
@@ -42,6 +43,7 @@ $num_c++;
 $lista_c[$num_c] = $lista_clienti[$num1];
 ${"cognome_".$num_c} = risul_query($dati_cliente,0,'cognome');
 # I controlli di non vuoto servono a risparmiare memoria, creando solo le variabili necessarie
+if (strcmp((string) risul_query($dati_cliente,0,'cognome2'),"")) ${"cognome2_".$num_c} = risul_query($dati_cliente,0,'cognome2');
 if (strcmp((string) risul_query($dati_cliente,0,'nome'),"")) ${"nome_".$num_c} = risul_query($dati_cliente,0,'nome');
 if (strcmp((string) risul_query($dati_cliente,0,'soprannome'),"")) ${"soprannome_".$num_c} = risul_query($dati_cliente,0,'soprannome');
 if (strcmp((string) risul_query($dati_cliente,0,'titolo'),"")) ${"titolo_".$num_c} = risul_query($dati_cliente,0,'titolo');
@@ -85,6 +87,7 @@ ${"campo_personalizzato_".risul_query($dati_relcliente,$num2,'testo1')."_".$num_
 } # fine for $num2
 chiudi_query($dati_relcliente);
 } # fine if (($vedi_clienti != "PROPRI" and...
+} # fine if (numlin_query($dati_cliente))
 chiudi_query($dati_cliente);
 } # fine for $num1
 
@@ -131,4 +134,4 @@ unset(${"num_pagamenti_$num1"});
 
 
 
-?>
\ No newline at end of file
+?>
