@@ -30,22 +30,24 @@ if ($tablepersonalizza and function_exists('altre_valute')) $altre_valute = altr
 else $altre_valute = array();
 } # fine if (!isset($altre_valute) or !is_array($altre_valute))
 else $canc_altre_valute = 0;
-if (!empty($pcanc)) $tableprenota = $tableprenotacanc;
 $tabelle_lock = "";
-$altre_tab_lock = array($tableanni,$tableprenota,$tablecostiprenota,$tableperiodi,$tableclienti,$tablerelclienti,$tablesoldi,$tableutenti);
+if (!empty($pcanc) and $pcanc != "+") $tableprenota = $tableprenotacanc;
+if (isset($pcanc) and $pcanc == "+") $altre_tab_lock = array($tableanni,$tableprenota,$tableprenotacanc,$tablecostiprenota,$tableperiodi,$tableclienti,$tablerelclienti,$tablesoldi,$tableutenti);
+else $altre_tab_lock = array($tableanni,$tableprenota,$tablecostiprenota,$tableperiodi,$tableclienti,$tablerelclienti,$tablesoldi,$tableutenti);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 $num_r = 0;
 $lista_p = array();
 $ultima_ripetizione_cliente = array();
 for ($num1 = 1 ; $num1 <= $num_ripeti ; $num1++) {
 $id_prenota = aggslashdb($lista_prenota[$num1]);
-$dati_prenota = esegui_query("select * from $tableprenota where idprenota = '$id_prenota'");
+if (isset($pcanc) and $pcanc == "+") $dati_prenota = esegui_query("(select * from $tableprenota where idprenota = '$id_prenota') union (select * from $tableprenotacanc where idprenota = '$id_prenota')");
+else $dati_prenota = esegui_query("select * from $tableprenota where idprenota = '$id_prenota'");
 if (numlin_query($dati_prenota) == 1) {
 $cont = "SI";
 $utente_inserimento = risul_query($dati_prenota,0,'utente_inserimento');
 if ($priv_vedi_tab_prenotazioni != "s" and ($priv_vedi_tab_mesi != "s" or $priv_mod_prenotazioni != "s")) {
 if ($priv_vedi_tab_prenotazioni == "g" or (($priv_vedi_tab_mesi == "g" or $priv_vedi_tab_mesi == "q") and $priv_mod_prenotazioni == "g")) {
-if (!$utenti_gruppi[$utente_inserimento]) $cont = "NO";
+if (empty($utenti_gruppi[$utente_inserimento])) $cont = "NO";
 } # fine if ($priv_vedi_tab_prenotazioni == "g" or...
 elseif ($utente_inserimento != $id_utente) $cont = "NO";
 } # fine if ($priv_vedi_tab_prenotazioni != "s" and ($priv_vedi_tab_mesi != "s" or $priv_mod_prenotazioni != "s"))
@@ -60,6 +62,7 @@ if (!empty($ultima_ripetizione_cliente[${"numero_cliente_".$num_r}])) ${"ultima_
 $ultima_ripetizione_cliente[${"numero_cliente_".$num_r}] = $num_r;
 ${"ultima_prenotazione_per_cliente_".$num_r} = 1;
 $dati_cliente = esegui_query("select * from $tableclienti where idclienti = '".${"numero_cliente_".$num_r}."' ");
+if (numlin_query($dati_cliente)) {
 if ($vedi_clienti == "PROPRI" or $vedi_clienti == "GRUPPI") {
 $mostra_cliente = "SI";
 $utente_inserimento = risul_query($dati_cliente,0,'utente_inserimento');
@@ -111,12 +114,15 @@ ${"campo_personalizzato_".risul_query($dati_relcliente,$num2,'testo1')."_".$num_
 } # fine for $num2
 chiudi_query($dati_relcliente);
 } # fine if (($vedi_clienti != "PROPRI" and...
+} # fine if if (numlin_query($dati_cliente))
 chiudi_query($dati_cliente);
 } # fine if ($vedi_clienti != "NO")
 ${"numero_prenotazione_".$num_r} = $id_prenota;
 if ($priv_mod_codice == "s") {
 $cod_prenota = risul_query($dati_prenota,0,'codice');
-${"codice_prenotazione_".$num_r} = substr($cod_prenota,0,2).${"numero_cliente_".$num_r}.substr($cod_prenota,2,1).$id_prenota.substr($anno,-1).substr($cod_prenota,-1);
+if ($vedi_clienti != "NO") ${"codice_prenotazione_".$num_r} = ${"numero_cliente_".$num_r};
+else ${"codice_prenotazione_".$num_r} = risul_query($dati_prenota,0,'idclienti');
+${"codice_prenotazione_".$num_r} = substr($cod_prenota,0,2).${"codice_prenotazione_".$num_r}.substr($cod_prenota,2,1).$id_prenota.substr($anno,-1).substr($cod_prenota,-1);
 } # fine if ($priv_mod_codice == "s")
 $id_data_inizio = risul_query($dati_prenota,0,'iddatainizio');
 $id_data_fine = risul_query($dati_prenota,0,'iddatafine');
@@ -130,7 +136,7 @@ ${"data_inizio_".$num_r} = risul_query(${"data_inizio_".$num_r},0,'datainizio');
 ${"num_periodi_".$num_r} = $id_data_fine - $id_data_inizio + 1;
 $tariffa = risul_query($dati_prenota,0,'tariffa');
 $tariffa = explode("#@&",$tariffa);
-$costo_tariffa = (double) $tariffa[1];
+$costo_tariffa = (float) $tariffa[1];
 $valuta_tariffa = risul_query($dati_prenota,0,'valuta');
 if ($valuta_tariffa) {
 $valuta_tariffa = explode(">",$valuta_tariffa);
@@ -152,7 +158,7 @@ if ($priv_mod_tariffa != "p") ${"costo_tariffa_".$num_r} = $costo_tariffa;
 ${"tariffesettimanali_".$num_r} = $tariffesettimanali;
 if (strcmp((string) risul_query($dati_prenota,0,'tasseperc'),"")) ${"percentuale_tasse_tariffa_".$num_r} = risul_query($dati_prenota,0,'tasseperc');
 } # fine if ($priv_mod_tariffa != "n")
-$sconto = (double) risul_query($dati_prenota,0,'sconto');
+$sconto = (float) risul_query($dati_prenota,0,'sconto');
 if (strcmp((string) $sconto,"") and $priv_mod_sconto != "n") {
 ${"sconto_".$num_r} = $sconto;
 if ($valuta_tariffa) ${"valore_valuta_sconto_".$num_r} = converti_valuta($sconto,$valuta_tariffa[1],$valuta_tariffa[2]);
@@ -166,7 +172,7 @@ if (strcmp((string) $comm[1],"")) ${"promemoria_entrata_".$num_r} = $comm[1];
 if (strcmp((string) $comm[2],"")) ${"promemoria_uscita_".$num_r} = $comm[2];
 for ($num2 = 3 ; $num2 < count($comm) ; $num2++) {
 $comm_pers = explode("<",$comm[$num2]);
-if (strcmp((string) $comm_pers[1],"")) ${"commento_personalizzato_".$comm_pers[0]."_".$num_r} = $comm_pers[1];
+if (isset($comm_pers[1]) and strcmp((string) $comm_pers[1],"")) ${"commento_personalizzato_".$comm_pers[0]."_".$num_r} = $comm_pers[1];
 } # fine for $num2
 } # fine if (strstr(${"commento_".$num_r},">"))
 } # fine if (strcmp(risul_query($dati_prenota,0,'commento'),""))
@@ -196,12 +202,14 @@ if ($priv_mod_pagato != "n" and $priv_mod_pagato != "i") ${"pagato_".$num_r} = $
 if ($pagato or substr((string) risul_query($dati_prenota,0,'conferma'),0,1) == "S") ${"conferma_".$num_r} = 1;
 else ${"conferma_".$num_r} = "";
 $num_letti_agg = array('max' => 0);
-$costo_agg_tot = (double) 0;
+$costo_agg_tot = (float) 0;
+$costo_escludi_perc = (float) 0;
 $dati_cap = dati_costi_agg_prenota($tablecostiprenota,$id_prenota,$dati_cat_pers);
 for ($numca = 0 ; $numca < $dati_cap['num'] ; $numca++) {
 aggiorna_letti_agg_in_periodi($dati_cap,$numca,$num_letti_agg,$id_data_inizio,$id_data_fine,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],"","");
-$costo_agg_parziale = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$id_data_inizio,$id_data_fine,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],$costo_tariffa,$tariffesettimanali,($costo_tariffa + $costo_agg_tot - $sconto),$caparra,$numpersone,fixset($dati_cap[$numca]['cat_pers']),0,0,1);
-$costo_agg_tot = (double) $costo_agg_tot + $costo_agg_parziale;
+$costo_agg_parziale = (float) calcola_prezzo_totale_costo($dati_cap,$numca,$id_data_inizio,$id_data_fine,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],$costo_tariffa,$tariffesettimanali,($costo_tariffa + $costo_agg_tot - $sconto),$caparra,$numpersone,fixset($dati_cap[$numca]['cat_pers']),0,$costo_escludi_perc,1);
+$costo_agg_tot = (float) $costo_agg_tot + $costo_agg_parziale;
+if ($dati_cap[$numca]['escludi_tot_perc'] == "s") $costo_escludi_perc = $costo_escludi_perc + $costo_agg_parziale;
 if ($priv_mod_costi_agg != "n") {
 ${"nome_costo_agg".$numca."_".$num_r} = $dati_cap[$numca]['nome'];
 ${"percentuale_tasse_costo_agg".$numca."_".$num_r} = "0";
@@ -359,4 +367,4 @@ if ($tabelle_lock) unlock_tabelle($tabelle_lock);
 
 
 
-?>
\ No newline at end of file
+?>
