@@ -60,6 +60,8 @@ $files_sorgente = array(
 'punto_vendita.php',
 'README',
 'storia_soldi.php',
+'sw.js',
+'sw_offline.html',
 'tabella2.php',
 'tabella3.php',
 'tabella.php',
@@ -77,6 +79,7 @@ $files_sorgente = array(
 'doc/README.translation',
 'doc/TODO',
 'img/',
+'img/aggiorna.png',
 'img/button28.gif',
 'img/button.gif',
 'img/croce.gif',
@@ -94,6 +97,9 @@ $files_sorgente = array(
 'img/fr_sx_checkin.gif',
 'img/fr_sx_rossa.gif',
 'img/logo.png',
+'img/logo48x48.png',
+'img/logo96x96.png',
+'img/logo144x144.png',
 'includes/',
 'includes/costanti.php',
 'includes/dati_form_prenotazione.php',
@@ -411,6 +417,7 @@ $files_sorgente = array(
 'themes/blu/img/xuser.png',
 'themes/blu/inc/',
 'themes/blu/inc/functions.js',
+'themes/blu/inc/manifest.json',
 'themes/blu/inc/mobile.css',
 'themes/blu/inc/paper.css',
 'themes/blu/inc/screen.css',
@@ -569,6 +576,7 @@ $files_sorgente = array(
 'themes/col/img/xuser.png',
 'themes/col/inc/',
 'themes/col/inc/functions.js',
+'themes/col/inc/manifest.json',
 'themes/col/inc/mobile.css',
 'themes/col/inc/paper.css',
 'themes/col/inc/screen.css',
@@ -586,6 +594,7 @@ $files_sorgente = array(
 'themes/sim/img/calpick.png',
 'themes/sim/inc/',
 'themes/sim/inc/functions.js',
+'themes/sim/inc/manifest.json',
 'themes/sim/inc/mobile.css',
 'themes/sim/inc/paper.css',
 'themes/sim/inc/screen.css',
