@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2009 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2024 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,6 +23,18 @@
 
 echo "
 </div>
+";
+
+
+
+if (defined('C_FILE_JS_PERS') and C_FILE_JS_PERS != "" and @is_file(C_FILE_JS_PERS)) echo "
+<script type=\"text/javascript\" src=\"".C_FILE_JS_PERS."\">
+</script>
+";
+
+
+
+echo "
 </body>
 </html>";
 
