@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2025 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -21,17 +21,20 @@
 ##################################################################################
 
 
+# "on", "off" or "param" to log the parameters the page is called with
 define('C_DEBUG_HD',"off");
 
-if (function_exists('version_compare') and version_compare(PHP_VERSION, '8.0.0', '>=')) error_reporting(E_ALL & ~E_NOTICE & ~E_STRICT & ~E_DEPRECATED & ~E_WARNING);
-else error_reporting(E_ALL & ~E_NOTICE & ~E_STRICT & ~E_DEPRECATED);
-/*if (C_DEBUG_HD == "on") {
+#if (function_exists('version_compare') and version_compare(PHP_VERSION, '8.0.0', '>=')) error_reporting(E_ALL & ~E_NOTICE & ~E_STRICT & ~E_DEPRECATED & ~E_WARNING);
+#else error_reporting(E_ALL & ~E_NOTICE & ~E_STRICT & ~E_DEPRECATED);
+if (C_DEBUG_HD == "on") {
 error_reporting(E_ALL);
-#if (function_exists('ini_set')) @ini_set('display_errors','Off');
+#if (function_exists('ini_set')) @ini_set('display_errors','On');
 } # fine if (C_DEBUG_HD == "on")
-else error_reporting(E_ALL & ~E_STRICT & ~E_DEPRECATED);*/
+else {
+error_reporting(E_ALL & ~E_STRICT & ~E_DEPRECATED);
+#if (function_exists('ini_set')) @ini_set('display_errors','Off');
+} # fine else if (C_DEBUG_HD == "on")
 if (function_exists('mb_internal_encoding')) mb_internal_encoding('UTF-8');
-if (function_exists('date_default_timezone_set')) if (!ini_get('date.timezone')) date_default_timezone_set('UTC');
 
 #$pag = explode("/", $SCRIPT_NAME);
 #$pag = end($pag);
@@ -50,33 +53,40 @@ if (isset($_REQUEST[$var_pag[$num1]]) and !isset(${$var_pag[$num1]})) ${$var_pag
 } # fine for $num1
 unset($var_pag);
 
-if (C_DEBUG_HD == "on") {
+if (C_DEBUG_HD == "on" or C_DEBUG_HD == "param") {
+$log_param = "";
 if (@is_array($_REQUEST)) reset($_REQUEST);
 for ($num1 = 0 ; $num1 < count($_REQUEST); $num1++) {
 $var_REQUEST = key($_REQUEST);
+if (is_array($_REQUEST[$var_REQUEST])) $log_param .= "&$var_REQUEST=arr:".substr(implode(",",$_REQUEST[$var_REQUEST]),0,30);
+else $log_param .= "&$var_REQUEST=".substr($_REQUEST[$var_REQUEST],0,30);
 if (!isset($$var_REQUEST)) {
 # nel caso fosse settato register_globals = Off
 #$$var_REQUEST = $_REQUEST[$var_REQUEST];
+if (C_DEBUG_HD == "on") {
 error_log("PHP not registered variable in $pag: \$var_pag[".($n_var_pag++ - 6)."] = '$var_REQUEST';");
 echo "\$var_pag[".($n_var_pag - 7)."] = '".htmlspecialchars($var_REQUEST)."';<br>";
+} # fine if (C_DEBUG_HD == "on")
 } # fine (!isset($$var_REQUEST))
 next($_REQUEST);
 } # fine for $num1
-} # fine if (C_DEBUG_HD == "on")
+if (C_DEBUG_HD == "param" and $log_param) error_log("$pag called with: $log_param");
+unset($log_param);
+} # fine if (C_DEBUG_HD == "on" or C_DEBUG_HD == "param")
 unset($n_var_pag);
 
 
 if (defined('C_DATI_PATH') and @is_file(C_DATI_PATH."/tema.php")) include(C_DATI_PATH."/tema.php");
 else {
-unset($tema);
+$tema = array(1 => 'base');
 $trad_ui = 0;
 $parole_sost = 0;
 } # fine else if (@is_file(C_DATI_PATH."/tema.php"))
 
 #@include("./includes/costanti.php");
 #@include(C_DATI_PATH."/costanti.php");
-define('C_PHPR_VERSIONE_NUM',3.06);
-define('C_PHPR_VERSIONE_TXT',"3.0.6");
+define('C_PHPR_VERSIONE_NUM',3.08);
+define('C_PHPR_VERSIONE_TXT',"3.0.8");
 
 if (!isset($nome_utente_phpr)) $nome_utente_phpr = "";
 if (!isset($password_phpr)) $password_phpr = "";
@@ -98,6 +108,10 @@ if (!defined('C_DIFF_ORE')) {
 if (@is_file(C_DATI_PATH."/versione.php")) include(C_DATI_PATH."/versione.php");
 else define('C_DIFF_ORE',0);
 } # fine if (!defined('C_DIFF_ORE'))
+if (function_exists('date_default_timezone_set')) {
+if (defined('C_DIFF_TZ') and C_DIFF_TZ != "" and C_DIFF_ORE == 0) date_default_timezone_set(C_DIFF_TZ);
+elseif (!ini_get('date.timezone')) date_default_timezone_set('UTC');
+} # fine if (function_exists('date_default_timezone_set'))
 $anno_corrente = date("Y",(time() + (C_DIFF_ORE * 3600)));
 if (empty($anno)) {
 if ($id_sessione) $anno = substr($id_sessione,0,4);
@@ -117,7 +131,7 @@ if (isset($vers_hinc)) $vers_hinc = "?v=".C_PHPR_VERSIONE_NUM;
 
 if ($_SERVER['SERVER_NAME']) $HOSTNAME = $_SERVER['SERVER_NAME'];
 elseif ($SERVER_NAME) $HOSTNAME = $SERVER_NAME;
-$HOSTNAME = htmlspecialchars($HOSTNAME);
+$HOSTNAME = htmlspecialchars($HOSTNAME,ENT_COMPAT);
 
 if (isset($_SERVER['HTTP_USER_AGENT']) and (strstr($_SERVER['HTTP_USER_AGENT'],'(iP') or strstr($_SERVER['HTTP_USER_AGENT'],'Android') or strstr($_SERVER['HTTP_USER_AGENT'],'webOS') or strstr($_SERVER['HTTP_USER_AGENT'],'BlackBerry') or strstr($_SERVER['HTTP_USER_AGENT'],'Mobile') or strstr($_SERVER['HTTP_USER_AGENT'],'Opera Mini'))) $mobile_device = 1;
 else $mobile_device = 0;
@@ -220,9 +234,11 @@ if (controlla_anno($anno) != "SI") $anno = "";
 function controlla_num_pos ($num) {
 
 $verificato = "SI";
-if (!strcmp((string) $num,"")) $verificato = "NO";
-$verifica_num = preg_replace("/[0-9]/","",(string) $num);
-if (strcmp((string) $verifica_num,"")) $verificato = "NO";
+if (is_array($num)) $num = "";
+else $num = (string) $num;
+if (!strcmp($num,"")) $verificato = "NO";
+$verifica_num = preg_replace("/[0-9]/","",$num);
+if (strcmp($verifica_num,"")) $verificato = "NO";
 
 return $verificato;
 
@@ -343,8 +359,8 @@ if (!strcmp((string) $decimali,"")) {
 if (!strstr((string) $num,".") or substr(strstr((string) $num,"."),1) == 0) $decimali = 0;
 else $decimali = 2;
 } # fine (!strcmp((string) $decimali,""))
-if ($stile_soldi == "usa") $num = number_format((double) $num,$decimali);
-else $num = number_format((double) $num,$decimali,",",".");
+if ($stile_soldi == "usa") $num = number_format((float) $num,$decimali);
+else $num = number_format((float) $num,$decimali,",",".");
 
 return $num;
 
@@ -387,10 +403,10 @@ if (strcmp((string) $num,"")) {
 $num = str_replace(",",".",$num);
 if (strstr($num,".")) {
 $parti = explode(".",$num);
-if ($parti[1]) {
+if (!empty($parti[1])) {
 if (strlen($parti[1]) > 2) {
 $parti[1] = substr($parti[1],0,2).".".substr($parti[1],2);
-$parti[1] = round((double) $parti[1]);
+$parti[1] = round((float) $parti[1]);
 if (strlen($parti[1]) == 1) $parti[1] = "0".$parti[1];
 elseif ((int) $parti[1] == 100) {
 $parti[0] = (int) $parti[0] + 1;
@@ -398,8 +414,8 @@ $parti[1] = "00";
 } # fine elseif ((int) $parti[1] == 100)
 } # fine if (strlen($parti[1]) > 2)
 $num = $parti[0].".".$parti[1];
-settype($num,'double');
-} # fine if ($parti[1])
+settype($num,'float');
+} # fine if (!empty($parti[1]))
 else $num = (int) $parti[0];
 } # fine if (strstr($num,"."))
 else $num = (int) $num;
@@ -450,7 +466,8 @@ $versione = esegui_query("select * from $tableversioni where $idversioni = '2'")
 if (numlin_query($versione)) {
 $versione = risul_query($versione,0,$num_versione);
 $versione = $versione + 1;
-if ($versione >= 99999990) $versione = 100;
+# mariadb per tipo float non scrive numeri maggiori di 1000000
+if ($versione >= 1000000) $versione = 100;
 esegui_query("update $tableversioni set $num_versione = '$versione' where $idversioni = '2'");
 } # fine if (numlin_query($versione))
 else {
@@ -517,9 +534,14 @@ $scadenza = trim(@implode("",@file("./".C_FILE_SCADENZA_ACCOUNT)));
 $adesso = date("Ymd")."000000";
 if (!$scadenza or $scadenza < $adesso) {
 $disattivato = 1;
+$pag = "";
+$titolo = "HotelDruid expired account";
+$lingua_mex = "en";
+include("./includes/head.php");
 if (defined("C_HTML_PRE_LOGIN") and C_HTML_PRE_LOGIN != "") echo C_HTML_PRE_LOGIN;
 echo "Expired account.<br>";
 if (defined("C_HTML_POST_LOGIN") and C_HTML_POST_LOGIN != "") echo C_HTML_POST_LOGIN;
+include("./includes/foot.php");
 } # fine (!$scadenza or $scadenza < $adesso)
 elseif (defined('C_HTML_POST_LOGIN') and C_HTML_POST_LOGIN != "") {
 $giorni_avviso = 3;
@@ -529,16 +551,30 @@ if ($scadenza < $limite_giorni_avviso) $avviso_giorni_scadenza = 1;
 } # fine (defined("C_FILE_SCADENZA_ACCOUNT") and C_FILE_SCADENZA_ACCOUNT != "")
 if (!isset($disattivato)) {
 
-global $lingua_mex,$tema,$pag,$ILIKE,$LIKE,$DATETIME,$nome_utente_login,$PHPR_LOG,$cookie_sess;
+global $lingua_mex,$locale_mex,$tema,$pag,$ILIKE,$LIKE,$DATETIME,$nome_utente_login,$PHPR_LOG,$cookie_sess;
 @include(C_DATI_PATH."/lingua.php");
 #@include_once(C_DATI_PATH."/versione.php");
-if (!empty($lingua[1]) and @is_dir("./includes/lang/".$lingua[1])) $lingua_mex = $lingua[1];
+$locale_mex = "";
+if (!empty($lingua[1])) {
+$locale_mex = substr(strstr($lingua[1],"-"),1);
+$lingua_mex = str_replace("-$locale_mex","",$lingua[1]);
+if (!$lingua_mex or !@is_dir("./includes/lang/$lingua_mex")) $lingua_mex = "ita";
+elseif ($locale_mex and !@is_dir("./includes/lang/$lingua_mex/locales/$locale_mex")) $locale_mex = "";
+} # fine if (!empty($lingua[1]))
 else $lingua_mex = "ita";
 $nome_utente_login = "";
 
 
 if (!is_file(C_DATI_PATH."/abilita_login")) {
-if ($pag == "inizio.php" or $pag == "creadb.php" or $pag == "aggiorna.php" or @is_file(C_DATI_PATH."/selectperiodi$anno.1.php")) $id_utente = 1;
+if ($pag == "inizio.php" or $pag == "creadb.php" or $pag == "aggiorna.php" or @is_file(C_DATI_PATH."/selectperiodi$anno.1.php")) {
+$id_utente = 1;
+if (isset($_SERVER['HTTP_REFERER']) and isset($_SERVER['SERVER_NAME'])) {
+if ((!empty($_SERVER['HTTPS']) and $_SERVER['HTTPS'] != 'off') or (isset($_SERVER['SERVER_PORT']) and $_SERVER['SERVER_PORT'] == "443")) $url_dom = "https://".$_SERVER['SERVER_NAME'];
+else $url_dom = "http://".$_SERVER['SERVER_NAME'];
+$url_ref = substr($_SERVER['HTTP_REFERER'],0,(strlen($url_dom) + 1));
+if ($url_ref != $url_dom."/" and $url_ref != $url_dom.":") $id_utente = "";
+} # fine if (isset($_SERVER['HTTP_REFERER']) and isset($_SERVER['SERVER_NAME']))
+} # fine if ($pag == "inizio.php" or $pag == "creadb.php" or $pag == "aggiorna.php" or...
 else echo "<br>The requested year does not exist.<br><br><a href=\"./inizio.php\">Go back</a><br>";
 } # fine if (!is_file(C_DATI_PATH."/abilita_login"))
 
@@ -634,12 +670,12 @@ $id_utente = risul_query($utente,0,'idutenti');
 $id_sessione = crea_id_sessione($anno,$tableversioni);
 $ultimo_accesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 global $_SERVER,$REMOTE_ADDR,$REMOTE_PORT,$HTTP_USER_AGENT,$test_cookie;
-if ($_SERVER['REMOTE_ADDR']) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
-$REMOTE_ADDR = aggslashdb($REMOTE_ADDR);
-if ($_SERVER['REMOTE_PORT']) $REMOTE_PORT = $_SERVER['REMOTE_PORT'];
-$REMOTE_PORT = aggslashdb($REMOTE_PORT);
-if ($_SERVER['HTTP_USER_AGENT']) $HTTP_USER_AGENT = $_SERVER['HTTP_USER_AGENT'];
-$HTTP_USER_AGENT = aggslashdb($HTTP_USER_AGENT);
+if (!empty($_SERVER['REMOTE_ADDR'])) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
+$REMOTE_ADDR = aggslashdb(fixstr($REMOTE_ADDR));
+if (!empty($_SERVER['REMOTE_PORT'])) $REMOTE_PORT = $_SERVER['REMOTE_PORT'];
+$REMOTE_PORT = aggslashdb(fixstr($REMOTE_PORT));
+if (!empty($_SERVER['HTTP_USER_AGENT'])) $HTTP_USER_AGENT = $_SERVER['HTTP_USER_AGENT'];
+$HTTP_USER_AGENT = aggslashdb(fixstr($HTTP_USER_AGENT));
 if ((isset($_SERVER['HTTPS']) and $_SERVER['HTTPS'] == "on") or (isset($_SERVER['SERVER_PORT']) and $_SERVER['SERVER_PORT'] == "443")) $tipo_conn = "HTTPS";
 else $tipo_conn = "HTTP";
 if (C_USA_COOKIES) {
@@ -699,12 +735,15 @@ $tabelle_lock = lock_tabelle($tabelle_lock);
 $limite_sessioni_vecchie = date("Y-m-d H:i:s",(time() - (C_MIN_SESSIONE * 60) + (C_DIFF_ORE * 3600)));
 esegui_query("delete from $tablesessioni where ultimo_accesso <= '$limite_sessioni_vecchie'");
 global $_SERVER,$REMOTE_ADDR,$REMOTE_PORT,$HTTP_USER_AGENT;
-if ($_SERVER['REMOTE_ADDR']) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
-$REMOTE_ADDR = aggslashdb($REMOTE_ADDR);
-if ($_SERVER['REMOTE_PORT']) $REMOTE_PORT = $_SERVER['REMOTE_PORT'];
-$REMOTE_PORT = aggslashdb($REMOTE_PORT);
-if ($_SERVER['HTTP_USER_AGENT']) $HTTP_USER_AGENT = $_SERVER['HTTP_USER_AGENT'];
-$HTTP_USER_AGENT = aggslashdb($HTTP_USER_AGENT);
+if (!empty($_SERVER['REMOTE_ADDR'])) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
+if (isset($REMOTE_ADDR)) $REMOTE_ADDR = aggslashdb($REMOTE_ADDR);
+else $REMOTE_ADDR = "";
+if (!empty($_SERVER['REMOTE_PORT'])) $REMOTE_PORT = $_SERVER['REMOTE_PORT'];
+if (isset($REMOTE_PORT)) $REMOTE_PORT = aggslashdb($REMOTE_PORT);
+else $REMOTE_PORT = "";
+if (!empty($_SERVER['HTTP_USER_AGENT'])) $HTTP_USER_AGENT = $_SERVER['HTTP_USER_AGENT'];
+if (isset($HTTP_USER_AGENT)) $HTTP_USER_AGENT = aggslashdb($HTTP_USER_AGENT);
+else $HTTP_USER_AGENT = "";
 $ultimo_accesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 $sessione = esegui_query("select * from $tablesessioni where idsessioni = '$id_sessione'");
 if (numlin_query($sessione) == 1) {
@@ -775,29 +814,19 @@ if ($pag == "aggiorna.php") $action = "aggiorna.php";
 else {
 if (!isset($_SERVER['HTTP_REFERER']) or !isset($_SERVER['SERVER_NAME'])) $pag = "";
 else {
-if (($_SERVER['HTTPS'] and $_SERVER['HTTPS'] != 'off') or $_SERVER['SERVER_PORT'] == "443") $url_dom = "https://".$_SERVER['SERVER_NAME']."/";
+if ((!empty($_SERVER['HTTPS']) and $_SERVER['HTTPS'] != 'off') or (isset($_SERVER['SERVER_PORT']) and $_SERVER['SERVER_PORT'] == "443")) $url_dom = "https://".$_SERVER['SERVER_NAME']."/";
 else $url_dom = "http://".$_SERVER['SERVER_NAME']."/";
 if (substr($_SERVER['HTTP_REFERER'],0,strlen($url_dom)) != $url_dom) $pag = "";
 } # fine else if (!isset($_SERVER['HTTP_REFERER']) or !isset($_SERVER['SERVER_NAME']))
-if ((@is_array($_POST) or @is_array($_GET)) and $pag) {
+if (isset($_REQUEST) and is_array($_REQUEST) and $pag) {
 $action = $pag;
-if (@is_array($_POST)) {
-reset($_POST);
-for ($num1 = 0 ; $num1 < count($_POST); $num1++) {
-$key = key($_POST);
-if ($key != "id_sessione" and $key != "nome_utente_phpr" and $key != "password_phpr" and $key != "pass_cc" and $key != "logout" and $key != "test_cookie") $input_var_passate .= "<input type=\"hidden\" name=\"$key\" value=\"".htmlspecialchars(strip_magic_slashs(current($_POST)))."\">";
-next($_POST);
+reset($_REQUEST);
+for ($num1 = 0 ; $num1 < count($_REQUEST); $num1++) {
+$key = key($_REQUEST);
+if (is_string($key) and $key != "id_sessione" and $key != "nome_utente_phpr" and $key != "password_phpr" and $key != "pass_cc" and $key != "logout" and $key != "test_cookie") $input_var_passate .= "<input type=\"hidden\" name=\"$key\" value=\"".htmlspecialchars(strip_magic_slashs(current($_REQUEST)))."\">";
+next($_REQUEST);
 } # fine for $num1
-} # fine if (@is_array($_POST))
-if (@is_array($_GET)) {
-reset($_GET);
-for ($num1 = 0 ; $num1 < count($_GET); $num1++) {
-$key = key($_GET);
-if ($key != "id_sessione" and $key != "nome_utente_phpr" and $key != "password_phpr" and $key != "pass_cc" and $key != "logout" and $key != "test_cookie") $input_var_passate .= "<input type=\"hidden\" name=\"$key\" value=\"".htmlspecialchars(strip_magic_slashs(current($_GET)))."\">";
-next($_GET);
-} # fine for $num1
-} # fine if (@is_array($_GET))
-} # fine if ((@is_array($_POST) or @is_array($_GET)) and $pag)
+} # fine if (isset($_REQUEST) and is_array($_REQUEST) and $pag)
 else $action = "inizio.php";
 } # fine else if ($pag == "aggiorna.php")
 if (C_USA_COOKIES) {
@@ -1094,6 +1123,7 @@ if ($blank_selected) $date_selected = "";
 $num_periodi_date = count($d_increment);
 if (($num_periodi_date > 1 or (isset($d_increment[0]) and $d_increment[0] > 1)) and $date_selected) {
 for ($num1 = 0 ; $num1 < $num_periodi_date ; $num1++) {
+$data_prec = "";
 for ($num2 = 0 ; $num2 < $n_dates_menu[$num1] ; $num2++) {
 $data_corr = date("Y-m-d",mktime(0,0,0,($m_ini_menu[$num1] + 1),($d_ini_menu[$num1] + ($num2 * $d_increment[$num1])),$y_ini_menu[$num1]));
 if ($data_corr == $date_selected) break;
@@ -1168,7 +1198,7 @@ function http_keep_alive ($car=" ") {
 
 echo $car;
 flush();
-if (function_exists('ob_flush')) ob_flush();
+if (function_exists('ob_flush')) @ob_flush();
 
 } # fine function http_keep_alive
 
@@ -1190,11 +1220,21 @@ return str_replace("\"","",str_replace(">","",str_replace("<","",$origine)));
 
 
 if (function_exists('mb_strcut')) {
-function par_taglia (&$str,$ini,$fine) { return mb_strcut($str,$ini,$fine); }
+# Taglia dopo un certo numero di byte (quindi può avere meno lettere di $fine - $ini). Per tagliare dopo numero di lettere usare tronca_testo() in funzioni_testo.php
+function par_taglia ($str,$ini,$fine) { return mb_strcut($str,$ini,$fine); }
 } # fine if (function_exists('mb_strcut'))
 else {
-function par_taglia (&$str,$ini,$fine) { return substr($str,$ini,$fine); }
-} # fine else if (function_exists(''))
+function par_taglia ($str,$ini,$fine) { return substr($str,$ini,$fine); }
+} # fine else if (function_exists('mb_strcut'))
+
+
+
+if (function_exists('htmlspecialchars_decode')) {
+function html_decod ($str) { return htmlspecialchars_decode((string) $str,ENT_QUOTES); }
+} # fine if (function_exists('htmlspecialchars_decode'))
+else {
+function html_decod ($str) { return str_replace("&amp;","&",str_replace("&quot;","\"",str_replace("&apos;","'",str_replace("&#039;","'",str_replace("&lt;","<",str_replace("&gt;",">",(string) $str)))))); }
+} # fine else if (function_exists('htmlspecialchars_decode'))
 
 
 
