@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2025 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -47,21 +47,29 @@ return $str;
 
 
 
-function inserisci_dati_cliente (&$cognome,&$nome,$soprannome,$titolo_cli,$sesso,$mesenascita,$giornonascita,$annonascita,&$nazionenascita,&$cittanascita,&$regionenascita,$documento,$tipodoc,$mesescaddoc,$giornoscaddoc,$annoscaddoc,&$cittadoc,&$regionedoc,&$nazionedoc,&$nazionalita,&$lingua_cli,&$nazione,&$citta,&$regione,&$via,$nomevia,$numcivico,$cap,$telefono,$telefono2,$telefono3,$fax,$email,$email2,$email_cert,$cod_fiscale,$partita_iva,$max_num_ordine,$id_utente_ins,$attiva_prefisso_clienti,$prefisso_clienti,$idclienti="",$valida="",$campi_pers_vett="") {
+function inserisci_dati_cliente (&$cognome,&$cognome2,&$nome,$soprannome,$titolo_cli,$sesso,$mesenascita,$giornonascita,$annonascita,&$nazionenascita,&$cittanascita,&$regionenascita,$documento,$tipodoc,$mesescaddoc,$giornoscaddoc,$annoscaddoc,&$cittadoc,&$regionedoc,&$nazionedoc,&$nazionalita,&$lingua_cli,&$nazione,&$citta,&$regione,&$via,$nomevia,$numcivico,$cap,$telefono,$telefono2,$telefono3,$fax,$email,$email2,$email_cert,$cod_fiscale,$partita_iva,$max_num_ordine,$id_utente_ins,$attiva_prefisso_clienti,$prefisso_clienti,$idclienti="",$valida="",$campi_pers_vett="") {
 global $lingua_mex,$HOSTNAME,$id_utente,$PHPR_TAB_PRE;
 $tableclienti = $PHPR_TAB_PRE."clienti";
 $tablerelclienti = $PHPR_TAB_PRE."relclienti";
 $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 
+$secondo_cognome = esegui_query("select idpersonalizza from $tablepersonalizza where idpersonalizza = 'sec_cogn' and idutente = '$id_utente' ");
+if (numlin_query($secondo_cognome)) $secondo_cognome = 1;
+else $secondo_cognome = 0;
 if (isset($campi_pers_vett) and is_array($campi_pers_vett) and !empty($campi_pers_vett['num'])) $num_campi_pers = $campi_pers_vett['num'];
 else $num_campi_pers = 0;
-$stile_nomi = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'stile_nomi' and idutente = '$id_utente'");
+if (C_VERSIONE_ATTUALE < 3.06) $stile_nomi = "ma1or";
+else {
+$stile_nomi = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'stile_nomi' and idutente = '$id_utente' ");
+if (!numlin_query($stile_nomi)) $stile_nomi = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'stile_nomi' and idutente = '1' ");
 $stile_nomi = risul_query($stile_nomi,0,'valpersonalizza');
+} # fine else if (C_VERSIONE_ATTUALE < 3.06)
 
 
 if ($valida != "NO") {
 if (@get_magic_quotes_gpc()) {
 $cognome = stripslashes($cognome);
+$cognome2 = stripslashes($cognome2);
 $nome = stripslashes($nome);
 $soprannome = stripslashes($soprannome);
 $titolo_cli = stripslashes($titolo_cli);
@@ -91,35 +99,36 @@ $cod_fiscale = stripslashes($cod_fiscale);
 $partita_iva = stripslashes($partita_iva);
 for ($num1 = 0 ; $num1 < $num_campi_pers ; $num1++) $campi_pers_vett['val'][$num1] = stripslashes($campi_pers_vett['val'][$num1]);
 } # fine if (@get_magic_quotes_gpc())
-$cognome = htmlspecialchars($cognome);
-$nome = htmlspecialchars((string) $nome);
-$soprannome = htmlspecialchars((string) $soprannome);
-$titolo_cli = htmlspecialchars((string) $titolo_cli);
-$documento = htmlspecialchars((string) $documento);
-$tipodoc = htmlspecialchars((string) $tipodoc);
-$cittadoc = htmlspecialchars((string) $cittadoc);
-$regionedoc = htmlspecialchars((string) $regionedoc);
-$nazionedoc = htmlspecialchars((string) $nazionedoc);
-$cittanascita = htmlspecialchars((string) $cittanascita);
-$regionenascita = htmlspecialchars((string) $regionenascita);
-$nazionenascita = htmlspecialchars((string) $nazionenascita);
-$nazionalita = htmlspecialchars((string) $nazionalita);
-$nazione = htmlspecialchars((string) $nazione);
-$regione = htmlspecialchars((string) $regione);
-$citta = htmlspecialchars((string) $citta);
-$nomevia = htmlspecialchars((string) $nomevia);
-$numcivico = htmlspecialchars((string) $numcivico);
-$cap = htmlspecialchars((string) $cap);
-$telefono = htmlspecialchars((string) $telefono);
-$telefono2 = htmlspecialchars((string) $telefono2);
-$telefono3 = htmlspecialchars((string) $telefono3);
-$fax = htmlspecialchars((string) $fax);
-$email = htmlspecialchars((string) $email);
-$email2 = htmlspecialchars((string) $email2);
-$email_cert = htmlspecialchars((string) $email_cert);
-$cod_fiscale = htmlspecialchars((string) $cod_fiscale);
-$partita_iva = htmlspecialchars((string) $partita_iva);
-for ($num1 = 0 ; $num1 < $num_campi_pers ; $num1++) $campi_pers_vett['val'][$num1] = htmlspecialchars((string) $campi_pers_vett['val'][$num1]);
+$cognome = htmlspecialchars($cognome,ENT_COMPAT);
+$cognome2 = htmlspecialchars((string) $cognome2,ENT_COMPAT);
+$nome = htmlspecialchars((string) $nome,ENT_COMPAT);
+$soprannome = htmlspecialchars((string) $soprannome,ENT_COMPAT);
+$titolo_cli = htmlspecialchars((string) $titolo_cli,ENT_COMPAT);
+$documento = htmlspecialchars((string) $documento,ENT_COMPAT);
+$tipodoc = htmlspecialchars((string) $tipodoc,ENT_COMPAT);
+$cittadoc = htmlspecialchars((string) $cittadoc,ENT_COMPAT);
+$regionedoc = htmlspecialchars((string) $regionedoc,ENT_COMPAT);
+$nazionedoc = htmlspecialchars((string) $nazionedoc,ENT_COMPAT);
+$cittanascita = htmlspecialchars((string) $cittanascita,ENT_COMPAT);
+$regionenascita = htmlspecialchars((string) $regionenascita,ENT_COMPAT);
+$nazionenascita = htmlspecialchars((string) $nazionenascita,ENT_COMPAT);
+$nazionalita = htmlspecialchars((string) $nazionalita,ENT_COMPAT);
+$nazione = htmlspecialchars((string) $nazione,ENT_COMPAT);
+$regione = htmlspecialchars((string) $regione,ENT_COMPAT);
+$citta = htmlspecialchars((string) $citta,ENT_COMPAT);
+$nomevia = htmlspecialchars((string) $nomevia,ENT_COMPAT);
+$numcivico = htmlspecialchars((string) $numcivico,ENT_COMPAT);
+$cap = htmlspecialchars((string) $cap,ENT_COMPAT);
+$telefono = htmlspecialchars((string) $telefono,ENT_COMPAT);
+$telefono2 = htmlspecialchars((string) $telefono2,ENT_COMPAT);
+$telefono3 = htmlspecialchars((string) $telefono3,ENT_COMPAT);
+$fax = htmlspecialchars((string) $fax,ENT_COMPAT);
+$email = htmlspecialchars((string) $email,ENT_COMPAT);
+$email2 = htmlspecialchars((string) $email2,ENT_COMPAT);
+$email_cert = htmlspecialchars((string) $email_cert,ENT_COMPAT);
+$cod_fiscale = htmlspecialchars((string) $cod_fiscale,ENT_COMPAT);
+$partita_iva = htmlspecialchars((string) $partita_iva,ENT_COMPAT);
+for ($num1 = 0 ; $num1 < $num_campi_pers ; $num1++) $campi_pers_vett['val'][$num1] = htmlspecialchars((string) $campi_pers_vett['val'][$num1],ENT_COMPAT);
 } # fine if ($valida != "NO")
 
 if (!$idclienti) {
@@ -140,7 +149,12 @@ $cognome_maius = trim(par_maius($cognome,$stile_nomi));
 if ($attiva_prefisso_clienti == "p") $cognome_maius = $prefisso_clienti.$cognome_maius;
 if ($attiva_prefisso_clienti == "s") $cognome_maius = $cognome_maius.$prefisso_clienti;
 esegui_query("update $tableclienti set cognome = '".aggslashdb(par_taglia($cognome_maius,0,70))."' where idclienti = '$idclienti' ");
+if (!$secondo_cognome) esegui_query("update $tableclienti set cognome2 = NULL where idclienti = '$idclienti' ");
 } # fine elseif ($cognome)
+if ($secondo_cognome and $cognome2) {
+$cognome2_maius = trim(par_maius($cognome2,$stile_nomi));
+esegui_query("update $tableclienti set cognome2 = '".aggslashdb(par_taglia($cognome2_maius,0,70))."' where idclienti = '$idclienti' ");
+} # fine if ($secondo_cognome and $cognome2)
 if ($nome) {
 $nome_maius = trim(par_maius($nome,$stile_nomi));
 esegui_query("update $tableclienti set nome = '".aggslashdb(par_taglia($nome_maius,0,70))."' where idclienti = '$idclienti' ");
@@ -289,8 +303,8 @@ return $idclienti;
 
 
 
-function mostra_dati_cliente (&$dati_cliente,&$dcognome,&$dnome,&$dsoprannome,&$dtitolo_cli,&$dsesso,&$ddatanascita,&$ddatanascita_f,&$dnazionenascita,&$dcittanascita,&$dregionenascita,&$ddocumento,&$dscadenzadoc,&$dscadenzadoc_f,&$dtipodoc,&$dnazionedoc,&$dregionedoc,&$dcittadoc,&$dnazionalita,&$dlingua_cli,&$dnazione,&$dregione,&$dcitta,&$dvia,&$dnumcivico,&$dtelefono,&$dtelefono2,&$dtelefono3,&$dfax,&$dcap,&$demail,&$demail2,&$demail_cert,&$dcod_fiscale,&$dpartita_iva,$mostra_num="",$priv_ins_clienti="",$silenzio="",$mostra_commento="") {
-global $pag,$id_utente,$PHPR_TAB_PRE,$stile_data;
+function mostra_dati_cliente (&$dati_cliente,&$dcognome,&$dcognome2,&$dnome,&$dsoprannome,&$dtitolo_cli,&$dsesso,&$ddatanascita,&$ddatanascita_f,&$dnazionenascita,&$dcittanascita,&$dregionenascita,&$ddocumento,&$dscadenzadoc,&$dscadenzadoc_f,&$dtipodoc,&$dnazionedoc,&$dregionedoc,&$dcittadoc,&$dnazionalita,&$dlingua_cli,&$dnazione,&$dregione,&$dcitta,&$dvia,&$dnumcivico,&$dtelefono,&$dtelefono2,&$dtelefono3,&$dfax,&$dcap,&$demail,&$demail2,&$demail_cert,&$dcod_fiscale,&$dpartita_iva,$mostra_num="",$priv_ins_clienti="",$silenzio="",$mostra_commento="") {
+global $pag,$id_utente,$PHPR_TAB_PRE,$stile_data,$lingua_mex,$locale_mex,$locale;
 
 if ($id_utente == 1 or !$id_utente) {
 $priv_vedi_telefoni = "s";
@@ -307,6 +321,7 @@ $priv_vedi_indirizzo = substr($priv_ins_clienti,4,1);
 
 $didclienti = risul_query($dati_cliente,0,'idclienti');
 $dcognome = risul_query($dati_cliente,0,'cognome');
+$dcognome2 = risul_query($dati_cliente,0,'cognome2');
 $dnome = risul_query($dati_cliente,0,'nome');
 $dsoprannome = risul_query($dati_cliente,0,'soprannome');
 $dtitolo_cli = risul_query($dati_cliente,0,'titolo');
@@ -348,14 +363,25 @@ if ($mostra_commento) $dcommento = risul_query($dati_cliente,0,'commento');
 else $dcommento = "";
 
 if ($dlingua_cli) {
-if ($dlingua_cli == "ita") $d_nome_lingua = "Italiano";
+if ($dlingua_cli == "ita") $d_nome_lingua = "italiano";
 elseif (preg_replace("/[a-z]{2,3}/","",$dlingua_cli) == "") {
 if (@is_file("./includes/lang/$dlingua_cli/l_n")) {
 $d_nome_lingua = file("./includes/lang/$dlingua_cli/l_n");
-$d_nome_lingua = ucfirst(togli_acapo($d_nome_lingua[0]));
+$d_nome_lingua = togli_acapo($d_nome_lingua[0]);
 } # fine if (@is_file("./includes/lang/$dlingua_cli/l_n"))
+if (!isset($locale)) {
+if ($lingua_mex == "ita") include("./includes/locale.php");
+else {
+if ($locale_mex and is_file("./includes/lang/$lingua_mex/locales/$locale_mex/locale.php")) include("./includes/lang/$lingua_mex/locales/$locale_mex/locale.php");
+else include("./includes/lang/$lingua_mex/locale.php");
+} # fine else if ($lingua_mex == "ita")
+} # fine if (!isset($locale))
+if (!empty($locale['language_capitalization'])) {
+if (function_exists('mb_convert_case')) $d_nome_lingua = mb_convert_case($d_nome_lingua,MB_CASE_TITLE,'UTF-8');
+else $d_nome_lingua = ucwords($d_nome_lingua);
+} # fine if (!empty($locale['language_capitalization']))
 } # fine elseif (preg_replace("/[a-z]{2,3}/","",$dlingua_cli) == "")
-if (!$d_nome_lingua) $dlingua_cli = "";
+if (empty($d_nome_lingua)) $dlingua_cli = "";
 } # fine if ($dlingua_cli)
 
 $output = "";
@@ -366,11 +392,13 @@ if ($dsesso == "f") $O = "a";
 #if ($dsesso2 == "f") $O2 = "a";
 if ($mostra_num == "SI") {
 $output .= "$didclienti. <em>$dcognome</em> ";
+if ($dcognome2) $output .= "<em>$dcognome2</em> ";
 if ($dnome) $output .= "<em>$dnome</em> ";
 } # fine if ($mostra_num == "SI")
 else {
 if ($dtitolo_cli) $output .= "$dtitolo_cli ";
 $output .= "<b>$dcognome</b>";
+if ($dcognome2) $output .= "<b> $dcognome2</b>";
 if ($dnome) $output .= " $dnome";
 if ($dsoprannome) $output .= " ($dsoprannome)";
 } # fine else if ($mostra_num == "SI")
