@@ -58,7 +58,7 @@ trova_rel($rel,$rel_sing,$rel_plur,$tablerel);
 trova_rel($rel_sup,$rel_sup_sing,$rel_sup_plur,$tablerel_sup);
 
 if (@get_magic_quotes_gpc()) $id = stripslashes($id);
-$id = htmlspecialchars($id);
+$id = htmlspecialchars($id,ENT_COMPAT);
 $id_sup = esegui_query("select distinct $tablerel_sup.id$rel_sup_plur from $tablerelutenti inner join $tablerel_sup on $tablerelutenti.id$rel_sup_sing = $tablerel_sup.id$rel_sup_plur where $tablerelutenti.idutente = '$id_ut_sel' and $tablerel_sup.nome_$rel_sup_sing = '".aggslashdb($id)."' ");
 if (numlin_query($id_sup)) $is_id = "= '".risul_query($id_sup,0,"id$rel_sup_plur",$tablerel_sup)."'";
 else $is_id = "is NULL";
@@ -82,12 +82,12 @@ if ($num_rel_utente) {
 echo "<select name=\"$cmp\" id=\"$cmp\">";
 if ($pieno != "SI") echo "<option value=\"\">------</option>";
 for ($num1 = 0 ; $num1 < $num_rel_utente ; $num1++) {
-$rel = htmlspecialchars(str_replace("&amp;","&",str_replace("&#039;","'",(string) risul_query($rel_utente,$num1,"nome_$rel_sing",$tablerel))));
+$rel = htmlspecialchars(str_replace("&amp;","&",str_replace("&#039;","'",(string) risul_query($rel_utente,$num1,"nome_$rel_sing",$tablerel))),ENT_COMPAT);
 echo "<option value=\"$rel\">$rel";
 if ($mostra_cod) {
-$codice = htmlspecialchars((string) risul_query($rel_utente,$num1,"codice_$rel_sing",$tablerel));
-$codice2 = htmlspecialchars((string) risul_query($rel_utente,$num1,"codice2_$rel_sing",$tablerel));
-$codice3 = htmlspecialchars((string) risul_query($rel_utente,$num1,"codice3_$rel_sing",$tablerel));
+$codice = htmlspecialchars((string) risul_query($rel_utente,$num1,"codice_$rel_sing",$tablerel),ENT_COMPAT);
+$codice2 = htmlspecialchars((string) risul_query($rel_utente,$num1,"codice2_$rel_sing",$tablerel),ENT_COMPAT);
+$codice3 = htmlspecialchars((string) risul_query($rel_utente,$num1,"codice3_$rel_sing",$tablerel),ENT_COMPAT);
 if (strcmp($codice,"")) echo " ($codice)";
 if (strcmp($codice2,"")) echo " (".mex("2°",'personalizza.php')." $codice2)";
 if (strcmp($codice3,"")) echo " (".mex("3°",'personalizza.php')." $codice3)";
