@@ -84,7 +84,7 @@ $mittente_email = explode("<",$mittente_email);
 $mittente_email = explode(">",$mittente_email[1]);
 $mittente_email = $mittente_email[0];
 } # fine if (strstr($mittente_email,"<"))
-if (!$dati_allegato) $dati_allegato = array('num' => 0);
+if (!$dati_allegato) $dati_allegato = array('num' => 0, 'num_iim' => 0);
 
 if (empty($dati_manda_email['modo'])) {
 if ($tablepersonalizza) {
@@ -107,13 +107,13 @@ else $dati_manda_email['percorso_phpmailer'] = "";
 if ($dati_manda_email['percorso_phpmailer'] and is_file($dati_manda_email['percorso_phpmailer'])) include($dati_manda_email['percorso_phpmailer']);
 } # fine if (!class_exists('PHPMailer\PHPMailer\PHPMailer'))
 
-if (!class_exists('PHPMailer\PHPMailer\PHPMailer')) $dati_manda_email['modo'] == "locale";
+if (!class_exists('PHPMailer\PHPMailer\PHPMailer')) $dati_manda_email['modo'] = "locale";
 else {
 if (empty($dati_manda_email['server'])) {
-if (!$tablepersonalizza) $dati_manda_email['modo'] == "locale";
+if (!$tablepersonalizza) $dati_manda_email['modo'] = "locale";
 else {
 $server_smtp = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'server_smtp' and idutente = '1' ");
-if (!numlin_query($server_smtp)) $dati_manda_email['modo'] == "locale";
+if (!numlin_query($server_smtp)) $dati_manda_email['modo'] = "locale";
 else {
 $server_smtp = explode("#@#",(string) risul_query($server_smtp,0,'valpersonalizza'));
 $dati_manda_email['server'] = $server_smtp[0];
@@ -165,14 +165,17 @@ if ($bcc_mittente == "SI") $mail->addBCC($mittente_email);
 if ($bcc_indirizzo) $mail->addBCC($bcc_indirizzo);
 $mail->Subject = $oggetto_email;
 # non usare MsgHTML e AltBody se si usa Body
-if ($cont_type == "text/plain") $mail->Body = $testo_email;
+if ($cont_type == "multipart/alternative") $mail->msgHTML($testo_email);
 else {
-$mail->msgHTML($testo_email);
+$mail->Body = $testo_email;
+if ($cont_type == "text/plain") $mail->IsHTML(false);
+else $mail->IsHTML(true);
 #$mail->AltBody = $testo_email;
-} # fine else if ($cont_type != "text/plain")
+} # fine else if ($cont_type == "multipart/alternative")
 for ($num1 = 1 ; $num1 <= $dati_allegato['num'] ; $num1++) {
 if ($allega[$num1] == "SI") $mail->AddStringAttachment(base64_decode(str_replace("\r\n","",$dati_allegato[$num1]['valo'])),$dati_allegato[$num1]['nome'],'base64',$dati_allegato[$num1]['tipo']);
 } # fine for $num1
+for ($num1 = 1 ; $num1 <= $dati_allegato['num_iim'] ; $num1++) $mail->addStringEmbeddedImage(base64_decode(str_replace("\r\n","",$dati_allegato['iim'][$num1]['valo'])),$dati_allegato['iim'][$num1]['cid'],$dati_allegato['iim'][$num1]['nome'],'base64',$dati_allegato['iim'][$num1]['tipo']);
 
 if (!$mail->send()) $inviato['err'] = $mail->ErrorInfo;
 else $inviato['ok'] = 1;
@@ -196,7 +199,7 @@ $email_oggi = esegui_query("select numero from $tablecache where tipo = 'mail_in
 if (numlin_query($email_oggi)) $email_oggi = risul_query($email_oggi,0,'numero');
 else $email_oggi = 0;
 if (isset($dati_manda_email['num_app'])) {
-$max_email = floor((double) C_MASSIMO_NUM_EMAIL_GIORNALIERE / 10);
+$max_email = floor((float) C_MASSIMO_NUM_EMAIL_GIORNALIERE / 10);
 $max_email = C_MASSIMO_NUM_EMAIL_GIORNALIERE + ($max_email * $dati_manda_email['num_app']);
 } # fine if (isset($dati_manda_email['num_app']))
 else $max_email = C_MASSIMO_NUM_EMAIL_GIORNALIERE;
@@ -233,31 +236,103 @@ default: $mailh_nl = "\n"; break;
 } # fine switch (strtoupper(substr(PHP_OS,0,3)))
 } # fine else if (function_exists('version_compare') and version_compare(PHP_VERSION, '8.0.0', '>='))
 $mailb_nl = $mailh_nl;
+$num_boundary = 1;
 if ($nome_mittente and !$reply_to) $headers = "From: \"".str_replace('"','',$nome_mittente)."\" <$mittente_email>$mailh_nl";
 else $headers = "From: <$mittente_email>$mailh_nl";
 if ($reply_to) {
 if ($nome_mittente) $headers .= "Reply-To: \"".str_replace('"','',$nome_mittente)."\" <$reply_to>$mailh_nl";
 else $headers .= "Reply-To: <$reply_to>$mailh_nl";
-} # fine ($reply_to)
+} # fine if ($reply_to)
 if ($bcc_mittente == "SI") $headers .= "Bcc: $mittente_email$mailh_nl";
 if ($bcc_indirizzo) $headers .= "Bcc: $bcc_indirizzo$mailh_nl";
-$testo_email = chunk_split(base64_encode($testo_email));
-$allegato_presente = 0;
-for ($num1 = 1 ; $num1 <= $dati_allegato['num'] ; $num1++) if ($allega[$num1] == "SI") $allegato_presente = 1;
-if ($allegato_presente) {
-$boundary = "--".md5(uniqid(rand()));
-$headers .= "MIME-Version: 1.0$mailh_nl";
-$headers .= "Content-Type: multipart/mixed;$mailh_nl";
-$headers .= " boundary=\"$boundary\"$mailh_nl";
 #$headers .= "X-Sender: $mittente_email$mailh_nl";
 #$headers .= "X-Mailer: PHP$mailh_nl";
 #$headers .= "X-Priority: 3$mailh_nl";
 #$headers .= "Return-Path: $mittente_email$mailh_nl";
-$testo_email = "This is a multi-part message in MIME format.$mailb_nl--$boundary$mailb_nl"."Content-type: $cont_type; charset=utf-8$mailb_nl"."Content-Transfer-Encoding: base64$mailb_nl$mailb_nl$testo_email";
+if ($cont_type == "multipart/alternative") {
+$testo_plain = strip_tags($testo_email,"<br><p>");
+$testo_plain = str_replace("<BR>","<br>",$testo_plain);
+$testo_plain = str_replace("<br>\r\n",$mailb_nl,$testo_plain);
+$testo_plain = str_replace("<br>\r",$mailb_nl,$testo_plain);
+$testo_plain = str_replace("<br>\n",$mailb_nl,$testo_plain);
+$testo_plain = str_replace("<br>",$mailb_nl,$testo_plain);
+$testo_plain = chunk_split(base64_encode($testo_plain));
+if (substr($testo_plain,-1) != $mailb_nl and substr($testo_plain,-2) != $mailb_nl) $testo_plain .= $mailb_nl;
+} # fine if ($cont_type == "multipart/alternative")
+$testo_email = chunk_split(base64_encode($testo_email));
+$allegato_presente = 0;
+for ($num1 = 1 ; $num1 <= $dati_allegato['num'] ; $num1++) if ($allega[$num1] == "SI") $allegato_presente = 1;
+if ($allegato_presente or $dati_allegato['num_iim'] or $cont_type == "multipart/alternative") {
+$boundary = "b$num_boundary=_".crea_val_casuale(22);
+$num_boundary++;
+$boundary_iim = "";
+$boundary_alt = "";
+$cont_type_char_enc = "$cont_type; charset=utf-8$mailb_nl"."Content-Transfer-Encoding: base64";
+$headers .= "MIME-Version: 1.0$mailh_nl";
+if ($allegato_presente) {
+$headers .= "Content-Type: multipart/mixed;$mailh_nl";
+if ($cont_type == "multipart/alternative") {
+$boundary_alt = "b$num_boundary=_".crea_val_casuale(22);
+$num_boundary++;
+$cont_type_char_enc = "$cont_type;$mailb_nl boundary=\"$boundary_alt\"";
+} # fine if ($cont_type == "multipart/alternative")
+if ($dati_allegato['num_iim']) {
+$boundary_iim = "b$num_boundary=_".crea_val_casuale(22);
+$num_boundary++;
+if (!$boundary_alt) $cont_type_char_enc = "multipart/related;$mailb_nl boundary=\"$boundary_iim\"";
+} # fine if ($dati_allegato['num_iim'])
+} # fine if ($allegato_presente)
+else {
+if ($cont_type == "multipart/alternative") {
+$headers .= "Content-Type: multipart/alternative;$mailh_nl";
+$boundary_alt = $boundary;
+$cont_type_char_enc = "Content-Type: text/plain; charset=UTF-8$mailb_nl"."Content-Transfer-Encoding: base64;";
+if ($dati_allegato['num_iim']) {
+$boundary_iim = "b$num_boundary=_".crea_val_casuale(22);
+$num_boundary++;
+} # fine if ($dati_allegato['num_iim'])
+} # fine if ($cont_type == "multipart/alternative")
+else {
+$headers .= "Content-Type: multipart/related;$mailh_nl";
+$boundary_iim = $boundary;
+} # fine else if ($cont_type == "multipart/alternative")
+} # fine else if ($allegato_presente)
+$headers .= " boundary=\"$boundary\"$mailh_nl";
+if ($boundary_iim and $boundary_iim != $boundary) {
+$testo_email = "--$boundary_iim$mailb_nl"."Content-Type: text/html; charset=UTF-8$mailb_nl"."Content-Transfer-Encoding: base64$mailb_nl$mailb_nl$testo_email";
+if (!$allegato_presente or $boundary_alt) $testo_email = "Content-type: multipart/related;$mailb_nl boundary=\"$boundary_iim\"$mailb_nl$mailb_nl$testo_email";
+} # fine if ($boundary_iim and $boundary_iim != $boundary)
+if ($boundary_alt) {
+if (!$boundary_iim) $testo_email = "Content-Type: text/html; charset=UTF-8$mailb_nl"."Content-Transfer-Encoding: base64$mailb_nl$mailb_nl$testo_email";
+if ($boundary_alt == $boundary) $testo_email = "$testo_plain$mailb_nl--$boundary_alt$mailb_nl$testo_email";
+else $testo_email = "--$boundary_alt$mailb_nl"."Content-Type: text/plain; charset=UTF-8$mailb_nl"."Content-Transfer-Encoding: base64$mailb_nl$mailb_nl$testo_plain$mailb_nl--$boundary_alt$mailb_nl$testo_email";
+} # fine if ($boundary_alt)
+$testo_email = "This is a multi-part message in MIME format.$mailb_nl--$boundary$mailb_nl"."Content-type: $cont_type_char_enc$mailb_nl$mailb_nl$testo_email";
+if ($boundary_iim) {
+for ($num1 = 1 ; $num1 <= $dati_allegato['num_iim'] ; $num1++) {
+if (substr($testo_email,-1) == $mailb_nl or substr($testo_email,-2) == $mailb_nl) $testo_email .= "$mailb_nl--$boundary_iim$mailb_nl";
+else $testo_email .= "$mailb_nl$mailb_nl--$boundary_iim$mailb_nl";
+$testo_email .= "Content-Type: ".$dati_allegato['iim'][$num1]['tipo'].";$mailb_nl";
+$testo_email .= " name=\"".$dati_allegato['iim'][$num1]['nome']."\"$mailb_nl";
+$testo_email .= "Content-Transfer-Encoding: base64$mailb_nl";
+$testo_email .= "Content-ID: ".$dati_allegato['iim'][$num1]['cid']."$mailb_nl";
+$testo_email .= "Content-Disposition: inline;$mailb_nl";
+$testo_email .= " filename=\"".$dati_allegato['iim'][$num1]['nome']."\"$mailb_nl$mailb_nl";
+$testo_email .= $dati_allegato['iim'][$num1]['valo'];
+} # fine for $num1
+if ($boundary_iim != $boundary) {
+if (substr($testo_email,-1) == $mailb_nl or substr($testo_email,-2) == $mailb_nl) $testo_email .= "$mailb_nl--$boundary_iim--$mailb_nl";
+else $testo_email .= "$mailb_nl$mailb_nl--$boundary_iim--$mailb_nl$mailb_nl";
+} # fine if ($boundary_iim != $boundary)
+} # fine if ($boundary_iim)
+if ($boundary_alt and $boundary_alt != $boundary) {
+if (substr($testo_email,-1) == $mailb_nl or substr($testo_email,-2) == $mailb_nl) $testo_email .= "$mailb_nl--$boundary_alt--$mailb_nl";
+else $testo_email .= "$mailb_nl$mailb_nl--$boundary_alt--$mailb_nl$mailb_nl";
+} # fine if ($boundary_alt and $boundary_alt != $boundary)
 for ($num1 = 1 ; $num1 <= $dati_allegato['num'] ; $num1++) {
 if ($allega[$num1] == "SI") {
 if (substr($testo_email,-1) == $mailb_nl or substr($testo_email,-2) == $mailb_nl) $testo_email .= "$mailb_nl--$boundary$mailb_nl";
-else $testo_email .= "--$boundary$mailb_nl";
+else $testo_email .= "$mailb_nl$mailb_nl--$boundary$mailb_nl";
 $testo_email .= "Content-Type: ".$dati_allegato[$num1]['tipo'].";$mailb_nl";
 $testo_email .= " name=\"".$dati_allegato[$num1]['nome']."\"$mailb_nl";
 $testo_email .= "Content-Transfer-Encoding: base64$mailb_nl";
@@ -266,18 +341,14 @@ $testo_email .= " filename=\"".$dati_allegato[$num1]['nome']."\"$mailb_nl$mailb_
 $testo_email .= $dati_allegato[$num1]['valo'];
 } # fine if ($allega[$num1] == "SI")
 } # fine for $num1
-if (substr($testo_email,-1) == $mailb_nl or substr($testo_email,-2) == $mailb_nl) $testo_email .= "--$boundary--";
-else $testo_email .= "$mailb_nl--$boundary--";
-} # fine if ($allegato_presente)
+if (substr($testo_email,-1) == $mailb_nl or substr($testo_email,-2) == $mailb_nl) $testo_email .= "$mailb_nl--$boundary--";
+else $testo_email .= "$mailb_nl$mailb_nl--$boundary--";
+} # fine if ($allegato_presente or $dati_allegato['num_iim'] or...
 else {
 if ($cont_type != "text/plain") $headers .= "MIME-Version: 1.0$mailh_nl";
 $headers .= "Content-type: $cont_type; charset=utf-8$mailh_nl";
 $headers .= "Content-Transfer-Encoding: base64$mailh_nl";
-#$headers .= "X-Sender: $mittente_email$mailh_nl";
-#$headers .= "X-Mailer: PHP$mailh_nl";
-#$headers .= "X-Priority: 3$mailh_nl";
-#$headers .= "Return-Path: $mittente_email$mailh_nl";
-} # fine else if ($allegato_presente)
+} # fine else if ($allegato_presente or $dati_allegato['num_iim'])
 if (function_exists('mb_encode_mimeheader')) {
 $oggetto_email = mb_encode_mimeheader($oggetto_email,'UTF-8','B',$mailh_nl,strlen('Subject: '));
 if ($nome_destinatario) $destinatario_email = "\"".addcslashes(mb_encode_mimeheader($nome_destinatario,"UTF-8","Q"),'"')."\" <$destinatario_email>";
