@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2025 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,7 +23,7 @@
 
 
 
-function inserisci_prenotazione ($inizioperiodo,$fineperiodo,$lista_app,$tipotariffa,$numpersone,$prenota_vicine,$idclienti,$conferma,$pagato,$caparra,$met_paga_caparra,$commissioni,$origine_prenota,$sconto,$giorno_stima_checkin,$ora_stima_checkin,$min_stima_checkin,$commento,&$stato,$anno,$PHPR_TAB_PRE,$ins_passato="",$id_utente_imp="",$id_prenota_imp="",$tariffe_sett_imp="",$ins_costi_agg="",$costo_letto_imposto="NO",$info_per_mod=array('num' => 0),$spezza=0) {
+function inserisci_prenotazione ($inizioperiodo,$fineperiodo,$lista_app,$tipotariffa,$numpersone,$prenota_vicine,$idclienti,$conferma,$pagato,$caparra,$met_paga_caparra,$commissioni,$origine_prenota,$sconto,$giorno_stima_checkin,$ora_stima_checkin,$min_stima_checkin,$commento,&$stato,$anno,$dati_app,$PHPR_TAB_PRE,$ins_passato="",$id_utente_imp="",$id_prenota_imp="",$tariffe_sett_imp="",$ins_costi_agg="",$costo_letto_imposto="NO",$info_per_mod=array('num' => 0),$spezza=0) {
 global $id_utente,$HOSTNAME;
 
 $PHPR_TAB_PRE = aggslashdb($PHPR_TAB_PRE);
@@ -63,6 +63,11 @@ $numappartamenti = numlin_query($appartamenti);
 $id_app_richiesti = 0;
 
 $dati_tariffe = dati_tariffe($tablenometariffe,"","",$tableregole);
+$costi_straordinari = array();
+if (is_array($ins_costi_agg)) {
+if (isset($ins_costi_agg['cs']) and is_array($ins_costi_agg['cs'])) $costi_straordinari = $ins_costi_agg['cs'];
+$ins_costi_agg = fixset($ins_costi_agg['ica']);
+}# fine if (is_array($ins_costi_agg))
 if ($ins_costi_agg or $costo_letto_imposto != "NO") {
 $stato['vincoli_num_persone'] = 1;
 if (!function_exists('dati_costi_agg_ntariffe')) include("./includes/funzioni_costi_agg.php");
@@ -169,27 +174,27 @@ if (!$id_utente_ins) $id_utente_ins = 1;
 
 # se vi è una regola 4 per la tariffa
 $regole3 = esegui_query("select * from $tableregole where tariffa_per_persone = '".aggslashdb($tipotariffa[$n_t])."'");
-if (!$numpersone[$n_t] and numlin_query($regole3) == 1 and risul_query($regole3,0,'iddatainizio')) $numpersone[$n_t] = risul_query($regole3,0,'iddatainizio');
-$numpersone_orig[$n_t] = $numpersone[$n_t];
+if (empty($numpersone[$n_t]) and numlin_query($regole3) == 1 and risul_query($regole3,0,'iddatainizio')) $numpersone[$n_t] = risul_query($regole3,0,'iddatainizio');
+$numpersone_orig[$n_t] = fixset($numpersone[$n_t]);
 if (numlin_query($regole3) == 1 and risul_query($regole3,0,'iddatafine')) {
 $num_pers_min = risul_query($regole3,0,'iddatafine');
-if (!$numpersone[$n_t] or $numpersone[$n_t] < $num_pers_min) {
+if (empty($numpersone[$n_t]) or $numpersone[$n_t] < $num_pers_min) {
 $numpersone[$n_t] = $num_pers_min;
 if ($adatta_num_persone) {
 $numpersone_orig2[$n_t] = $numpersone_orig[$n_t];
 $numpersone_orig[$n_t] = $numpersone[$n_t];
 } # fine if ($adatta_num_persone)
-} # fine if (!$numpersone[$n_t] or $numpersone[$n_t] < $num_pers_min)
+} # fine if (empty($numpersone[$n_t]) or $numpersone[$n_t] < $num_pers_min)
 } # fine if (risul_query($regole3,0,'iddatafine'))
 
-if (!$numpersone[$n_t]) {
+if (empty($numpersone[$n_t])) {
 if ($dati_tariffe[$tipotariffa[$n_t]]['moltiplica'] == "p") {
 $inserire = "NO";
 $mess_errore .= mex("Si deve inserire il numero delle persone per questa tariffa","clienti.php")." ($nometariffa_vedi)";
 if ($num_tipologie > 1) $mess_errore .= "(".mex("tipologia","clienti.php")." $n_t)";
 $mess_errore .= ".<br>";
 } # fine if ($dati_tariffe[$tipotariffa[$n_t]]['moltiplica'] == "p")
-} # fine if (!$numpersone[$n_t])
+} # fine if (empty($numpersone[$n_t]))
 
 } # fine else if ($tariffa_sbagliata == "SI")
 
@@ -261,7 +266,7 @@ $inserire = "NO";
 } # fine else if ($lista_app[$n_t] or ($adatta_num_persone))
 } # fine if ($costo_letto_imposto != "NO" and !empty($costo_letto_imposto[$n_t]['id']) and strcmp((string) $dati_ca[$dati_ca['id'][$costo_letto_imposto[$n_t]['id']]]['appincompatibili'],""))
 
-if ($numpersone[$n_t]) {
+if (!empty($numpersone[$n_t])) {
 if (controlla_num_pos($numpersone[$n_t]) == "NO") {
 $inserire = "NO";
 $mess_errore .= mex("Il numero di persone è sbagliato","clienti.php");
@@ -287,7 +292,7 @@ else {
 $numpersone[$n_t] = $maxoccupanti;
 $app_richiesti_id[$n_t][$idapp] = "SI";
 $posti++;
-} # fine if (!$adatta_num_persone)
+} # fine else if (!$adatta_num_persone)
 } # fine if ($maxoccupanti and $maxoccupanti < $numpersone[$n_t])
 else {
 $app_richiesti_id[$n_t][$idapp] = "SI";
@@ -306,7 +311,7 @@ if ($num_tipologie > 1) $mess_errore .= " (".mex("tipologia","clienti.php")." $n
 $mess_errore .= ".<br>";
 $inserire = "NO";
 } # fine if ($posti == 0 or...
-} # fine if ($numpersone[$n_t])
+} # fine if (!empty($numpersone[$n_t]))
 
 $lista_app_richiesti = "";
 if (!$app_richiesti_id[$n_t]) $lista_app_richiesti = ",tutti,,";
@@ -355,7 +360,7 @@ unset($inizio_prenota_id);
 unset($fine_prenota_id);
 unset($app_assegnabili_id);
 unset($prenota_in_app_sett);
-unset($dati_app);
+#unset($dati_app);
 $profondita = array();
 $limiti_var['n_ini'] = $idinizioperiodo_tot;
 $limiti_var['n_fine'] = $idfineperiodo_tot;
@@ -594,7 +599,7 @@ $mess_errore .= ".<br>";
 for ($n_t = 1 ; $n_t <= $num_tipologie ; $n_t++) {
 $mess_prenota .= mex("Prenotazione","prenota.php")." ".mex("dal","prenota.php")." <b>".formatta_data($inizioperiodo_orig[$n_t],$stile_data)."</b> ".mex("al","prenota.php")." <b>".formatta_data($fineperiodo_orig[$n_t],$stile_data)."</b>";
 $mess_prenota .= " ".mex("a nome di","prenota.php")." <b>$cognome</b> ";
-if ($numpersone[$n_t]) $mess_prenota .= " ".mex("per","prenota.php")." <b>".$numpersone[$n_t]."</b> ".mex("persone","prenota.php")."";
+if (!empty($numpersone[$n_t])) $mess_prenota .= " ".mex("per","prenota.php")." <b>".$numpersone[$n_t]."</b> ".mex("persone","prenota.php")."";
 if ($dati_tariffe[$tipotariffa[$n_t]]['nome']) $nometariffa_vedi = $dati_tariffe[$tipotariffa[$n_t]]['nome'];
 else $nometariffa_vedi = mex("tariffa","prenota.php").substr($tipotariffa[$n_t],7);
 $mess_prenota .= ", ".mex("tariffa","prenota.php")." \"$nometariffa_vedi\".<br><br>";
@@ -695,7 +700,7 @@ $mess_errore .= ".<br>";
 for ($n_t = 1 ; $n_t <= $num_tipologie ; $n_t++) {
 $mess_prenota .= mex("Prenotazione","prenota.php")." ".mex("dal","prenota.php")." <b>".formatta_data($inizioperiodo_orig[$n_t],$stile_data)."</b> ".mex("al","prenota.php")." <b>".formatta_data($fineperiodo_orig[$n_t],$stile_data)."</b>";
 $mess_prenota .= " ".mex("a nome di","prenota.php")." <b>$cognome</b> ";
-if ($numpersone[$n_t]) $mess_prenota .= " ".mex("per","prenota.php")." <b>".$numpersone[$n_t]."</b> ".mex("persone","prenota.php")."";
+if (!empty($numpersone[$n_t])) $mess_prenota .= " ".mex("per","prenota.php")." <b>".$numpersone[$n_t]."</b> ".mex("persone","prenota.php")."";
 if ($dati_tariffe[$tipotariffa[$n_t]]['nome']) $nometariffa_vedi = $dati_tariffe[$tipotariffa[$n_t]]['nome'];
 else $nometariffa_vedi = mex("tariffa","prenota.php").substr($tipotariffa[$n_t],7);
 $mess_prenota .= ", ".mex("tariffa","prenota.php")." \"$nometariffa_vedi\".<br><br>";
@@ -722,14 +727,14 @@ $lungh_periodo_tot = $idfineperiodo_vett[$n_to] - $idinizioperiodo_vett[$n_to] +
 $idfineperiodo_vett[$n_to] = $idfine_vett[$n_to][1];
 $fineperiodo_orig[$num_tipologie] = $fineperiodo_orig[$n_to];
 $lungh_periodo_corr = $idfineperiodo_vett[$n_to] - $idinizioperiodo_vett[$n_to] + 1;
-$pagato_t = floor((double) fix_set($pagato[$n_to]) / (double) $lungh_periodo_tot);
-$pagato[$n_to] = ($pagato_t * $lungh_periodo_corr) + ((double) $pagato[$n_to] - ($pagato_t * $lungh_periodo_tot));
-$caparra_t = floor((double) fix_set($caparra[$n_to]) / (double) $lungh_periodo_tot);
-$caparra[$n_to] = ($caparra_t * $lungh_periodo_corr) + ((double) $caparra[$n_to] - ($caparra_t * $lungh_periodo_tot));
-$sconto_t = floor((double) fix_set($sconto[$n_to]) / (double) $lungh_periodo_tot);
-$sconto[$n_to] = ($sconto_t * $lungh_periodo_corr) + ((double) $sconto[$n_to] - ($sconto_t * $lungh_periodo_tot));
-$commissioni_t = floor((double) fix_set($commissioni[$n_to]) / (double) $lungh_periodo_tot);
-$commissioni[$n_to] = ($commissioni_t * $lungh_periodo_corr) + ((double) $commissioni[$n_to] - ($commissioni_t * $lungh_periodo_tot));
+$pagato_t = floor((float) fix_set($pagato[$n_to]) / (float) $lungh_periodo_tot);
+$pagato[$n_to] = ($pagato_t * $lungh_periodo_corr) + ((float) $pagato[$n_to] - ($pagato_t * $lungh_periodo_tot));
+$caparra_t = floor((float) fix_set($caparra[$n_to]) / (float) $lungh_periodo_tot);
+$caparra[$n_to] = ($caparra_t * $lungh_periodo_corr) + ((float) $caparra[$n_to] - ($caparra_t * $lungh_periodo_tot));
+$sconto_t = floor((float) fix_set($sconto[$n_to]) / (float) $lungh_periodo_tot);
+$sconto[$n_to] = ($sconto_t * $lungh_periodo_corr) + ((float) $sconto[$n_to] - ($sconto_t * $lungh_periodo_tot));
+$commissioni_t = floor((float) fix_set($commissioni[$n_to]) / (float) $lungh_periodo_tot);
+$commissioni[$n_to] = ($commissioni_t * $lungh_periodo_corr) + ((float) $commissioni[$n_to] - ($commissioni_t * $lungh_periodo_tot));
 $frase_da_sett[$n_to] = mex("da","prenota.php")." $lungh_periodo_tot ".mex("$parola_settiman","prenota.php").mex("$lettera_e","prenota.php");
 $stato['spezzata'][($n_to - 1)] = ($n_t_ini_agg - 1)."-".($num_tipologie - 1);
 $n_tronco = 1;
@@ -743,7 +748,7 @@ $inizioperiodo_orig[$n_t] = risul_query($data_corr,0,'datainizio');
 if ($n_t == $n_t_ini_agg) $n_t_prec = $n_to;
 else $n_t_prec = ($n_t - 1);
 $fineperiodo_orig[$n_t_prec] = $inizioperiodo_orig[$n_t];
-$numpersone[$n_t] = $numpersone[$n_to];
+$numpersone[$n_t] = fixset($numpersone[$n_to]);
 $numpersone_orig[$n_t] = $numpersone_orig[$n_to];
 $numpersone_orig2[$n_t] = fixset($numpersone_orig2[$n_to]);
 $assegnazioneapp[$n_t] = $assegnazioneapp[$n_to];
@@ -798,7 +803,7 @@ if ($lunghezza_periodo == 1) $mess_prenota .= mex("$lettera_a","prenota.php");
 else $mess_prenota .= mex("$lettera_e","prenota.php");
 if (!empty($frase_da_sett[$n_t])) $mess_prenota .= " <em>".$frase_da_sett[$n_t]."</em>";
 $mess_prenota .= ") ".mex("a nome di","prenota.php")." <b>$cognome</b> ";
-if ($numpersone[$n_t]) {
+if (!empty($numpersone[$n_t])) {
 $mess_prenota .= mex("per",'prenota.php')." <b>".$numpersone[$n_t]."</b> ".mex("persone",'prenota.php')." ";
 if ($numpersone_orig[$n_t] != $numpersone[$n_t] or (!empty($numpersone_orig2[$n_t]) and $numpersone_orig2[$n_t] != $numpersone_orig[$n_t])) {
 $mess_prenota .= "(<em>".mex("da",'prenota.php')." <b>";
@@ -809,7 +814,7 @@ if ($numpersone_orig[$n_t] != $numpersone[$n_t]) $mess_prenota .= " -> ";
 if ($numpersone_orig[$n_t] != $numpersone[$n_t]) $mess_prenota .= $numpersone_orig[$n_t];
 $mess_prenota .= "</b> ".mex("persone",'prenota.php')."</em>) ";
 } # fine if ($numpersone_orig[$n_t] != $numpersone[$n_t] or (!empty($numpersone_orig2[$n_t]) and
-} # fine if ($numpersone[$n_t])
+} # fine if (!empty($numpersone[$n_t]))
 $mess_prenota .= mex("nell'appartamento",'unit.php')." <b>".$appartamento[$n_t]."</b>";
 if ($assegnazioneapp[$n_t] == "k") $mess_prenota .= " (".mex("fisso","unit.php").")";
 else {
@@ -819,7 +824,7 @@ $mess_prenota .= ")";
 } # fine else if ($assegnazioneapp[$n_t] == "k")
 $mess_prenota .= ":<br><br>";
 
-$costo_tariffa_tot = (double) 0;
+$costo_tariffa_tot = (float) 0;
 $lista_tariffe_sett = "";
 $lista_tariffep_sett = "";
 $lista_tariffepo_sett = "";
@@ -834,11 +839,11 @@ if (isset($tar_sett_imp[$num2]) and strcmp((string) $tar_sett_imp[$num2],"")) $c
 else $costo_tariffap = risul_query($riga_tariffa,0,$tipotariffa[$n_t]."p");
 if (!strcmp((string) $costo_tariffap,"")) $costo_tariffap = 0;
 $lista_tariffepo_sett .= ",".$costo_tariffap;
-$costo_tariffap = (double) $costo_tariffap * (double) $numpersone[$n_t];
+$costo_tariffap = (float) $costo_tariffap * (float) fixset($numpersone[$n_t]);
 $lista_tariffep_sett .= ",".$costo_tariffap;
-$costo_tariffa = (double) $costo_tariffa + $costo_tariffap;
+$costo_tariffa = (float) $costo_tariffa + $costo_tariffap;
 } # fine if ($dati_tariffe[$tipotariffa[$n_t]]['moltiplica'] == "p")
-$costo_tariffa_tot = (double) $costo_tariffa_tot + (double) $costo_tariffa;
+$costo_tariffa_tot = (float) $costo_tariffa_tot + (float) $costo_tariffa;
 $lista_tariffe_sett .= ",".$costo_tariffa;
 } # fine for $num2
 $lista_tariffe_sett = substr($lista_tariffe_sett,1);
@@ -861,9 +866,15 @@ $costo_tariffa_tot_p = punti_in_num($costo_tariffa_tot,$stile_soldi);
 $mess_prenota .= "$costo_tariffa_tot_p $Euro &nbsp;&nbsp;&nbsp;&nbsp;&nbsp; ".mex("tariffa","prenota.php")." \"$nometariffa_vedi\"<br>";
 
 $valori = "abcdefghijkmnpqrstuvwxz";
-srand((double)microtime() * 1000000);
 $cod_prenota = "";
-for ($num2 = 0 ; $num2 < 4 ; $num2++) $cod_prenota .= substr($valori,rand(0,22),1);
+if (function_exists('random_int')) {
+for ($num2 = 0 ; $num2 < 4 ; $num2++) $cod_prenota .= substr($valori,random_int(0,22),1);
+} # fine if (function_exists('random_int')) 
+else {
+list($usec, $sec) = explode(' ', microtime());
+mt_srand($sec + (int) ((float) $usec * 1000000.0));
+for ($num2 = 0 ; $num2 < 4 ; $num2++) $cod_prenota .= substr($valori,mt_rand(0,22),1);
+} # fine else if (function_exists('random_int')) 
 if ($conferma[$n_t] == "SI") $conf = "S";
 else $conf = "N";
 if (isset($pagato[$n_t]) and $pagato[$n_t] > 0) $conf = "S";
@@ -871,9 +882,9 @@ $datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 
 esegui_query("insert into $tableprenota (idprenota,idclienti,idappartamenti,iddatainizio,iddatafine,tariffa,tariffesettimanali,codice,conferma,datainserimento,hostinserimento,utente_inserimento) values ('$idprenota','".$idclienti[$n_t]."','".aggslashdb($appartamento[$n_t])."','".$inizioperiodo[$n_t]."','".$fineperiodo[$n_t]."','$tariffa','$lista_tariffe_sett','$cod_prenota','$conf','$datainserimento','$HOSTNAME','$id_utente_ins')");
 
-if ($numpersone[$n_t]) {
+if (!empty($numpersone[$n_t])) {
 esegui_query("update $tableprenota set num_persone = '".$numpersone[$n_t]."' where idprenota = '$idprenota' ");
-} # fine if ($numpersone[$n_t])
+} # fine if (!empty($numpersone[$n_t]))
 
 if ($dati_tariffe[$tipotariffa[$n_t]]['tasse_percent']) {
 esegui_query("update $tableprenota set tasseperc = '".$dati_tariffe[$tipotariffa[$n_t]]['tasse_percent']."' where idprenota = '$idprenota' ");
@@ -884,6 +895,24 @@ if (controlla_soldi($caparra[$n_t],"pos") == "NO") $caparra[$n_t] = "";
 if (!$caparra[$n_t]) $caparra[$n_t] = calcola_caparra($dati_tariffe,$tipotariffa[$n_t],$inizioperiodo[$n_t],$fineperiodo[$n_t],$costo_tariffa_tot,$lista_tariffe_sett);
 
 
+# costi straordinari (passati in $ins_costi_agg)
+if (!empty($costi_straordinari[$n_t]['num'])) {
+for ($num_cs = 1 ; $num_cs <= $costi_straordinari[$n_t]['num'] ; $num_cs++) {
+$idcostiprenota = esegui_query("select max(idcostiprenota) from $tablecostiprenota");
+$idcostiprenota = risul_query($idcostiprenota,0,0) + 1;
+$nome_cs = htmlspecialchars($costi_straordinari[$n_t][$num_cs]['nome'],ENT_COMPAT);
+$nome_cs = par_taglia($nome_cs,0,40);
+$val_cs = formatta_soldi($costi_straordinari[$n_t][$num_cs]['val']);
+esegui_query("insert into $tablecostiprenota (idcostiprenota,idprenota,tipo,nome,valore,moltiplica,letto,idntariffe,varmoltiplica,varnumsett,datainserimento,hostinserimento,utente_inserimento) values ('$idcostiprenota','$idprenota','uf','".aggslashdb($nome_cs)."','$val_cs','1','n','-1','cx0','c','$datainserimento','$HOSTNAME','$id_utente_ins')");
+if ($val_cs) {
+$val_cs_p = punti_in_num($val_cs,$stile_soldi);
+$mess_prenota .= "$val_cs_p $Euro &nbsp;&nbsp;&nbsp;&nbsp;&nbsp; ".mex("Costo unico","prenota.php")." \"$nome_cs\"<br>";
+$costo_tariffa_tot = (float) $costo_tariffa_tot + (float) $val_cs;
+} # fine if ($val_cs)
+} # fine for $num_cs
+} # fine if (!empty($costi_straordinari[$n_t]['num']))
+
+
 # calcolo costi nulli, non letto e senza inventario da associare alla tariffa, tutti come se fossero "se possibile". Oppure il costo imposto per letti aggiuntivi
 if ($ins_costi_agg or $costo_letto_imposto != "NO") {
 $num_letti_agg = array('max' => 0);
@@ -907,10 +936,10 @@ if (substr($dati_ca[$num_costo]['assegna_da_ini_prenota'],0,1) == "<" and $oggi_
 } # fine if ($associa_costo_tariffa != "SI" and...
 } # fine if (!$dati_ca[$num_costo]['valore'] and empty($dati_ca[$num_costo]['valore_perc']) and...
 } # fine if ($ins_costi_agg == "costi_nulli")
-if ($costo_letto_imposto != "NO" and $costo_letto_imposto[$n_t]['id'] == $dati_ca[$num_costo]['id'] and $dati_ca[$num_costo]['letto'] == "s") {
+if ($costo_letto_imposto != "NO" and fixset($costo_letto_imposto[$n_t]['id']) == $dati_ca[$num_costo]['id'] and $dati_ca[$num_costo]['letto'] == "s") {
 $associa_costo = "SI";
 $nummoltiplica_ca = $costo_letto_imposto[$n_t]['molt'];
-} # fine if ($costo_letto_imposto != "NO" and $costo_letto_imposto[$n_t]['id'] == $dati_ca[$num_costo]['id'] and...
+} # fine if ($costo_letto_imposto != "NO" and fixset($costo_letto_imposto[$n_t]['id']) == $dati_ca[$num_costo]['id'] and...
 
 if ($associa_costo == "SI") {
 #if ($dati_ca[$num_costo][tipo_val] == "q" and $costo_totale_presente = "SI") $associa_costo = "NO";
@@ -954,7 +983,7 @@ else $vartariffeassociate_ca = "";
 $vartariffeincomp_ca = "";
 if ($dati_ca[$num_costo]['var_tariffei'] == "s") {
 for ($numtariffa = 1 ; $numtariffa <= $dati_tariffe['num'] ; $numtariffa++) {
-if ($dati_ca[$num_costo]["incomp_tariffa".$numtariffa] == "i") $vartariffeincomp_ca .= ",".$numtariffa;
+if (!empty($dati_ca[$num_costo]["incomp_tariffa".$numtariffa])) $vartariffeincomp_ca .= ",".$numtariffa;
 } # fine for $numtariffa
 if ($vartariffeincomp_ca) $vartariffeincomp_ca = substr($vartariffeincomp_ca,1);
 } # fine if ($dati_ca[$num_costo][var_tariffei] == "s")
@@ -979,7 +1008,7 @@ for ($num2 = 2 ; $num2 < (count($moltiplica) - 1) ; $num2++) if ($moltiplica[$nu
 else $valnummoltiplica_ca = $moltiplica;
 if ($valnummoltiplica_ca != 1) $mess_prenota .= " (".mex("moltiplicato per","prenota.php")." $valnummoltiplica_ca)";
 $mess_prenota .= "<br>";
-$costo_tariffa_tot = (double) $costo_tariffa_tot + (double) $prezzo_costo_tot;
+$costo_tariffa_tot = (float) $costo_tariffa_tot + (float) $prezzo_costo_tot;
 } # fine if ($prezzo_costo_tot)
 } # fine if ($associa_costo == "SI")
 } # fine if ($associa_costo == "SI")
@@ -995,7 +1024,7 @@ if (!empty($app_eliminati_costi[$n_t])) {
 esegui_query("update $tableprenota set incompatibilita = '".aggslashdb($app_eliminati_costi[$n_t])."' where idprenota = '$idprenota' ");
 } # fine if (!empty($app_eliminati_costi[$n_t]))
 
-$sconto[$n_t] = (double) formatta_soldi(fixset($sconto[$n_t]));
+$sconto[$n_t] = (float) formatta_soldi(fixset($sconto[$n_t]));
 if ($sconto[$n_t] and controlla_soldi($sconto[$n_t]) == "SI") {
 if ($sconto[$n_t] > $costo_tariffa_tot) $sconto[$n_t] = $costo_tariffa_tot;
 esegui_query("update $tableprenota set sconto = '".$sconto[$n_t]."' where idprenota = '$idprenota' ");
@@ -1003,7 +1032,7 @@ $sconto_p = punti_in_num($sconto[$n_t],$stile_soldi);
 if (substr($sconto_p,0,1) == "-") $sconto_p = substr($sconto_p,1);
 else $mess_prenota .= "-";
 $mess_prenota .= "$sconto_p $Euro &nbsp;&nbsp;&nbsp;&nbsp;&nbsp; ".mex("Sconto","prenota.php")."<br>";
-$costo_tariffa_tot = (double) $costo_tariffa_tot - (double) $sconto[$n_t];
+$costo_tariffa_tot = (float) $costo_tariffa_tot - (float) $sconto[$n_t];
 } # fine if ($sconto[$n_t] and...
 
 $commissioni[$n_t] = formatta_soldi(fixset($commissioni[$n_t]));
@@ -1084,7 +1113,7 @@ $mess_prenota .= "<br>".mex("Orario stimato di entrata","prenota.php").": <b>".s
 } # fine if (controlla_num_pos($giorno_stima_checkin) == "SI" and...
 } # fine if (!empty($giorno_stima_checkin[$n_t]) and !empty($ora_stima_checkin[$n_t]) and...
 
-if ($numpersone[$n_t] and ($numpersone_orig[$n_t] != $numpersone[$n_t] or (!empty($numpersone_orig2[$n_t]) and $numpersone_orig2[$n_t] != $numpersone_orig[$n_t]))) {
+if (!empty($numpersone[$n_t]) and ($numpersone_orig[$n_t] != $numpersone[$n_t] or (!empty($numpersone_orig2[$n_t]) and $numpersone_orig2[$n_t] != $numpersone_orig[$n_t]))) {
 if (strcmp(fixstr($commento[$n_t]),"")) $commento[$n_t] .= " - ";
 else $commento[$n_t] = "";
 $commento[$n_t] .= "*".mex("Prenotazione","prenota.php")." ".mex("per",'prenota.php')." ";
@@ -1094,9 +1123,9 @@ if ($numpersone_orig[$n_t] != $numpersone[$n_t]) $commento[$n_t] .= " -> ";
 } # fine if (!empty($numpersone_orig2[$n_t]) and $numpersone_orig2[$n_t] != $numpersone_orig[$n_t])
 if ($numpersone_orig[$n_t] != $numpersone[$n_t]) $commento[$n_t] .= $numpersone_orig[$n_t];
 $commento[$n_t] .= " ".mex("persone",'prenota.php')."*";
-} # fine if ($numpersone[$n_t] and $numpersone_orig[$n_t] != $numpersone[$n_t]) 
+} # fine if (!empty($numpersone[$n_t]) and $numpersone_orig[$n_t] != $numpersone[$n_t]) 
 if (strcmp(fixstr($commento[$n_t]),"") or !empty($commento['pers_esist'][$n_t]) or !empty($commento['ins_pers_tipo'][$n_t])) {
-$commento[$n_t] = htmlspecialchars(fixstr($commento[$n_t]));
+$commento[$n_t] = htmlspecialchars(fixstr($commento[$n_t]),ENT_COMPAT);
 if (strcmp($commento[$n_t],"")) {
 $mess_prenota .= "<br>".mex("Commento",'prenota.php').": ".$commento[$n_t];
 if (empty($commento['ins_pers_tipo'][$n_t])) $mess_prenota .= "<br>";
@@ -1110,8 +1139,8 @@ $commento[$n_t] = $commento[$n_t][0].strstr(fixstr($commento[$n_t][1]),">");
 } # fine if (!empty($commento['pers_esist'][$n_t]))
 elseif (!empty($commento['ins_pers_tipo'][$n_t])) $commento[$n_t] .= ">>";
 if (!empty($commento['ins_pers_tipo'][$n_t])) {
-$commento[$n_t] .= ">".$commento['ins_pers_tipo'][$n_t]."<".htmlspecialchars($commento['ins_pers_txt'][$n_t]);
-$mess_prenota .= "<br>".mex("Commento","prenota.php")." \"".$commento['ins_pers_tipo'][$n_t]."\": ".htmlspecialchars($commento['ins_pers_txt'][$n_t])."<br>";
+$commento[$n_t] .= ">".$commento['ins_pers_tipo'][$n_t]."<".htmlspecialchars($commento['ins_pers_txt'][$n_t],ENT_COMPAT);
+$mess_prenota .= "<br>".mex("Commento","prenota.php")." \"".$commento['ins_pers_tipo'][$n_t]."\": ".htmlspecialchars($commento['ins_pers_txt'][$n_t],ENT_COMPAT)."<br>";
 } # fine if (!empty($commento['ins_pers_tipo'][$n_t]))
 esegui_query("update $tableprenota set commento = '".aggslashdb($commento[$n_t])."' where idprenota = '$idprenota' ");
 } # fine if (strcmp((string) $commento[$n_t],"") or !empty($commento['pers_esist'][$n_t] or..
@@ -1122,8 +1151,8 @@ if ($n_t != $num_tipologie) $mess_prenota .= "<hr style=\"width: 95%\">";
 $lista_idprenota .= ",$idprenota";
 $lista_idini .= ",".$inizioperiodo[$n_t];
 $lista_idfine .= ",".$fineperiodo[$n_t];
-#$costo_tot_mess = (double) $costo_tot_mess + (double) $costo_tariffa_tot;
-#$caparra_mess = (double) $caparra_mess + (double) $caparra;
+#$costo_tot_mess = (float) $costo_tot_mess + (float) $costo_tariffa_tot;
+#$caparra_mess = (float) $caparra_mess + (float) $caparra;
 
 } # fine for $n_t
 
@@ -1131,6 +1160,7 @@ $lista_idprenota = substr($lista_idprenota,1);
 $lista_idini = substr($lista_idini,1);
 $lista_idfine = substr($lista_idfine,1);
 if (@is_array($prenota_vicine)) {
+$lista_idprenota_corr = "";
 $lista_idprenota_vett = explode(",",$lista_idprenota);
 $num_idprenota_vett = count($lista_idprenota_vett);
 $num_corr = 0;
@@ -1139,7 +1169,7 @@ $idprenota = $lista_idprenota_vett[$num1];
 if ($lista_idprenota_corr) $lista_idprenota_corr .= ",";
 $lista_idprenota_corr .= $idprenota;
 $num_corr++;
-if ($prenota_vicine[$num_corr] or $num1 == ($num_idprenota_vett - 1)) {
+if (!empty($prenota_vicine[$num_corr]) or $num1 == ($num_idprenota_vett - 1)) {
 if (strstr($lista_idprenota_corr,",")) {
 $lista_idprenota_corr_vett = explode(",",$lista_idprenota_corr);
 for ($num2 = 0 ; $num2 < count($lista_idprenota_corr_vett) ; $num2++) {
@@ -1149,7 +1179,7 @@ esegui_query("update $tableprenota set idprenota_compagna = '$idprenota_vicine'
 } # fine for $num2
 } # fine if (strstr($lista_idprenota_corr,","))
 $lista_idprenota_corr = "";
-} # fine if ($prenota_vicine[$num_corr] or $num1 == ($num_idprenota_vett - 1))
+} # fine if (!empty($prenota_vicine[$num_corr]) or $num1 == ($num_idprenota_vett - 1))
 } # fine for $num1
 } # fine if (@is_array($prenota_vicine))
 elseif ($prenota_vicine == "SI") {
