@@ -113,8 +113,43 @@ return $risul;
 
 
 
+function correggi_utf8_reale (&$str) {
+# espressione regolare da standard w3: https://www.w3.org/International/questions/qa-forms-utf-8.en
+if (!preg_match('%^(?:
+   [\x09\x0A\x0D\x20-\x7E]           # ASCII
+ | [\xC2-\xDF][\x80-\xBF]            # non-overlong 2-byte
+ | \xE0[\xA0-\xBF][\x80-\xBF]        # excluding overlongs
+ | [\xE1-\xEC\xEE\xEF][\x80-\xBF]{2} # straight 3-byte
+ | \xED[\x80-\x9F][\x80-\xBF]        # excluding surrogates
+ | \xF0[\x90-\xBF][\x80-\xBF]{2}     # planes 1-3
+ | [\xF1-\xF3][\x80-\xBF]{3}         # planes 4-15
+ | \xF4[\x80-\x8F][\x80-\xBF]{2}     # plane 16
+)*$%xs',$str)) {
+if (function_exists('mb_convert_encoding')) $str = mb_convert_encoding($str,'UTF-8','UTF-8');
+else {
+if (function_exists('iconv')) $str = @iconv('CP1252','UTF-8//IGNORE',$str);
+else $str = "?";
+} # fine else if (function_exists('mb_convert_encoding'))
+} # fine if (!preg_match('%^(?:...
+} # fine function correggi_utf8_reale
+
+if (function_exists('version_compare') and version_compare(PHP_VERSION,'7.0.0','>=')) {
+function correggi_utf8 (&$str) {
+if (isset($str)) correggi_utf8_reale($str);
+}
+} # fine if (function_exists('version_compare') and version_compare(PHP_VERSION,'7.0.0','>='))
+else {
+function correggi_utf8 (&$str) {
+# bug con preg_match troppo lungo di php5
+if (isset($str) and strlen($str) < 7000) correggi_utf8_reale($str);
+}
+} # fine else if (function_exists('version_compare') and version_compare(PHP_VERSION,'7.0.0','>='))
+
+
+
 function aggslashdb ($stringa) {
 
+correggi_utf8($stringa);
 $risul = addslashes($stringa);
 return $risul;
 
@@ -179,6 +214,7 @@ $query = "";
 
 function lock_tabelle ($tabelle,$altre_tab_usate = "") {
 
+$lista_tabelle = "";
 if (@is_array($tabelle)) {
 for ($num1 = 0 ; $num1 < count($tabelle); $num1++) {
 $lista_tabelle .= $tabelle[$num1]." write,";
