@@ -35,11 +35,12 @@ $MEDIUMTEXT = "text";
 
 function connetti_db ($database,$host,$port,$user,$password,$estensione) {
 
+global $link_pgsql;
 if ($estensione == "SI") dl("pgsql.so");
-$numconnessione = pg_connect("dbname=$database host=$host port=$port user=$user password=$password ");
-pg_exec("set datestyle to 'iso'");
+$link_pgsql = pg_connect("dbname=$database host=$host port=$port user=$user password=$password ");
+pg_exec($link_pgsql,"set datestyle to 'iso'");
 
-return $numconnessione;
+return $link_pgsql;
 
 } # fine function connetti_db
 
@@ -58,7 +59,8 @@ if (substr($PHPR_LOG,0,2) != "SI") {
 
 function esegui_query ($query,$silenzio = "",$idlog = "") {
 
-$risul = pg_exec($query);
+global $link_pgsql;
+$risul = pg_exec($link_pgsql,$query);
 if (!$risul and $silenzio != "totale") {
 global $PHPR_TAB_PRE;
 if (!$silenzio) echo "<br>ERROR in: ".htmlspecialchars(str_replace(" ".$PHPR_TAB_PRE," ",$query))."<br>";
@@ -76,7 +78,8 @@ if (!function_exists("inserisci_log")) include("./includes/funzioni_log.php");
 
 function esegui_query ($query,$silenzio = "",$idlog = "") {
 
-$risul = pg_exec($query);
+global $link_pgsql;
+$risul = pg_exec($link_pgsql,$query);
 if (!$risul and $silenzio != "totale") {
 global $PHPR_TAB_PRE;
 if (!$silenzio) echo "<br>ERROR in: ".htmlspecialchars(str_replace(" ".$PHPR_TAB_PRE," ",$query))."<br>";
@@ -93,6 +96,29 @@ return $risul;
 
 
 
+if (function_exists('pg_fetch_result')) {
+
+function risul_query ($query,$riga,$colonna,$tab="") {
+
+$risul = pg_fetch_result($query,$riga,$colonna);
+return $risul;
+
+} # fine function risul_query
+
+
+
+function numlin_query ($query) {
+
+$risul = pg_num_rows($query);
+return $risul;
+
+} # fine function numlin_query
+
+} # fine if (function_exists('pg_fetch_result'))
+
+
+else {
+
 function risul_query ($query,$riga,$colonna,$tab="") {
 
 $risul = pg_result($query,$riga,$colonna);
@@ -109,12 +135,50 @@ return $risul;
 
 } # fine function numlin_query
 
+} # fine else if (function_exists('pg_fetch_result'))
+
+
+
+function correggi_utf8_reale (&$str) {
+# espressione regolare da standard w3: https://www.w3.org/International/questions/qa-forms-utf-8.en
+if (!preg_match('%^(?:
+   [\x09\x0A\x0D\x20-\x7E]           # ASCII
+ | [\xC2-\xDF][\x80-\xBF]            # non-overlong 2-byte
+ | \xE0[\xA0-\xBF][\x80-\xBF]        # excluding overlongs
+ | [\xE1-\xEC\xEE\xEF][\x80-\xBF]{2} # straight 3-byte
+ | \xED[\x80-\x9F][\x80-\xBF]        # excluding surrogates
+ | \xF0[\x90-\xBF][\x80-\xBF]{2}     # planes 1-3
+ | [\xF1-\xF3][\x80-\xBF]{3}         # planes 4-15
+ | \xF4[\x80-\x8F][\x80-\xBF]{2}     # plane 16
+)*$%xs',$str)) {
+if (function_exists('mb_convert_encoding')) $str = mb_convert_encoding($str,'UTF-8','UTF-8');
+else {
+if (function_exists('iconv')) $str = @iconv('CP1252','UTF-8//IGNORE',$str);
+else $str = "?";
+} # fine else if (function_exists('mb_convert_encoding'))
+} # fine if (!preg_match('%^(?:...
+} # fine function correggi_utf8_reale
+
+if (function_exists('version_compare') and version_compare(PHP_VERSION,'7.0.0','>=')) {
+function correggi_utf8 (&$str) {
+if (isset($str)) correggi_utf8_reale($str);
+}
+} # fine if (function_exists('version_compare') and version_compare(PHP_VERSION,'7.0.0','>='))
+else {
+function correggi_utf8 (&$str) {
+# bug con preg_match troppo lungo di php5
+if (isset($str) and strlen($str) < 7000) correggi_utf8_reale($str);
+}
+} # fine else if (function_exists('version_compare') and version_compare(PHP_VERSION,'7.0.0','>='))
+
 
 
 if (function_exists('pg_escape_string')) {
 function aggslashdb ($stringa) {
 
-$risul = pg_escape_string($stringa);
+global $link_pgsql;
+correggi_utf8($stringa);
+$risul = pg_escape_string($link_pgsql,$stringa);
 return $risul;
 
 } # fine function aggslashdb
@@ -123,6 +187,7 @@ return $risul;
 else {
 function aggslashdb ($stringa) {
 
+correggi_utf8($stringa);
 $risul = addslashes($stringa);
 return $risul;
 
@@ -188,11 +253,12 @@ $query = "";
 function lock_tabelle ($tabelle,$altre_tab_usate = "") {
 
 if (@is_array($tabelle)) {
-pg_exec("begin");
+global $link_pgsql;
+pg_exec($link_pgsql,"begin");
 $num_tabelle = count($tabelle);
 for ($num1 = 0 ; $num1 < $num_tabelle; $num1++) {
 $tabella = $tabelle[$num1];
-pg_exec("lock table $tabella");
+pg_exec($link_pgsql,"lock table $tabella");
 } # fine for $num1
 $risul = "commit";
 } # fine if (@is_array($tabelle))
@@ -207,8 +273,9 @@ return $risul;
 function unlock_tabelle (&$tabelle_lock,$azione = "") {
 
 if ($tabelle_lock != "nocommit") {
-if ($azione == "rollback") pg_exec("rollback");
-else pg_exec("commit");
+global $link_pgsql;
+if ($azione == "rollback") pg_exec($link_pgsql,"rollback");
+else pg_exec($link_pgsql,"commit");
 } # fine if ($tabelle_lock != "nocommit")
 $tabelle_lock = null;
 
