@@ -104,6 +104,7 @@ $num_raggr++;
 } # fine if ($mostra_quadro_disp == "pers")
 
 $righe_tab_disp = "";
+if ($return_var) $tab_liberi = array();
 for ($num1 = 0 ; $num1 < $num_raggr ; $num1++) {
 if ($app_ric_raggr[$num1]) {
 $righe_tab_disp .= "<tr><td class=\"t1left\" style=\"text-align: right;$sfondo\">$aper_font_tab_disp".$nome_raggr[$num1]."$chiu_font_tab_disp</td>";
@@ -281,24 +282,24 @@ if (is_array($tariffe_mostra)) {
 $tutti_consentiti = "NO";
 $appartamenti_consentiti_regola2 = array();
 for ($numtariffa = 1 ; $numtariffa <= $dati_tariffe['num'] ; $numtariffa++) {
-if ($tariffe_mostra[$numtariffa] == "SI") {
-if (!$dati_r2["tariffa$numtariffa"]) {
+if (isset($tariffe_mostra[$numtariffa]) and $tariffe_mostra[$numtariffa] == "SI") {
+if (empty($dati_r2["tariffa$numtariffa"])) {
 $tutti_consentiti = "SI";
 break;
-} # fine if (!$dati_r2["tariffa$numtariffa"])
+} # fine if (empty($dati_r2["tariffa$numtariffa"]))
 else {
 $appartamenti_regola2 = explode(",",$dati_r2["tariffa$numtariffa"]);
 for ($num1 = 0 ; $num1 < count($appartamenti_regola2) ; $num1++) $appartamenti_consentiti_regola2[$appartamenti_regola2[$num1]] = "SI";
-} # fine else if (!$dati_r2["tariffa$numtariffa"])
-} # fine if ($tariffe_mostra[$numtariffa] == "SI")
+} # fine else if (empty($dati_r2["tariffa$numtariffa"]))
+} # fine if (isset($tariffe_mostra[$numtariffa]) and $tariffe_mostra[$numtariffa] == "SI")
 } # fine for $numtariffa
 if ($tutti_consentiti != "SI") {
 for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
 $idapp = $dati_app['posizione'][$num1];
-if ($appartamenti_consentiti_regola2[$idapp] != "SI") {
+if (!isset($appartamenti_consentiti_regola2[$idapp]) or $appartamenti_consentiti_regola2[$idapp] != "SI") {
 $app_consentito[$idapp] = "NO";
 $quadro_non_preciso = "SI";
-} # fine if ($appartamenti_consentiti_regola2[$idapp] != "SI")
+} # fine if (!isset($appartamenti_consentiti_regola2[$idapp]) or $appartamenti_consentiti_regola2[$idapp] != "SI")
 } # fine for $num1
 } # fine if ($tutti_consentiti != "SI")
 } # fine if (is_array($tariffe_mostra))
@@ -308,4 +309,4 @@ $quadro_non_preciso = "SI";
 
 
 
-?>
\ No newline at end of file
+?>
