@@ -45,12 +45,13 @@ $dati_tariffe['tariffa'.$num1]['importa_prezzi'][$num2] = $importa_prezzi[0];
 $dati_tariffe['tariffa'.$num1]['parte_prezzo'][$num2] = fixset($importa_prezzi[1]);
 $dati_tariffe['tariffa'.$num1]['tipo_importa'][$num2] = fixset($importa_prezzi[2]);
 $dati_tariffe['tariffa'.$num1]['val_importa'][$num2] = fixset($importa_prezzi[3]);
-if ($importa_prezzi[2] == "p") $dati_tariffe['tariffa'.$num1]['arrotond_importa'][$num2] = $importa_prezzi[4];
-if (isset($importa_prezzi[5])) {
-$per_imp = explode("-",$importa_prezzi[5]);
+$dati_tariffe['tariffa'.$num1]['perc_importa'][$num2] = fixset($importa_prezzi[4]);
+$dati_tariffe['tariffa'.$num1]['arrotond_importa'][$num2] = fixset($importa_prezzi[5]);
+if (isset($importa_prezzi[6])) {
+$per_imp = explode("-",$importa_prezzi[6]);
 $dati_tariffe['tariffa'.$num1]['periodo_importa_i'][$num2] = $per_imp[0];
 $dati_tariffe['tariffa'.$num1]['periodo_importa_f'][$num2] = $per_imp[1];
-} # fine if (isset($importa_prezzi[5]))
+} # fine if (isset($importa_prezzi[6]))
 if (!strstr(",".fixset($dati_tariffe['tariffa'.$importa_prezzi[0]]['esporta_prezzi']),",$num1,")) $dati_tariffe['tariffa'.$importa_prezzi[0]]['esporta_prezzi'] .= "$num1,";
 } # fine for $num2
 } # fine if ($dati_tariffe['tariffa'.$num1]['imp_prezzi_int'])
@@ -100,7 +101,7 @@ global $id_utente;
 if ($id_utente) $id_utente_pers = $id_utente;
 else $id_utente_pers = 1;
 $arrotond_tasse = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'arrotond_tasse' and idutente = '$id_utente_pers'");
-$dati_tariffe['tasse_arrotond'] = (double) risul_query($arrotond_tasse,0,'valpersonalizza');
+$dati_tariffe['tasse_arrotond'] = (float) risul_query($arrotond_tasse,0,'valpersonalizza');
 } # fine if ($tablepersonalizza)
 
 return $dati_tariffe;
@@ -179,18 +180,18 @@ return $lista_app;
 
 function calcola_commissioni ($dati_tariffe,$tipotariffa,$iddataini,$iddatafine,$tariffesettimanali,$sconto,$prezzo_costi_tot) {
 
-$commissioni = (double) 0;
+$commissioni = (float) 0;
 if (@is_array($dati_tariffe[$tipotariffa]['commissioni_percent'])) {
-$costo_tariffa_corr = (double) 0;
+$costo_tariffa_corr = (float) 0;
 $num_sett = 0;
 $numsett = 0;
 $tariffesettimanali = explode(";",$tariffesettimanali);
 $tariffesettimanali = explode(",",$tariffesettimanali[0]);
-$agg_sett_sconto = round((((double) $sconto * -1) / ($iddatafine - $iddataini + 1)),2);
-$agg_sett_costi = round(((((double) $sconto * -1) + (double) $prezzo_costi_tot) / ($iddatafine - $iddataini + 1)),2);
+$agg_sett_sconto = round((((float) $sconto * -1) / ($iddatafine - $iddataini + 1)),2);
+$agg_sett_costi = round(((((float) $sconto * -1) + (float) $prezzo_costi_tot) / ($iddatafine - $iddataini + 1)),2);
 for ($num1 = $iddataini ; $num1 <= $iddatafine ; $num1++) {
 
-$costo_tariffa_sett = (double) $tariffesettimanali[$numsett];
+$costo_tariffa_sett = (float) $tariffesettimanali[$numsett];
 $commissioni_percent = $dati_tariffe[$tipotariffa]['commissioni_percent']['def'];
 $commissioni_arrotond = $dati_tariffe[$tipotariffa]['commissioni_arrotond']['def'];
 $commissioni_base = $dati_tariffe[$tipotariffa]['commissioni_base']['def'];
@@ -213,17 +214,17 @@ if ($num1 != $iddataini and ($ultime_comm_perc != $commissioni_percent or $ultim
 if ($ultime_comm_perc) {
 if ($ultime_comm_arr == "val") $commissioni_corr = $ultime_comm_perc * $num_sett;
 else {
-$costo_base = (double) $costo_tariffa_corr;
-if ($ultime_comm_base == "s") $costo_base = $costo_base + ((double) $agg_sett_sconto * $num_sett);
-if ($ultime_comm_base == "c") $costo_base = $costo_base + ((double) $agg_sett_costi * $num_sett);
-$commissioni_corr = ($costo_base * (double) $ultime_comm_perc) / 100;
+$costo_base = (float) $costo_tariffa_corr;
+if ($ultime_comm_base == "s") $costo_base = $costo_base + ((float) $agg_sett_sconto * $num_sett);
+if ($ultime_comm_base == "c") $costo_base = $costo_base + ((float) $agg_sett_costi * $num_sett);
+$commissioni_corr = ($costo_base * (float) $ultime_comm_perc) / 100;
 $commissioni_corr = $commissioni_corr / $ultime_comm_arr;
 $commissioni_corr = floor(round($commissioni_corr));
 $commissioni_corr = $commissioni_corr * $ultime_comm_arr;
 } # fine else if ($commissioni_arrotond == "val")
-$commissioni += (double) $commissioni_corr;
+$commissioni += (float) $commissioni_corr;
 } # fine if ($ultime_comm_perc)
-$costo_tariffa_corr = (double) 0;
+$costo_tariffa_corr = (float) 0;
 $num_sett = 0;
 } # fine if ($num1 != $iddataini and ($ultime_comm_perc != $commissioni_percent or...
 
@@ -231,22 +232,22 @@ $num_sett++;
 $ultime_comm_perc = $commissioni_percent;
 $ultime_comm_arr = $commissioni_arrotond;
 $ultime_comm_base = $commissioni_base;
-$costo_tariffa_corr += (double) $tariffesettimanali[$numsett];
+$costo_tariffa_corr += (float) $tariffesettimanali[$numsett];
 $numsett++;
 } # fine for $num1
 
 if ($ultime_comm_perc) {
 if ($ultime_comm_arr == "val") $commissioni_corr = $ultime_comm_perc * $num_sett;
 else {
-$costo_base = (double) $costo_tariffa_corr;
-if ($ultime_comm_base == "s") $costo_base = $costo_base + ((double) $agg_sett_sconto * $num_sett);
-if ($ultime_comm_base == "c") $costo_base = $costo_base + ((double) $agg_sett_costi * $num_sett);
-$commissioni_corr = ($costo_base * (double) $ultime_comm_perc) / 100;
+$costo_base = (float) $costo_tariffa_corr;
+if ($ultime_comm_base == "s") $costo_base = $costo_base + ((float) $agg_sett_sconto * $num_sett);
+if ($ultime_comm_base == "c") $costo_base = $costo_base + ((float) $agg_sett_costi * $num_sett);
+$commissioni_corr = ($costo_base * (float) $ultime_comm_perc) / 100;
 $commissioni_corr = $commissioni_corr / $ultime_comm_arr;
 $commissioni_corr = floor(round($commissioni_corr));
 $commissioni_corr = $commissioni_corr * $ultime_comm_arr;
 } # fine else if ($commissioni_arrotond == "val")
-$commissioni += (double) $commissioni_corr;
+$commissioni += (float) $commissioni_corr;
 } # fine if ($ultime_comm_perc)
 } # fine if (@is_array($dati_tariffe[$tipotariffa]['commissioni_percent']))
 
@@ -259,7 +260,7 @@ return $commissioni;
 
 function calcola_caparra ($dati_tariffe,$tipotariffa,$iddataini,$iddatafine,$costo_tariffa,$tariffesettimanali) {
 
-$caparra = (double) 0;
+$caparra = (float) 0;
 
 $caparra_percent = $dati_tariffe[$tipotariffa]['caparra_percent'];
 if ($caparra_percent) {
@@ -271,11 +272,11 @@ if ($lunghezza_periodo <= $caparra_percent) $caparra = $costo_tariffa;
 else {
 $tariffesettimanali = explode(";",$tariffesettimanali);
 $tariffesettimanali = explode(",",$tariffesettimanali[0]);
-for ($num1 = 0 ; $num1 < $caparra_percent ; $num1++) $caparra += (double) $tariffesettimanali[$num1];
+for ($num1 = 0 ; $num1 < $caparra_percent ; $num1++) $caparra += (float) $tariffesettimanali[$num1];
 } # fine else if ($lunghezza_periodo >= $caparra_percent)
 } # fine if ($caparra_arrotond == "gio")
 if ($caparra_arrotond != "val" and $caparra_arrotond != "gio") {
-$caparra = ($costo_tariffa * (double) $caparra_percent) / 100;
+$caparra = ($costo_tariffa * (float) $caparra_percent) / 100;
 $caparra = $caparra / $caparra_arrotond;
 $caparra = floor($caparra);
 $caparra = $caparra * $caparra_arrotond;
@@ -333,12 +334,14 @@ break;
 if ($num_ord > 0 or "tariffa".$dati_tariffe[$tariffa]['importa_prezzi'][0] == $tariffa_da) {
 
 if ($num_ord != $num_ord_prec) {
-$importa_percent = (double) $dati_tariffe[$tariffa]['val_importa'][$num_ord];
-$importa_arrotond = (double) fixset($dati_tariffe[$tariffa]['arrotond_importa'][$num_ord]);
-$tipo_percent = $dati_tariffe[$tariffa]['tipo_importa'][$num_ord];
-if ($tipo_percent == "s" and empty($agg_vett[$tariffa][$num_ord])) {
-$agg_int = floor($importa_percent);
-$resto_int = $importa_percent - (double) $agg_int;
+$tipo_fisso = $dati_tariffe[$tariffa]['tipo_importa'][$num_ord];
+$importa_fisso = (float) $dati_tariffe[$tariffa]['val_importa'][$num_ord];
+$importa_percent = (float) $dati_tariffe[$tariffa]['perc_importa'][$num_ord];
+$importa_arrotond = (float) fixset($dati_tariffe[$tariffa]['arrotond_importa'][$num_ord]);
+$parte_prezzo = $dati_tariffe[$tariffa]['parte_prezzo'][$num_ord];
+if ($tipo_fisso == "s" and empty($agg_vett[$tariffa][$num_ord])) {
+$agg_int = floor($importa_fisso);
+$resto_int = $importa_fisso - (float) $agg_int;
 $agg_gio = floor($agg_int / 7);
 for ($num2 = 1 ; $num2 <= 7 ; $num2++) $agg_vett[$tariffa][$num_ord][$num2] = $agg_gio;
 $resto = $agg_int - ($agg_gio * 7);
@@ -350,47 +353,48 @@ for ($num2 = 7 ; $num2 > (7 - $resto) ; $num2--) $agg_vett[$tariffa][$num_ord][$
 $agg_vett[$tariffa][$num_ord][1] += $resto_int;
 $num_agg[$tariffa][$num_ord]['s'] = 0;
 $num_agg[$tariffa][$num_ord]['p'] = 0;
-} # fine if ($tipo_percent == "s" and empty($agg_vett[$tariffa][$num_ord]))
-if ($tipo_percent == "g") $perc = $importa_percent;
+} # fine if ($tipo_fisso == "s" and empty($agg_vett[$tariffa][$num_ord]))
+if ($tipo_fisso == "g") $fisso = $importa_fisso;
 } # fine if ($num_ord != $num_ord_prec)
 
-if ((string) $prezzoperiodo != "NO") {
-if ($tipo_percent == "s") {
+$prezzo_a_p = (float) $prezzoperiodop;
+
+if ($tipo_fisso == "s") {
 $num_agg[$tariffa][$num_ord]['s']++;
-$perc = $agg_vett[$tariffa][$num_ord][$num_agg[$tariffa][$num_ord]['s']];
+$fisso = $agg_vett[$tariffa][$num_ord][$num_agg[$tariffa][$num_ord]['s']];
 if ($num_agg[$tariffa][$num_ord]['s'] == 7) $num_agg[$tariffa][$num_ord]['s'] = 0;
-} # fine if ($tipo_percent == "s")
+} # fine if ($tipo_fisso == "s")
 
-$prezzo_a = (double) $prezzoperiodo;
-if ($dati_tariffe[$tariffa]['parte_prezzo'][$num_ord] != "p") {
-if ($tipo_percent == "p") $perc = (double) (($prezzo_a / 100.0) * $importa_percent);
-if ($perc) {
-if ($tipo_percent == "p") $perc = (round(($perc / $importa_arrotond),0) * $importa_arrotond);
-$prezzo_a = $prezzo_a + $perc;
-} # fine if ($perc)
-} # fine if ($dati_tariffe[$tariffa]['parte_prezzo'][$num_ord] != "p")
-if (($prezzo_a and strcmp((string) $prezzoperiodo,"")) or ((string) $prezzo_a == "0" and (string) $prezzoperiodo == "0")) esegui_query("update $tableperiodi set $tariffa = '$prezzo_a' where idperiodi = '$num1'");
+$prezzo_a = (float) $prezzoperiodo;
+
+if ($parte_prezzo == "f" or $parte_prezzo == "fn" or $parte_prezzo == "2" or $parte_prezzo == "fp" or $parte_prezzo == "fpf") {
+if ($parte_prezzo == "fpf") $prezzo_agg = $prezzo_a;
+else $prezzo_agg = (float) 0;
+if ($parte_prezzo == "fp" or $parte_prezzo == "fpf") $prezzo_a = $prezzo_a_p;
+$perc = (float) (($prezzo_a / 100.0) * $importa_percent);
+if ($perc) $perc = (round(($perc / $importa_arrotond),0) * $importa_arrotond);
+$prezzo_a = $prezzo_a + $fisso + $perc + $prezzo_agg;
+} # fine if ($parte_prezzo == "f" or $parte_prezzo == "fn" or...
+if ($parte_prezzo == "pn" or $parte_prezzo == "pf") $prezzo_a_agg = 0;
+else $prezzo_a_agg = $prezzo_a;
+if (($prezzo_a_agg and (strcmp((string) $prezzoperiodo,"") or $parte_prezzo == "fp" or $parte_prezzo == "2")) or ((string) $prezzo_a_agg == "0" and (string) $prezzoperiodo == "0")) esegui_query("update $tableperiodi set $tariffa = '$prezzo_a_agg' where idperiodi = '$num1'");
 else esegui_query("update $tableperiodi set $tariffa = NULL where idperiodi = '$num1'");
-} # fine if ((string) $prezzoperiodo != "NO")
 
-if ((string) $prezzoperiodop != "NO") {
-if ($tipo_percent == "s") {
+if ($tipo_fisso == "s") {
 $num_agg[$tariffa][$num_ord]['p']++;
-$perc = $agg_vett[$tariffa][$num_ord][$num_agg[$tariffa][$num_ord]['p']];
+$fisso = $agg_vett[$tariffa][$num_ord][$num_agg[$tariffa][$num_ord]['p']];
 if ($num_agg[$tariffa][$num_ord]['p'] == 7) $num_agg[$tariffa][$num_ord]['p'] = 0;
-} # fine if ($tipo_percent == "s")
+} # fine if ($tipo_fisso == "s")
 
-$prezzo_a_p = (double) $prezzoperiodop;
-if ($dati_tariffe[$tariffa]['parte_prezzo'][$num_ord] != "f") {
-if ($tipo_percent == "p") $perc = (double) (($prezzo_a_p / 100.0) * $importa_percent);
-if ($perc) {
-if ($tipo_percent == "p") $perc = (round(($perc / $importa_arrotond),0) * $importa_arrotond);
-$prezzo_a_p = $prezzo_a_p + $perc;
-} # fine if ($perc)
-} # fine if ($dati_tariffe[$tariffa]['parte_prezzo'][$num_ord] != "f")
-if (($prezzo_a_p and strcmp((string) $prezzoperiodop,"")) or ((string) $prezzo_a_p == "0" and (string) $prezzoperiodop == "0")) esegui_query("update $tableperiodi set $tariffa"."p = '$prezzo_a_p' where idperiodi = '$num1'");
+if ($parte_prezzo == "p" or $parte_prezzo == "pn" or $parte_prezzo == "2" or $parte_prezzo == "pf") {
+if ($parte_prezzo == "pf") $prezzo_a_p = $prezzo_a;
+$perc = (float) (($prezzo_a_p / 100.0) * $importa_percent);
+if ($perc) $perc = (round(($perc / $importa_arrotond),0) * $importa_arrotond);
+$prezzo_a_p = $prezzo_a_p + $fisso + $perc;
+} # fine if ($parte_prezzo == "p" or $parte_prezzo == "pn" or...
+if ($parte_prezzo == "fn" or $parte_prezzo == "fp" or $parte_prezzo == "fpf") $prezzo_a_p = 0;
+if (($prezzo_a_p and (strcmp((string) $prezzoperiodop,"") or $parte_prezzo == "pf" or $parte_prezzo == "2")) or ((string) $prezzo_a_p == "0" and (string) $prezzoperiodop == "0")) esegui_query("update $tableperiodi set $tariffa"."p = '$prezzo_a_p' where idperiodi = '$num1'");
 else esegui_query("update $tableperiodi set $tariffa"."p = NULL where idperiodi = '$num1'");
-} # fine if ((string) $prezzoperiodop != "NO")
 
 $num_ord_prec = $num_ord;
 } # fine if ($num_ord > 0 or "tariffa".$dati_tariffe[$tariffa]['importa_prezzi'][0] == $tariffa_da)
@@ -547,8 +551,8 @@ else $dati_cat_pers_p[$num1]['n_corr'] = $cat_pers_corr[5];
 if (isset($dati_cat_pers[$cat_pers]['langs'][$cat_pers_corr[4]]['n_p']) and $dati_cat_pers[$cat_pers]['langs'][$cat_pers_corr[4]]['n_p'] == $cat_pers_corr[6]) {
 $esist = 1;
 if ($lingua_mex and $lingua_mex != $cat_pers_corr[4]) {
-if ($cat_pers_corr[1] > 1) $dati_cat_pers_p[$num1]['n_corr'] = $dati_cat_pers[$cat_pers]['langs'][$lingua_mex]['n_p'];
-else $dati_cat_pers_p[$num1]['n_corr'] = $dati_cat_pers[$cat_pers]['langs'][$lingua_mex]['n_s'];
+if ($cat_pers_corr[1] > 1) $dati_cat_pers_p[$num1]['n_corr'] = fixset($dati_cat_pers[$cat_pers]['langs'][$lingua_mex]['n_p']);
+else $dati_cat_pers_p[$num1]['n_corr'] = fixset($dati_cat_pers[$cat_pers]['langs'][$lingua_mex]['n_s']);
 } # fine if ($lingua_mex and $lingua_mex != $cat_pers_corr[4])
 } # fine if (isset($dati_cat_pers[$cat_pers]['langs'][$cat_pers_corr[4]]['n_p']) and...
 else $esist = 0;
@@ -609,11 +613,11 @@ return $dati_cat_pers_p;
 
 function converti_valuta ($val,$cambio,$arrotond,$inv=0) {
 
-if ($inv) $val = (double) formatta_soldi($val) / (double) $cambio;
-else $val = (double) formatta_soldi($val) * (double) $cambio;
-$val = $val / (double) $arrotond;
+if ($inv) $val = (float) formatta_soldi($val) / (float) $cambio;
+else $val = (float) formatta_soldi($val) * (float) $cambio;
+$val = $val / (float) $arrotond;
 $val = round($val);
-$val = $val * (double) $arrotond;
+$val = $val * (float) $arrotond;
 
 return $val;
 
