@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2025 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -22,39 +22,34 @@
 
 
 if (function_exists('mb_strlen')) {
-function num_caratteri_testo ($testo) {
 
+function num_caratteri_testo ($testo) {
 return mb_strlen((string) $testo);
-
 } # fine function num_caratteri_testo
 
-function sottostringa ($testo,$ini,$lung=null) {
+function str_a_minuscolo ($testo) {
+return mb_strtolower((string) $testo);
+} # fine function str_a_minuscolo
 
+# Taglia dopo il numero di lettere. Per tagliare con numero di byte (quindi possibilmente con meno lettere di $lung) usare par_taglia() in funzioni.php
+function tronca_testo ($testo,$ini,$lung=null) {
 return mb_substr((string) $testo,$ini,$lung);
+} # fine function tronca_testo
 
-} # fine function num_caratteri_testo
 } # fine if (function_exists('mb_strlen'))
-
 else {
-function num_caratteri_testo ($testo) {
 
+function num_caratteri_testo ($testo) {
 if (function_exists('utf8_decode')) return strlen(@utf8_decode((string) $testo));
 else return strlen((string) $testo);
-
 } # fine function num_caratteri_testo
 
-function sottostringa ($testo,$ini,$lung=null) {
-
-if (function_exists('utf8_encode')) return substr(@utf8_encode((string) $testo),$ini,$lung);
-else return substr((string) $testo,$ini,$lung);
-
-} # fine function num_caratteri_testo
-} # fine else if (function_exists('mb_strlen'))
-
-
-
-function tronca_testo ($testo,$inizio,$lunghezza = "NO") {
+function str_a_minuscolo ($testo) {
+return strtolower((string) $testo);
+} # fine function str_a_minuscolo
 
+function tronca_testo ($testo,$inizio,$lunghezza="NO") {
+$testo = (string) $testo;
 $num_caratteri = 0;
 $num_byte = strlen($testo);
 for ($num1 = 0 ; $num1 < $num_byte ; $num1++) {
@@ -87,9 +82,10 @@ $testo = substr($testo,$n_ini,$n_lun);
 } # fine else if ($lunghezza == "NO")
 
 return $testo;
-
 } # fine function tronca_testo
 
+} # fine else if (function_exists('mb_strlen'))
+
 
 
 function trova_prima_data ($testo,$stile_data,$lingua,&$lung_resto) {
@@ -113,9 +109,9 @@ $lung_resto = (int) $lung_prima_data + strlen($prima_data);
 $prima_data_corr = preg_split("|[-/ ]|",$prima_data);
 if (strlen($prima_data_corr[0]) < 2) $prima_data_corr[0] = "0".$prima_data_corr[0];
 if (strlen($prima_data_corr[1]) < 2) $prima_data_corr[1] = "0".$prima_data_corr[1];
-if ((integer) $prima_data_corr[0] > 12) $prima_data = $prima_data_corr[2]."-".$prima_data_corr[1]."-".$prima_data_corr[0];
+if ((int) $prima_data_corr[0] > 12) $prima_data = $prima_data_corr[2]."-".$prima_data_corr[1]."-".$prima_data_corr[0];
 else {
-if ((integer) $prima_data_corr[1] > 12) $prima_data = $prima_data_corr[2]."-".$prima_data_corr[0]."-".$prima_data_corr[1];
+if ((int) $prima_data_corr[1] > 12) $prima_data = $prima_data_corr[2]."-".$prima_data_corr[0]."-".$prima_data_corr[1];
 else {
 if ($stile_data == "usa") $prima_data = $prima_data_corr[2]."-".$prima_data_corr[0]."-".$prima_data_corr[1];
 else $prima_data = $prima_data_corr[2]."-".$prima_data_corr[1]."-".$prima_data_corr[0];
@@ -296,22 +292,24 @@ return $numero;
 
 function ricava_val_json ($json,$val,$contenuto="") {
 $risul = "";
+
 if ($contenuto) {
+$prima_parte = $json;
 if (substr($contenuto,0,1) == "-") {
 $non_contenuto = 1;
 $contenuto = substr($contenuto,1);
-$prima_parte = $json;
 } # fine if (substr($contenuto,0,1) == "-")
 else $non_contenuto = 0;
-if (strstr($json,"\"$contenuto\":")) { $json = strstr($json,"\"$contenuto\":"); $contenuto = ""; }
+if (strstr($json,"\"$contenuto\":")) { $json = substr(strstr($json,"\"$contenuto\":"),strlen("\"$contenuto\":")); $contenuto = ""; }
 else {
-if (strstr($json,",$contenuto:")) { $json = strstr($json,",$contenuto:"); $contenuto = ""; }
-elseif (strstr($json,"{"."$contenuto:")) { $json = strstr($json,"{"."$contenuto:"); $contenuto = ""; }
-if ($non_contenuto) {
-if ($contenuto) $contenuto = "";
-else {
-$prima_parte = substr($prima_parte,0,(-1 * strlen($json)));
+if (strstr($json,",$contenuto:")) { $json = substr(strstr($json,",$contenuto:"),strlen(",$contenuto:")); $contenuto = ""; }
+elseif (strstr($json,"{"."$contenuto:")) { $json = substr(strstr($json,"{"."$contenuto:"),strlen("{"."$contenuto:")); $contenuto = ""; }
+} # fine else if (strstr($json,"\"$contenuto\":"))
+if ($non_contenuto and $contenuto) $contenuto = "";
+elseif (!$contenuto) {
+if ($non_contenuto) $prima_parte = substr($prima_parte,0,(-1 * strlen($json)));
 if (substr(trim($json),0,1) == "{") {
+if (!$non_contenuto) $prima_parte = substr(trim($json),1);
 $json = substr(trim($json),1);
 $prof = 1;
 while ($prof > 0 and strstr($json,"}")) {
@@ -324,13 +322,13 @@ $json = substr(strstr($json,"}"),1);
 $prof--;
 } # fine else if (strlen(strstr($json,"{")) > strlen(strstr($json,"}")))
 } # fine while ($prof > 0 and strstr($json,"}"))
+if (!$non_contenuto) $json = substr($prima_parte,0,(-1 * (strlen($json) + 1)));
 } # fine if (substr(trim($json),0,1) == "{")
-$json = $prima_parte.$json;
-} # fine else if ($contenuto)
+if ($non_contenuto) $json = $prima_parte.$json;
+} # fine elseif (!$contenuto)
 unset($prima_parte);
-} # fine if ($non_contenuto)
-} # fine else if (strstr($json,"\"$contenuto\":"))
 } # fine if ($contenuto)
+
 if (!$contenuto) {
 if (strstr($json,"\"$val\":")) $risul = explode("\"$val\":",$json);
 else {
@@ -344,9 +342,36 @@ $risul = trim($risul[0]);
 if ((substr($risul,0,1) == '"' and substr($risul,-1) == '"') or (substr($risul,0,1) == "'" and substr($risul,-1) == "'")) $risul = substr($risul,1,-1);
 } # fine if ($risul)
 } # fine if (!$contenuto)
+
 return $risul;
 } # fine function ricava_val_json
 
 
 
+function http_chunked_decodif ($str) {
+$pos = 0;
+$lung = strlen($str);
+$risul = null;
+$pos_acapo = strpos($str,"\n",1);
+$strlungHex = substr($str,$pos,$pos_acapo);
+echo "$lung - $strlungHex QUI<br>";
+while ($pos < $lung and $strlungHex) {
+$hex = strtolower(trim(ltrim($strlungHex,"0")));
+if (empty($hex)) $hex = 0;
+$dec = hexdec(preg_replace("/[^0-9a-f]/","",$hex));
+if ($hex != dechex($dec)) return $str;
+$pos = $pos_acapo + 1;
+$strlung = hexdec(rtrim($strlungHex,"\r\n"));
+$risul .= substr($str, $pos, $strlung);
+$pos = strpos($str, "\n", $pos + $strlung) + 1;
+if ($pos < $lung) {
+$pos_acapo = strpos($str,"\n",($pos + 1));
+$strlungHex = substr($str,$pos,($pos_acapo - $pos));
+} # fine if ($pos < $lung)
+} # fine while ($pos < $lung and $strlungHex)
+return $risul;
+} # fine function http_chunked_decodif
+
+
+
 ?>
\ No newline at end of file
