@@ -204,6 +204,7 @@ case "non chiedere":  				$messaggio = "do not ask"; break;
 case "Inviare la richiesta di prenotazione come messaggio a":	$messaggio = "Send the request for reservation as a messagge to"; break;
 case "Campi della form da chiedere":  		$messaggio = "Form fields to be asked"; break;
 case "Cognome":  				$messaggio = "Surname"; break;
+case "Secondo cognome":  			$messaggio = "Second surname"; break;
 case "Genere":  				$messaggio = "Gender"; break;
 case "Data di nascita":  			$messaggio = "Birthdate"; break;
 case "Documento":  				$messaggio = "Document"; break;
@@ -335,6 +336,7 @@ case "notte":  					$messaggio = "night"; break;
 case "notti":  					$messaggio = "nights"; break;
 case "cambia date":  				$messaggio = "change dates"; break;
 case "Per questa tariffa si deve inserire un minimo di":	$messaggio = "For this rate you have to insert at least"; break;
+case "2° cognome":  				$messaggio = "2nd surname"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -526,6 +528,7 @@ case "var_fr_Novembre":  			$messaggio = "var_phr_November"; break;
 case "var_fr_Dicembre":  			$messaggio = "var_phr_December"; break;
 case "var_utente_messaggio":  			$messaggio = "var_message_user"; break;
 case "var_chiedi_cognome":  			$messaggio = "var_ask_surname"; break;
+case "var_chiedi_cognome2":  			$messaggio = "var_ask_surname2"; break;
 case "var_chiedi_nome":  			$messaggio = "var_ask_name"; break;
 case "var_chiedi_email":  			$messaggio = "var_ask_email"; break;
 case "var_chiedi_email2":  			$messaggio = "var_ask_email2"; break;
@@ -557,6 +560,7 @@ case "var_ins_campi_form_personalizzati":  	$messaggio = "var_ins_custom_form_fi
 case "var_campi_form_doc_condizioni":  		$messaggio = "var_doc_conditions_form_fields"; break;
 case "var_chiedi_campi_form_doc_condizioni":  	$messaggio = "var_ask_doc_conditions_form_fields"; break;
 case "var_fr_Cognome":  			$messaggio = "var_phr_Surname"; break;
+case "var_fr_Secondo_cognome":  		$messaggio = "var_phr_Second_surname"; break;
 case "var_fr_Genere":  				$messaggio = "var_phr_Gender"; break;
 case "var_fr_Data_di_nascita":  		$messaggio = "var_phr_Birthdate"; break;
 case "var_fr_Documento":  			$messaggio = "var_phr_Document"; break;
@@ -629,4 +633,4 @@ case "var_":  		$messaggio = "var_"; break;
 
 
 
-?>
\ No newline at end of file
+?>
