@@ -326,6 +326,11 @@ case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messag
 case "Neonati (0-23 mesi)":  			$messaggio = "Infants (0-23 months)"; break;
 case "tariffe con":  				$messaggio = "rates with"; break;
 case "a":  					$messaggio = "to"; break;
+case "per persona nullo":  			$messaggio = "per person zero"; break;
+case "fisso nullo":  				$messaggio = "fixed zero"; break;
+case "da per persona":  			$messaggio = "from per person"; break;
+case "più fisso":  				$messaggio = "from fixed"; break;
+case "dal fisso":  				$messaggio = "plus fixed"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
