@@ -26,6 +26,8 @@ case "Mancano meno di":  			$messaggio = "Less than"; break;
 case "giorni alla scadenza dell'account":  	$messaggio = "days left until the account expires"; break;
 case "Numero eccesivo di sessioni <span style=\"color: red;\">errate</span> originate dal tuo indirizzo IP negli ultimi":	$messaggio = "Excessive number of <span style=\"color: red;\">incorrect</span> sessions from your IP address in the last"; break;
 case "È possibile che qualcuno dalla tua stessa rete stia tentando di rubare il tuo accesso":	$messaggio = "It is possible that someone from your same network is trying to steal your access"; break;
+case "Non hai i privilegi per accedere a questa pagina":	$messaggio = "You do not have privileges to access this page"; break;
+case "Accedi come utente amministratore o altro utente abilitato":	$messaggio = "Log in as an administrator user or another authorized user"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
