@@ -66,25 +66,6 @@ case " e vi erano":  				$messaggio = " and there were"; break;
 case "prenotazioni che finivano dopo il limite posto al ":	$messaggio = "reservations that ended after the limit given for "; break;
 case ", queste prenotazioni non sono state importate":	$messaggio = ", these reservations have not been imported"; break;
 case "Anno già creato": 			$messaggio = "Year already created"; break;
-case " Do":  					$messaggio = " Su"; break;
-case " Lu":  					$messaggio = " Mo"; break;
-case " Ma":  					$messaggio = " Tu"; break;
-case " Me":  					$messaggio = " We"; break;
-case " Gi":  					$messaggio = " Th"; break;
-case " Ve":  					$messaggio = " Fr"; break;
-case " Sa":  					$messaggio = " Sa"; break;
-case "Gen":  					$messaggio = "Jan"; break;
-case "Feb":  					$messaggio = "Feb"; break;
-case "Mar":  					$messaggio = "Mar"; break;
-case "Apr":  					$messaggio = "Apr"; break;
-case "Mag":  					$messaggio = "May"; break;
-case "Giu":  					$messaggio = "Jun"; break;
-case "Lug":  					$messaggio = "Jul"; break;
-case "Ago":  					$messaggio = "Aug"; break;
-case "Set":  					$messaggio = "Sep"; break;
-case "Ott":  					$messaggio = "Oct"; break;
-case "Nov":  					$messaggio = "Nov"; break;
-case "Dic":  					$messaggio = "Dec"; break;
 case "Il formato dell'anno richiesto è sbagliato":	$messaggio = "The format of the requested year is wrong"; break;
 case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":	$messaggio = "Months were wrongly selected, they have been inserted from January to December"; break;
 case "N&deg;":  				$messaggio = "N&deg;"; break;
