@@ -33,7 +33,8 @@ case "Non si è potuto scaricare il backup remoto":	$messaggio = "It was not pos
 case "Non si è potuto stabilire la connessione":	$messaggio = "It was not possible to establish the connection"; break;
 case "Non ho i permassi di scrittura sulla cartella dati":	$messaggio = "I don't have write premissions on dati folder"; break;
 case "Prova a mantenere i dati degli anni non presenti nell'installazione remota":	$messaggio = "Try to retain data of years not present in remote installation"; break;
-case "nella pagina delle interconnessioni":  	$messaggio = "in interconnections page"; break;
+case "nella":  					$messaggio = "in"; break;
+case "pagina delle interconnessioni":  		$messaggio = "interconnections page"; break;
 case "Modifica la regola di assegnazione":  	$messaggio = "Modify the assignment rule"; break;
 case "La prenotazione cancellata non era presente nel database":	$messaggio = "The deleted reservation was not present in the database"; break;
 case "gruppo":  				$messaggio = "group"; break;
@@ -41,9 +42,10 @@ case "Attenzione":  				$messaggio = "Warning"; break;
 case "carta di credito non salvata":  		$messaggio = "credit card not saved"; break;
 case "Se vuoi collegare altri account per una interconnessione già attiva inquesta pagina, allora":	$messaggio = "If you want to connect other accounts for an interconnection already active on this page, then"; break;
 case "aggiungi altre interconnessioni":  	$messaggio = "add more interconnections"; break;
+case "nella pagina delle interconnessioni":  	$messaggio = "in the interconnections page"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
\ No newline at end of file
+?>
