@@ -162,9 +162,12 @@ case "La seconda email verrà cambiata da":  	$messaggio = "The second email wil
 case "L'email certificata (PEC) o il codice destinatario verrà cambiato da":	$messaggio = "The certified email will be changed from"; break;
 case "La <b>seconda email</b> verrà cancellata":	$messaggio = "The <b>second email</b> will be deleted"; break;
 case "L'<b>email certificata (PEC) o il codice destinatario</b> verrà cancellato":	$messaggio = "The <b>certified email</b> will be deleted"; break;
+case "2° cognome":  				$messaggio = "2nd surname"; break;
+case "Il 2° cognome verrà cambiato da":  	$messaggio = "The 2nd surname will be changed from"; break;
+case "Il <b>2° cognome</b> verrà cancellato":	$messaggio = "The <b>2nd surname</b> will be deleted"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
\ No newline at end of file
+?>
