@@ -133,12 +133,39 @@ case "in una condizione come questa":  		$messaggio = "in a condition like this
 case "aggiungi ora questa condizione al documento":	$messaggio = "add now this condition to the document"; break;
 case "Così i dati delle ripetizioni precedenti possono essere memorizzati in uno o più array della variabile":	$messaggio = "This way data from previous repetitions can be stored in one or more arrays of variable"; break;
 case "È stato trovato un allegato uguale":  	$messaggio = "An identical attachment was found"; break;
-case "riutilizzare l'allegato esistente o renderlo predefinito per evitare di ingombreare il database":	$messaggio = "reuse the existing attachment or make it the default to avoid cluttering the database"; break;
+case "riutilizzare l'allegato esistente o renderlo predefinito per evitare di ingombrare il database":	$messaggio = "reuse the existing attachment or make it the default to avoid cluttering the database"; break;
 case "Unisci più condizioni con":  		$messaggio = "Merge multiple conditions with"; break;
-case "sempre da sinistra a destra":  		$messaggio = "always from left to right"; break;
+case "considerate sempre come raggruppate a destra":	$messaggio = "always considered as grouped on the right"; break;
 case "Indirizzi IP":  				$messaggio = "IP addresses"; break;
 case "lista separata da virgole, qualsiasi IP se vuota":	$messaggio = "comma separated list, any IP if empty"; break;
 case "Gli indirizzi IP da cui è permesso accedere alla API del documento sono stati cambiati":	$messaggio = "The IP addresses allowed to access the document API have been changed"; break;
+case "aggiungendo":  				$messaggio = "adding"; break;
+case "alla URL verranno cercate solo (o anche) le prenotazioni cancellate, anche nelle URL successive":	$messaggio = "to the URL will search only (or also) deleted reservations, also in subsequent URLs"; break;
+case "numero del":  				$messaggio = "number from"; break;
+case "prima di essere importata nel":  		$messaggio = "before being imported into"; break;
+case "o":  					$messaggio = "or"; break;
+case "Il valore può essere un testo tra virgolette \" o un'altra variabile":	$messaggio = "The value can be a text in quotes \" or another variable"; break;
+case "condizione":  				$messaggio = "condition"; break;
+case "Invia anche la versione alternativa in testo semplice":	$messaggio = "Also send the alternative version in plain text"; break;
+case "etichette html rimosse":  		$messaggio = "html tags removed"; break;
+case "Immagine inline":  			$messaggio = "Inline image"; break;
+case "Immagine salvata":  			$messaggio = "Image saved"; break;
+case "incorporata":  				$messaggio = "embedded"; break;
+case "Immagine eliminata":  			$messaggio = "Image deleted"; break;
+case "È stata trovata una immagine uguale":  	$messaggio = "An identical image was found"; break;
+case "riutilizzare l'immagine esistente per evitare di ingombrare il database":	$messaggio = "reuse the existing image to avoid cluttering the database"; break;
+case "Pagine dove non mostrare questo documento":	$messaggio = "Pages where this document should not be displayed"; break;
+case "tabella del mese":  			$messaggio = "month table"; break;
+case "tabella delle prenotazioni":  		$messaggio = "reservations table"; break;
+case "tabella dei clienti":  			$messaggio = "clients table"; break;
+case "tabella dei messaggi":  			$messaggio = "messages table"; break;
+case "controllo disponibilità":  		$messaggio = "availability check"; break;
+case "modifica della prenotazione":  		$messaggio = "reservation modification"; break;
+case "modifica del cliente":  			$messaggio = "client modification"; break;
+case "punto vendita":  				$messaggio = "point of sale"; break;
+case "casse":  					$messaggio = "cashboxes"; break;
+case "È stata aggiunta la pagina dove non mostrare il documento":	$messaggio = "The page where the document should not be displayed has been added"; break;
+case "È stata eliminata la pagina dove non mostrare il documento":	$messaggio = "The page where the document should not be displayed has been removed"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
