@@ -73,25 +73,6 @@ case "spazio":  				$messaggio = "space"; break;
 case "trattino":  				$messaggio = "hyphen"; break;
 case "a capo":  				$messaggio = "new line"; break;
 case "Pagine per il sito web":  		$messaggio = "Website pages"; break;
-case " Do":  					$messaggio = " Su"; break;
-case " Lu":  					$messaggio = " Mo"; break;
-case " Ma":  					$messaggio = " Tu"; break;
-case " Me":  					$messaggio = " We"; break;
-case " Gi":  					$messaggio = " Th"; break;
-case " Ve":  					$messaggio = " Fr"; break;
-case " Sa":  					$messaggio = " Sa"; break;
-case "Gen":  					$messaggio = "Jan"; break;
-case "Feb":  					$messaggio = "Feb"; break;
-case "Mar":  					$messaggio = "Mar"; break;
-case "Apr":  					$messaggio = "Apr"; break;
-case "Mag":  					$messaggio = "May"; break;
-case "Giu":  					$messaggio = "Jun"; break;
-case "Lug":  					$messaggio = "Jul"; break;
-case "Ago":  					$messaggio = "Aug"; break;
-case "Set":  					$messaggio = "Sep"; break;
-case "Ott":  					$messaggio = "Oct"; break;
-case "Nov":  					$messaggio = "Nov"; break;
-case "Dic":  					$messaggio = "Dec"; break;
 case "nome della tariffa":  			$messaggio = "rate name"; break;
 case "data di inserimento":  			$messaggio = "insertion date"; break;
 case "tariffa completa":  			$messaggio = "complete rate"; break;
@@ -160,7 +141,7 @@ case "Il mascheramento della provenienza delle email è stato cambiato":	$messag
 case "SI":  					$messaggio = "YES"; break;
 case "NO":  					$messaggio = "NO"; break;
 case "Cartelle in cui creare le pagine per il sito web":	$messaggio = "Directories where website pages are created"; break;
-case "percorsi separati da virgole relativi":	$messaggio = "comma separated paths relative"; break;
+case "percorsi relativi":  			$messaggio = "paths relative"; break;
 case "alla cartella di HotelDruid, se non iniziano con /":	$messaggio = "to the HotelDruid directory, if they don't begin with /"; break;
 case "Non ho i permessi di scrittura sulla cartella":	$messaggio = "I don't have write permissions on directory"; break;
 case "La cartella inserita <div style=\"display: inline; color: red;\">non esiste</div>":	$messaggio = "The inserted directory <div style=\"display: inline; color: red;\">does not exist</div>"; break;
@@ -485,6 +466,12 @@ case "configurare il loro server remoto smtp":	$messaggio = "configure their rem
 case "per inviare email":  			$messaggio = "to avoid that emails sent"; break;
 case "da hoteldruid":  				$messaggio = "from hoteldruid"; break;
 case "senza che vengano considerate come spam":	$messaggio = "are considered as spam"; break;
+case "Secondo cognome disattivato":  		$messaggio = "Second surname disabled"; break;
+case "Secondo cognome attivato":  		$messaggio = "Second surname enabled"; break;
+case "Fuso orario":  				$messaggio = "Time zone"; break;
+case "nessun fuso orario":  			$messaggio = "no time zone"; break;
+case "Si possono creare solo cartelle con nome composto da lettere e numeri":	$messaggio = "Only folders with names that contain letters and numbers can be created"; break;
+case "la seguente cartella verrà creata":  	$messaggio = "the following folder will be created"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
