@@ -105,7 +105,9 @@ case "valuta":  				$messaggio = "currency"; break;
 case "Il numero di persone inserite non include i bambini (vedere il commento per il numero di bambini)":	$messaggio = "The inserted number of people does not include children (see comment for the number of children)"; break;
 case "da":  					$messaggio = "from"; break;
 case "Si è dovuto diminuire il <b>numero di persone</b> per inserire la prenotazione":	$messaggio = "The <b>number of people</b> has been decreased in order to insert the reservation"; break;
-case "Prenotazione non inserita":  			$messaggio = "Reservation not inserted"; break;
+case "Prenotazione non inserita":  		$messaggio = "Reservation not inserted"; break;
+case "Prenotazione non modificata":  		$messaggio = "Reservation not modified"; break;
+case "2° cognome":  				$messaggio = "2nd surname"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
