@@ -5,6 +5,7 @@
 # numbers and underscore: NO ACCENTS, NO SPACES
 
 $trad_var['cognome'] = 'surname';
+$trad_var['cognome2'] = 'surname2';
 $trad_var['nome'] = 'name';
 $trad_var['soprannome'] = 'nickname';
 $trad_var['titolo'] = 'title';
@@ -189,6 +190,7 @@ $trad_var['num_ospiti_tot'] = 'guests_tot_num';
 $trad_var['numero_ospite'] = 'number_guest';
 $trad_var['numero_cliente_ospite'] = 'client_number_guest';
 $trad_var['cognome_ospite'] = 'surname_guest';
+$trad_var['cognome2_ospite'] = 'surname2_guest';
 $trad_var['nome_ospite'] = 'name_guest';
 $trad_var['soprannome_ospite'] = 'nickname_guest';
 $trad_var['titolo_ospite'] = 'title_guest';
@@ -263,6 +265,9 @@ $trad_var['piano_unita'] = 'unit_floor';
 $trad_var['capacita_unita'] = 'unit_capacity';
 $trad_var['priorita_unita'] = 'unit_priority';
 $trad_var['num_unita'] = 'units_num';
+$trad_var['lista_inventario_unita'] = 'units_inventory_list';
+$trad_var['mancanti_inventario_unita'] = 'units_inventory_missing';
+$trad_var['dettagli_inventario_unita'] = 'units_inventory_details';
 $trad_var['costo_tot_somma_ripetizioni'] = 'price_tot_repetitions_sum';
 $trad_var['costo_tot_somma_ripetizioni_p'] = 'price_tot_repetitions_sum_p';
 $trad_var['caparra_somma_ripetizioni'] = 'deposit_repetitions_sum';
@@ -276,6 +281,7 @@ $trad_var['resto_da_pagare_somma_ripetizioni_p'] = 'rest_to_pay_repetitions_sum_
 $trad_var['num_persone_tot_somma_ripetizioni'] = 'people_num_tot_repetitions_sum';
 $trad_var['data_inizio_selezione'] = 'selection_starting_date';
 $trad_var['data_fine_selezione'] = 'selection_ending_date';
+$trad_var['numero_prenotazioni_selezione'] = 'selection_reservations_number';
 $trad_var['utente_attuale'] = 'current_user';
 $trad_var['nome_struttura'] = 'structure_name';
 $trad_var['tipo_struttura'] = 'structure_type';
