@@ -364,7 +364,6 @@ case "al cambio attuale":  			$messaggio = "at current exchange rate"; break;
 case "Le altre valute presenti nella cassa":  	$messaggio = "Other currencies in cashbox"; break;
 case "sono state convertite in":  		$messaggio = "have been converted into"; break;
 case "Tabella con le prenotazioni cancellate":	$messaggio = "Table with deleted reservations"; break;
-case "Prenotazioni cancellate":  		$messaggio = "Deleted reservations"; break;
 case "<b>non importare</b> i prezzi":  		$messaggio = "<b>do not import</b> prices"; break;
 case "Attenzione":  				$messaggio = "Notice"; break;
 case "i periodi aggiunti non potranno più essere eliminati":	$messaggio = "periods added now can't be deleted later"; break;
@@ -378,6 +377,11 @@ case "Numero_predefinito di persone":  		$messaggio = "Default_number of people"
 case "Numero_minimo di persone":  		$messaggio = "Minimum_number of people"; break;
 case "Id":  					$messaggio = "Id"; break;
 case "chiedere":  				$messaggio = "ask"; break;
+case "Cancellare anche":  			$messaggio = "Delete also"; break;
+case "clienti con solo prenotazioni cancellate negli anni passati, cancellando le loro prenotazioni in modo permanente":	$messaggio = "clients with only deleted reservations in past years, deleting their reservations permanently"; break;
+case "Prenotazioni cancellate":  		$messaggio = "Deleted reservations"; break;
+case "Anche cancellate":  			$messaggio = "Also deleted"; break;
+case "Solo cancellate":  			$messaggio = "Only deleted"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
