@@ -204,6 +204,7 @@ case "non chiedere":  				$messaggio = "no preguntar"; break;
 case "Inviare la richiesta di prenotazione come messaggio a":	$messaggio = "Enviar el pedido de reserva como mensaje a"; break;
 case "Campi della form da chiedere":  		$messaggio = "Campos del formulario a preguntar"; break;
 case "Cognome":  				$messaggio = "Apellido"; break;
+case "Secondo cognome":  			$messaggio = "Segundo apellido"; break;
 case "Genere":  				$messaggio = "Género"; break;
 case "Data di nascita":  			$messaggio = "Fecha de nacimiento"; break;
 case "Documento":  				$messaggio = "Documento"; break;
@@ -335,6 +336,7 @@ case "notte":  					$messaggio = "noche"; break;
 case "notti":  					$messaggio = "noches"; break;
 case "cambia date":  				$messaggio = "cambiar fechas"; break;
 case "Per questa tariffa si deve inserire un minimo di":	$messaggio = "Para esta tarifa hay que insertar por lo menos"; break;
+case "2° cognome":  				$messaggio = "2° apellido"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -527,6 +529,7 @@ case "var_fr_Novembre":  			$messaggio = "var_fr_Noviembre"; break;
 case "var_fr_Dicembre":  			$messaggio = "var_fr_Diciembre"; break;
 case "var_utente_messaggio":  			$messaggio = "var_usuario_mensaje"; break;
 case "var_chiedi_cognome":  			$messaggio = "var_pedir_apellido"; break;
+case "var_chiedi_cognome2":  			$messaggio = "var_pedir_apellido2"; break;
 case "var_chiedi_nome":  			$messaggio = "var_pedir_nombre"; break;
 case "var_chiedi_email":  			$messaggio = "var_pedir_email"; break;
 case "var_chiedi_email2":  			$messaggio = "var_pedir_email2"; break;
@@ -558,6 +561,7 @@ case "var_ins_campi_form_personalizzati":  	$messaggio = "var_ins_campos_formula
 case "var_campi_form_doc_condizioni":  		$messaggio = "var_campos_formulario_doc_condiciones"; break;
 case "var_chiedi_campi_form_doc_condizioni":  	$messaggio = "var_pedir_campos_formulario_doc_condiciones"; break;
 case "var_fr_Cognome":  			$messaggio = "var_fr_Apellido"; break;
+case "var_fr_Secondo_cognome":  		$messaggio = "var_fr_Segundo_apellido"; break;
 case "var_fr_Genere":  				$messaggio = "var_fr_Genero"; break;
 case "var_fr_Data_di_nascita":  		$messaggio = "var_fr_Fecha_de_nacimiento"; break;
 case "var_fr_Documento":  			$messaggio = "var_fr_Documento"; break;
