@@ -326,7 +326,11 @@ case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messag
 case "Neonati (0-23 mesi)":  				$messaggio = "Bebés (0-23 meses)"; break;
 case "tariffe con":  				$messaggio = "tarifas con"; break;
 case "a":  					$messaggio = "a"; break;
-case "":  		$messaggio = ""; break;
+case "per persona nullo":  			$messaggio = "por persona nulo"; break;
+case "fisso nullo":  				$messaggio = "fijo nulo"; break;
+case "da per persona":  			$messaggio = "desde por persona"; break;
+case "più fisso":  				$messaggio = "más fijo"; break;
+case "dal fisso":  				$messaggio = "desde el fijo"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
