@@ -65,6 +65,9 @@ case "personalizzazioni e gruppi":  		$messaggio = "personalizaciones y grupos";
 case "solo i gruppi":  				$messaggio = "solo grupos"; break;
 case "Gruppi importati":  			$messaggio = "Grupos importados"; break;
 case "Password aggiornata":  			$messaggio = "Contraseña actualizada"; break;
+case "Password troppo debole":			$messaggio = "Contraseña demasiado débil"; break;
+case "almeno":  				$messaggio = "al menos"; break;
+case "caratteri":  				$messaggio = "caracteres"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
