@@ -67,25 +67,6 @@ case " e vi erano":  				$messaggio = " y habían"; break;
 case "prenotazioni che finivano dopo il limite posto al ":	$messaggio = "reservas que acababan después del limite dado para el "; break;
 case ", queste prenotazioni non sono state importate":	$messaggio = ", estas reservas no han sido importadas"; break;
 case "Anno già creato": 			$messaggio = "Año ya creado"; break;
-case " Do":  					$messaggio = " Do"; break;
-case " Lu":  					$messaggio = " Lu"; break;
-case " Ma":  					$messaggio = " Ma"; break;
-case " Me":  					$messaggio = " Mi"; break;
-case " Gi":  					$messaggio = " Ju"; break;
-case " Ve":  					$messaggio = " Vi"; break;
-case " Sa":  					$messaggio = " Sá"; break;
-case "Gen":  					$messaggio = "Ene"; break;
-case "Feb":  					$messaggio = "Feb"; break;
-case "Mar":  					$messaggio = "Mar"; break;
-case "Apr":  					$messaggio = "Abr"; break;
-case "Mag":  					$messaggio = "May"; break;
-case "Giu":  					$messaggio = "Jun"; break;
-case "Lug":  					$messaggio = "Jul"; break;
-case "Ago":  					$messaggio = "Ago"; break;
-case "Set":  					$messaggio = "Sep"; break;
-case "Ott":  					$messaggio = "Oct"; break;
-case "Nov":  					$messaggio = "Nov"; break;
-case "Dic":  					$messaggio = "Dic"; break;
 case "Il formato dell'anno richiesto è sbagliato":	$messaggio = "El formato del año pedido está equivocado"; break;
 case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":	$messaggio = "Los meses estaban indicados en modo erroneo, han sido insertados los meses desde Enero hasta Diciembre"; break;
 case "N&deg;":  				$messaggio = "N&deg;"; break;
