@@ -33,7 +33,8 @@ case "Non si è potuto scaricare il backup remoto":	$messaggio = "No se ha podid
 case "Non si è potuto stabilire la connessione":	$messaggio = "No se ha podido establecer la conexión"; break;
 case "Non ho i permassi di scrittura sulla cartella dati":	$messaggio = "No tengo los permisos para escribir en el directorio dati"; break;
 case "Prova a mantenere i dati degli anni non presenti nell'installazione remota":	$messaggio = "Intentar mantener los datos de los años no presentes en la instalación remota"; break;
-case "nella pagina delle interconnessioni":  	$messaggio = "en la página de las interconexiones"; break;
+case "nella":  	  	  	  	  	$messaggio = "en la"; break;
+case "pagina delle interconnessioni":  	  	$messaggio = "página de las interconexiones"; break;
 case "Modifica la regola di assegnazione":  	$messaggio = "Modificar la regla de asignación"; break;
 case "La prenotazione cancellata non era presente nel database":	$messaggio = "La reserva borrada no estaba presente en la base de datos"; break;
 case "gruppo":  				$messaggio = "grupo"; break;
@@ -41,9 +42,10 @@ case "Attenzione":  				$messaggio = "Atención"; break;
 case "carta di credito non salvata":  		$messaggio = "la tarjeta de crédito no ha sido salvada"; break;
 case "Se vuoi collegare altri account per una interconnessione già attiva inquesta pagina, allora":	$messaggio = "Para conectar otras cuentas a una interconexión que ya está activa en esta página se pueden"; break;
 case "aggiungi altre interconnessioni":  	$messaggio = "añadir más interconexiones"; break;
+case "nella pagina delle interconnessioni":  	$messaggio = "en la página de las interconexiones"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
\ No newline at end of file
+?>
