@@ -37,7 +37,7 @@ case "modifica":  				$messaggio = "modificar"; break;
 case "commento":  				$messaggio = "comentario"; break;
 case "Persona":  				$messaggio = "Persona"; break;
 case "più bassa viene assegnata prima":  	$messaggio = "la más baja es asignada antes"; break;
-case "Solo":  					$messaggio = "Solo queda"; break;
+case "Rimane solo":  				$messaggio = "Solo queda"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
