@@ -164,9 +164,12 @@ case "La seconda email verrà cambiata da":  	$messaggio = "El segundo correo el
 case "L'email certificata (PEC) o il codice destinatario verrà cambiato da":	$messaggio = "El correo electrónico certificado será cambiado de"; break;
 case "La <b>seconda email</b> verrà cancellata":	$messaggio = "El <b>segundo correo electrónico</b> será borrado"; break;
 case "L'<b>email certificata (PEC) o il codice destinatario</b> verrà cancellato":	$messaggio = "El <b>correo electrónico certificado</b> será borrado"; break;
+case "2° cognome":  				$messaggio = "2° apellido"; break;
+case "Il 2° cognome verrà cambiato da":  	$messaggio = "El segundo apellido será cambiado de"; break;
+case "Il <b>2° cognome</b> verrà cancellato":	$messaggio = "El <b>segundo apellido</b> será borrado"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
\ No newline at end of file
+?>
