@@ -133,12 +133,39 @@ case "in una condizione come questa":  		$messaggio = "en una condición como es
 case "aggiungi ora questa condizione al documento":	$messaggio = "añadir ahora esta condición al documento"; break;
 case "Così i dati delle ripetizioni precedenti possono essere memorizzati in uno o più array della variabile":	$messaggio = "Así los datos de las repeticiones anteriores pueden ser almacenados en uno o más arrays de la variable"; break;
 case "È stato trovato un allegato uguale":  	$messaggio = "Se ha encontrado un archivo adjunto idéntico"; break;
-case "riutilizzare l'allegato esistente o renderlo predefinito per evitare di ingombreare il database":	$messaggio = "reutilicar el archivo adjunto existente o convertirlo a predefinido para evitar saturar la base de datos"; break;
+case "riutilizzare l'allegato esistente o renderlo predefinito per evitare di ingombrare il database":	$messaggio = "reutilizar el archivo adjunto existente o convertirlo a predefinido para evitar saturar la base de datos"; break;
 case "Unisci più condizioni con":  		$messaggio = "Combinar múltiples condiciones con"; break;
-case "sempre da sinistra a destra":  		$messaggio = "siempre de izquierda a derecha"; break;
+case "considerate sempre come raggruppate a destra":	$messaggio = "siempre consideradas como agrupadas a la derecha"; break;
 case "Indirizzi IP":  				$messaggio = "Direcciones IP"; break;
 case "lista separata da virgole, qualsiasi IP se vuota":	$messaggio = "lista separada por comas, cualquier IP si está vacía"; break;
 case "Gli indirizzi IP da cui è permesso accedere alla API del documento sono stati cambiati":	$messaggio = "Las direcciones IP desde las que se permite el acceso a la API del documento han sido cambiadas"; break;
+case "aggiungendo":  				$messaggio = "añadiendo"; break;
+case "alla URL verranno cercate solo (o anche) le prenotazioni cancellate, anche nelle URL successive":	$messaggio = "a la URL se buscarán solo (o también) las reservas canceladas, también en URLs posteriores"; break;
+case "numero del":  				$messaggio = "número del"; break;
+case "prima di essere importata nel":  		$messaggio = "antes de ser importada al"; break;
+case "o":  					$messaggio = "o"; break;
+case "Il valore può essere un testo tra virgolette \" o un'altra variabile":	$messaggio = "El valor puede ser un texto entre comillas \" u otra variable"; break;
+case "condizione":  				$messaggio = "condición"; break;
+case "Invia anche la versione alternativa in testo semplice":	$messaggio = "Enviar también la versión alternativa en texto sin formato"; break;
+case "etichette html rimosse":  		$messaggio = "etiquetas html eliminadas"; break;
+case "Immagine inline":  			$messaggio = "Imagen inline"; break;
+case "Immagine salvata":  			$messaggio = "Imagen salvada"; break;
+case "incorporata":  				$messaggio = "incorporada"; break;
+case "Immagine eliminata":  			$messaggio = "Imagen eliminada"; break;
+case "È stata trovata una immagine uguale":  	$messaggio = "Se ha encontrado una imagen idéntica"; break;
+case "riutilizzare l'immagine esistente per evitare di ingombrare il database":	$messaggio = "reutilizar la imagen existente para evitar saturar la base de datos"; break;
+case "Pagine dove non mostrare questo documento":	$messaggio = "Páginas donde no se debe enseñar este documento"; break;
+case "tabella del mese":  			$messaggio = "tabla del mes"; break;
+case "tabella delle prenotazioni":  		$messaggio = "tabla de las reservas"; break;
+case "tabella dei clienti":  			$messaggio = "tabla de los clientes"; break;
+case "tabella dei messaggi":  			$messaggio = "tabla de los mensajes"; break;
+case "controllo disponibilità":  		$messaggio = "control de disponibilidad"; break;
+case "modifica della prenotazione":  		$messaggio = "modificación de la reserva"; break;
+case "modifica del cliente":  			$messaggio = "modificación del cliente"; break;
+case "punto vendita":  				$messaggio = "punto de venta"; break;
+case "casse":  					$messaggio = "cajas"; break;
+case "È stata aggiunta la pagina dove non mostrare il documento":	$messaggio = "Se ha añadido la página donde no se debe enseñar el documento"; break;
+case "È stata eliminata la pagina dove non mostrare il documento":	$messaggio = "Se ha eliminado la página donde no se debe enseñar el documento"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
