@@ -108,8 +108,8 @@ case "Periodi in cui è permesso<br> inserire il costo":	$messaggio = "Períodos
 case "In tutti":  				$messaggio = "En todos"; break;
 case "Solo nei periodi selezionati":  		$messaggio = "Solo en períodos seleccionados"; break;
 case "dal":  					$messaggio = "desde"; break;
-case "Elimina un periodo":  			$messaggio = "Elimina un período"; break;
-case "Aggiungi un periodo":  			$messaggio = "Añade un período"; break;
+case "Elimina un periodo":  			$messaggio = "Eliminar un período"; break;
+case "Aggiungi un periodo":  			$messaggio = "Añadir un período"; break;
 case "se tutte le settimane della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "si todas las semanas de la reserva estan dentro de los períodos seleccionados"; break;
 case "se tutti i giorni della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "si todos los días de la reserva estan dentro de los períodos seleccionados"; break;
 case "se anche una sola settimana della prenotazione è all'interno dei periodi selezionati":	$messaggio = "aunque solo una semana de la reserva esté dentro de los períodos seleccionados"; break;
