@@ -280,6 +280,24 @@ case "Informazioni extra":  			$messaggio = "Informaciones extra"; break;
 case "Inserisci una prenotazione uguale":  	$messaggio = "Insertar una reserva igual"; break;
 case "Inserisci prenotazioni uguali":  		$messaggio = "Insertar reservas iguales"; break;
 case "Cambia il cliente anche nei pagamenti effettuati":	$messaggio = "Cambiar el cliente también en los pagos realizados"; break;
+case "Ripristina la prenotazione":  		$messaggio = "Restaurar la reserva"; break;
+case "Ripristina le prenotazioni":  		$messaggio = "Restaurar las reservas"; break;
+case "Non si possono inserire prenotazioni nel passato":	$messaggio = "No se pueden insertar reservas en el pasado"; break;
+case "Si è sicuri di voler provare a <b>ripristinare</b> la prenotazione":	$messaggio = "Estás seguro de que quieres intentar <b>restaurar</b> la reserva"; break;
+case "Si è sicuri di voler provare a <b>ripristinare</b> le prenotazioni":	$messaggio = "Estás seguro de que quieres intentar <b>restaurar</b> las reservas"; break;
+case "ripristinata":  				$messaggio = "restaurada"; break;
+case "Le date della prenotazione":  		$messaggio = "Las fechas de la reserva"; break;
+case "non sono attualmente disponibili":  	$messaggio = "no están disponibles actualmente"; break;
+case "sono attualmente chiuse":  		$messaggio = "están actualmente cerradas"; break;
+case "Le date vanno liberate manualmente prima di poter ripristinare la prenotazione":	$messaggio = "Las fechas tienen que ser liberadas manualmente antes de que se pueda restaurar la reserva"; break;
+case "Le prenotazioni vicine alla prenotazione":	$messaggio = "Reservas cercanas a la reserva"; break;
+case "vanno ripristinate manualemnte":  	$messaggio = "tienen que ser restauradas manualmente"; break;
+case "cancellare manualmente una prenotazione proveniente dalle interconnessioni":	$messaggio = "borrar manualmente una reserva llegada desde las interconexiones"; break;
+case "senza aspettare che venga cancellata dall'interconnessione":	$messaggio = "sin esperar a que sea borrada por la interconexión"; break;
+case "può creare overbooking":  		$messaggio = "puede causar overbooking"; break;
+case "rimpicciolire manualmente una prenotazione proveniente dalle interconnessioni":	$messaggio = "reducir manualmente una reserva llegada desde las interconexiones"; break;
+case "senza aspettare che venga modificata dall'interconnessione":	$messaggio = "sin esperar a que sea modificada por la interconexión"; break;
+case "gli altri campi":  			$messaggio = "las otras opciones"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
