@@ -67,7 +67,7 @@ case "nuova condizione":  			$messaggio = "nueva condición"; break;
 case "da applicare":  				$messaggio = "a aplicar"; break;
 case "solo all'inizio del documento":  		$messaggio = "solo al principio del codumento"; break;
 case "sempre":  				$messaggio = "siempre"; break;
-case "azione":  				$messaggio = "ación"; break;
+case "azione":  				$messaggio = "acción"; break;
 case "aggiungi un altro &quot;se&quot;":  	$messaggio = "añadir otro &quot;si&quot;"; break;
 case "azzera l'array":  			$messaggio = "anular el array"; break;
 case "assegna all'array":  			$messaggio = "asignar al array"; break;
