@@ -73,25 +73,6 @@ case "spazio":  				$messaggio = "espacio"; break;
 case "trattino":  				$messaggio = "raya"; break;
 case "a capo":  				$messaggio = "nueva línea"; break;
 case "Pagine per il sito web":  		$messaggio = "Páginas para el sitio web"; break;
-case " Do":  					$messaggio = " Do"; break;
-case " Lu":  					$messaggio = " Lu"; break;
-case " Ma":  					$messaggio = " Ma"; break;
-case " Me":  					$messaggio = " Mi"; break;
-case " Gi":  					$messaggio = " Ju"; break;
-case " Ve":  					$messaggio = " Vi"; break;
-case " Sa":  					$messaggio = " Sá"; break;
-case "Gen":  					$messaggio = "Ene"; break;
-case "Feb":  					$messaggio = "Feb"; break;
-case "Mar":  					$messaggio = "Mar"; break;
-case "Apr":  					$messaggio = "Abr"; break;
-case "Mag":  					$messaggio = "May"; break;
-case "Giu":  					$messaggio = "Jun"; break;
-case "Lug":  					$messaggio = "Jul"; break;
-case "Ago":  					$messaggio = "Ago"; break;
-case "Set":  					$messaggio = "Sep"; break;
-case "Ott":  					$messaggio = "Oct"; break;
-case "Nov":  					$messaggio = "Nov"; break;
-case "Dic":  					$messaggio = "Dic"; break;
 case "nome della tariffa":  			$messaggio = "nombre de la tarifa"; break;
 case "data di inserimento":  			$messaggio = "fecha de inserción"; break;
 case "tariffa completa":  			$messaggio = "tarifa completa"; break;
@@ -160,7 +141,7 @@ case "Il mascheramento della provenienza delle email è stato cambiato":	$messag
 case "SI":  					$messaggio = "SI"; break;
 case "NO":  					$messaggio = "NO"; break;
 case "Cartelle in cui creare le pagine per il sito web":	$messaggio = "Carpetas en donde crear las páginas para el sitio web"; break;
-case "percorsi separati da virgole relativi":	$messaggio = "recorridos separados por comas relativos"; break;
+case "percorsi relativi":  			$messaggio = "recorridos relativos"; break;
 case "alla cartella di HotelDruid, se non iniziano con /":	$messaggio = "a la carpeta de HotelDruid, si no empiezan con /"; break;
 case "Non ho i permessi di scrittura sulla cartella":	$messaggio = "No tengo permisos para escribir en el directorio"; break;
 case "La cartella inserita <div style=\"display: inline; color: red;\">non esiste</div>":	$messaggio = "El directorio insertado <div style=\"display: inline; color: red;\">no existe</div>"; break;
@@ -485,6 +466,12 @@ case "configurare il loro server remoto smtp":	$messaggio = "configurar su servi
 case "per inviare email":  			$messaggio = "para enviar correos electrónicos"; break;
 case "da hoteldruid":  				$messaggio = "desde hoteldruid"; break;
 case "senza che vengano considerate come spam":	$messaggio = "sin que sean considerados spam"; break;
+case "Secondo cognome disattivato":  		$messaggio = "Segundo apellido desactivado"; break;
+case "Secondo cognome attivato":  		$messaggio = "Segundo apellido activado"; break;
+case "Fuso orario":  				$messaggio = "Zona horaria"; break;
+case "nessun fuso orario":  			$messaggio = "ninguna zona horaria"; break;
+case "Si possono creare solo cartelle con nome composto da lettere e numeri":	$messaggio = "Solo se pueden crear carpetas con nombres que contengan letras y números"; break;
+case "la seguente cartella verrà creata":  	$messaggio = "se creará la siguiente carpeta"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
