@@ -5,6 +5,7 @@
 # numbers and underscore: NO ACCENTS, NO SPACES
 
 $trad_var['cognome'] = 'apellido';
+$trad_var['cognome2'] = 'apellido2';
 $trad_var['nome'] = 'nombre';
 $trad_var['soprannome'] = 'apodo';
 $trad_var['titolo'] = 'titulo';
@@ -187,13 +188,14 @@ $trad_var['num_ospiti_tot'] = 'num_huespedes_tot';
 $trad_var['numero_ospite'] = 'numero_huesped';
 $trad_var['numero_cliente_ospite'] = 'numero_cliente_huesped';
 $trad_var['cognome_ospite'] = 'apellido_huesped';
+$trad_var['cognome2_ospite'] = 'apellido2_huesped';
 $trad_var['nome_ospite'] = 'nombre_huesped';
 $trad_var['soprannome_ospite'] = 'apodo_huesped';
 $trad_var['titolo_ospite'] = 'titulo_huesped';
 $trad_var['sesso_ospite'] = 'sexo_huesped';
 $trad_var['cittadinanza_ospite'] = 'nacionalidad_huesped';
 $trad_var['parentela_ospite'] = 'emparentado_huesped';
-$trad_var['datanascita_ospite'] = 'fecha_nacimiento_huesped';
+$trad_var['data_nascita_ospite'] = 'fecha_nacimiento_huesped';
 $trad_var['citta_nascita_ospite'] = 'ciudad_nacimiento_huesped';
 $trad_var['regione_nascita_ospite'] = 'region_nacimiento_huesped';
 $trad_var['nazione_nascita_ospite'] = 'nacion_nacimiento_huesped';
@@ -261,6 +263,9 @@ $trad_var['piano_unita'] = 'piso_unidad';
 $trad_var['capacita_unita'] = 'capacidad_unidad';
 $trad_var['priorita_unita'] = 'prioridad_unidad';
 $trad_var['num_unita'] = 'num_unidades';
+$trad_var['lista_inventario_unita'] = 'lista_inventario_unidad';
+$trad_var['mancanti_inventario_unita'] = 'faltantes_inventario_unidad';
+$trad_var['dettagli_inventario_unita'] = 'detalles_inventario_unidad';
 $trad_var['costo_tot_somma_ripetizioni'] = 'coste_tot_suma_repeticiones';
 $trad_var['costo_tot_somma_ripetizioni_p'] = 'coste_tot_suma_repeticiones_p';
 $trad_var['caparra_somma_ripetizioni'] = 'fianza_suma_repeticiones';
@@ -274,6 +279,7 @@ $trad_var['resto_da_pagare_somma_ripetizioni_p'] = 'resto_a_pagar_suma_repeticio
 $trad_var['num_persone_tot_somma_ripetizioni'] = 'num_personas_tot_suma_repeticiones';
 $trad_var['data_inizio_selezione'] = 'fecha_inicial_seleccion';
 $trad_var['data_fine_selezione'] = 'fecha_final_seleccion';
+$trad_var['numero_prenotazioni_selezione'] = 'numero_reservas_seleccion';
 $trad_var['utente_attuale'] = 'usuario_actual';
 $trad_var['nome_struttura'] = 'nombre_estructura';
 $trad_var['tipo_struttura'] = 'tipo_estructura';
