@@ -30,35 +30,9 @@ $sec_limite_libsett = 0;
 #if (function_exists('ini_set')) @ini_set('xdebug.max_nesting_level',1000000);
 
 
-# Function per passare dalla tabella prenota alle variabili
-function tab_a_var (&$limiti_var,&$app_prenota_id,&$app_orig_prenota_id,&$inizio_prenota_id,&$fine_prenota_id,&$app_assegnabili_id,&$prenota_in_app_sett,$anno,&$dati_app,$profondita,$nome_tab_prenota = "prenota") {
-global $PHPR_TAB_PRE,$sec_limite_libsett,$debug;
-if ($nome_tab_prenota == "prenota") $nome_tab_prenota = $PHPR_TAB_PRE.$nome_tab_prenota;
-if (!isset($profondita['iniziale'])) $profondita['iniziale'] = "";
-$tableprenota = $nome_tab_prenota.$anno.$profondita['iniziale'];
-$tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
-$tableappartamenti = $PHPR_TAB_PRE."appartamenti";
 
-if (empty($limiti_var['idperiodocorrente'])) $limiti_var['idperiodocorrente'] = calcola_id_periodo_corrente($anno);
-if (!isset($limiti_var['tutti_fissi'])) {
-$tablepersonalizza = $PHPR_TAB_PRE."personalizza";
-$prenota_tutte_fisse = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'tutti_fissi' and idutente = '1'");
-$limiti_var['tutti_fissi'] = risul_query($prenota_tutte_fisse,0,'valpersonalizza');
-if ($limiti_var['tutti_fissi'] != "SI") {
-if (defined("C_SEC_LIMITE_LIBERA_APP") and C_SEC_LIMITE_LIBERA_APP != "") $sec_limite_libsett = C_SEC_LIMITE_LIBERA_APP;
-else $sec_limite_libsett = $limiti_var['tutti_fissi'];
-} # fine if ($limiti_var['tutti_fissi'] != "SI")
-else $sec_limite_libsett = 2;
-$limiti_var['t_limite'] = (time() + $sec_limite_libsett);
-} # fine if (!isset($limiti_var['tutti_fissi']))
-if (!isset($limiti_var['lim_prenota_temp'])) {
-$minuti_durata_insprenota = esegui_query("select valpersonalizza_num from $tablepersonalizza where idpersonalizza = 'minuti_durata_insprenota' and idutente = '1'");
-$minuti_durata_insprenota = risul_query($minuti_durata_insprenota,0,'valpersonalizza_num');
-$limiti_var['lim_prenota_temp'] = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600) - ($minuti_durata_insprenota * 60)));
-} # fine if (!isset($limiti_var['lim_prenota_temp']))
-
-# metto i dati della tabella appartamenti in $dati_app
-if (empty($dati_app)) {
+function prendi_dati_app ($tableappartamenti) {
+$dati_app = array();
 $idapp = esegui_query("select idappartamenti,maxoccupanti,app_vicini from $tableappartamenti order by priorita");
 $numappartamenti = numlin_query($idapp);
 $grp_vicini = array();
@@ -109,7 +83,41 @@ $dati_app['grp_vicini_num'][count($dati_app['grp_vicini_num'])] = count($val_vic
 $dati_app['grp_vicini'][count($dati_app['grp_vicini'])] = ",".implode(",",$val_vicini).",";
 } # fine if ($grp_vicini[$num1])
 } # fine for $num1
-} # fine if (empty($dati_app))
+return $dati_app;
+} # fine function prendi_dati_app
+
+
+
+
+# Function per passare dalla tabella prenota alle variabili
+function tab_a_var (&$limiti_var,&$app_prenota_id,&$app_orig_prenota_id,&$inizio_prenota_id,&$fine_prenota_id,&$app_assegnabili_id,&$prenota_in_app_sett,$anno,&$dati_app,$profondita,$nome_tab_prenota = "prenota") {
+global $PHPR_TAB_PRE,$sec_limite_libsett,$debug;
+if ($nome_tab_prenota == "prenota") $nome_tab_prenota = $PHPR_TAB_PRE.$nome_tab_prenota;
+if (!isset($profondita['iniziale'])) $profondita['iniziale'] = "";
+$tableprenota = $nome_tab_prenota.$anno.$profondita['iniziale'];
+$tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
+$tableappartamenti = $PHPR_TAB_PRE."appartamenti";
+
+if (empty($limiti_var['idperiodocorrente'])) $limiti_var['idperiodocorrente'] = calcola_id_periodo_corrente($anno);
+if (!isset($limiti_var['tutti_fissi'])) {
+$tablepersonalizza = $PHPR_TAB_PRE."personalizza";
+$prenota_tutte_fisse = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'tutti_fissi' and idutente = '1'");
+$limiti_var['tutti_fissi'] = risul_query($prenota_tutte_fisse,0,'valpersonalizza');
+if ($limiti_var['tutti_fissi'] != "SI") {
+if (defined("C_SEC_LIMITE_LIBERA_APP") and C_SEC_LIMITE_LIBERA_APP != "") $sec_limite_libsett = C_SEC_LIMITE_LIBERA_APP;
+else $sec_limite_libsett = $limiti_var['tutti_fissi'];
+} # fine if ($limiti_var['tutti_fissi'] != "SI")
+else $sec_limite_libsett = 2;
+$limiti_var['t_limite'] = (time() + $sec_limite_libsett);
+} # fine if (!isset($limiti_var['tutti_fissi']))
+if (!isset($limiti_var['lim_prenota_temp'])) {
+$minuti_durata_insprenota = esegui_query("select valpersonalizza_num from $tablepersonalizza where idpersonalizza = 'minuti_durata_insprenota' and idutente = '1'");
+$minuti_durata_insprenota = risul_query($minuti_durata_insprenota,0,'valpersonalizza_num');
+$limiti_var['lim_prenota_temp'] = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600) - ($minuti_durata_insprenota * 60)));
+} # fine if (!isset($limiti_var['lim_prenota_temp']))
+
+# metto i dati della tabella appartamenti in $dati_app
+if (empty($dati_app)) $dati_app = prendi_dati_app($tableappartamenti);
 
 if (!isset($limiti_var['ini']) or (string) $limiti_var['ini'] == "") $limiti_var['ini'] = ($limiti_var['n_fine'] + 1);
 if (!isset($limiti_var['fine']) or (string) $limiti_var['fine'] == "") $limiti_var['fine'] = ($limiti_var['n_ini'] - 1);
@@ -166,9 +174,9 @@ if ($assegnazione_app == "c") $lista_app = ",".$app_assegnabili.",";
 $app_in_lista = explode (",", $lista_app);
 $num_app_in_lista = count($app_in_lista) - 1;
 for ($num2 = 1 ; $num2 < $num_app_in_lista ; $num2++) {
-if ($dati_app['maxocc'][$app_in_lista[$num2]] and $dati_app['maxocc'][$app_in_lista[$num2]] < $num_persone) {
+if (!empty($dati_app['maxocc'][$app_in_lista[$num2]]) and $dati_app['maxocc'][$app_in_lista[$num2]] < $num_persone) {
 $lista_app = str_replace(",".$app_in_lista[$num2].",",",",$lista_app);
-} # fine if ($dati_app['maxocc'][$app_in_lista[$num2]] and $dati_app['maxocc'][$app_in_lista[$num2]] < $num_persone)
+} # fine if (!empty($dati_app['maxocc'][$app_in_lista[$num2]]) and $dati_app['maxocc'][$app_in_lista[$num2]] < $num_persone)
 } # fine for $num2
 $lista_app = substr($lista_app,1,-1);
 $app_assegnabili_id[$idprenota] = $lista_app;
@@ -389,7 +397,7 @@ $app_richiesti[',vicini,'] = "SI";
 $app_richiesti[',numero,'] = $num_idprenota_comp + 1;
 for ($num1 = 0 ; $num1 < $num_idprenota_comp ; $num1++) {
 $id_comp = $idprenota_comp[$num1];
-if ($fine_prenota_id[$id_comp]) {
+if (!empty($fine_prenota_id[$id_comp])) {
 $id_ric++;
 $idinizioprenota[$id_ric] = $inizio_prenota_id[$id_comp];
 $idfineprenota[$id_ric] = $fine_prenota_id[$id_comp];
@@ -400,7 +408,7 @@ for ($num2 = $idinizioprenota[$id_ric] ; $num2 <= $idfineprenota[$id_ric] ; $num
 $prenota_in_app_sett[$app_prenota_id[$id_comp]][$num2] = "";
 } # fine for $num2
 #$app_prenota_id[$id_comp] = "";
-} # fine if ($fine_prenota_id[$id_comp])
+} # fine if (!empty($fine_prenota_id[$id_comp]))
 } # fine for $num1
 } # fine function cancella_prenota_compagne
 
@@ -411,7 +419,7 @@ function ripristina_prenota_compagne ($idprenota_comp,$num_idprenota_comp,&$idin
 global $debug;
 for ($num1 = 0 ; $num1 < $num_idprenota_comp ; $num1++) {
 $id_comp = $idprenota_comp[$num1];
-if ($fine_prenota_id[$id_comp]) {
+if (!empty($fine_prenota_id[$id_comp])) {
 $id_ric = $num1 + 2;
 $app_prenota_id[$id_comp] = $appartamento[$id_ric];
 if ($debug == "on") {
@@ -422,7 +430,7 @@ echo "<b>".$profondita['attuale']."</b> spostata pren $id_comp in  ".$appartamen
 for ($num2 = $idinizioprenota[$id_ric] ; $num2 <= $idfineprenota[$id_ric] ; $num2++) {
 $prenota_in_app_sett[$appartamento[$id_ric]][$num2] = $id_comp;
 } # fine for $num2
-} # fine if ($fine_prenota_id[$id_comp])
+} # fine if (!empty($fine_prenota_id[$id_comp]))
 } # fine for $num1
 $idinizioprenota = $idinizioprenota[1];
 $idfineprenota = $idfineprenota[1];
@@ -492,7 +500,8 @@ $app_richiesti_vett['id']++;
 $limiti_var['n_ini'] = $idinizio_vett[$app_richiesti_vett['id']];
 $limiti_var['n_fine'] = $idfine_vett[$app_richiesti_vett['id']];
 } # fine else if (empty($app_richiesti_vett['id']))
-unset($app_richiesti);
+$app_richiesti = array();
+#unset($app_richiesti);
 if ($app_richiesti_vett[$app_richiesti_vett['id']] != ",tutti,") {
 $vett_app = explode(",",$app_richiesti_vett[$app_richiesti_vett['id']]);
 $n_vett_app = count($vett_app);
@@ -619,7 +628,7 @@ $app_controllati .= substr($dati_app['grp_vicini'][$num2],1);
 break;
 } # fine if (strstr($dati_app['grp_vicini'][$num2],",$numapp,"))
 } # fine for $num2
-} # fine if ((empty($app_richiesti) or $app_richiesti[$numapp] == "SI") and !strstr($app_controllati,",$numapp,"))
+} # fine if ((empty($app_richiesti) or (isset($app_richiesti[$numapp]) and $app_richiesti[$numapp] == "SI")) and !strstr($app_controllati,",$numapp,") and...
 } # fine for $num1
 if ($num_vicini_tot > $num_vicini_disp_tot) $app_non_liberabili .= substr($app_gruppi_disp,1);
 elseif ($num_vicini_tot > $num_vicini and $app_gruppi_disp) {
@@ -755,7 +764,7 @@ if ($num3 != $num1) {
 $numapp2 = $dati_app['posizione'][$num3];
 if ((isset($app_assegnabili_id[$idprenotainperiodo]) and $app_assegnabili_id[$idprenotainperiodo] == "v") or (isset($app_assegnabili[$idprenotainperiodo][$numapp2]) and $app_assegnabili[$idprenotainperiodo][$numapp2] == "SI")) {
 $prenotainperiodo2 = prenota_in_app_e_periodo($numapp2,$inizio_prenota_id[$idprenotainperiodo],$fine_prenota_id[$idprenotainperiodo],$prenota_in_app_sett,$fine_prenota_id,$num_pp2);
-if (!$num_pp2 and !$app_assegnabili_id[0][$idprenotainperiodo]) {
+if (!$num_pp2 and empty($app_assegnabili_id[0][$idprenotainperiodo])) {
 $nuovo_app[$idprenotainperiodo] = $numapp2;
 $liberabile[$idprenotainperiodo] = "SI";
 $scambiabile[$idprenotainperiodo] = "NO";
@@ -790,7 +799,7 @@ if ($prenota_fissa_presente == "NO") {
 $scambiabile[$idprenotainperiodo] = "SI";
 $da_scambiare[$idprenotainperiodo][$numapp2] = "SI";
 } # fine if ($prenota_fissa_presente == "NO")
-} # fine else if (!$num_pp2)
+} # fine else if (!$num_pp2 and...
 } # fine if ((isset($app_assegnabili_id[$idprenotainperiodo]) and $app_assegnabili_id[$idprenotainperiodo] == "v") or...
 } # fine if ($num3 != $num1)
 } # fine for $num3
@@ -916,7 +925,7 @@ $limiti_var_orig = $limiti_var;
 $num_pp_s = $num_pp;
 $prenotainperiodo_s = $prenotainperiodo;
 $scambiabile_s = $scambiabile;
-unset($prenotainperiodo_agg);
+$prenotainperiodo_agg = array();
 for ($num2 = 1 ; $num2 <= $num_pp_s ; $num2++) {
 $idprenotainperiodo = $prenotainperiodo_s[$num2];
 if ($scambiabile_s[$idprenotainperiodo] == "SI") {
@@ -933,13 +942,13 @@ if ($numapp != $n_app_prenota_id[$idprenotainperiodo]) {
 $idinizio_prenota_falsa = $idinizio_rimpicciolito;
 $prenota_falsa_da_inserire = "NO";
 for ($num3 = $idinizio_rimpicciolito ; $num3 <= ($idfine_rimpicciolito + 1) ; $num3++) {
-if ($n_prenota_in_app_sett[$numapp][$num3] and !$prenotainperiodo_agg[$n_prenota_in_app_sett[$numapp][$num3]] and $num3 != ($idfine_rimpicciolito + 1)) {
+if (!empty($n_prenota_in_app_sett[$numapp][$num3]) and empty($prenotainperiodo_agg[$n_prenota_in_app_sett[$numapp][$num3]]) and $num3 != ($idfine_rimpicciolito + 1)) {
 $prenotainperiodo_agg[$n_prenota_in_app_sett[$numapp][$num3]] = 1;
 $num_pp_s++;
 $prenotainperiodo_s[$num_pp_s] = $n_prenota_in_app_sett[$numapp][$num3];
 $scambiabile_s[$n_prenota_in_app_sett[$numapp][$num3]] = "SI";
-} # fine ($n_prenota_in_app_sett[$numapp][$num3] and !$prenotainperiodo_agg[$n_prenota_in_app_sett[$numapp][$num3]] and...
-if ($n_prenota_in_app_sett[$numapp][$num3] or $num3 == ($idfine_rimpicciolito + 1)) {
+} # fine (!empty($n_prenota_in_app_sett[$numapp][$num3]) and empty($prenotainperiodo_agg[$n_prenota_in_app_sett[$numapp][$num3]]) and...
+if (!empty($n_prenota_in_app_sett[$numapp][$num3]) or $num3 == ($idfine_rimpicciolito + 1)) {
 if ($prenota_falsa_da_inserire == "SI") {
 $nuova_profondita['tot_prenota_attuale']++;
 $n_app_prenota_id[$nuova_profondita['tot_prenota_attuale']] = $numapp;
@@ -951,11 +960,11 @@ $n_prenota_in_app_sett[$numapp][$num4] = $nuova_profondita['tot_prenota_attuale'
 } # fine if ($prenota_falsa_da_inserire == "SI")
 $prenota_falsa_da_inserire = "NO";
 $idinizio_prenota_falsa = $num3 + 1;
-} # fine if ($n_prenota_in_app_sett[$numapp][$num2] or $num2 == ($idfine+1))
+} # fine if (!empty($n_prenota_in_app_sett[$numapp][$num3]) or $num3 == ($idfine_rimpicciolito + 1))
 else {
 $prenota_falsa_da_inserire = "SI";
 $idfine_prenota_falsa = $num3;
-} # fine else if ($n_prenota_in_app_sett[$numapp][$num2] or $num2 == ($idfine+1))
+} # fine else if (!empty($n_prenota_in_app_sett[$numapp][$num3]) or $num3 == ($idfine_rimpicciolito + 1))
 } # fine for $num3
 } # fine if ($numapp != $n_app_prenota_id[$idprenotainperiodo])
 
@@ -968,7 +977,7 @@ $n_prenota_in_app_sett[$numapp][$num3] = "";
 for ($num3 = ($idfine_rimpicciolito + 1) ; $num3 <= $idfineprenota2 ; $num3++) {
 $n_prenota_in_app_sett[$numapp][$num3] = "";
 } # fine for $num3
-$app_assegnabili_id2 = $app_assegnabili_id[$idprenotainperiodo];
+$app_assegnabili_id2 = fixset($app_assegnabili_id[$idprenotainperiodo]);
 $app_assegnabili_id[$idprenotainperiodo] = "";
 $ap_ric = array();
 for ($num3 = 0 ; $num3 < $dati_app['totapp'] ; $num3++) {
@@ -979,13 +988,13 @@ $ap_ric[$numapp2] = "SI";
 } # fine for $num3
 
 # Se la prenotazione da scambiare ne ha altre compagne
-if ($app_assegnabili_id[0][$idprenotainperiodo]) {
+if (!empty($app_assegnabili_id[0][$idprenotainperiodo])) {
 $idprenota_comp = explode(",",$app_assegnabili_id[0][$idprenotainperiodo]);
 $num_idprenota_comp = count($idprenota_comp);
 cancella_prenota_compagne($idprenota_comp,$num_idprenota_comp,$idinizioprenota2,$idfineprenota2,$ap_ric,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$n_app_prenota_id,$n_prenota_in_app_sett);
-$app_richiesti_orig = $app_assegnabili_id[0][0];
+$app_richiesti_orig = fixset($app_assegnabili_id[0][0]);
 $app_assegnabili_id[0][0] = "";
-} # fine if ($app_assegnabili_id[0][$idprenotainperiodo])
+} # fine if (!empty($app_assegnabili_id[0][$idprenotainperiodo]))
 
 $appartamento2 = "";
 $fatto2 = "";
@@ -1013,16 +1022,16 @@ for ($i = 0 ; $i < $profondita['attuale'] ; $i++) echo "&nbsp;&nbsp;";
 echo "<b>".$profondita['attuale']."</b> finito <em>".date("H:i:s")."</em> $fatto2 (app $appartamento2)<br>";
 } # fine if ($debug == "on")
 
-if ($app_assegnabili_id[0][$idprenotainperiodo]) {
+if (!empty($app_assegnabili_id[0][$idprenotainperiodo])) {
 $inizio_prenota_id[$idprenotainperiodo] = $idinizioprenota2[1];
 $fine_prenota_id[$idprenotainperiodo] = $idfineprenota2[1];
 if ($fatto2 == "SI") ripristina_prenota_compagne($idprenota_comp,$num_idprenota_comp,$idinizioprenota2,$idfineprenota2,$appartamento2,$n_app_prenota_id,$n_prenota_in_app_sett,$fine_prenota_id,$profondita);
 $app_assegnabili_id[0][0] = $app_richiesti_orig;
-} # fine if ($app_assegnabili_id[0][$idprenotainperiodo])
+} # fine if (!empty($app_assegnabili_id[0][$idprenotainperiodo]))
 else {
 $inizio_prenota_id[$idprenotainperiodo] = $idinizioprenota2;
 $fine_prenota_id[$idprenotainperiodo] = $idfineprenota2;
-} # fine else if ($app_assegnabili_id[0][$idprenotainperiodo])
+} # fine else if (!empty($app_assegnabili_id[0][$idprenotainperiodo]))
 $app_assegnabili_id[$idprenotainperiodo] = $app_assegnabili_id2;
 
 if ($fatto2 == "SI") {
@@ -1108,7 +1117,8 @@ if ($ini_blocco2 == $idiniziop and $fine_blocco2 == $idfinep) {
 $scambiabili = "SI";
 for ($num3 = $idiniziop ; $num3 <= $idfinep ; $num3++) {
 if (!empty($prenota_in_app_sett[$numapp2][$num3])) {
-$app_ass_num3 = $app_assegnabili_id[$prenota_in_app_sett[$numapp2][$num3]];
+if (isset($prenota_in_app_sett[$numapp2][$num3]) and isset($app_assegnabili_id[$prenota_in_app_sett[$numapp2][$num3]])) $app_ass_num3 = $app_assegnabili_id[$prenota_in_app_sett[$numapp2][$num3]];
+else $app_ass_num3 = "";
 if ($app_ass_num3 != "v" and str_replace(",$numapp,","",$app_ass_num3) == $app_ass_num3) {
 $scambiabili = "NO";
 break;
@@ -1158,11 +1168,11 @@ $n_prenota_in_app_sett[$appartamento][$num1] = $id_prenota_lib;
 if (isset($app_richiesti_vett[',vicini,']) and $app_richiesti_vett[',vicini,'] == "SI" and empty($app_richiesti_vett[',succ_non_vicino,'][$app_richiesti_vett['id']])) {
 $fatto = "NO";
 $lim_for = $app_richiesti_vett[',numero,'];
-if ($lim_for != ($app_richiesti_vett['id'] + 1) and $limiti_var['t_limite'] < time()) {
-$lim_for = ($app_richiesti_vett['id'] + 1);
 if (($limiti_var['t_limite'] + 20) < time()) $lim_for = 0;
+elseif ($lim_for > ($app_richiesti_vett['id'] + 1) and $limiti_var['t_limite'] < time()) {
+$lim_for = ($app_richiesti_vett['id'] + 1);
 if ($debug == "on") echo "timeout<br>";
-} # fine if ($lim_for != ($app_richiesti_vett['id'] + 1) and $limiti_var['t_limite'] < time())
+} # fine elseif ($lim_for > ($app_richiesti_vett['id'] + 1) and $limiti_var['t_limite'] < time())
 for ($num1 = ($app_richiesti_vett['id'] + 1) ; $num1 <= $lim_for ; $num1++) {
 if (!isset($provato[$idinizio_vett[$num1]][$idfine_vett[$num1]][$app_richiesti_vett[$num1]])) {
 $provato[$idinizio_vett[$num1]][$idfine_vett[$num1]][$app_richiesti_vett[$num1]] = 1;
@@ -1218,7 +1228,7 @@ else {
 if ($app_richiesti_vett[$app_richiesti_vett['id']] == ",tutti,") $app_assegnabili_id[$id_prenota_lib] = "v";
 else if (str_replace(",","",$app_richiesti_vett[$app_richiesti_vett['id']]) != $app_richiesti_vett[$app_richiesti_vett['id']]) $app_assegnabili_id[$id_prenota_lib] = $app_richiesti_vett[$app_richiesti_vett['id']];
 liberasettimane($idinizio_vett,$idfine_vett,$limiti_var,$anno,$fatto,$appartamento_vett,$nuova_profondita,$app_richiesti_vett,$n_app_prenota_id,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$n_prenota_in_app_sett,$dati_app,$nome_tab_prenota);
-} # fine else if ($app_richiesti[',vicini,'] == "SI" and !$app_richiesti_vett[',succ_non_vicino,'][$app_richiesti_vett['id']])
+} # fine else if (isset($app_richiesti_vett[',vicini,']) and $app_richiesti_vett[',vicini,'] == "SI" and...
 
 if ($fatto == "SI") {
 $app_prenota_id = $n_app_prenota_id;
@@ -1238,7 +1248,7 @@ $fine_prenota_id[$id_prenota_lib] = "";
 $app_assegnabili_id[$id_prenota_lib] = "";
 } # fine if ($app_richiesti_vett[',numero,'] > $app_richiesti_vett['id'])
 else $appartamento_vett[$app_richiesti_vett['id']] = $appartamento;
-$appartamento = $appartamento_vett;
+$appartamento = fixset($appartamento_vett);
 } # fine if ($fatto == "SI" and !empty($app_richiesti_vett[',numero,']))
 
 
@@ -1279,7 +1289,7 @@ echo "<b>".$profondita['attuale']."</b> fatto riprova ".$app_richiesti_vett['id'
 if ($fatto == "SI") {
 $app_prenota_id = $n_app_prenota_id;
 $prenota_in_app_sett = $n_prenota_in_app_sett;
-$appartamento = $appartamento_vett;
+$appartamento = fixset($appartamento_vett);
 } # fine if ($fatto == "SI")
 else aggiorna_app_aggiunti($limiti_var,$limiti_var_orig,$app_orig_prenota_id,$app_prenota_id,$inizio_prenota_id,$fine_prenota_id,$prenota_in_app_sett);
 } # fine if ((string) $app_richiesti_vett[$app_richiesti_vett['id']] != "")
@@ -1297,4 +1307,103 @@ if (!empty($ass00)) $app_assegnabili_id[0][0] = "";
 
 
 
+
+function trova_numpersone_per_app (&$lista_app,&$posti_mancanti,&$cat_pers_letto,&$cat_persone,&$dati_app_pos,$dati_app,$napp_r2,$numpersone_orig,$dati_cat_pers) {
+# in $dati_app_pos cambio la priorità mettendo prima gli app più capienti mantenendo la priorità per capienze uguali
+if (!is_array($dati_app_pos)) {
+$num1 = 0;
+$mo_esist = array();
+$dati_app_pos = array();
+reset($dati_app['maxocc']);
+foreach ($dati_app['maxocc'] as $app => $maxocc) {
+if (!isset($mo_esist[$maxocc]) and strcmp((string) $maxocc,"")) {
+$mo_esist[$maxocc] = 1;
+for ($num2 = ($dati_app['totapp'] - 1) ; $num2 >= 0 ; $num2--) {
+$idapp = $dati_app['posizione'][$num2];
+if ($dati_app['maxocc'][$idapp] == $maxocc) {
+$num1++;
+$dati_app_pos[($dati_app['totapp'] - $num1)] = $idapp;
+} # fine if ($dati_app['maxocc'][$idapp] == $maxocc)
+} # fine for ($num2
+} # fine if (!isset($mo_esist[$maxocc]) and strcmp((string) $maxocc,""))
+} # fine foreach ($dati_app['maxocc'] as $app => $maxocc)
+for ($num2 = ($dati_app['totapp'] - 1) ; $num2 >= 0 ; $num2--) {
+$idapp = $dati_app['posizione'][$num2];
+if (!strcmp((string) $dati_app['maxocc'][$idapp],"")) {
+$num1++;
+$dati_app_pos[($dati_app['totapp'] - $num1)] = $idapp;
+} # fine if (!strcmp((string) $dati_app['maxocc'][$idapp],""))
+} # fine for ($num2
+} # fine if (!is_array($dati_app_pos))
+$tot_pers_max = 0;
+$num_app_corr = 0;
+$maxocc = array();
+$numpersone_nr = array();
+for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
+$idapp = $dati_app_pos[$num1];
+if (str_replace(",$idapp,","",",$lista_app,") != ",$lista_app,") {
+$num_app_corr++;
+if ($dati_app['maxocc'][$idapp]) $maxocc[$num_app_corr] = $dati_app['maxocc'][$idapp];
+else $maxocc[$num_app_corr] = $numpersone_orig;
+if ($num_app_corr <= $napp_r2) {
+$tot_pers_max += $maxocc[$num_app_corr];
+if ($num_app_corr == ($napp_r2 - 1)) $tot_pers_max_meno_1 = $tot_pers_max;
+if ($num_app_corr == $napp_r2) {
+$maxocc_min = $maxocc[$num_app_corr];
+if ($tot_pers_max < $numpersone_orig) {
+# uso "posti mancanti" per vedere dopo se è possibile inserire la prenotazione con i letti aggiuntivi
+$posti_mancanti = ($numpersone_orig - $tot_pers_max);
+$numpersone_assegna = $tot_pers_max;
+} # fine if ($tot_pers_max < $numpersone_orig)
+else $numpersone_assegna = $numpersone_orig;
+# metto $numpersone_nr con le persone di ogni appartamento per i controlli dei costi aggiuntivi e degli app assegnabili
+for ($num2 = 0 ; $num2 < $napp_r2 ; $num2++) $numpersone_nr[$num2] = 0;
+$num2 = 0;
+$num_pers_corr = 0;
+while ($num_pers_corr < $numpersone_assegna) {
+$num2++;
+if ($numpersone_nr[($num2 - 1)] < $maxocc[$num2]) {
+$numpersone_nr[($num2 - 1)]++;
+$num_pers_corr++;
+} # fine if ($numpersone_nr[($num2 - 1)] < $maxocc[$num2])
+if ($num2 == $napp_r2) $num2 = 0;
+} # fine while ($num_pers_corr < $numpersone_assegna)
+} # fine if ($num_app_corr == $napp_r2)
+} # fine if ($num_app_corr <= $napp_r2)
+elseif (($tot_pers_max_meno_1 + $maxocc[$num_app_corr]) < $numpersone_orig and $maxocc[$num_app_corr] < $maxocc_min) $lista_app = substr(str_replace(",$idapp,",",",",$lista_app,"),1,-1);
+} # fine if (str_replace(",$idapp,","",",$lista_app,") != ",$lista_app,")
+} # fine for $num1
+
+$cat_pers_letto = -1;
+if ($posti_mancanti and $dati_cat_pers['num']) {
+$cat_pers_letto = -2;
+for ($num1 = 0 ; $num1 < $dati_cat_pers['num'] ; $num1++) {
+if (isset($cat_persone['ord'][$num1]) and !empty($cat_persone[$cat_persone['ord'][$num1]]['molt'])) {
+if ($posti_mancanti <= $cat_persone[$cat_persone['ord'][$num1]]['molt']) {
+$osp_princ_trovato = 0;
+if ($dati_cat_pers[$num1]['osp_princ'] != "s" or $posti_mancanti < $cat_persone[$cat_persone['ord'][$num1]]['molt']) $osp_princ_trovato = 1;
+else {
+for ($num2 = 0 ; $num2 < $dati_cat_pers['num'] ; $num2++) {
+if ($num2 != $num1 and $dati_cat_pers[$num2]['osp_princ'] == "s" and isset($cat_persone['ord'][$num2]) and !empty($cat_persone[$cat_persone['ord'][$num2]]['molt'])) {
+$osp_princ_trovato = 1;
+break;
+} # fine if ($num2 != $num1 and $dati_cat_pers[$num2]['osp_princ'] == "s" and...
+} # fine for $num2
+} # fine else if ($dati_cat_pers[$num1]['osp_princ'] != "s" or...
+if ($osp_princ_trovato) {
+$cat_pers_letto = $num1;
+$cat_persone[$cat_persone['ord'][$num1]]['molt'] = $cat_persone[$cat_persone['ord'][$num1]]['molt'] - $posti_mancanti;
+break;
+} # fine if ($osp_princ_trovato)
+} # fine if ($posti_mancanti <= $cat_persone[$cat_persone['ord'][$num1]]['molt'])
+}# fine if (isset($cat_persone['ord'][$num1]) and !empty($cat_persone[$cat_persone['ord'][$num1]]['molt']))
+} # fine for $num1
+} # fine if ($posti_mancanti and $dati_cat_pers['num'])
+
+return $numpersone_nr;
+} # fine function trova_numpersone_per_app
+
+
+
+
 ?>
