@@ -55,7 +55,7 @@ if (empty($n_tronchi)) $n_tronchi = 0;
 # prenotazione fissa, non spostabile o con $maxoccupanti troppo basso
 $numsettimane = $idfine - $idinizio + 1;
 $n_tronchi3 = -1;
-if ($limiti_var['tutti_fissi'] != "SI" and $limiti_var['t_limite'] >= time()) {
+if ($limiti_var['t_limite'] >= time()) {
 
 for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
 $numapp = $dati_app['posizione'][$num1];
@@ -155,7 +155,7 @@ if (isset($app_prenota_id_mod)) aggiorna_app_aggiunti($limiti_var,$limiti_var_or
 } # fine if ((!$num_persone or $dati_app['maxocc'][$numapp] >= $num_persone) and (empty($app_richiesti) or...
 } # fine for $num1
 
-} # fine if ($limiti_var['tutti_fissi'] != "SI" and...
+} # fine if ($limiti_var['t_limite'] >= time())
 
 $n_tronchi = $n_tronchi3;
 if ($n_tronchi != -1) {
