@@ -28,7 +28,7 @@ if (function_exists('aggiorna_var_modello')) {
 $lingua_orig = $lingua_mex;
 if ($id_utente != 1) {
 include(C_DATI_PATH."/lingua.php");
-$lingua_mex_1 = $lingua[1];
+$lingua_mex_1 = str_replace(strstr($lingua[1],"-"),"",$lingua[1]);
 } # fine if ($id_utente != 1)
 else $lingua_mex_1 = $lingua_mex;
 $lingua_mex = $lingua_mex_1;
@@ -59,7 +59,7 @@ if ($crea_modello) crea_modello_disponibilita($percorso_cartella_modello,$anno_m
 } # fine if (@is_file("$percorso_cartella_modello/mdl_disponibilita.php"))
 } # fine for $num_cart
 $lang_dir = opendir("./includes/lang/");
-include(C_DATI_PATH."/lingua.php");
+#include(C_DATI_PATH."/lingua.php");
 while ($ini_lingua = readdir($lang_dir)) {
 if ($ini_lingua != "." && $ini_lingua != "..") {
 $nome_file = mex2("mdl_disponibilita",$pag,$ini_lingua).".php";
