@@ -298,11 +298,11 @@ echo "".mex("Tag html di apertura per la formattazione delle font",$pag).":
 if (empty($file_css_frame)) $file_css_frame = "https://";
 else $file_css_frame = htmlspecialchars($file_css_frame);
 echo "".mex("Url del file css per la modalità frame",$pag).":
- <input type=\"text\" name=\"file_css_frame\" size=\"35\" value=\"$file_css_frame\"><br>";
+ <input type=\"text\" id=\"file_css_frame\" name=\"file_css_frame\" size=\"35\" value=\"$file_css_frame\"> ".upload_hd_img_form("file_css_frame",$tablepersonalizza,"css")."<br>";
 if (empty($file_js_frame)) $file_js_frame = "https://";
 else $file_js_frame = htmlspecialchars($file_js_frame);
 echo mex("Url del file javascript per la modalità frame",$pag).":
- <input type=\"text\" name=\"file_js_frame\" size=\"35\" value=\"$file_js_frame\"> <small>(".mex("non deve contenere \"php\" e deve terminare con \".js\"",$pag).")</small><br>";
+ <input type=\"text\" id=\"file_js_frame\" name=\"file_js_frame\" size=\"35\" value=\"$file_js_frame\"> <small>(".mex("non deve contenere \"php\" e deve terminare con \".js\"",$pag).")</small> ".upload_hd_img_form("file_js_frame",$tablepersonalizza,"js")."<br>";
 
 include("./includes/templates/$template_data_dir/themes.php");
 $num_temi = count($template_theme_name);
@@ -340,8 +340,9 @@ $valore_corr = $valori_tema[$num2]['default'];
 if ($sel and $modello_esistente == "SI") $valore_corr = ${"valore_tema_".$num2};
 $js_opz_tema .= "".mex("Valore del tema",$pag)." \"".mex($template_theme_name[$num1],$pag)."\" ".mex("per",$pag)." \"".$valori_tema[$num2]['name']."\":\\
  <input type=\"text\" name=\"valore_tema_$num2\" id=\"valtema$num2\" size=\"24\" value=\"".addslashes($valore_corr)."\">";
-if (!empty($valori_tema[$num2]['img'])) $js_opz_tema .= " ".upload_hd_img_form("valtema$num2",$tablepersonalizza,$num2,1);
 if (!empty($valori_tema[$num2]['comment'])) $js_opz_tema .= " <small>(".$valori_tema[$num2]['comment'].")</small>";
+if (!empty($valori_tema[$num2]['img'])) $js_opz_tema .= " ".upload_hd_img_form("valtema$num2",$tablepersonalizza,$num2,1);
+if (!empty($valori_tema[$num2]['file'])) $js_opz_tema .= " ".upload_hd_img_form("valtema$num2",$tablepersonalizza,$num2,1,$valori_tema[$num2]['file']);
 $js_opz_tema .= "<br>";
 } # fine for $num2
 $js_opz_tema .= "<input type=\"hidden\" name=\"n_col_tema\" value=\"$num_colori\"><input type=\"hidden\" name=\"n_val_tema\" value=\"$num_valori\"><\/td><\/tr><\/table>';
@@ -441,7 +442,7 @@ echo "</td></tr></table>
 </td></tr></table>";
 } # fine if (!empty($cambia_frasi))
 elseif ($modello_esistente == "SI") {
-for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) echo "<input type=\"hidden\" name=\"".$fr_frase[$num_fr]."\" value=\"".str_replace("\"","&quot;",${$fr_frase[$num_fr]})."\">";
+for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) echo "<input type=\"hidden\" name=\"".$fr_frase[$num_fr]."\" value=\"".str_replace("\"","&quot;",fixstr(${$fr_frase[$num_fr]}))."\">";
 } # fine elseif ($modello_esistente == "SI")
 
 echo "<br><div style=\"text-align: center;\"><input type=\"hidden\" name=\"$template_name\" value=\"SI\">
