@@ -576,9 +576,13 @@ if ($regola1_consentita) $motivazioni_regola1 .= "\"$motivazione\" => \"$SI\",";
 } # fine for $num1
 if ($motivazioni_regola1) $motivazioni_regola1 = substr($motivazioni_regola1,0,-1);
 
+if (defined('C_CARTELLA_CREA_MODELLI') and defined('C_CARTELLA_UPLOAD_IMG') and C_CARTELLA_UPLOAD_IMG != "" and @is_dir(C_CARTELLA_CREA_MODELLI."/".C_CARTELLA_UPLOAD_IMG)) $sovrascrivi_upl = 1;
+else $sovrascrivi_upl = 0;
 if ($file_css_frame == "https://") $file_css_frame = "";
+elseif (function_exists('upload_hd_img')) upload_hd_img($file_css_frame,"css",$sovrascrivi_upl,"css");
 if ($file_js_frame == "https://") $file_js_frame = "";
 if (!preg_match("/^((?!php).)+\.js$/i",$file_js_frame)) $file_js_frame = "";
+if ($file_js_frame and function_exists('upload_hd_img')) upload_hd_img($file_js_frame,"js",$sovrascrivi_upl,"js");
 
 $num_colori = 0;
 $num_valori = 0;
@@ -601,7 +605,7 @@ $valori_tema = $template_theme_values[$tema_sel];
 $num_valori = count($valori_tema);
 for ($num1 = 1 ; $num1 <= $num_valori ; $num1++) {
 global ${"valore_tema_".$num1};
-if (!empty($valori_tema[$num1]['pattern']) and !preg_match("/".$valori_tema[$num1]['pattern']."/i",${"valore_tema_".$num1})) ${"valore_tema_".$num1} = "";
+if (!empty($valori_tema[$num1]['pattern']) and !preg_match("/".$valori_tema[$num1]['pattern']."/i",(string) ${"valore_tema_".$num1})) ${"valore_tema_".$num1} = "";
 ${"valore_tema_".$num1} = formatta_input_var_x_file(${"valore_tema_".$num1});
 $valore_sost = ${"valore_tema_".$num1};
 if (!strcmp((string) $valore_sost,"")) $valore_sost = fixstr($valori_tema[$num1]['null']);
@@ -609,18 +613,19 @@ elseif (isset($valori_tema[$num1]['replace']) and strcmp((string) $valori_tema[$
 $prima_parte_html = str_replace("[theme_value_$num1]",$valore_sost,$prima_parte_html);
 $ultima_parte_html = str_replace("[theme_value_$num1]",$valore_sost,$ultima_parte_html);
 $extra_head_frame = str_replace("[theme_value_$num1]",$valore_sost,$extra_head_frame);
-if (!empty($valori_tema[$num1]['img']) and function_exists('upload_hd_img')) {
+if (${"valore_tema_".$num1} and (!empty($valori_tema[$num1]['img']) or !empty($valori_tema[$num1]['file'])) and function_exists('upload_hd_img')) {
 $lingua_mex_orig = $lingua_mex;
 $lingua_mex = $lingua_orig;
-upload_hd_img(${"valore_tema_".$num1},$num1);
+if (!empty($valori_tema[$num1]['file'])) upload_hd_img(${"valore_tema_".$num1},$num1,$sovrascrivi_upl,$valori_tema[$num1]['file']);
+else upload_hd_img(${"valore_tema_".$num1},$num1,$sovrascrivi_upl);
 $lingua_mex = $lingua_mex_orig;
-} # fine if ($valori_tema[$num1]['img'] and function_exists('upload_hd_img'))
+} # fine if (${"valore_tema_".$num1} and (!empty($valori_tema[$num1]['img']) or...
 } # fine for $num1
 $colori_tema = $template_theme_colors[$tema_sel];
 $num_colori = count($colori_tema);
 for ($num1 = 1 ; $num1 <= $num_colori ; $num1++) {
 global ${"colore_tema_".$num1};
-if (!preg_match("/^#[0-9a-f]{3,3}$/i",${"colore_tema_".$num1}) and !preg_match("/^#[0-9a-f]{6,6}$/i",${"colore_tema_".$num1})) ${"colore_tema_".$num1} = $colori_tema[$num1]['default'];
+if (!preg_match("/^#[0-9a-f]{3,3}$/i",(string) ${"colore_tema_".$num1}) and !preg_match("/^#[0-9a-f]{6,6}$/i",(string) ${"colore_tema_".$num1})) ${"colore_tema_".$num1} = $colori_tema[$num1]['default'];
 $prima_parte_html = str_replace("[theme_color_$num1]",${"colore_tema_".$num1},$prima_parte_html);
 $ultima_parte_html = str_replace("[theme_color_$num1]",${"colore_tema_".$num1},$ultima_parte_html);
 $extra_head_frame = str_replace("[theme_color_$num1]",${"colore_tema_".$num1},$extra_head_frame);
@@ -851,7 +856,7 @@ if (\$HOTELD_TAB_PRE) \$PHPR_TAB_PRE = \$HOTELD_TAB_PRE;
 fwrite($file,"\$lingua_modello = \$".mex("var_lingua_modello",$pag).";
 if (strtoupper(\$".mex("var_estendi_ultima_data",$pag).") == \"$SI\") \$estendi_ultima_data = \"SI\";
 else \$estendi_ultima_data = \"NO\";
-unset(\$tariffe_mostra);
+\$tariffe_mostra = array();
 reset (\$".mex("var_tariffe_mostra",$pag).");
 foreach (\$".mex("var_tariffe_mostra",$pag)." as \$key => \$val) {
 if (strtoupper(\$val) == \"$SI\") \$tariffe_mostra[\$key] = \"SI\";
