@@ -23,12 +23,12 @@
 
 global $template_name,$template_name_show,$template_file_name,$template_data_dir;
 $template_name = "availability_calendar_template";
-$template_name_show = "";
+$template_name_show = array();
 $template_name_show['en'] = "Availability calendar page";
 $template_name_show['ita'] = "Pagina calendario disponibilità";
 $template_name_show['es'] = "Página calendario disponibilidad";
 $template_class = "vmon";
-$template_file_name = "";
+$template_file_name = array();
 $template_file_name['en'] = "availability_calendar_tpl.php";
 $template_file_name['ita'] = "mdl_calendario_disponibilita.php";
 $template_file_name['es'] = "mdl_calendario_disponibilidad.php";
