@@ -199,7 +199,7 @@ unlock_tabelle($tabelle_lock);
 
 
 $num_regole2 = numlin_query($regole2);
-unset($app_regola2_orig);
+$app_regola2_orig = array();
 for ($num1 = 0 ; $num1 < $num_regole2 ; $num1++) {
 $numtariffa_regola2 = str_replace("tariffa","",risul_query($regole2,$num1,'tariffa_per_app'));
 if (isset($tariffe_mostra[$numtariffa_regola2]) and $tariffe_mostra[$numtariffa_regola2] == "SI") {
@@ -223,6 +223,7 @@ $nome_mese["11"] = $fr_Novembre;
 $nome_mese["12"] = $fr_Dicembre;
 
 # Calcolo i nomi delle tariffe
+$nome_tariffa = array();
 for ($numtariffa = 1 ; $numtariffa <= $dati_tariffe['num'] ; $numtariffa++) {
 if (isset($tariffe_mostra[$numtariffa]) and $tariffe_mostra[$numtariffa] == "SI") {
 if ($mostra_quadro_disp == "reg2") {
