@@ -51,6 +51,7 @@ $template_theme_values[1][4]['name'] = mex("URL file css",$pag);
 $template_theme_values[1][4]['default'] = "";
 $template_theme_values[1][4]['replace'] = "
 <link rel=\"stylesheet\" type=\"text/css\" href=\"[theme_value_4]\" media=\"all\">";
+$template_theme_values[1][4]['file'] = "css";
 $template_theme_values[1][5]['name'] = mex("titolo html",$pag);
 if (!empty($dati_struttura[0])) $template_theme_values[1][5]['default'] = $dati_struttura[0]." - ".mex2("Quadro indicativo disponibilità",$pag,$lingua_modello);
 else $template_theme_values[1][5]['default'] = mex2("Quadro indicativo disponibilità",$pag,$lingua_modello);
@@ -62,6 +63,7 @@ $template_theme_values[1][6]['replace'] = "
 </script>";
 $template_theme_values[1][6]['pattern'] = "^((?!php).)+\.js$";
 $template_theme_values[1][6]['comment'] = mex("non deve contenere \"php\" e deve terminare con \".js\"",$pag);
+$template_theme_values[1][6]['file'] = "js";
 
 $template_theme_html_pre[1] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"
         \"http://www.w3.org/TR/html4/strict.dtd\">
