@@ -92,49 +92,50 @@ $fr_frase[62] = "fr_Ottobre";
 $fr_frase[63] = "fr_Novembre";
 $fr_frase[64] = "fr_Dicembre";
 $fr_frase[65] = "fr_Cognome";
-$fr_frase[66] = "fr_Nome";
-$fr_frase[67] = "fr_Email";
-$fr_frase[68] = "fr_Email_alternativa";
-$fr_frase[69] = "fr_Email_certificata_o_codice_destinatario";
-$fr_frase[70] = "fr_Commento";
-$fr_frase[71] = "fr_Genere";
-$fr_frase[72] = "fr_Data_di_nascita";
-$fr_frase[73] = "fr_Documento";
-$fr_frase[74] = "fr_Nazione";
-$fr_frase[75] = "fr_Citta";
-$fr_frase[76] = "fr_Regione";
-$fr_frase[77] = "fr_Via";
-$fr_frase[78] = "fr_Numero_civico";
-$fr_frase[79] = "fr_Codice_postale";
-$fr_frase[80] = "fr_Telefono";
-$fr_frase[81] = "fr_Secondo_telefono";
-$fr_frase[82] = "fr_Terzo_telefono";
-$fr_frase[83] = "fr_Fax";
-$fr_frase[84] = "fr_Codice_fiscale";
-$fr_frase[85] = "fr_Partita_iva";
-$fr_frase[86] = "fr_Orario_stimato_di_arrivo";
-$fr_frase[87] = "fr_Accetto";
-$fr_frase[88] = "fr_Valuta_della_caparra";
-$fr_frase[89] = "fr_Metodo_di_pagamento_della_caparra";
-$fr_frase[90] = "fr_campi_necessari";
-$fr_frase[91] = "fr_asterisco_nero";
-$fr_frase[92] = "fr_asterisco_rosso";
-$fr_frase[93] = "fr_maschile";
-$fr_frase[94] = "fr_femminile";
-$fr_frase[95] = "fr_Prenota";
-$fr_frase[96] = "fr_da";
-$fr_frase[97] = "fr_OPPURE_linee";
-$fr_frase[98] = "fr_Prenotazione_istantanea_con_PayPal";
-$fr_frase[99] = "fr_Chiudi";
-$fr_frase[100] = "fr_Richesta_prenotazione";
-$fr_frase[101] = "fr_Abbiamo_ricevuto_la_sua_richiesta_di_prenotazione_ecc";
-$fr_frase[102] = "fr_Copia_della_richiesta_e_stata_inviata_a";
-$fr_frase[103] = "fr_posizioni_vicine";
-$fr_frase[104] = "fr_con_posizioni_vicine";
-$fr_frase[105] = "fr_Codice_promozionale";
-$fr_frase[106] = "fr_Codice_promozionale_applicato";
-$fr_frase[107] = "fr_Si_deve_inserire_almeno_una_persona_che_possa_ecc";
-$fr_frase[108] = "fr_Per_questa_tariffa_si_deve_inserire_un_minimo_di";
+$fr_frase[66] = "fr_Secondo_cognome";
+$fr_frase[67] = "fr_Nome";
+$fr_frase[68] = "fr_Email";
+$fr_frase[69] = "fr_Email_alternativa";
+$fr_frase[70] = "fr_Email_certificata_o_codice_destinatario";
+$fr_frase[71] = "fr_Commento";
+$fr_frase[72] = "fr_Genere";
+$fr_frase[73] = "fr_Data_di_nascita";
+$fr_frase[74] = "fr_Documento";
+$fr_frase[75] = "fr_Nazione";
+$fr_frase[76] = "fr_Citta";
+$fr_frase[77] = "fr_Regione";
+$fr_frase[78] = "fr_Via";
+$fr_frase[79] = "fr_Numero_civico";
+$fr_frase[80] = "fr_Codice_postale";
+$fr_frase[81] = "fr_Telefono";
+$fr_frase[82] = "fr_Secondo_telefono";
+$fr_frase[83] = "fr_Terzo_telefono";
+$fr_frase[84] = "fr_Fax";
+$fr_frase[85] = "fr_Codice_fiscale";
+$fr_frase[86] = "fr_Partita_iva";
+$fr_frase[87] = "fr_Orario_stimato_di_arrivo";
+$fr_frase[88] = "fr_Accetto";
+$fr_frase[89] = "fr_Valuta_della_caparra";
+$fr_frase[90] = "fr_Metodo_di_pagamento_della_caparra";
+$fr_frase[91] = "fr_campi_necessari";
+$fr_frase[92] = "fr_asterisco_nero";
+$fr_frase[93] = "fr_asterisco_rosso";
+$fr_frase[94] = "fr_maschile";
+$fr_frase[95] = "fr_femminile";
+$fr_frase[96] = "fr_Prenota";
+$fr_frase[97] = "fr_da";
+$fr_frase[98] = "fr_OPPURE_linee";
+$fr_frase[99] = "fr_Prenotazione_istantanea_con_PayPal";
+$fr_frase[100] = "fr_Chiudi";
+$fr_frase[101] = "fr_Richesta_prenotazione";
+$fr_frase[102] = "fr_Abbiamo_ricevuto_la_sua_richiesta_di_prenotazione_ecc";
+$fr_frase[103] = "fr_Copia_della_richiesta_e_stata_inviata_a";
+$fr_frase[104] = "fr_posizioni_vicine";
+$fr_frase[105] = "fr_con_posizioni_vicine";
+$fr_frase[106] = "fr_Codice_promozionale";
+$fr_frase[107] = "fr_Codice_promozionale_applicato";
+$fr_frase[108] = "fr_Si_deve_inserire_almeno_una_persona_che_possa_ecc";
+$fr_frase[109] = "fr_Per_questa_tariffa_si_deve_inserire_un_minimo_di";
 
 
 $frase[0] = "in";
@@ -203,53 +204,54 @@ $frase[62] = "Ottobre";
 $frase[63] = "Novembre";
 $frase[64] = "Dicembre";
 $frase[65] = "Cognome";
-$frase[66] = "Nome";
-$frase[67] = "Email";
-$frase[68] = "Email alternativa";
-$frase[69] = "Email certificata (PEC) o codice destinatario";
-$frase[70] = "Commento";
-$frase[71] = "Genere";
-$frase[72] = "Data di nascita";
-$frase[73] = "Documento";
-$frase[74] = "Nazione";
-$frase[75] = "Città";
-$frase[76] = "Regione";
-$frase[77] = "Via";
-$frase[78] = "Numero civico";
-$frase[79] = "Codice postale";
-$frase[80] = "Telefono";
-$frase[81] = "Secondo telefono";
-$frase[82] = "Terzo telefono";
-$frase[83] = "Fax";
-$frase[84] = "Codice fiscale";
-$frase[85] = "Partita iva";
-$frase[86] = "Orario stimato di arrivo";
-$frase[87] = "Accetto";
-$frase[88] = "Valuta della caparra";
-$frase[89] = "Metodo di pagamento della caparra";
-$frase[90] = "<small>campi necessari</small>";
-$frase[91] = "<small>*</small>";
-$frase[92] = "<span style=\\\"color: red;\\\">*</span>";
-$frase[93] = "M";
-$frase[94] = "F";
-$frase[95] = "Prenota";
-$frase[96] = "da";
-$frase[97] = "--- OPPURE ---";
-$frase[98] = "Prenotazione istantanea con PayPal";
-$frase[99] = "Chiudi";
-$frase[100] = "Richesta prenotazione";
-$frase[101] = "Abbiamo ricevuto la sua richiesta di prenotazione e risponderemo al più presto possibile";
-$frase[102] = "Copia della richiesta è stata inviata a";
-$frase[103] = "posizioni vicine";
-$frase[104] = "con posizioni vicine";
-$frase[105] = "Codice promozionale";
-$frase[106] = "Codice promozionale applicato";
-$frase[107] = "Si deve inserire almeno una persona che possa essere legalmente responsabile";
-$frase[108] = "Per questa tariffa si deve inserire un minimo di";
+$frase[66] = "Secondo cognome";
+$frase[67] = "Nome";
+$frase[68] = "Email";
+$frase[69] = "Email alternativa";
+$frase[70] = "Email certificata (PEC) o codice destinatario";
+$frase[71] = "Commento";
+$frase[72] = "Genere";
+$frase[73] = "Data di nascita";
+$frase[74] = "Documento";
+$frase[75] = "Nazione";
+$frase[76] = "Città";
+$frase[77] = "Regione";
+$frase[78] = "Via";
+$frase[79] = "Numero civico";
+$frase[80] = "Codice postale";
+$frase[81] = "Telefono";
+$frase[82] = "Secondo telefono";
+$frase[83] = "Terzo telefono";
+$frase[84] = "Fax";
+$frase[85] = "Codice fiscale";
+$frase[86] = "Partita iva";
+$frase[87] = "Orario stimato di arrivo";
+$frase[88] = "Accetto";
+$frase[89] = "Valuta della caparra";
+$frase[90] = "Metodo di pagamento della caparra";
+$frase[91] = "<small>campi necessari</small>";
+$frase[92] = "<small>*</small>";
+$frase[93] = "<span style=\\\"color: red;\\\">*</span>";
+$frase[94] = "M";
+$frase[95] = "F";
+$frase[96] = "Prenota";
+$frase[97] = "da";
+$frase[98] = "--- OPPURE ---";
+$frase[99] = "Prenotazione istantanea con PayPal";
+$frase[100] = "Chiudi";
+$frase[101] = "Richesta prenotazione";
+$frase[102] = "Abbiamo ricevuto la sua richiesta di prenotazione e risponderemo al più presto possibile";
+$frase[103] = "Copia della richiesta è stata inviata a";
+$frase[104] = "posizioni vicine";
+$frase[105] = "con posizioni vicine";
+$frase[106] = "Codice promozionale";
+$frase[107] = "Codice promozionale applicato";
+$frase[108] = "Si deve inserire almeno una persona che possa essere legalmente responsabile";
+$frase[109] = "Per questa tariffa si deve inserire un minimo di";
 
 $num_frasi = count($fr_frase);
 
 
 
 
-?>
\ No newline at end of file
+?>
