@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2025 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -115,7 +115,17 @@ function trova_url_pagina ($nome_file,$percorso_cartella_modello,$pag) {
 $url_pagina = "";
 if (defined('C_URL_CREA_MODELLI') and (strtolower(substr(C_URL_CREA_MODELLI,0,6)) == "http:/" or strtolower(substr(C_URL_CREA_MODELLI,0,7)) == "https:/")) {
 $url_pagina = C_URL_CREA_MODELLI;
-if (substr($url_pagina,0,-1) != "/") $url_pagina .= "/";
+if (defined('C_CARTELLA_CREA_MODELLI') and C_CARTELLA_CREA_MODELLI != "" and $percorso_cartella_modello != C_CARTELLA_CREA_MODELLI and substr($percorso_cartella_modello,0,strlen(C_CARTELLA_CREA_MODELLI)) == C_CARTELLA_CREA_MODELLI) {
+$percorso_cartella_modello = substr($percorso_cartella_modello,strlen(C_CARTELLA_CREA_MODELLI));
+if (substr($url_pagina,-1) != "/") {
+if (substr($percorso_cartella_modello,0,1) != "/") $url_pagina .= "/";
+} # fine if (substr($url_pagina,-1) != "/")
+else {
+if (substr($percorso_cartella_modello,0,1) == "/") $url_pagina = substr($url_pagina,0,-1);
+} # fine else if (substr($url_pagina,-1) != "/")
+$url_pagina .= $percorso_cartella_modello;
+} # fine if (defined('C_CARTELLA_CREA_MODELLI') and C_CARTELLA_CREA_MODELLI != "" and...
+if (substr($url_pagina,-1) != "/") $url_pagina .= "/";
 $url_pagina .= $nome_file;
 } # fine if (defined('C_URL_CREA_MODELLI') and (strtolower(substr(C_URL_CREA_MODELLI,0,6)) == "http:/" or...
 else {
@@ -168,6 +178,7 @@ else $url_pagina = "$url_dir$percorso_cartella_modello/$nome_file";
 } # fine else if (defined('C_DOMINIO_CREA_MODELLI') and C_DOMINIO_CREA_MODELLI and..
 
 $url_pagina = str_replace("/./","/",$url_pagina);
+$url_pagina = substr($url_pagina,0,8).str_replace("//","/",substr($url_pagina,8));
 while (str_replace("/../","",$url_pagina) != $url_pagina) {
 $url_vett1 = explode("/../",$url_pagina);
 $url_vett2 = explode("/",$url_vett1[0]);
