@@ -236,7 +236,7 @@ $lista_idc_passa = "";
 for ($numca = 0 ; $numca < $dati_ca['num'] ; $numca++) {
 if (isset($costi_aggiuntivi_mostra[$dati_ca[$numca]['id']]) and strtoupper($costi_aggiuntivi_mostra[$dati_ca[$numca]['id']]) == $SI) $checked = " checked";
 else $checked = "";
-if ($attiva_costi_agg_consentiti == "n" or $costi_agg_consentiti_vett[$dati_ca[$numca]['id']] == "SI" or $checked) {
+if ($attiva_costi_agg_consentiti == "n" or (isset($costi_agg_consentiti_vett[$dati_ca[$numca]['id']]) and $costi_agg_consentiti_vett[$dati_ca[$numca]['id']] == "SI") or $checked) {
 $lista_idc_passa .= ",".$dati_ca[$numca]['id'];
 if ($celle == 1) echo "<tr>";
 if ($dati_ca[$numca]['tipo'] == "u") $tipo_costo = "Costo unico";
@@ -252,7 +252,7 @@ echo "</tr>";
 $celle = 0;
 } # fine if ($celle == $num_colonne)
 $celle++;
-} # fine if ($attiva_costi_agg_consentiti == "n" or $costi_agg_consentiti_vett[$dati_ca[$numca]['id']] == "SI" or $checked)
+} # fine if ($attiva_costi_agg_consentiti == "n" or (isset($costi_agg_consentiti_vett[$dati_ca[$numca]['id']]) and...
 } # fine for $numca
 if ($celle != 1) {
 for ($num1 = $celle ; $num1 <= $num_colonne ; $num1++) echo "<td>&nbsp;</td>";
@@ -280,11 +280,11 @@ echo "".mex("Tag html di apertura per la formattazione delle font",$pag).":
 if (empty($file_css_frame)) $file_css_frame = "https://";
 else $file_css_frame = htmlspecialchars($file_css_frame);
 echo "".mex("Url del file css per la modalità frame",$pag).":
- <input type=\"text\" name=\"file_css_frame\" size=\"35\" value=\"$file_css_frame\"><br>";
+ <input type=\"text\" id=\"file_css_frame\" name=\"file_css_frame\" size=\"35\" value=\"$file_css_frame\"> ".upload_hd_img_form("file_css_frame",$tablepersonalizza,"css")."<br>";
 if (empty($file_js_frame)) $file_js_frame = "https://";
 else $file_js_frame = htmlspecialchars($file_js_frame);
 echo mex("Url del file javascript per la modalità frame",$pag).":
- <input type=\"text\" name=\"file_js_frame\" size=\"35\" value=\"$file_js_frame\"> <small>(".mex("non deve contenere \"php\" e deve terminare con \".js\"",$pag).")</small><br>";
+ <input type=\"text\" id=\"file_js_frame\" name=\"file_js_frame\" size=\"35\" value=\"$file_js_frame\"> <small>(".mex("non deve contenere \"php\" e deve terminare con \".js\"",$pag).")</small> ".upload_hd_img_form("file_js_frame",$tablepersonalizza,"js")."<br>";
 
 include("./includes/templates/$template_data_dir/themes.php");
 $num_temi = count($template_theme_name);
@@ -322,8 +322,9 @@ $valore_corr = $valori_tema[$num2]['default'];
 if ($sel and $modello_esistente == "SI") $valore_corr = ${"valore_tema_".$num2};
 $js_opz_tema .= "".mex("Valore del tema",$pag)." \"".mex($template_theme_name[$num1],$pag)."\" ".mex("per",$pag)." \"".$valori_tema[$num2]['name']."\":\\
  <input type=\"text\" name=\"valore_tema_$num2\" id=\"valtema$num2\" size=\"24\" value=\"".addslashes($valore_corr)."\">";
-if (!empty($valori_tema[$num2]['img'])) $js_opz_tema .= " ".upload_hd_img_form("valtema$num2",$tablepersonalizza,$num2,1);
 if (!empty($valori_tema[$num2]['comment'])) $js_opz_tema .= " <small>(".$valori_tema[$num2]['comment'].")</small>";
+if (!empty($valori_tema[$num2]['img'])) $js_opz_tema .= " ".upload_hd_img_form("valtema$num2",$tablepersonalizza,$num2,1);
+if (!empty($valori_tema[$num2]['file'])) $js_opz_tema .= " ".upload_hd_img_form("valtema$num2",$tablepersonalizza,$num2,1,$valori_tema[$num2]['file']);
 $js_opz_tema .= "<br>";
 } # fine for $num2
 $js_opz_tema .= "<input type=\"hidden\" name=\"n_col_tema\" value=\"$num_colori\"><input type=\"hidden\" name=\"n_val_tema\" value=\"$num_valori\"><\/td><\/tr><\/table>';
@@ -424,7 +425,7 @@ echo "</td></tr></table>
 </td></tr></table>";
 } # fine if (!empty($cambia_frasi))
 elseif ($modello_esistente == "SI") {
-for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) echo "<input type=\"hidden\" name=\"".$fr_frase[$num_fr]."\" value=\"".str_replace("\"","&quot;",${$fr_frase[$num_fr]})."\">";
+for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) echo "<input type=\"hidden\" name=\"".fixstr($fr_frase[$num_fr])."\" value=\"".str_replace("\"","&quot;",fixstr(${$fr_frase[$num_fr]}))."\">";
 } # fine elseif ($modello_esistente == "SI")
 
 echo "<br><div style=\"text-align: center;\"><input type=\"hidden\" name=\"$template_name\" value=\"SI\">
@@ -441,4 +442,4 @@ echo "<br><div style=\"text-align: center;\"><input type=\"hidden\" name=\"$temp
 
 
 
-?>
\ No newline at end of file
+?>
