@@ -189,11 +189,11 @@ $ini_colonna_periodo[$num_colonne_periodi] = $inizioperiodi[$num_p];
 $ini_colonna_periodo[$num_colonne_periodi] = formatta_data($ini_colonna_periodo[$num_colonne_periodi],$stile_data);
 for ($num1 = 1 ; $num1 <= $num_tariffe_mostra ; $num1++) {
 if ($tariffe_mostra[${"numtariffa".$num1}] == "SI") {
-$tariffa_colonna_periodo[$num1][$num_colonne_periodi] = (double) risul_query($periodi,$inizioperiodi_id[$num_p],$tariffa[$num1]);
-$tariffap_colonna_periodo[$num1][$num_colonne_periodi] = (double) risul_query($periodi,$inizioperiodi_id[$num_p],$tariffa[$num1]."p");
+$tariffa_colonna_periodo[$num1][$num_colonne_periodi] = (float) risul_query($periodi,$inizioperiodi_id[$num_p],$tariffa[$num1]);
+$tariffap_colonna_periodo[$num1][$num_colonne_periodi] = (float) risul_query($periodi,$inizioperiodi_id[$num_p],$tariffa[$num1]."p");
 if (isset($dati_r2['napp'][$tariffa[$num1]]) and $dati_r2['napp'][$tariffa[$num1]] > 1) {
-$tariffa_colonna_periodo[$num1][$num_colonne_periodi] = $tariffa_colonna_periodo[$num1][$num_colonne_periodi] * (double) $dati_r2['napp'][$tariffa[$num1]];
-#$tariffap_colonna_periodo[$num1][$num_colonne_periodi] = $tariffap_colonna_periodo[$num1][$num_colonne_periodi] * (double) $dati_r2['napp'][$tariffa[$num1]];
+$tariffa_colonna_periodo[$num1][$num_colonne_periodi] = $tariffa_colonna_periodo[$num1][$num_colonne_periodi] * (float) $dati_r2['napp'][$tariffa[$num1]];
+#$tariffap_colonna_periodo[$num1][$num_colonne_periodi] = $tariffap_colonna_periodo[$num1][$num_colonne_periodi] * (float) $dati_r2['napp'][$tariffa[$num1]];
 } # fine if (isset($dati_r2['napp'][$tariffa[$num1]]) and $dati_r2['napp'][$tariffa[$num1]] > 1)
 if (!empty($dati_tariffe[$tariffa[$num1]]['chiusa'][($inizioperiodi_id[$num_p] + 1)])) {
 $tariffa_colonna_periodo[$num1][$num_colonne_periodi] = "c";
@@ -201,18 +201,18 @@ $tariffap_colonna_periodo[$num1][$num_colonne_periodi] = "c";
 } # fine if (!empty($dati_tariffe[$tariffa[$num1]]['chiusa'][($inizioperiodi_id[$num_p] + 1)]))
 for ($num_i = 1 ; $num_i < $intervalloperiodi[$num_p] ; $num_i++) {
 if ($tariffa_colonna_periodo[$num1][$num_colonne_periodi] == "c") break;
-$tar_corr = (double) risul_query($periodi,($inizioperiodi_id[$num_p] + $num_i),$tariffa[$num1]);
-$tarp_corr = (double) risul_query($periodi,($inizioperiodi_id[$num_p] + $num_i),$tariffa[$num1]."p");
+$tar_corr = (float) risul_query($periodi,($inizioperiodi_id[$num_p] + $num_i),$tariffa[$num1]);
+$tarp_corr = (float) risul_query($periodi,($inizioperiodi_id[$num_p] + $num_i),$tariffa[$num1]."p");
 if (isset($dati_r2['napp'][$tariffa[$num1]]) and $dati_r2['napp'][$tariffa[$num1]] > 1) {
-$tar_corr = $tar_corr * (double) $dati_r2['napp'][$tariffa[$num1]];
-#$tarp_corr = $tarp_corr * (double) $dati_r2['napp'][$tariffa[$num1]];
+$tar_corr = $tar_corr * (float) $dati_r2['napp'][$tariffa[$num1]];
+#$tarp_corr = $tarp_corr * (float) $dati_r2['napp'][$tariffa[$num1]];
 } # fine if (isset($dati_r2['napp'][$tariffa[$num1]]) and $dati_r2['napp'][$tariffa[$num1]] > 1)
 $tariffa_colonna_periodo[$num1][$num_colonne_periodi] += $tar_corr;
 $tariffap_colonna_periodo[$num1][$num_colonne_periodi] += $tarp_corr;
-if ($dati_tariffe[$tariffa[$num1]]['chiusa'][($inizioperiodi_id[$num_p] + $num_i + 1)]) {
+if (!empty($dati_tariffe[$tariffa[$num1]]['chiusa'][($inizioperiodi_id[$num_p] + $num_i + 1)])) {
 $tariffa_colonna_periodo[$num1][$num_colonne_periodi] = "c";
 $tariffap_colonna_periodo[$num1][$num_colonne_periodi] = "c";
-} # fine if ($dati_tariffe[$tariffa[$num1]]['chiusa'][($inizioperiodi_id[$num_p] + $num_i + 1)])
+} # fine if (!empty($dati_tariffe[$tariffa[$num1]]['chiusa'][($inizioperiodi_id[$num_p] + $num_i + 1)]))
 } # fine for $num_i
 } # fine if ($tariffe_mostra[${"numtariffa".$num1}] == "SI")
 } # fine for $num1
@@ -221,11 +221,11 @@ $datafine = $datafine_db[$inizioperiodi_id[$num_p] + $intervalloperiodi[$num_p]
 for ($num1 = ($inizioperiodi_id[$num_p] + $intervalloperiodi[$num_p]) ; $num1 <= $fineperiodi_id[$num_p] ; $num1++) {
 for ($num2 = 1 ; $num2 <= $num_tariffe_mostra ; $num2++) {
 if ($tariffe_mostra[${"numtariffa".$num2}] == "SI") {
-${$tariffa[$num2]} = (double) risul_query($periodi,$num1,$tariffa[$num2]);
-${$tariffa[$num2]."p"} = (double) risul_query($periodi,$num1,$tariffa[$num2]."p");
+${$tariffa[$num2]} = (float) risul_query($periodi,$num1,$tariffa[$num2]);
+${$tariffa[$num2]."p"} = (float) risul_query($periodi,$num1,$tariffa[$num2]."p");
 if (isset($dati_r2['napp'][$tariffa[$num2]]) and $dati_r2['napp'][$tariffa[$num2]] > 1) {
-${$tariffa[$num2]} = ${$tariffa[$num2]} * (double) $dati_r2['napp'][$tariffa[$num2]];
-#${$tariffa[$num2]."p"} = ${$tariffa[$num2]."p"} * (double) $dati_r2['napp'][$tariffa[$num2]];
+${$tariffa[$num2]} = ${$tariffa[$num2]} * (float) $dati_r2['napp'][$tariffa[$num2]];
+#${$tariffa[$num2]."p"} = ${$tariffa[$num2]."p"} * (float) $dati_r2['napp'][$tariffa[$num2]];
 } # fine if (isset($dati_r2['napp'][$tariffa[$num2]]) and $dati_r2['napp'][$tariffa[$num2]] > 1)
 if (!empty($dati_tariffe[$tariffa[$num2]]['chiusa'][($num1 + 1)])) {
 ${$tariffa[$num2]} = "c";
@@ -233,18 +233,18 @@ ${$tariffa[$num2]."p"} = "c";
 } # fine if (!empty($dati_tariffe[$tariffa[$num2]]['chiusa'][($num1 + 1)]))
 for ($num_i = 1 ; $num_i < $intervalloperiodi[$num_p] ; $num_i++) {
 if (${$tariffa[$num2]} == "c") break;
-$tar_corr = (double) risul_query($periodi,($num1 + $num_i),$tariffa[$num2]);
-$tarp_corr = (double) risul_query($periodi,($num1 + $num_i),$tariffa[$num2]."p");
+$tar_corr = (float) risul_query($periodi,($num1 + $num_i),$tariffa[$num2]);
+$tarp_corr = (float) risul_query($periodi,($num1 + $num_i),$tariffa[$num2]."p");
 if (isset($dati_r2['napp'][$tariffa[$num2]]) and $dati_r2['napp'][$tariffa[$num2]] > 1) {
-$tar_corr = $tar_corr * (double) $dati_r2['napp'][$tariffa[$num2]];
-#$tarp_corr = $tarp_corr * (double) $dati_r2['napp'][$tariffa[$num2]];
+$tar_corr = $tar_corr * (float) $dati_r2['napp'][$tariffa[$num2]];
+#$tarp_corr = $tarp_corr * (float) $dati_r2['napp'][$tariffa[$num2]];
 } # fine if (isset($dati_r2['napp'][$tariffa[$num2]]) and $dati_r2['napp'][$tariffa[$num2]] > 1)
 ${$tariffa[$num2]} += $tar_corr;
 ${$tariffa[$num2]."p"} += $tarp_corr;
-if ($dati_tariffe[$tariffa[$num2]]['chiusa'][($num1 + $num_i + 1)]) {
+if (!empty($dati_tariffe[$tariffa[$num2]]['chiusa'][($num1 + $num_i + 1)])) {
 ${$tariffa[$num2]} = "c";
 ${$tariffa[$num2]."p"} = "c";
-} # fine if ($dati_tariffe[$tariffa[$num2]]['chiusa'][($num1 + $num_i + 1)])
+} # fine if (!empty($dati_tariffe[$tariffa[$num2]]['chiusa'][($num1 + $num_i + 1)]))
 } # fine for $num_i
 if (${$tariffa[$num2]} != $tariffa_colonna_periodo[$num2][$num_colonne_periodi] or ${$tariffa[$num2]."p"} != $tariffap_colonna_periodo[$num2][$num_colonne_periodi]) $nuova_colonna = "SI";
 } # fine if ($tariffe_mostra[${"numtariffa".$num2}] == "SI")
