@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2025 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -81,7 +81,7 @@ break;
 if (@is_file("./COPYING")) $file_copying = "file <a href=\"COPYING\">COPYING</a>";
 else $file_copying = "<a href=\"http://www.gnu.org/licenses/agpl-3.0.html\">AGPLv3</a> License";
 echo "<div style=\"text-align: center;\"><h3>".mex("Benvenuto a HOTELDRUID",$pag).".</h3><br><br>
-HOTELDRUID version ".C_PHPR_VERSIONE_TXT.", Copyright (C) 2001-2023 Marco M. F. De Santis<br>
+HOTELDRUID version ".C_PHPR_VERSIONE_TXT.", Copyright (C) 2001-2025 Marco M. F. De Santis<br>
 HotelDruid comes with ABSOLUTELY NO WARRANTY; <br>for details see the $file_copying.<br>
 This is free software, and you are welcome to redistribute it<br>
  under certain conditions; see the $file_copying for details.<br>
@@ -89,18 +89,42 @@ This is free software, and you are welcome to redistribute it<br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"creadb.php\"><div>
 <br><br>
 ".mex("Scegli la lingua",$pag).": <select name=\"lingua\">";
-if ($lingua_mex == "ita") $sel = " selected";
-else $sel = "";
-echo "<option value=\"ita\"$sel>italiano</option>";
+if ($lingua_mex == "ita") {
+$sel = " selected";
+include("./includes/locale.php");
+} # fine if ($lingua_mex == "ita")
+else {
+$sel = "";
+include("./includes/lang/$lingua_mex/locale.php");
+} # fine else if ($lingua_mex == "ita")
+if (!empty($locale['language_capitalization'])) $nome_lingua = "Italiano";
+else $nome_lingua = "italiano";
+echo "<option value=\"ita\"$sel>$nome_lingua</option>";
 $lang_dir = opendir("./includes/lang/");
 while ($ini_lingua = readdir($lang_dir)) {
-if ($ini_lingua != "." && $ini_lingua != "..") {
+if (preg_replace("/[a-z]*/i","",$ini_lingua) == "" and strlen($ini_lingua) < 4 and is_dir("./includes/lang/$ini_lingua")) {
 $nome_lingua = file("./includes/lang/$ini_lingua/l_n");
 $nome_lingua = togli_acapo($nome_lingua[0]);
+if (!empty($locale['language_capitalization'])) {
+if (function_exists('mb_convert_case')) $nome_lingua = mb_convert_case($nome_lingua,MB_CASE_TITLE,'UTF-8');
+else $nome_lingua = ucwords($nome_lingua);
+} # fine if (!empty($locale['language_capitalization']))
 if ($ini_lingua == $lingua_mex) $sel = " selected";
 else $sel = "";
 echo "<option value=\"$ini_lingua\"$sel>$nome_lingua</option>";
-} # fine if ($file != "." && $file != "..")
+if (@is_dir("./includes/lang/$ini_lingua/locales")) {
+$locale_dir = opendir("./includes/lang/$ini_lingua/locales");
+while ($ini_locale = readdir($locale_dir)) {
+if (preg_replace("/[a-z]*/i","",$ini_locale) == "" and strlen($ini_locale) < 4 and is_file("./includes/lang/$ini_lingua/locales/$ini_locale/l_n")) {
+$nome_locale = file("./includes/lang/$ini_lingua/locales/$ini_locale/l_n");
+$nome_locale = togli_acapo($nome_locale[0]);
+if (function_exists('mb_convert_case')) $nome_locale = mb_convert_case($nome_locale,MB_CASE_TITLE,'UTF-8');
+else $nome_locale = ucwords($nome_locale);
+echo "<option value=\"$ini_lingua-$ini_locale\">$nome_lingua - $nome_locale</option>";
+} # fine if ($ini_locale != "." && $ini_locale != ".." and...
+} # fine while ($ini_locale = readdir($locale_dir))
+} # fine if (@is_dir("./includes/lang/$ini_lingua/locales"))
+} # fine if (preg_replace("/[a-z]*/i","",$ini_lingua) == "" and strlen($ini_lingua) < 4 and...
 } # fine while ($file = readdir($lang_dig))
 closedir($lang_dir);
 echo "</select><br>
@@ -117,12 +141,18 @@ $fileaperto = @fopen(C_DATI_PATH."/ultimo_accesso","w+");
 @fwrite($fileaperto,date("d-m-Y H:i:s"));
 @fclose($fileaperto);
 } # fine if (defined('C_CREA_ULTIMO_ACCESSO') and C_CREA_ULTIMO_ACCESSO == "SI")
+if (is_file(C_DATI_PATH."/selectperiodi$anno.1.php")) $anno_esistente = "SI";
+else {
+$anno_esistente = "NO";
+$anno_attuale = date("Y",(time() + (C_DIFF_ORE * 3600) - (C_GIORNI_NUOVO_ANNO * 86400)));
+} # fine else if (is_file(C_DATI_PATH."/selectperiodi$anno.1.php"))
 
 if ($id_utente != 1) {
 $tableprivilegi = $PHPR_TAB_PRE."privilegi";
 $tablerelgruppi = $PHPR_TAB_PRE."relgruppi";
 $prendi_gruppi = "";
-$privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
+if ($anno_esistente == "NO" and $anno == $anno_attuale and is_file(C_DATI_PATH."/selectperiodi".((int) $anno - 1).".1.php")) $privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '".((int) $anno - 1)."'");
+else $privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
 if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
 else {
 $anno_utente_attivato = "SI";
@@ -261,11 +291,7 @@ $priv_mod_checkin = "n";
 else $form_aggiorna_sub = "";
 
 
-$anno_esistente = "SI";
-if (!@is_file(C_DATI_PATH."/selectperiodi$anno.1.php") or $anno_utente_attivato != "SI") {
-$anno_esistente = "NO";
-$anno_attuale = date("Y",(time() + (C_DIFF_ORE * 3600) - (C_GIORNI_NUOVO_ANNO * 86400)));
-if ($anno == $anno_attuale) {
+if ($anno_esistente == "NO" and $anno == $anno_attuale) {
 if (!$numconnessione) {
 include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
@@ -316,12 +342,13 @@ $id_utente = $id_utente_orig;
 $anno_esistente = "SI";
 } # fine if ($anno == ($ultimo_anno + 1) or (!$num_ultimi_anni and defined('C_UTILIZZA_SEMPRE_DEFAULTS') and C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO"))
 } # fine if ($auto_crea_anno == "SI")
-} # fine if ($anno == $anno_attuale)
-} # fine if (!@is_file(C_DATI_PATH."/selectperiodi$anno.1.php") or $anno_utente_attivato != "SI")
+} # fine if ($anno_esistente == "NO" and $anno == $anno_attuale)
 
 
 if ($anno_esistente == "SI") {
 //esiste l'anno richiesto
+if ($anno_utente_attivato == "SI") {
+
 
 if ($numconnessione and $anno and $id_sessione and substr($id_sessione,0,4) != $anno) {
 $n_id_sessione = $anno.substr($id_sessione,4);
@@ -835,6 +862,7 @@ else include("./includes/foot.php");
 
 
 
+} # fine if ($anno_utente_attivato == "SI")
 } # fine if ($anno_esistente == "SI")
 
 
@@ -864,12 +892,12 @@ else {
 echo "<br> ".mex("Non esiste l'anno ",$pag).$anno.mex(" nel database",$pag).". <br>";
 if ($anno_attuale_esist and $anno > $anno_attuale) {
 $data_crea_anno = formatta_data(date("Y-m-d",mktime(0,0,0,1,(C_GIORNI_NUOVO_ANNO + 1),($anno_attuale + 1))));
-if (defined('C_CREA_ANNO_MANUALMENTE') and C_CREA_ANNO_MANUALMENTE == "SI") echo "<br>".mex("<span class=\"colred\">Avviso</span>: è consigliabile attendere fino al",$pag)." $data_crea_anno ".mex("per creare il nuovo anno, nel frattempo si possono aggiungere periodi oltre il",$pag);
+if (defined('C_CREA_ANNO_MANUALMENTE') and (C_CREA_ANNO_MANUALMENTE == "SI" or (C_CREA_ANNO_MANUALMENTE == "NUOVO" and $anno == $anno_corrente))) echo "<br>".mex("<span class=\"colred\">Avviso</span>: è consigliabile attendere fino al",$pag)." $data_crea_anno ".mex("per creare il nuovo anno, nel frattempo si possono aggiungere periodi oltre il",$pag);
 else echo "<br><span class=\"colinfo\">".mex("Nota",$pag)."</span>: ".mex("l'anno",$pag)." $anno_attuale ".mex("verrà archiviato automaticamente il",$pag)." $data_crea_anno, ".mex("nel frattempo si possono aggiungere periodi oltre il",$pag);
 echo " $anno_attuale ".mex("dalla",$pag)."
  <a href=\"./visualizza_tabelle.php?anno=$anno_attuale&amp;id_sessione=$id_sessione&amp;tipo_tabella=periodi#agg_per\">".mex("tabella con i periodi e le tariffe",$pag)."</a> ".mex("anche senza creare un nuovo anno",$pag).".<br>";
 } # fine if ($anno_attuale_esist and $anno > $anno_attuale)
-if ((!$anno_attuale_esist and $anno == $anno_attuale) or $anno < $anno_attuale or (defined('C_CREA_ANNO_MANUALMENTE') and C_CREA_ANNO_MANUALMENTE == "SI")) {
+if ((!$anno_attuale_esist and $anno == $anno_attuale) or $anno < $anno_attuale or (defined('C_CREA_ANNO_MANUALMENTE') and (C_CREA_ANNO_MANUALMENTE == "SI") or (C_CREA_ANNO_MANUALMENTE == "NUOVO" and $anno == $anno_corrente))) {
 echo "<br><form accept-charset=\"utf-8\" method=\"post\" action=\"creaanno.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
@@ -940,30 +968,30 @@ echo "".mex("e prenotazioni da",$pag)."
 <option value=\"10\">".mex("Ottobre",$pag)."</option>
 <option value=\"11\">".mex("Novembre",$pag)."</option>
 <option value=\"12\"$sel_12>".mex("Dicembre",$pag)."</option>
-<option value=\"13\">".mex("Gen",$pag).". ".mex("anno successivo",$pag)."</option>
-<option value=\"14\">".mex("Feb",$pag).". ".mex("anno successivo",$pag)."</option>
-<option value=\"15\">".mex("Mar",$pag).". ".mex("anno successivo",$pag)."</option>
-<option value=\"16\">".mex("Apr",$pag).". ".mex("anno successivo",$pag)."</option>
-<option value=\"17\">".mex("Mag",$pag).". ".mex("anno successivo",$pag)."</option>
-<option value=\"18\">".mex("Giu",$pag).". ".mex("anno successivo",$pag)."</option>
-<option value=\"19\">".mex("Lug",$pag).". ".mex("anno successivo",$pag)."</option>
-<option value=\"20\">".mex("Ago",$pag).". ".mex("anno successivo",$pag)."</option>
-<option value=\"21\">".mex("Set",$pag).". ".mex("anno successivo",$pag)."</option>
-<option value=\"22\">".mex("Ott",$pag).". ".mex("anno successivo",$pag)."</option>
-<option value=\"23\">".mex("Nov",$pag).". ".mex("anno successivo",$pag)."</option>
-<option value=\"24\"$sel_24>".mex("Dic",$pag).". ".mex("anno successivo",$pag)."</option>";
-$n_mese[1] = mex("Gen",$pag);
-$n_mese[2] = mex("Feb",$pag);
-$n_mese[3] = mex("Mar",$pag);
-$n_mese[4] = mex("Apr",$pag);
-$n_mese[5] = mex("Mag",$pag);
-$n_mese[6] = mex("Giu",$pag);
-$n_mese[7] = mex("Lug",$pag);
-$n_mese[8] = mex("Ago",$pag);
-$n_mese[9] = mex("Set",$pag);
-$n_mese[10] = mex("Ott",$pag);
-$n_mese[11] = mex("Nov",$pag);
-$n_mese[12] = mex("Dic",$pag);
+<option value=\"13\">".mex("Gen",'giorni_mesi.php').". ".mex("anno successivo",$pag)."</option>
+<option value=\"14\">".mex("Feb",'giorni_mesi.php').". ".mex("anno successivo",$pag)."</option>
+<option value=\"15\">".mex("Mar",'giorni_mesi.php').". ".mex("anno successivo",$pag)."</option>
+<option value=\"16\">".mex("Apr",'giorni_mesi.php').". ".mex("anno successivo",$pag)."</option>
+<option value=\"17\">".mex("Mag",'giorni_mesi.php').". ".mex("anno successivo",$pag)."</option>
+<option value=\"18\">".mex("Giu",'giorni_mesi.php').". ".mex("anno successivo",$pag)."</option>
+<option value=\"19\">".mex("Lug",'giorni_mesi.php').". ".mex("anno successivo",$pag)."</option>
+<option value=\"20\">".mex("Ago",'giorni_mesi.php').". ".mex("anno successivo",$pag)."</option>
+<option value=\"21\">".mex("Set",'giorni_mesi.php').". ".mex("anno successivo",$pag)."</option>
+<option value=\"22\">".mex("Ott",'giorni_mesi.php').". ".mex("anno successivo",$pag)."</option>
+<option value=\"23\">".mex("Nov",'giorni_mesi.php').". ".mex("anno successivo",$pag)."</option>
+<option value=\"24\"$sel_24>".mex("Dic",'giorni_mesi.php').". ".mex("anno successivo",$pag)."</option>";
+$n_mese[1] = mex("Gen",'giorni_mesi.php');
+$n_mese[2] = mex("Feb",'giorni_mesi.php');
+$n_mese[3] = mex("Mar",'giorni_mesi.php');
+$n_mese[4] = mex("Apr",'giorni_mesi.php');
+$n_mese[5] = mex("Mag",'giorni_mesi.php');
+$n_mese[6] = mex("Giu",'giorni_mesi.php');
+$n_mese[7] = mex("Lug",'giorni_mesi.php');
+$n_mese[8] = mex("Ago",'giorni_mesi.php');
+$n_mese[9] = mex("Set",'giorni_mesi.php');
+$n_mese[10] = mex("Ott",'giorni_mesi.php');
+$n_mese[11] = mex("Nov",'giorni_mesi.php');
+$n_mese[12] = mex("Dic",'giorni_mesi.php');
 for ($num1 = 2 ; $num1 <= 3 ; $num1++) {
 for ($num2 = 1 ; $num2 <= 12 ; $num2++) {
 echo "<option value=\"".(($num1*12) + $num2)."\">".$n_mese[$num2].". $num1 ".mex("anni successivi",$pag)."</option>";
