@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2025 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -70,7 +70,8 @@ $var_pag[42] = 'cancella_subordinazione';
 $var_pag[43] = 'aggiorna_subordinazione';
 $var_pag[44] = 'agg_disp';
 $var_pag[45] = 'agg_tar';
-$n_var_pag = 46;
+$var_pag[46] = 'azione_ic';
+$n_var_pag = 47;
 $num1 = "";
 if (isset($_POST['interc_dir_passa'])) $num1 = $_POST['interc_dir_passa'];
 elseif (isset($_GET['interc_dir_passa'])) $num1 = $_GET['interc_dir_passa'];
@@ -115,7 +116,7 @@ $id_utente_azione_ic = "";
 fixset($mostra_form_iniziale);
 fixset($nuova_pass);
 
-if (defined('C_UTENTE_AZIONE_IC') and C_UTENTE_AZIONE_IC != "" and $utente_azione_ic == C_UTENTE_AZIONE_IC) {
+if (defined('C_UTENTE_AZIONE_IC') and C_UTENTE_AZIONE_IC != "" and isset($utente_azione_ic) and $utente_azione_ic == C_UTENTE_AZIONE_IC) {
 if (defined('C_FILE_SCADENZA_ACCOUNT') and C_FILE_SCADENZA_ACCOUNT != "") {
 $scadenza = trim(@implode("",@file("./".C_FILE_SCADENZA_ACCOUNT)));
 #$adesso = date("YmdHis");
@@ -127,19 +128,20 @@ if (!$scadenza or $scadenza < $adesso) exit();
 $id_utente = "a";
 $id_utente_azione_ic = "a";
 include(C_DATI_PATH."/lingua.php");
-$lingua_mex = $lingua[1];
+$locale_mex = substr(strstr($lingua[1],"-"),1);
+$lingua_mex = str_replace("-$locale_mex","",$lingua[1]);
 if (defined('C_URL_MOD_EXT_CARTE_CREDITO') and C_URL_MOD_EXT_CARTE_CREDITO != "") {
 $id_utente_sessione = "-1";
 $id_sessione = crea_id_sessione($anno,$tableversioni);
 if (C_VERSIONE_ATTUALE < 3.04) $id_sessione = substr($id_sessione,0,20).substr($id_sessione,30);
 $ultimo_accesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
-if ($_SERVER['REMOTE_ADDR']) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
-$REMOTE_ADDR = aggslashdb($REMOTE_ADDR);
-if ($_SERVER['REMOTE_PORT']) $REMOTE_PORT = $_SERVER['REMOTE_PORT'];
-$REMOTE_PORT = aggslashdb($REMOTE_PORT);
-if ($_SERVER['HTTP_USER_AGENT']) $HTTP_USER_AGENT = $_SERVER['HTTP_USER_AGENT'];
-$HTTP_USER_AGENT = aggslashdb($HTTP_USER_AGENT);
-if ($_SERVER['HTTPS'] == "on" or $_SERVER['SERVER_PORT'] == "443") $tipo_conn = "HTTPS";
+if (!empty($_SERVER['REMOTE_ADDR'])) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
+$REMOTE_ADDR = aggslashdb(fixset($REMOTE_ADDR));
+if (!empty($_SERVER['REMOTE_PORT'])) $REMOTE_PORT = $_SERVER['REMOTE_PORT'];
+$REMOTE_PORT = aggslashdb(fixset($REMOTE_PORT));
+if (!empty($_SERVER['HTTP_USER_AGENT'])) $HTTP_USER_AGENT = $_SERVER['HTTP_USER_AGENT'];
+$HTTP_USER_AGENT = aggslashdb(fixset($HTTP_USER_AGENT));
+if ((isset($_SERVER['HTTPS']) and $_SERVER['HTTPS'] == "on") or (isset($_SERVER['SERVER_PORT']) and $_SERVER['SERVER_PORT'] == "443")) $tipo_conn = "HTTPS";
 else $tipo_conn = "HTTP";
 $minuti_durata_sessione = esegui_query("select valpersonalizza_num from $tablepersonalizza where idpersonalizza = 'minuti_durata_sessione' and idutente = '1'");
 $minuti_durata_sessione = risul_query($minuti_durata_sessione,0,'valpersonalizza_num');
@@ -148,13 +150,14 @@ esegui_query("delete from $tablesessioni where ultimo_accesso <= '$limite_sessio
 esegui_query("insert into $tablesessioni (idsessioni,idutente,indirizzo_ip,tipo_conn,user_agent,ultimo_accesso) values ('$id_sessione','$id_utente_sessione','$REMOTE_ADDR','$tipo_conn','$HTTP_USER_AGENT','$ultimo_accesso')","",1);
 } # fine if (defined('C_URL_MOD_EXT_CARTE_CREDITO') and C_URL_MOD_EXT_CARTE_CREDITO != "")
 #} # fine if (!numlin_query($id_utente_az))
-} # fine if (defined("C_UTENTE_AZIONE_IC") and C_UTENTE_AZIONE_IC != "" and $utente_azione_ic == C_UTENTE_AZIONE_IC)
+} # fine if (defined('C_UTENTE_AZIONE_IC') and C_UTENTE_AZIONE_IC != "" and isset($utente_azione_ic) and $utente_azione_ic == C_UTENTE_AZIONE_IC)
 
 if (!$id_utente_azione_ic) $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
 
 if ($id_utente != 1 and $id_utente != "a") {
 $privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
-$priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
+if (numlin_query($privilegi_globali_utente)) $priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
+else $priv_mod_pers = "nnnnnn";
 $priv_crea_interconnessioni = substr($priv_mod_pers,3,1);
 $priv_gest_pass_cc = substr($priv_mod_pers,5,1);
 $privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
@@ -212,7 +215,7 @@ unset($ic_present);
 
 
 $titolo = "HotelDruid: ".mex("Interconnessioni",$pag);
-if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
+if (!empty($tema[$id_utente]) and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 
 
@@ -302,6 +305,7 @@ $maxocc[$idapp] = risul_query($appartamenti,$num1,'maxoccupanti');
 $lista_tutti_app .= "$idapp,";
 } # fine for $num1
 $lista_tutti_app = substr($lista_tutti_app,0,-1);
+asort($maxocc);
 
 $lista_regola2 = array();
 $regole2 = esegui_query("select * from $tableregole where tariffa_per_app != ''");
@@ -478,16 +482,16 @@ if ($tipo_err == '12') $agg_tar = 1;
 else $num_err = 0;
 if (!empty($agg_disp) or !empty($agg_tar)) {
 $lock = 1;
-if ($agg_disp) $aggiorna_disp = 1;
+if (!empty($agg_disp)) $aggiorna_disp = 1;
 else $aggiorna_disp = 0;
-if ($agg_tar) $aggiorna_tar = 1;
+if (!empty($agg_tar)) $aggiorna_tar = 1;
 else $aggiorna_tar = 0;
 if (@function_exists('pcntl_fork')) include("./includes/interconnect/aggiorna_ic_fork.php");
 else include("./includes/interconnect/aggiorna_ic.php");
 } # fine if (!empty($agg_disp) or !empty($agg_tar))
 if ($num_err) {
-if ($agg_disp) esegui_query("delete from $tablecache where numero = '11' and tipo = 'error_ic' ");
-if ($agg_tar) esegui_query("delete from $tablecache where numero = '12' and tipo = 'error_ic' ");
+if (!empty($agg_disp)) esegui_query("delete from $tablecache where numero = '11' and tipo = 'error_ic' ");
+if (!empty($agg_tar)) esegui_query("delete from $tablecache where numero = '12' and tipo = 'error_ic' ");
 } # fine if ($num_err)
 
 } # fine if (@is_array($ic_present))
@@ -578,7 +582,7 @@ fwrite($file_sub,"<?php
 \$url_subordinazione = \"$url_subordinazione\";
 \$utente_subordinazione = \"".aggiungi_slash($utente_subordinazione)."\";
 \$password_subordinazione = \"".aggiungi_slash($password_subordinazione)."\";
-\$commento_subordinazione = \"".aggiungi_slash(htmlspecialchars($commento_subordinazione))."\";
+\$commento_subordinazione = \"".aggiungi_slash(htmlspecialchars($commento_subordinazione,ENT_COMPAT))."\";
 \$compresso_subordinazione = \"".aggiungi_slash($compresso_subordinazione)."\";
 \$mantieni_anni = \"".aggiungi_slash($mantieni_anni)."\";
 \$ultimo_aggiornamento = \"$adesso\";
@@ -801,11 +805,20 @@ sel_memu[n1].querySelector('option[selected]').selected = true;
 
 
 
-if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/foot.php");
+if (!empty($tema[$id_utente]) and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/foot.php");
 else include("./includes/foot.php");
 
 
 } # fine if ($id_utente and (($priv_crea_interconnessioni == "s" and $anno_utente_attivato == "SI") or $id_utente == $id_utente_azione_ic) and (!defined('C_CREA_SUBORDINAZIONI') or C_CREA_SUBORDINAZIONI != "NO"))
+elseif ($id_utente and ($priv_crea_interconnessioni != "s" or $anno_utente_attivato != "SI")) {
+$titolo = "HotelDruid: ".mex("Interconnessioni",$pag);
+if (!empty($tema[$id_utente]) and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
+else include("./includes/head.php");
+echo "<br>".mex("Non hai i privilegi per accedere a questa pagina",'funzioni.php').". ".mex("Accedi come utente amministratore o altro utente abilitato",'funzioni.php').".<br>";
+if (!empty($tema[$id_utente]) and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/foot.php");
+else include("./includes/foot.php");
+} # fine elseif ($id_utente and ($priv_crea_interconnessioni != "s" or $anno_utente_attivato != "SI"))
+
 
 
 
