@@ -92,9 +92,12 @@ $tablerelgruppi = $PHPR_TAB_PRE."relgruppi";
 
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
 if ($id_utente) {
+$tariffe_consentite_vett = array();
+$costi_agg_consentiti_vett = array();
 
 
 if ($id_utente != 1) {
+$prendi_gruppi = "";
 $privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
 if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
 else {
@@ -129,14 +132,12 @@ $tariffe_consentite = risul_query($privilegi_annuali_utente,0,'tariffe_consentit
 $attiva_tariffe_consentite = substr($tariffe_consentite,0,1);
 if ($attiva_tariffe_consentite == "s") {
 $tariffe_consentite = explode(",",substr($tariffe_consentite,2));
-unset($tariffe_consentite_vett);
 for ($num1 = 0 ; $num1 < count($tariffe_consentite) ; $num1++) if ($tariffe_consentite[$num1]) $tariffe_consentite_vett[$tariffe_consentite[$num1]] = "SI";
 } # fine if ($attiva_tariffe_consentite == "s")
 $costi_agg_consentiti = risul_query($privilegi_annuali_utente,0,'costi_agg_consentiti');
 $attiva_costi_agg_consentiti = substr($costi_agg_consentiti,0,1);
 if ($attiva_costi_agg_consentiti == "s") {
 $costi_agg_consentiti = explode(",",substr($costi_agg_consentiti,2));
-unset($costi_agg_consentiti_vett);
 for ($num1 = 0 ; $num1 < count($costi_agg_consentiti) ; $num1++) if ($costi_agg_consentiti[$num1]) $costi_agg_consentiti_vett[$costi_agg_consentiti[$num1]] = "SI";
 } # fine if ($attiva_costi_agg_consentiti == "s")
 $priv_ins_tariffe = risul_query($privilegi_annuali_utente,0,'priv_ins_tariffe');
@@ -144,6 +145,14 @@ $priv_ins_costi_agg = substr($priv_ins_tariffe,1,1);
 if ($priv_ins_costi_agg == "g") $prendi_gruppi = "SI";
 } # fine else if (numlin_query($privilegi_annuali_utente) == 0)
 
+$attiva_regole1_consentite_gr = array();
+$regole1_consentite_gr = array();
+$attiva_tariffe_consentite_gr = array();
+$tariffe_consentite_vett_gr = array();
+$priv_ins_nuove_prenota_gr = array();
+$priv_ins_assegnazione_app_gr = array();
+$priv_mod_prenotazioni_gr = array();
+$priv_mod_assegnazione_app_gr = array();
 $priv_app_gruppi = "NO";
 if ($priv_vedi_inv_app == "g" or $priv_ins_beni_in_app == "g" or $priv_mod_beni_in_app == "g") $priv_app_gruppi = "SI";
 if ($priv_app_gruppi == "SI") {
@@ -167,7 +176,7 @@ $utenti_gruppo = esegui_query("select idutente from $tablerelgruppi where idgrup
 $num_utenti_gruppo = numlin_query($utenti_gruppo);
 for ($num2 = 0 ; $num2 < $num_utenti_gruppo ; $num2++) {
 $idutente_gruppo = risul_query($utenti_gruppo,$num2,'idutente');
-if ($idutente_gruppo != $id_utente and !$utenti_gruppi[$idutente_gruppo]) {
+if ($idutente_gruppo != $id_utente and empty($utenti_gruppi[$idutente_gruppo])) {
 $utenti_gruppi[$idutente_gruppo] = 1;
 
 if ($priv_app_gruppi == "SI") {
@@ -196,7 +205,7 @@ $priv_mod_prenotazioni_gr[$idutente_gruppo] = "n";
 } # fine else if (numlin_query($priv_anno_ut_gr) == 1)
 } # fine if ($priv_app_gruppi == "SI")
 
-} # fine if ($idutente_gruppo != $id_utente)
+} # fine if ($idutente_gruppo != $id_utente and empty($utenti_gruppi[$idutente_gruppo]))
 } # fine for $num2
 } # fine for $num1
 } # fine if ($prendi_gruppi == "SI")
@@ -244,7 +253,7 @@ else include("./includes/head.php");
 $Euro = nome_valuta();
 $frase_modifica = "";
 
-#if (empty($url_enc)) $idmag = htmlspecialchars($idmag);
+#if (empty($url_enc)) $idmag = htmlspecialchars($idmag,ENT_COMPAT);
 $idmag_url = urlencode($idmag);
 $idmag_orig = htmlspecialchars($idmag);
 $idmag = aggslashdb($idmag);
@@ -671,7 +680,7 @@ $num_appda = (int) $num_appda;
 for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1++) {
 $idapp_da = risul_query($appartamenti,$num1,'idappartamenti');
 $num_appda_corr = 0;
-for ($num2 = 1 ; $num2 <= $num_appda ; $num2++) if (htmlspecialchars(${"nome_app_da$num2"}) == $idapp_da) $num_appda_corr = $num2;
+for ($num2 = 1 ; $num2 <= $num_appda ; $num2++) if (htmlspecialchars(${"nome_app_da$num2"},ENT_COMPAT) == $idapp_da) $num_appda_corr = $num2;
 if ($num_appda_corr and !empty(${"app_da$num_appda_corr"}) and controlla_num_pos(${"app_da$num_appda_corr"}) == "SI") {
 if ($priv_vedi_inv_app == "s" or $appartamenti_consentiti[$idapp] != "NO") {
 $bene_in_app_da = esegui_query("select * from $tablerelinventario where idappartamento = '$idapp_da' and idbeneinventario = '$id_bene' ");
@@ -825,7 +834,7 @@ $id_in_mag = array();
 $lista_id_beni_in_mag_passa = "";
 for ($num1 = 0 ; $num1 < $num_beni_in_mag ; $num1++) {
 $id_bene_in_mag = risul_query($beni_in_mag,$num1,'idbeneinventario',$tablerelinventario);
-if ($bene_permesso[$id_bene_in_mag]) {
+if (!empty($bene_permesso[$id_bene_in_mag])) {
 $lista_id_beni_in_mag_passa .= ",$id_bene_in_mag";
 $quantita = risul_query($beni_in_mag,$num1,'quantita',$tablerelinventario);
 $quantita_min_predef = risul_query($beni_in_mag,$num1,'quantita_min_predef',$tablerelinventario);
@@ -864,7 +873,7 @@ if ($priv_ins_beni == "n" and ($num_diff >= 0 or $priv_mod_beni == "n")) echo "&
 echo "</td>";
 } # fine if ($priv_ins_beni != "n" or $priv_mod_beni != "n")
 echo "</tr>";
-} # fine if ($bene_permesso[$id_bene_in_mag])
+} # fine if (!empty($bene_permesso[$id_bene_in_mag]))
 } # fine for $num1
 
 $opt_beni = "";
