@@ -423,7 +423,7 @@ $eml_reply_to = $eml_header->reply_to;
 if (is_array($eml_reply_to) and count($eml_reply_to) > 0) {
 for ($num2 = 0 ; $num2 < count($eml_reply_to) ; $num2++) $mittente .= $eml_reply_to[$num2]->mailbox."@".$eml_reply_to[$num2]->host.",";
 $mittente = substr($mittente,0,-1);
-$nome_cognome_richiedente = $eml_reply_to[0]->personal;
+if (isset($eml_reply_to[0]->personal)) $nome_cognome_richiedente = $eml_reply_to[0]->personal;
 } # fine if (is_array($eml_reply_to) and count($eml_reply_to) > 0)
 else {
 $eml_from = $eml_header->from;
@@ -539,10 +539,10 @@ if ($partenza) $partenza_trovata = 1;
 if (!$partenza_trovata and empty($partenza_cercata[$fr_partenza])) {
 $partenza_cercata[$fr_partenza] = 1;
 $partenza = preg_split("/$fr_partenza"."[^0-9a-z]/i",$testo);
-if ($partenza[1]) {
+if (!empty($partenza[1])) {
 $partenza = trova_prima_data(substr($testo,strlen($partenza[0]),40),$stile_data,$lingue[$num2],$lung_prima_data);
 if ($partenza and $partenza != $arrivo) $partenza_trovata = 1;
-} # fine if ($partenza[1])
+} # fine if (!empty($partenza[1]))
 } # fine if (!$partenza_trovata and empty($partenza_cercata[$fr_partenza]))
 if (!$num_persone and empty($persone_cercate[$fr_persone])) {
 $persone_cercate[$fr_persone] = 1;
@@ -584,7 +584,7 @@ if (!$partenza_trovata and $arrivo_trovato and !$partenza_cercata[$fr_notti]) {
 $partenza = trova_numero_vicino($testo,$fr_notti);
 if ($partenza) {
 $partenza_trovata = 1;
-$partenza = date("Y-m-d",mktime(0,0,0,substr($arrivo,5,2),((integer) substr($arrivo,8,2) + $partenza),substr($arrivo,0,4)));
+$partenza = date("Y-m-d",mktime(0,0,0,substr($arrivo,5,2),((int) substr($arrivo,8,2) + $partenza),substr($arrivo,0,4)));
 } # fine if ($partenza)
 } # fine if (!$partenza_trovata and $arrivo_trovato and...
 } # fine for $num2
@@ -640,11 +640,11 @@ if ($n_cognome_richiedente or $n_email_richiedente) {
 $dati_richiedente = risul_query($mess_esist,0,'dati_messaggio15');
 $dati_richiedente = explode("<d>",$dati_richiedente);
 if ($n_cognome_richiedente) {
-$n_cognome_richiedente = htmlspecialchars($n_cognome_richiedente);
+$n_cognome_richiedente = htmlspecialchars($n_cognome_richiedente,ENT_COMPAT);
 $dati_richiedente[0] = $n_cognome_richiedente;
 } # fine if ($n_cognome_richiedente)
 if ($n_email_richiedente) {
-$n_email_richiedente = htmlspecialchars($n_email_richiedente);
+$n_email_richiedente = htmlspecialchars($n_email_richiedente,ENT_COMPAT);
 $dati_richiedente[2] = $n_email_richiedente;
 } # fine if ($n_email_richiedente)
 $dati_richiedente = implode("<d>",$dati_richiedente);
@@ -727,13 +727,18 @@ $nome_contratto[$dati_nome_contratto[0]] = fixset($dati_nome_contratto[1]);
 } # fine for $num1
 $max_contr = esegui_query("select max(numero) from $tablecontratti where tipo $LIKE 'contr%'");
 $max_contr = risul_query($max_contr,0,0);
+$contr_escludi = array();
+$escludi_pag = esegui_query("select numero from $tablecontratti where tipo = 'pag_esc' and testo $LIKE '%,messaggi,%' ");
+for ($num1 = 0 ; $num1 < numlin_query($escludi_pag) ; $num1++) $contr_escludi[risul_query($escludi_pag,$num1,'numero')] = 1;
 $option_contratti = "";
 for ($num_contratto = 1 ; $num_contratto <= $max_contr ; $num_contratto++) {
-if ($attiva_contratti_consentiti == "n" or $contratti_consentiti_vett[$num_contratto] == "SI") {
+if (empty($contr_escludi[$num_contratto])) {
+if ($attiva_contratti_consentiti == "n" or (isset($contratti_consentiti_vett[$num_contratto]) and $contratti_consentiti_vett[$num_contratto] == "SI")) {
 if (!empty($nome_contratto[$num_contratto])) $num_contratto_vedi = $nome_contratto[$num_contratto];
 else $num_contratto_vedi = $num_contratto;
 $option_contratti .= "<option value=\"$num_contratto\">$num_contratto_vedi</option>";
 } # fine if ($attiva_contratti_consentiti == "n" or...
+} # fine if (empty($contr_escludi[$num_contratto]))
 } # fine for $num_contratto
 
 include("./includes/funzioni_costi_agg.php");
@@ -813,12 +818,12 @@ $data_ins_prenota = risul_query($dati_prenota,0,'datainserimento');
 if ($priv_mod_prenotazioni == "n") $link_modifica = "NO";
 if ($priv_mod_prenotazioni == "p" and $utente_ins_prenota != $id_utente) $link_modifica = "NO";
 if ($priv_mod_prenotazioni == "g" and empty($utenti_gruppi[$utente_ins_prenota])) $link_modifica = "NO";
-if ($priv_mod_prenota_iniziate != "s" and $id_periodo_corrente >= $id_data_ini_prenota) $link_modifica = "NO";
-if ($priv_mod_prenota_ore != "000") {
+if ($priv_mod_prenota_iniziate != "s" and $link_modifica != "NO" and $id_periodo_corrente >= $id_data_ini_prenota) $link_modifica = "NO";
+if ($priv_mod_prenota_ore != "000" and $link_modifica != "NO") {
 $adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
 $limite = date("YmdHis",mktime((substr($data_ins_prenota,11,2) + (int) $priv_mod_prenota_ore),substr($data_ins_prenota,14,2),substr($data_ins_prenota,17,2),substr($data_ins_prenota,5,2),substr($data_ins_prenota,8,2),substr($data_ins_prenota,0,4)));
 if ($adesso > $limite) $link_modifica = "NO";
-} # fine if ($priv_mod_prenota_ore != "000")
+} # fine if ($priv_mod_prenota_ore != "000" and $link_modifica != "NO")
 if ($link_modifica == "SI") {
 $link_modifica_inizio = "<a$stilebarrato href=\"modifica_prenota.php?id_prenota=".$prenota_inserite[$num2]."$pcanc&anno=$anno&id_sessione=$id_sessione&origine=messaggi.php\">";
 $link_modifica_fine = "</a>";
@@ -928,13 +933,13 @@ $numpersone[$n_t] = $numpersone_dt[($n_t - 1)];
 $num_app_tipo_richiesti[$n_t] = $num_app_tipo_richiesti_dt[($n_t - 1)];
 $dati_calcolati = explode(":",$dati_calcolati_dt[($n_t - 1)]);
 $dati_calcolati_0 = explode(",",$dati_calcolati[0]);
-$costo_tariffa[$n_t] = (double) $dati_calcolati_0[0];
+$costo_tariffa[$n_t] = (float) $dati_calcolati_0[0];
 $caparra[$n_t] = fixset($dati_calcolati_0[1]);
 $letti_agg[$n_t] = fixset($dati_calcolati_0[2]);
 $num_ca_calc[$n_t] = (count($dati_calcolati) - 1);
 for ($num2 = 1 ; $num2 < $num_ca_calc[$n_t] ; $num2++) {
 $dati_calcolati_ca = explode(",",$dati_calcolati[$num2]);
-$prezzo_ca_calc[$n_t][$num2] = (double) $dati_calcolati_ca[0];
+$prezzo_ca_calc[$n_t][$num2] = (float) $dati_calcolati_ca[0];
 $nome_ca_calc[$n_t][$num2] = $dati_calcolati_ca[1];
 $ripeti_ca_calc[$n_t][$num2] = $dati_calcolati_ca[2];
 $tasseperc_ca_calc[$n_t][$num2] = fixset($dati_calcolati_ca[3]);
@@ -949,19 +954,20 @@ $costoagg_dt2 = explode(",",$costoagg_dt[($n_t - 1)]);
 $numsettimane_dt2 = explode(",",$numsettimane_dt[($n_t - 1)]);
 $nummoltiplica_ca_dt2 = explode(",",$nummoltiplica_ca_dt[($n_t - 1)]);
 $id_periodi_costo_dt2 = explode(":",$id_periodi_costo_dt[($n_t - 1)]);
-$catpers_ca_dt2 = explode(",",$catpers_ca_dt[($n_t - 1)]);
+$catpers_ca_dt2 = explode(",",fixstr($catpers_ca_dt[($n_t - 1)]));
 for ($numca = 1 ; $numca <= $numcostiagg[$n_t] ; $numca++) {
 if ($costoagg_dt2[($numca - 1)] == "SI") {
 $costo_presente[$n_t][$idcostoagg_dt2[($numca - 1)]] = 1;
 $numsettimane[$n_t][$idcostoagg_dt2[($numca - 1)]] = $numsettimane_dt2[($numca - 1)];
 $nummoltiplica_ca[$n_t][$idcostoagg_dt2[($numca - 1)]] = $nummoltiplica_ca_dt2[($numca - 1)];
-$catpers_ca[$n_t][$idcostoagg_dt2[($numca - 1)]] = $catpers_ca_dt2[($numca - 1)];
+$catpers_ca[$n_t][$idcostoagg_dt2[($numca - 1)]] = fixset($catpers_ca_dt2[($numca - 1)]);
 } # fine if ($costoagg_dt2[($numca - 1)] == "SI")
 } # fine for $numca
-$cat_numpers[$n_t] = explode(",",$cat_numpers_dt[($n_t - 1)]);
+$cat_numpers[$n_t] = explode(",",fixstr($cat_numpers_dt[($n_t - 1)]));
 } # fine for $n_t
 $dati_richiedente_dt = explode("<d>",(string) risul_query($messaggi,$num1,'dati_messaggio15'));
 $cognome_richiedente = $dati_richiedente_dt[0];
+$cognome2_richiedente = fixstr($dati_richiedente_dt[30]);
 $nome_richiedente = $dati_richiedente_dt[1];
 $email_richiedente = $dati_richiedente_dt[2];
 $sesso = $dati_richiedente_dt[3];
@@ -1005,6 +1011,7 @@ $tasto_prenota = "<form accept-charset=\"utf-8\" method=\"post\" action=\"prenot
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idmessaggi\" value=\"$idmessaggi\">
 <input type=\"hidden\" name=\"cognome\" value=\"$cognome_richiedente\">
+<input type=\"hidden\" name=\"cognome2\" value=\"$cognome2_richiedente\">
 <input type=\"hidden\" name=\"nome\" value=\"$nome_richiedente\">";
 $tasto_prenota .= "<input type=\"hidden\" name=\"mos_tut_dat\" value=\"SI\">
 <input type=\"hidden\" name=\"num_tipologie\" value=\"$num_tipologie\">
@@ -1047,7 +1054,7 @@ $tasto_prenota .= "<input type=\"hidden\" name=\"giorno_stima_checkin$n_t\" valu
 $ncostiagg = 0;
 $ngrcostiagg = 0;
 for ($num2 = 0 ; $num2 < $dati_ca['num'] ; $num2++) {
-if ($attiva_costi_agg_consentiti == "n" or $costi_agg_consentiti_vett[$dati_ca[$num2]['id']] == "SI") {
+if ($attiva_costi_agg_consentiti == "n" or (isset($costi_agg_consentiti_vett[$dati_ca[$num2]['id']]) and $costi_agg_consentiti_vett[$dati_ca[$num2]['id']] == "SI")) {
 if ($dati_ca[$num2]['combina'] != "s" and $dati_ca[$num2]['raggruppa'] != "s") {
 $ncostiagg++;
 if (isset($costo_presente[$n_t][$dati_ca[$num2]['id']])) {
@@ -1081,6 +1088,7 @@ $tasto_prenota .= "<form accept-charset=\"utf-8\" method=\"post\" action=\"dispo
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"cognome_1\" value=\"$cognome_richiedente\">
+<input type=\"hidden\" name=\"cognome2_1\" value=\"$cognome2_richiedente\">
 <input type=\"hidden\" name=\"email_1\" value=\"$email_richiedente\">
 <input type=\"hidden\" name=\"testo_email_richiesta\" value=\"".str_replace("\"","&quot;",$testo_orig)."\">
 <input type=\"hidden\" name=\"inizioperiodo\" value=\"".$inizioperiodo[1]."\">
@@ -1129,14 +1137,15 @@ $tasto_contr .= "<input type=\"hidden\" name=\"cognome_$n_c\" value=\"$cognome_r
 <input type=\"hidden\" name=\"num_persone_$n_c\" value=\"".$numpersone[$n_t]."\">
 <input type=\"hidden\" name=\"costo_tariffa_$n_c\" value=\"".$costo_tariffa[$n_t]."\">
 <input type=\"hidden\" name=\"caparra_$n_c\" value=\"".$caparra[$n_t]."\">
-<input type=\"hidden\" name=\"n_letti_agg_$n_c\" value=\"".$letti_agg[$n_t]."\">";
+<input type=\"hidden\" name=\"n_letti_agg_$n_c\" value=\"".$letti_agg[$n_t]."\">
+<input type=\"hidden\" name=\"numero_cliente_$n_c\" value=\"0\">";
 if ($n_t == $num_tipologie and $n_r == $num_app_tipo_richiesti[$n_t]) $tasto_contr .= "<input type=\"hidden\" name=\"ultima_prenotazione_per_cliente_$n_c\" value=\"1\">";
 else $tasto_contr .= "<input type=\"hidden\" name=\"ultima_prenotazione_per_cliente_$n_c\" value=\"0\">";
-$costo_tot = (double) $costo_tariffa[$n_t];
+$costo_tot = (float) $costo_tariffa[$n_t];
 $num_costi_agg = 0;
 for ($num2 = 1 ; $num2 < $num_ca_calc[$n_t] ; $num2++) {
 if (!$ripeti_ca_calc[$n_t][$num2] or $ripeti_ca_calc[$n_t][$num2] >= $n_r) {
-$costo_tot = (double) ($costo_tot + $prezzo_ca_calc[$n_t][$num2]);
+$costo_tot = (float) ($costo_tot + $prezzo_ca_calc[$n_t][$num2]);
 $tasto_contr .= "<input type=\"hidden\" name=\"nome_costo_agg$num_costi_agg"."_$n_c\" value=\"".$nome_ca_calc[$n_t][$num2]."\">
 <input type=\"hidden\" name=\"val_costo_agg$num_costi_agg"."_$n_c\" value=\"".$prezzo_ca_calc[$n_t][$num2]."\">
 <input type=\"hidden\" name=\"percentuale_tasse_costo_agg$num_costi_agg"."_$n_c\" value=\"".$tasseperc_ca_calc[$n_t][$num2]."\">
@@ -1181,7 +1190,7 @@ $tasto_prenota .= "<br><br><br>";
 } # fine if ($tipo_messaggio == "intercon")
 
 
-if ($tipo_messaggio == "sistema") $testo = str_replace("<sessione>","anno=$anno&amp;id_sessione=$id_sessione",$testo);
+if ($tipo_messaggio == "sistema" or $tipo_messaggio == "intercon") $testo = str_replace("<sessione>","anno=$anno&amp;id_sessione=$id_sessione",$testo);
 
 
 $data = risul_query($messaggi,$num1,'datavisione');
