@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2025 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -62,6 +62,7 @@ elseif (isset($_GET["num_ospiti_inviati$num2"])) $num3 = (int) $_GET["num_ospiti
 for ($num1 = 1 ; $num1 <= $num3 ; $num1++) {
 $var_pag[$n_var_pag++] = "id_osp_num$num2"."_$num1";
 $var_pag[$n_var_pag++] = "cognome$num2"."_$num1";
+$var_pag[$n_var_pag++] = "cognome2_$num2"."_$num1";
 $var_pag[$n_var_pag++] = "nome$num2"."_$num1";
 $var_pag[$n_var_pag++] = "sesso$num2"."_$num1";
 $var_pag[$n_var_pag++] = "nazionalita$num2"."_$num1";
@@ -99,7 +100,7 @@ include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
 $numconnessione = connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
 include("./includes/funzioni.php");
-include(C_DATI_PATH."/lingua.php");
+#include(C_DATI_PATH."/lingua.php");
 include("./includes/funzioni_costi_agg.php");
 include("./includes/funzioni_clienti.php");
 $tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
@@ -201,7 +202,7 @@ if ($num_clienti_esistenti >= C_MASSIMO_NUM_CLIENTI) $inserimento_nuovi_clienti
 } # fine if (defined("C_MASSIMO_NUM_CLIENTI") and C_MASSIMO_NUM_CLIENTI != 0)
 
 
-$id_prenota = aggslashdb($id_prenota);
+$id_prenota = aggslashdb(fixset($id_prenota));
 $id_prenota_int = $id_prenota;
 unset($id_prenota_idpr);
 $id_prenota_idpr[0] = $id_prenota;
@@ -265,6 +266,9 @@ if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$t
 else include("./includes/head.php");
 
 
+$secondo_cognome = esegui_query("select idpersonalizza from $tablepersonalizza where idpersonalizza = 'sec_cogn' and idutente = '$id_utente' ");
+if (numlin_query($secondo_cognome)) $secondo_cognome = 1;
+else $secondo_cognome = 0;
 $stile_soldi = stile_soldi();
 $stile_data = stile_data();
 
@@ -335,15 +339,19 @@ $lista_ospiti['lista'] .= $idclienti.",";
 $presente_id[$idclienti] = "SI";
 $idclienti_compagni .= substr($compagni_cliente,1);
 $principale = $idclienti;
+$titolare_non_ospite = "";
 } # fine if (isset(${"cliente_ospite".$id_prenota."_".$idclienti}) and ${"cliente_ospite".$id_prenota."_".$idclienti} == "SI")
-elseif (isset(${"id_osp_num".$id_prenota."_1"}) and ${"id_osp_num".$id_prenota."_1"} == $idclienti) esegui_query("delete from $tablerclientiprenota where idprenota = '$id_prenota' and idclienti = '$idclienti' ");
+else {
+if (isset(${"id_osp_num".$id_prenota."_1"}) and ${"id_osp_num".$id_prenota."_1"} == $idclienti) esegui_query("delete from $tablerclientiprenota where idprenota = '$id_prenota' and idclienti = '$idclienti' ");
+$titolare_non_ospite = $idclienti;
+} # fine else if (isset(${"cliente_ospite".$id_prenota."_".$idclienti}) and...
 
 $ospiti = esegui_query("select idclienti,num_ordine,parentela from $tablerclientiprenota where idprenota = '$id_prenota' order by num_ordine ");
 $d_num_ospiti = numlin_query($ospiti);
 for ($num1 = 0 ; $num1 < $d_num_ospiti ; $num1++) $osp_presente[risul_query($ospiti,$num1,'idclienti')] = ($num1 + 1);
 
 if ($principale != $idclienti) {
-if (!empty($osp_presente[$principale]) and ${"ospite".$id_prenota."_".$principale} == "SI") {
+if (!empty($osp_presente[$principale]) and isset(${"ospite".$id_prenota."_".$principale}) and ${"ospite".$id_prenota."_".$principale} == "SI") {
 if ($app_letto_idpr[$num_idpr] and $num_ospiti > 0) $mess_letto = 1;
 else {
 $num_ospiti++;
@@ -351,7 +359,7 @@ $lista_ospiti[$num_ospiti] = $principale;
 $lista_ospiti['lista'] .= $principale.",";
 $presente_id[$principale] = "SI";
 } # fine else if ($app_letto_idpr[$num_idpr] and $num_ospiti > 0)
-} # fine if (!empty($osp_presente[$principale]) and ${"ospite".$id_prenota."_".$principale} == "SI")
+} # fine if (!empty($osp_presente[$principale]) and isset(${"ospite".$id_prenota."_".$principale}) and...
 else $principale = "";
 } # fine if ($principale != $idclienti)
 
@@ -376,7 +384,7 @@ $lista_ospiti['lista'] .= $id_clienti_osp.",";
 $presente_id[$id_clienti_osp] = "SI";
 $parentela = fixstr(${"parentela_".$id_prenota."_".$id_clienti_osp});
 if (@get_magic_quotes_gpc()) $parentela = stripslashes($parentela);
-$parentela = htmlspecialchars($parentela);
+$parentela = htmlspecialchars(fixstr($parentela),ENT_COMPAT);
 $d_parentela = risul_query($ospiti,($osp_presente[$id_clienti_osp] - 1),'parentela');
 if ($parentela != $d_parentela) {
 esegui_query("update $tablerclientiprenota set parentela = '".aggslashdb($parentela)."' where idprenota = '$id_prenota' and idclienti = '$id_clienti_osp' ");
@@ -392,6 +400,7 @@ if (!$id_clienti_osp and ${"cognome".$id_prenota."_".$num1} and $inserimento_nuo
 if ($app_letto_idpr[$num_idpr] and $num_ospiti > 0) $mess_letto = 1;
 else {
 $cognome_aux = fixset(${"cognome".$id_prenota."_".$num1});
+$cognome2_aux = fixset(${"cognome2_".$id_prenota."_".$num1});
 $nome_aux = fixset(${"nome".$id_prenota."_".$num1});
 $titolo_cli_aux = fixset(${"titolo_cli".$id_prenota."_".$num1});
 $sesso_aux = fixset(${"sesso".$id_prenota."_".$num1});
@@ -425,7 +434,7 @@ $fax_aux = fixset(${"fax".$id_prenota."_".$num1});
 $email_aux = fixset(${"email".$id_prenota."_".$num1});
 $email2_aux = fixset(${"email2".$id_prenota."_".$num1});
 $email_cert_aux = fixset(${"email_cert".$id_prenota."_".$num1});
-$id_clienti_ins = inserisci_dati_cliente($cognome_aux,$nome_aux,"",$titolo_cli_aux,$sesso_aux,$mesenascita_aux,$giornonascita_aux,$annonascita_aux,$nazionenascita_aux,$cittanascita_aux,$regionenascita_aux,$documento_aux,$tipodoc_aux,$mesescaddoc_aux,$giornoscaddoc_aux,$annoscaddoc_aux,$cittadoc_aux,$regionedoc_aux,$nazionedoc_aux,$nazionalita_aux,$lingua_cli_aux,$nazione_aux,$citta_aux,$regione_aux,$via_aux,$nomevia_aux,$numcivico_aux,$cap_aux,$telefono__aux,$telefono2__aux,$telefono3__aux,$fax_aux,$email_aux,$email2_aux,$email_cert_aux,"","",($num_ospiti_inviati + 1),$id_utente_ins,$attiva_prefisso_clienti,$prefisso_clienti);
+$id_clienti_ins = inserisci_dati_cliente($cognome_aux,$cognome2_aux,$nome_aux,"",$titolo_cli_aux,$sesso_aux,$mesenascita_aux,$giornonascita_aux,$annonascita_aux,$nazionenascita_aux,$cittanascita_aux,$regionenascita_aux,$documento_aux,$tipodoc_aux,$mesescaddoc_aux,$giornoscaddoc_aux,$annoscaddoc_aux,$cittadoc_aux,$regionedoc_aux,$nazionedoc_aux,$nazionalita_aux,$lingua_cli_aux,$nazione_aux,$citta_aux,$regione_aux,$via_aux,$nomevia_aux,$numcivico_aux,$cap_aux,$telefono__aux,$telefono2__aux,$telefono3__aux,$fax_aux,$email_aux,$email2_aux,$email_cert_aux,"","",($num_ospiti_inviati + 1),$id_utente_ins,$attiva_prefisso_clienti,$prefisso_clienti);
 $num_ospiti++;
 $lista_ospiti[$num_ospiti] = $id_clienti_ins;
 $n_parentela[$num_ospiti] = ${"parentela".$id_prenota."_".$num1};
@@ -457,10 +466,10 @@ if (empty($osp_presente[$id_clienti_osp])) {
 $datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 if ($n_num_ordine > 2) {
 if (@get_magic_quotes_gpc()) $n_parentela[$num1] = stripslashes($n_parentela[$num1]);
-$parentela = htmlspecialchars(fixstr($n_parentela[$num1]));
+$parentela = htmlspecialchars(fixstr($n_parentela[$num1]),ENT_COMPAT);
 } # fine if ($n_num_ordine > 2)
 else $parentela = "";
-esegui_query("insert into $tablerclientiprenota (idprenota,idclienti,num_ordine,parentela,datainserimento,hostinserimento,utente_inserimento) values ('$id_prenota','$id_clienti_osp','$n_num_ordine','$parentela','$datainserimento','$HOSTNAME','$id_utente_ins') ");
+esegui_query("insert into $tablerclientiprenota (idprenota,idclienti,num_ordine,parentela,datainserimento,hostinserimento,utente_inserimento) values ('$id_prenota','$id_clienti_osp','$n_num_ordine','".aggslashdb($parentela)."','$datainserimento','$HOSTNAME','$id_utente_ins') ");
 } # fine if (emtpy($osp_presente[$id_clienti_osp]))
 else {
 $num_ordine = risul_query($ospiti,($osp_presente[$id_clienti_osp] - 1),'num_ordine');
@@ -477,6 +486,10 @@ $n_idclienti_compagni = $d_idclienti_compagni;
 for ($num2 = 1 ; $num2 <= $num_ospiti ; $num2++) {
 if ($lista_ospiti[$num2] != $id_clienti_osp and str_replace(",".$lista_ospiti[$num2].",","",$n_idclienti_compagni) == $n_idclienti_compagni) $n_idclienti_compagni .= $lista_ospiti[$num2].",";
 } # fine for $num2
+if ($titolare_non_ospite and $num1 == 1 and str_replace(",$titolare_non_ospite,","",$n_idclienti_compagni) == $n_idclienti_compagni) {
+$n_idclienti_compagni .= "$titolare_non_ospite,";
+esegui_query("update $tableclienti set idclienti_compagni = '$compagni_cliente"."$id_clienti_osp,' where idclienti = '$idclienti'");
+} # fine if ($titolare_non_ospite and $num1 == 1)
 if ($n_idclienti_compagni != $d_idclienti_compagni) esegui_query("update $tableclienti set idclienti_compagni = '$n_idclienti_compagni' where idclienti = '$id_clienti_osp'");
 } # fine for $num1
 
@@ -533,7 +546,7 @@ $dati_cliente = esegui_query("select * from $tableclienti where idclienti = '$id
 echo "".mex("Cliente titolare",$pag);
 if ($num_id_prenota > 1) echo " ".mex("della prenotazione",$pag)." <b>$id_prenota</b>";
 echo ":<br>";
-mostra_dati_cliente($dati_cliente,$dcognome,$dnome,$dsoprannome,$dtitolo_cli,$dsesso,$ddatanascita,$ddatanascita_f,$dnazionenascita,$dcittanascita,$dregionenascita,$ddocumento,$dscadenzadoc,$dscadenzadoc_f,$dtipodoc,$dnazionedoc,$dregionedoc,$dcittadoc,$dnazionalita,$dnazione,$dlingua_cli,$dregione,$dcitta,$dvia,$dnumcivico,$dtelefono,$dtelefono2,$dtelefono3,$dfax,$dcap,$demail,$demail2,$demail_cert,$dcod_fiscale,$dpartita_iva,"",$priv_ins_clienti);
+mostra_dati_cliente($dati_cliente,$dcognome,$dcognome2,$dnome,$dsoprannome,$dtitolo_cli,$dsesso,$ddatanascita,$ddatanascita_f,$dnazionenascita,$dcittanascita,$dregionenascita,$ddocumento,$dscadenzadoc,$dscadenzadoc_f,$dtipodoc,$dnazionedoc,$dregionedoc,$dcittadoc,$dnazionalita,$dnazione,$dlingua_cli,$dregione,$dcitta,$dvia,$dnumcivico,$dtelefono,$dtelefono2,$dtelefono3,$dfax,$dcap,$demail,$demail2,$demail_cert,$dcod_fiscale,$dpartita_iva,"",$priv_ins_clienti);
 $cognome_def = $dcognome;
 if ($dnazionalita) $nazione_def = $dnazionalita;
 elseif ($dnazione) $nazione_def = $dnazione;
@@ -581,7 +594,7 @@ if (($modifica_clienti == "PROPRI" and $utente_ospite != $id_utente) or ($modifi
 else echo "<br><a$stile href=\"$url_mod_cli\">".($num1 + $agg_num).".</a>";
 echo " <label><input name=\"ospite$id_prenota"."_".$id_clienti_osp."\" value=\"SI\" type=\"checkbox\" checked>";
 if (($vedi_clienti == "PROPRI" and $utente_ospite != $id_utente) or ($vedi_clienti == "GRUPPI" and !$utenti_gruppi[$utente_ospite])) echo "".mex("Cliente",$pag)." $id_clienti_osp";
-else mostra_dati_cliente($dati_ospite,$dcognome,$dnome,$dsoprannome,$dtitolo_cli,$dsesso,$ddatanascita,$ddatanascita_f,$dnazionenascita,$dcittanascita,$dregionenascita,$ddocumento,$dscadenzadoc,$dscadenzadoc_f,$dtipodoc,$dnazionedoc,$dregionedoc,$dcittadoc,$dnazionalita,$dlingua_cli,$dnazione,$dregione,$dcitta,$dvia,$dnumcivico,$dtelefono,$dtelefono2,$dtelefono3,$dfax,$dcap,$demail,$demail2,$demail_cert,$dcod_fiscale,$dpartita_iva,"",$priv_ins_clienti);
+else mostra_dati_cliente($dati_ospite,$dcognome,$dcognome2,$dnome,$dsoprannome,$dtitolo_cli,$dsesso,$ddatanascita,$ddatanascita_f,$dnazionenascita,$dcittanascita,$dregionenascita,$ddocumento,$dscadenzadoc,$dscadenzadoc_f,$dtipodoc,$dnazionedoc,$dregionedoc,$dcittadoc,$dnazionalita,$dlingua_cli,$dnazione,$dregione,$dcitta,$dvia,$dnumcivico,$dtelefono,$dtelefono2,$dtelefono3,$dfax,$dcap,$demail,$demail2,$demail_cert,$dcod_fiscale,$dpartita_iva,"",$priv_ins_clienti);
 echo "</label>";
 if ($num1 == 0) {
 $checked = " checked";
@@ -623,14 +636,17 @@ $n_ini = $num1 + $agg_num;
 for ( ; $num1 < $num_fine ; $num1++) {
 $n_o = $num1 + $agg_num;
 if ($n_ini != 1) $n_ini = $n_o;
-echo "<br>$n_o. ".mex("Cognome",$pag).": <input type=\"text\" id=\"cognome$id_prenota"."_$n_o\" name=\"cognome$id_prenota"."_$n_o\"><input type=\"button\" class=\"cpbutton\" onclick=\"cp_val('cognome$id_prenota"."_$n_o','cognome$id_prenota"."_$n_ini','$cognome_def')\" value=\"#\">,
-<span class=\"wsnw\">".mex("nome",$pag).": <input type=\"text\" name=\"nome$id_prenota"."_$n_o\">;</span>
-<span class=\"wsnw\">".mex("sesso",$pag).": <select name=\"sesso$id_prenota"."_$n_o\">
+echo "<br>$n_o. ".mex("Cognome",$pag).": <input type=\"text\" id=\"cognome$id_prenota"."_$n_o\" name=\"cognome$id_prenota"."_$n_o\"><input type=\"button\" class=\"cpbutton\" onclick=\"cp_val('cognome$id_prenota"."_$n_o','cognome$id_prenota"."_$n_ini','$cognome_def')\" value=\"#\">,";
+if ($secondo_cognome) echo " ".mex("2° cognome",$pag).": <input type=\"text\" id=\"cognome2_$id_prenota"."_$n_o\" name=\"cognome2_$id_prenota"."_$n_o\"><input type=\"button\" class=\"cpbutton\" onclick=\"cp_val('cognome2_$id_prenota"."_$n_o','cognome2_$id_prenota"."_$n_ini','$cognome_def')\" value=\"#\">,";
+echo " <span class=\"wsnw\">".mex("nome",$pag).": <input type=\"text\" name=\"nome$id_prenota"."_$n_o\">;</span>";
+if ($secondo_cognome) echo "<br>";
+echo "<span class=\"wsnw\">".mex("sesso",$pag).": <select name=\"sesso$id_prenota"."_$n_o\">
 <option value=\"\" selected>-</option>
 <option value=\"m\">m</option>
 <option value=\"f\">f</option>
-</select>;</span><br>
-<span class=\"wsnw\">".mex("cittadinanza",$pag).": ".mostra_lista_relutenti("nazionalita$id_prenota"."_$n_o","",$id_utente,"nome_nazione","idnazioni","idnazione",$tablenazioni,$tablerelutenti)."<input type=\"button\" class=\"cpbutton\" onclick=\"cp_val('nazionalita$id_prenota"."_$n_o','nazionalita$id_prenota"."_$n_ini','$nazione_def')\" value=\"#\">;</span>
+</select>;</span>";
+if (!$secondo_cognome) echo "<br>";
+echo "<span class=\"wsnw\">".mex("cittadinanza",$pag).": ".mostra_lista_relutenti("nazionalita$id_prenota"."_$n_o","",$id_utente,"nome_nazione","idnazioni","idnazione",$tablenazioni,$tablerelutenti)."<input type=\"button\" class=\"cpbutton\" onclick=\"cp_val('nazionalita$id_prenota"."_$n_o','nazionalita$id_prenota"."_$n_ini','$nazione_def')\" value=\"#\">;</span>
  <span class=\"wsnw\">".addslashes(mex("parentela",$pag)).": ".mostra_lista_relutenti("parentela$id_prenota"."_$n_o","",$id_utente,"nome_parentela","idparentele","idparentela",$tableparentele,$tablerelutenti)."</span><br>
 <div style=\"height: 2px\"></div>
 ".mex("Data di nascita",$pag).": ";
@@ -708,14 +724,16 @@ for ($num1 = 0 ; $num1 < $num_idclienti_compagni ; $num1++) {
 $id_clienti_osp = $idclienti_compagni[$num1];
 if (!isset($presente_id[$id_clienti_osp]) or $presente_id[$id_clienti_osp] != "SI") {
 $presente_id[$id_clienti_osp] = "SI";
-$dati_ospite = esegui_query("select cognome,nome,sesso,datanascita,utente_inserimento from $tableclienti where idclienti = '$id_clienti_osp' ");
+$dati_ospite = esegui_query("select cognome,cognome2,nome,sesso,datanascita,utente_inserimento from $tableclienti where idclienti = '$id_clienti_osp' ");
 $dati_osp .= "<label><input name=\"altro_ospite$id_prenota"."_$id_clienti_osp\" value=\"SI\" type=\"checkbox\"><input type=\"hidden\" name=\"id_altro_osp_num$id_prenota"."_$num1\" value=\"$id_clienti_osp\">\
  <em>".addslashes(risul_query($dati_ospite,0,'cognome'))."</em> ";
-$ccnome = addslashes(risul_query($dati_ospite,0,'nome'));
+$cccognome2 = addslashes((string) risul_query($dati_ospite,0,'cognome2'));
+$ccnome = addslashes((string) risul_query($dati_ospite,0,'nome'));
 $ccsesso = risul_query($dati_ospite,0,'sesso');
 $ccdatanascita = risul_query($dati_ospite,0,'datanascita');
 $O = "o";
 if ($ccsesso == "f") $O = "a";
+if ($cccognome2) $dati_osp .=  "<em>$cccognome2</em> ";
 if ($ccnome) $dati_osp .=  "$ccnome ";
 if ($ccdatanascita) $dati_osp .= mex("nat$O il",$pag)." ".formatta_data($ccdatanascita,$stile_data)." ";
 $dati_osp .= "</label><br>";
