@@ -173,7 +173,7 @@ $stile_data = stile_data();
 
 
 if (!isset($contr_cond) or controlla_num_pos($contr_cond) == "NO" or $contr_cond < 1) $contr_cond = "";
-if ($attiva_contratti_consentiti != "n" and $contratti_consentiti_vett[$contr_cond] != "SI") $contr_cond = "";
+if ($attiva_contratti_consentiti != "n" and (!isset($contratti_consentiti_vett[$contr_cond]) or $contratti_consentiti_vett[$contr_cond] != "SI")) $contr_cond = "";
 if (strcmp((string) $contr_cond,"")) {
 $contr_cond = (int) $contr_cond;
 $contr_cond_esist = esegui_query("select tipo from $tablecontratti where numero = '".aggslashdb($contr_cond)."' and tipo $LIKE 'contr%' ");
@@ -203,7 +203,7 @@ $num_campi_pers_cliente = count($campi_pers_cliente);
 else $num_campi_pers_cliente = 0;
 include_once("./includes/funzioni_tariffe.php");
 $dati_cat_pers = dati_cat_pers($id_utente,$tablepersonalizza,$lingua_mex,"v",0,1);
-$dati_allegato = array('num' => 0);
+$dati_allegato = array('num' => 0, 'num_iim' => 0);
 $allegati = esegui_query("select * from $tablecontratti where numero = '".aggslashdb($contr_cond)."' and tipo = 'allegato'");
 if (numlin_query($allegati)) {
 $allegati = risul_query($allegati,0,'testo');
@@ -269,11 +269,11 @@ closedir($lang_dir);
 for ($num1 = 0 ; $num1 < $num_var_predef ; $num1++) {
 if ($nuova_var_pers == $var_predef[$num1]) $continua = "NO";
 } # fine for $num1
-if ($solo_contr_cond and strcmp((string) $contr_cond,"")) {
+if (!empty($solo_contr_cond) and strcmp((string) $contr_cond,"")) {
 $tipo = "var$contr_cond";
 $contr_cond_esist = esegui_query("select numero from $tablecontratti where numero = '".aggslashdb($contr_cond)."' and tipo $LIKE 'contr%' ");
 if (numlin_query($contr_cond_esist) != 1) $continua = "NO";
-} # fine if ($solo_contr_cond and strcmp((string) $contr_cond,""))
+} # fine if (!empty($solo_contr_cond) and strcmp((string) $contr_cond,""))
 else $tipo = "var";
 if ($continua == "SI") {
 $max_var = esegui_query("select max(numero) from $tablecontratti where tipo $LIKE 'var%'");
@@ -338,15 +338,15 @@ closedir($lang_dir);
 for ($num1 = 0 ; $num1 < $num_var_predef ; $num1++) {
 if ($nuovo_arr_pers == $var_predef[$num1]) $continua = "NO";
 } # fine for $num1
-if ($solo_contr_cond and strcmp((string) $contr_cond,"")) {
+if (!empty($solo_contr_cond) and strcmp((string) $contr_cond,"")) {
 $tipo = "vett$contr_cond";
 $contr_cond_esist = esegui_query("select numero from $tablecontratti where numero = '".aggslashdb($contr_cond)."' and tipo $LIKE 'contr%' ");
 if (numlin_query($contr_cond_esist) != 1) $continua = "NO";
-} # fine if ($solo_contr_cond and strcmp((string) $contr_cond,""))
+} # fine if (!empty($solo_contr_cond) and strcmp((string) $contr_cond,""))
 else {
 $solo_contr_cond = "";
 $tipo = "vett";
-} # fine else if ($solo_contr_cond and strcmp((string) $contr_cond,""))
+} # fine else if (!empty($solo_contr_cond) and strcmp((string) $contr_cond,""))
 if ($continua == "SI") {
 if ($solo_contr_cond) $variabili_pers = esegui_query("select * from $tablecontratti where tipo = 'var' or tipo = 'var$contr_cond' order by tipo, numero");
 else $variabili_pers = esegui_query("select * from $tablecontratti where tipo = 'var' order by numero");
@@ -356,7 +356,7 @@ $var_pers = risul_query($variabili_pers,$num1,'testo');
 $num_var_pers = risul_query($variabili_pers,$num1,'numero');
 $var_predef[$num_var_predef] = $var_pers;
 $num_var_predef++;
-$nome_var[$num_var_pers] = $var_pers;
+#$nome_var[$num_var_pers] = $var_pers;
 } # fine for $num1
 if (empty($var_arr)) {
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
@@ -411,7 +411,7 @@ $tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 if ($contr_imp) {
 if (controlla_num_pos($contr_imp) == "NO" or $contr_imp < 1) $contr_imp = "";
-if ($contr_imp == $contr_cond or ($attiva_contratti_consentiti != "n" and $contratti_consentiti_vett[$contr_imp] != "SI")) $contr_imp = "";
+if ($contr_imp == $contr_cond or ($attiva_contratti_consentiti != "n" and (!isset($contratti_consentiti_vett[$contr_imp]) or $contratti_consentiti_vett[$contr_imp] != "SI"))) $contr_imp = "";
 if (strcmp((string) $contr_imp,"")) {
 $contr_imp_esist = esegui_query("select numero from $tablecontratti where numero = '".aggslashdb($contr_imp)."' and tipo $LIKE 'contr%' ");
 if (numlin_query($contr_imp_esist) != 1) $contr_imp = "";
@@ -422,14 +422,14 @@ if (numlin_query($contr_imp_esist)) $contr_imp = "";
 } # fine if (strcmp((string) $contr_imp,""))
 if ($contr_imp) {
 esegui_query("delete from $tablecontratti where tipo = 'var$contr_cond' or tipo = 'cond$contr_cond' or tipo = 'vett$contr_cond' ");
-if ($tipo_contr_imp != "importa") {
+if (!isset($tipo_contr_imp) or $tipo_contr_imp != "importa") {
 $contr_importa = esegui_query("select testo from $tablecontratti where numero = '$contr_cond' and tipo = 'impor_vc' ");
 if (numlin_query($contr_importa)) esegui_query("update $tablecontratti set testo = '$contr_imp' where numero = '$contr_cond' and tipo = 'impor_vc' ");
 else {
 esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$contr_cond','impor_vc','$contr_imp') ");
 esegui_query("update $tablecontratti set testo = '$contr_imp' where testo = '$contr_cond' and tipo = 'impor_vc' ");
 } # fine else if (numlin_query($contr_importa))
-} # fine if ($tipo_contr_imp != "importa")
+} # fine if (!isset($tipo_contr_imp) or $tipo_contr_imp != "importa")
 else {
 $var_cond_importa = esegui_query("select * from $tablecontratti where tipo = 'var$contr_imp' or tipo = 'cond$contr_imp' or tipo = 'vett$contr_imp' ");
 $num_var_cond = numlin_query($var_cond_importa);
@@ -440,7 +440,7 @@ $tipo_imp = preg_replace("/[0-9]/","",$tipo_imp).$contr_cond;
 $testo_imp = aggslashdb(risul_query($var_cond_importa,$num1,'testo'));
 esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$num_imp','$tipo_imp','$testo_imp') ");
 } # fine for $num1
-} # fine else if ($tipo_contr_imp == "sempre")
+} # fine else if (!isset($tipo_contr_imp) or $tipo_contr_imp != "importa")
 } # fine if ($contr_imp)
 } # fine if ($contr_imp)
 else esegui_query("delete from $tablecontratti where numero = '$contr_cond' and tipo = 'impor_vc' ");
@@ -460,7 +460,7 @@ if (numlin_query($arr_esistente) != 1) $continua = "NO";
 if ($inizializza != "rpt" and $inizializza != "inr" and $inizializza != "ind" and $inizializza != "ros" and $inizializza != "rca" and $inizializza != "rpa" and $inizializza != "run" and $inizializza != "rds" and preg_replace("/rar[1-9][0-9]*/","",fixstr($inizializza)) != "") $continua = "NO";
 if (isset($cond_sempre) and strcmp((string) $cond_sempre,"") and $cond_sempre != "SI" and $cond_sempre != "NO") $continua = "NO";
 if (fix_set($azione) != "set" and $azione != "trunc" and $azione != "oper" and $azione != "date" and $azione != "unset" and $azione != "array" and $azione != "break" and $azione != "cont") $continua = "NO";
-if (!empty($oper_data) and $azione = "date") $azione = "opdat";
+if (!empty($oper_data) and $azione == "date") $azione = "opdat";
 if ($num_se < 1 or $num_se > 80) $continua = "NO";
 if ($num_se > 1 and $and_or != "and" and $and_or != "or") $continua = "NO";
 if ($continua == "SI") {
@@ -733,6 +733,7 @@ $variabili_pers = esegui_query("select * from $tablecontratti where tipo = 'var'
 $num_variabili_pers = numlin_query($variabili_pers);
 $option_var_pers = "";
 $option_var_pers_tipo = "";
+$nome_var = array();
 $nome_var['-1'] = mexv('messaggio_di_errore');
 $nome_var['-2'] = mexv('errore_ripetizione');
 $nome_var['-3'] = mexv('nome_documento_scaricato');
@@ -829,7 +830,7 @@ else $sel = "";
 $opt_contr = "<option value=\"\"$sel>".mex("a tutti i documenti",$pag)."</option>";
 for ($num1 = 0 ; $num1 < $num_contratti ; $num1++) {
 $num_contr = risul_query($contratti,$num1,'numero');
-if ($attiva_contratti_consentiti == "n" or $contratti_consentiti_vett[$num_contr] == "SI") {
+if ($attiva_contratti_consentiti == "n" or (isset($contratti_consentiti_vett[$num_contr]) and $contratti_consentiti_vett[$num_contr] == "SI")) {
 $mod_doc_corr = 1;
 if ($priv_mod_doc_api != "s") {
 $api_esistente = esegui_query("select * from $tablecontratti where numero = '".aggslashdb($num_contr)."' and tipo = 'api'");
@@ -847,7 +848,7 @@ $opt_contr .= "<option value=\"$num_contr\"$sel>".mex("al documento",$pag)." $nu
 if (!empty($nome_contratto[$num_contr])) $opt_contr .= " (".$nome_contratto[$num_contr].")";
 $opt_contr .= "</option>";
 } # fine if ($mod_doc_corr)
-} # fine if ($attiva_contratti_consentiti == "n" or $contratti_consentiti_vett[$num_contr] == "SI")
+} # fine if ($attiva_contratti_consentiti == "n" or (isset($contratti_consentiti_vett[$num_contr]) and $contratti_consentiti_vett[$num_contr] == "SI"))
 } # fine for $num1
 echo "<br><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -942,13 +943,13 @@ $num_cond_mod_orig = $num_cond_mod;
 if (!empty($agg_se) or !empty($canc_se)) $num_cond_mod = "";
 } # fine if (isset($num_cond_mod) and $num_cond_mod == $num_cond)
 
-if ($num1 == $num_cond_rpt and $condizione[0] == "ros") echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni degli ospiti",$pag)." (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
-if ($num1 == $num_cond_rip_o and $condizione[0] == "rca") echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dei costi aggiuntivi",$pag)." (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
-if ($num1 == $num_cond_rip_c and $condizione[0] == "rpa") echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dei pagamenti",$pag)." (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
-if ($num1 == $num_cond_rip_p and $condizione[0] == "run") echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni delle unità",$pag)." (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
-if ($num1 == $num_cond_rip_u and $condizione[0] == "rds") echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dei documenti salvati",$pag)." (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
-if ($num1 == $num_cond_rip_d and $condizione[0] == "rar".$num_cond_rip_a['arr'][1]) echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dell'array",$pag)." [".$nome_var["a".$num_cond_rip_a['arr'][1]]."] (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
-for ($num2 = 1 ; $num2 < $num_rip_a ; $num2++) if ($num1 == $num_cond_rip_a[$num2] and $condizione[0] == "rar".$num_cond_rip_a['arr'][($num2 + 1)]) echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dell'array",$pag)." [".$nome_var["a".$num_cond_rip_a['arr'][($num2 + 1)]]."] (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
+if ($num1 == $num_cond_rpt and $condizione[0] == "ros") echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni degli ospiti",$pag)." [r2]...[/r2] (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
+if ($num1 == $num_cond_rip_o and $condizione[0] == "rca") echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dei costi aggiuntivi",$pag)." [r3]...[/r3] (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
+if ($num1 == $num_cond_rip_c and $condizione[0] == "rpa") echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dei pagamenti",$pag)." [r5]...[/r5] (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
+if ($num1 == $num_cond_rip_p and $condizione[0] == "run") echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni delle unità",$pag)." [r6]...[/r6] (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
+if ($num1 == $num_cond_rip_u and $condizione[0] == "rds") echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dei documenti salvati",$pag)." [r7]...[/r7] (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
+if ($num1 == $num_cond_rip_d and $condizione[0] == "rar".$num_cond_rip_a['arr'][1]) echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dell'array",$pag)." [".fixset($nome_var["a".$num_cond_rip_a['arr'][1]])."] (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
+for ($num2 = 1 ; $num2 < $num_rip_a ; $num2++) if ($num1 == $num_cond_rip_a[$num2] and $condizione[0] == "rar".$num_cond_rip_a['arr'][($num2 + 1)]) echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dell'array",$pag)." [".fixset($nome_var["a".$num_cond_rip_a['arr'][($num2 + 1)]])."] (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
 echo "<tr style=\"background-color: ".rowbgcolor().";\"><td><b>".($num1 + 1)."</b>. ";
 if (isset($num_cond_passa) and $num_cond_passa == ($num1 + 20)) echo "<a name=\"condizioni\"></a>";
 $str_cond = "";
@@ -997,7 +998,7 @@ $str_cond .= mex("allora",$pag)." ";
 } # fine if ($condizione[1])
 
 if ($azione[0] == "set") {
-$str_cond .= mex("porre",$pag)." [".$nome_var[$azione[1]]."] ";
+$str_cond .= mex("porre",$pag)." [".fixset($nome_var[$azione[1]])."] ";
 if ($azione[2] == "=") $str_cond .= mex("uguale a",$pag);
 if ($azione[2] == ".=") $str_cond .= mex("concatenato con",$pag);
 if ($azione[3] == "var") {
@@ -1045,7 +1046,7 @@ $oper_allora_sel = $azione[9];
 } # fine if ($azione[0] == "set")
 
 if ($azione[0] == "trunc") {
-$str_cond .= mex("troncare",$pag)." [".$nome_var[$azione[1]]."] ";
+$str_cond .= mex("troncare",$pag)." [".fixset($nome_var[$azione[1]])."] ";
 if ($azione[2] < 0) $str_cond .= mex("prima di",$pag)." ".($azione[2] * -1);
 else $str_cond .= mex("dopo",$pag)." ".$azione[2];
 $str_cond .= " ".mex("caratteri",$pag);
@@ -1064,7 +1065,7 @@ $pos_trunc2 = $azione[4];
 } # fine if ($azione[0] == "trunc")
 
 if ($azione[0] == "oper") {
-$str_cond .= mex("porre",$pag)." [".$nome_var[$azione[1]]."] ".mex("uguale a",$pag);
+$str_cond .= mex("porre",$pag)." [".fixset($nome_var[$azione[1]])."] ".mex("uguale a",$pag);
 $str_cond .= " [".mexv($azione[2])."] ";
 $str_cond .= $azione[3]." ";
 if ($azione[4] == "var") $str_cond .= "[".mexv($azione[5])."]";
@@ -1082,7 +1083,7 @@ $val_arrotond = $azione[6];
 } # fine if ($azione[0] == "oper")
 
 if ($azione[0] == "date") {
-$str_cond .= mex("porre",$pag)." [".$nome_var[$azione[1]]."] ".mex("uguale a",$pag)." \"";
+$str_cond .= mex("porre",$pag)." [".fixset($nome_var[$azione[1]])."] ".mex("uguale a",$pag)." \"";
 if ($azione[3] == "gi") $str_cond .= mex("il giorno",$pag);
 if ($azione[3] == "me") $str_cond .= mex("il mese",$pag);
 if ($azione[3] == "an") $str_cond .= mex("l'anno",$pag);
@@ -1112,7 +1113,7 @@ $tipo_giorni = $azione[5];
 } # fine if ($azione[0] == "date")
 
 if ($azione[0] == "opdat") {
-$str_cond .= mex("porre",$pag)." [".$nome_var[$azione[1]]."] ".mex("uguale al numero di",$pag)." \"";
+$str_cond .= mex("porre",$pag)." [".fixset($nome_var[$azione[1]])."] ".mex("uguale al numero di",$pag)." \"";
 if ($azione[2] == "g") $str_cond .= mex("giorni",$pag);
 if ($azione[2] == "m") $str_cond .= mex("mesi",$pag);
 if ($azione[2] == "a") $str_cond .= mex("anni",$pag);
@@ -1127,16 +1128,16 @@ $var_opdat3 = $azione[4];
 } # fine if ($azione[0] == "opdat")
 
 if ($azione[0] == "unset") {
-$str_cond .= mex("azzera l'array",$pag)." [".$nome_var[$azione[1]]."]";
+$str_cond .= mex("azzera l'array",$pag)." [".fixset($nome_var[$azione[1]])."]";
 if (isset($num_cond_mod) and $num_cond_mod == $num_cond) $arr_azz = $azione[1];
 } # fine if ($azione[0] == "unset")
 
 if ($azione[0] == "array") {
-$str_cond .= mex("assegna all'array",$pag)." [".$nome_var[$azione[1]]."] ";
+$str_cond .= mex("assegna all'array",$pag)." [".fixset($nome_var[$azione[1]])."] ";
 if ($azione[2] == "dat") $str_cond .= mex("valori progressivi tra le date selezionate",$pag);
 if ($azione[2] == "dap") $str_cond .= mex("valori progressivi tra il primo arrivo e l'ultima partenza",$pag);
 if ($azione[2] == "val") $str_cond .= mex("i valori",$pag)." \"".htmlspecialchars(str_replace(",",", ",$azione[3]))."\"";
-if ($azione[2] == "cop") $str_cond .= mex("i valori dell'array",$pag)." [".$nome_var[$azione[3]]."]";
+if ($azione[2] == "cop") $str_cond .= mex("i valori dell'array",$pag)." [".fixset($nome_var[$azione[3]])."]";
 if (isset($num_cond_mod) and $num_cond_mod == $num_cond) {
 $array = $azione[1];
 $tipo_arr = $azione[2];
@@ -1160,7 +1161,7 @@ if ($condizione[0] == "rca") $str_cond .= " ".mex("solo nelle ripetizioni dei co
 if ($condizione[0] == "rpa") $str_cond .= " ".mex("solo nelle ripetizioni dei pagamenti",$pag);
 if ($condizione[0] == "run") $str_cond .= " ".mex("solo nelle ripetizioni delle unità",$pag);
 if ($condizione[0] == "rds") $str_cond .= " ".mex("solo nelle ripetizioni dei documenti salvati",$pag);
-if (substr($condizione[0],0,3) == "rar") $str_cond .= " ".mex("solo nelle ripetizioni dell'array",$pag)." [".$nome_var["a".substr($condizione[0],3)]."]";
+if (substr($condizione[0],0,3) == "rar") $str_cond .= " ".mex("solo nelle ripetizioni dell'array",$pag)." [".fixset($nome_var["a".substr($condizione[0],3)])."]";
 echo ucfirst($str_cond).".</td>";
 $fine_cond_rip_a = 0;
 for ($num2 = 1 ; $num2 <= $num_rip_a ; $num2++) if ($num1 == ($num_cond_rip_a[$num2] - 1)) $fine_cond_rip_a = 1;
@@ -1248,7 +1249,7 @@ if ($contr_cond) {
 $opt_contr_imp = "";
 for ($num1 = 0 ; $num1 < $num_contratti ; $num1++) {
 $num_contr = risul_query($contratti,$num1,'numero');
-if ($contr_cond != $num_contr and ($attiva_contratti_consentiti == "n" or $contratti_consentiti_vett[$num_contr] == "SI" or $num_contr == $contr_importa_vc)) {
+if ($contr_cond != $num_contr and ($attiva_contratti_consentiti == "n" or $num_contr == $contr_importa_vc or (isset($contratti_consentiti_vett[$num_contr]) and $contratti_consentiti_vett[$num_contr] == "SI"))) {
 $contr_imp_esist = esegui_query("select numero from $tablecontratti where numero = '$num_contr' and tipo = 'impor_vc' ");
 if (!numlin_query($contr_imp_esist)) {
 if ($num_contr == $contr_importa_vc) $sel = " selected";
@@ -1280,14 +1281,14 @@ $opt_contr_imp</select>
 <input class=\"sbutton\" type=\"submit\" value=\"".mex("Modifica",$pag)."\">
 </div></form>";
 if (isset($num_condizioni) and $num_condizioni > 0) echo "<small>&nbsp;&nbsp;(".mex("le variabili e condizioni attuali verranno cancellate",$pag).")</small>";
-if ($contr_importa_vc and ($attiva_contratti_consentiti == "n" or $contratti_consentiti_vett[$contr_importa_vc] == "SI")) {
+if ($contr_importa_vc and ($attiva_contratti_consentiti == "n" or (isset($contratti_consentiti_vett[$contr_importa_vc]) and $contratti_consentiti_vett[$contr_importa_vc] == "SI"))) {
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"contr_cond\" value=\"$contr_importa_vc\">
 &nbsp;&nbsp;<input class=\"sbutton\" type=\"submit\" value=\"".mex("Visualizza le condizioni del documento",$pag)." $contr_importa_vc\">
 </div></form>";
-} # fine if ($contr_importa_vc and...
+} # fine if ($contr_importa_vc and ($attiva_contratti_consentiti == "n" or...
 echo "<br><br>";
 } # fine if ($opt_contr_imp)
 } # fine if ($contr_cond)
@@ -1505,7 +1506,7 @@ echo "<table onclick=\"document.getElementById('az_set').checked='1'\"><tr><td>
 <td><b style=\"font-size: 260%;\">{</b></td><td>
 <table cellspacing=\"0\"><tr><td>
 <input type=\"radio\" id=\"val_all_txt\" name=\"tipo_val_allora\" value=\"txt\"$chk_txt></td><td>
-<input type=\"text\" name=\"val_allora_txt\" value=\"".htmlspecialchars(fixstr($val_allora_txt))."\" size=\"20\" maxlength=\"750\" onfocus=\"document.getElementById('val_all_txt').checked='1'\">
+<input type=\"text\" name=\"val_allora_txt\" value=\"".htmlspecialchars(fixstr($val_allora_txt))."\" size=\"28\" maxlength=\"750\" onfocus=\"document.getElementById('val_all_txt').checked='1'\">
 </td></tr><tr><td><input type=\"radio\" id=\"val_all_sel\" name=\"tipo_val_allora\" value=\"var\"$chk_var></td><td>
 <select name=\"val_allora_sel\" onfocus=\"document.getElementById('val_all_sel').checked='1'\">
 ".str_replace("\"".fixset($val_allora_sel)."\">","\"".fixset($val_allora_sel)."\" selected>",$option_var_predef)."
