@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2025 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -70,11 +70,10 @@ include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
 $numconnessione = connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
 include("./includes/funzioni.php");
-include(C_DATI_PATH."/lingua.php");
+#include(C_DATI_PATH."/lingua.php");
 include("./includes/sett_gio.php");
 include("./includes/funzioni_tariffe.php");
 include("./includes/funzioni_costi_agg.php");
-include("./includes/sett_gio.php");
 $tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
 $tableprenota = $PHPR_TAB_PRE."prenota".$anno;
 $tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
@@ -281,22 +280,22 @@ $app_prenota = risul_query($dati_prenota,0,'idappartamenti');
 $d_tariffa = risul_query($dati_prenota,0,'tariffa');
 $d_tariffa = explode("#@&",$d_tariffa);
 $d_nome_tariffa = $d_tariffa[0];
-$d_costo_tariffa = (double) $d_tariffa[1];
-$d_sconto = (double) risul_query($dati_prenota,0,'sconto');
-if (!$d_sconto) $d_sconto = (double) 0;
-$d_costo_tot = (double) risul_query($dati_prenota,0,'tariffa_tot');
-if (!$d_costo_tot) $d_costo_tot = (double) 0;
+$d_costo_tariffa = (float) fixset($d_tariffa[1]);
+$d_sconto = (float) risul_query($dati_prenota,0,'sconto');
+if (!$d_sconto) $d_sconto = (float) 0;
+$d_costo_tot = (float) risul_query($dati_prenota,0,'tariffa_tot');
+if (!$d_costo_tot) $d_costo_tot = (float) 0;
 $d_caparra = risul_query($dati_prenota,0,'caparra');
 $d_num_persone = risul_query($dati_prenota,0,'num_persone');
 if (!$d_num_persone) $d_num_persone = 0;
 $d_cat_persone = dati_cat_pers_p($dati_prenota,0,$dati_cat_pers,$d_num_persone);
 $d_tariffesettimanali = risul_query($dati_prenota,0,'tariffesettimanali');
 $dati_cap = dati_costi_agg_prenota($tablecostiprenota,$id_prenota,$dati_cat_pers);
-$d_costo_agg_tot = (double) 0;
+$d_costo_agg_tot = (float) 0;
 for ($numca = 0 ; $numca < $dati_cap['num'] ; $numca++) {
 aggiorna_letti_agg_in_periodi($dati_cap,$numca,$num_letti_agg,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],"","",fixset($dati_cap[$numca]['cat_pers']),"0");
-$d_prezzo_costo_agg[$numca] = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],$d_costo_tariffa,$d_tariffesettimanali,($d_costo_tariffa + $d_costo_agg_tot - $d_sconto),$d_caparra,$d_num_persone,fixset($dati_cap[$numca]['cat_pers']),0);
-$d_costo_agg_tot = (double) $d_costo_agg_tot + $d_prezzo_costo_agg[$numca];
+$d_prezzo_costo_agg[$numca] = (float) calcola_prezzo_totale_costo($dati_cap,$numca,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],$d_costo_tariffa,$d_tariffesettimanali,($d_costo_tariffa + $d_costo_agg_tot - $d_sconto),$d_caparra,$d_num_persone,fixset($dati_cap[$numca]['cat_pers']),0);
+$d_costo_agg_tot = (float) $d_costo_agg_tot + $d_prezzo_costo_agg[$numca];
 } # fine for $numca
 $d_pagato = risul_query($dati_prenota,0,'pagato');
 if (!$d_pagato) $d_pagato = 0;
@@ -325,7 +324,7 @@ $azione = 1;
 $incassa = 0;
 } # fine if (!empty($canc_incassa))
 
-if (!empty($agg_costo) and (strcmp((string) $dati_ca['id'][$agg_costo],"") or substr($agg_costo,0,1) == "c") and !$azione) {
+if (!empty($agg_costo) and (strcmp(fixstr($dati_ca['id'][$agg_costo]),"") or substr($agg_costo,0,1) == "c") and !$azione) {
 $azione = 1;
 if (substr($agg_costo,0,1) != "c") {
 if ($id_costi) $id_costi .= ",";
@@ -340,7 +339,7 @@ $id_costi .= $dati_ca[$num1]['id'];
 } # fine if ($dati_ca[$num1]['combina'] == "s" and...
 } # fine for $num1
 } # fine else if (substr($agg_costo,0,1) != "c")
-} # fine if (!empty($agg_costo) and (strcmp((string) $dati_ca['id'][$agg_costo],"") or...
+} # fine if (!empty($agg_costo) and (strcmp(fixstr($dati_ca['id'][$agg_costo]),"") or...
 
 if (isset($canc_costo) and strcmp((string) $canc_costo,"") and !$azione) {
 $azione = 1;
@@ -375,6 +374,7 @@ if ($moltiplica > 1) $id_costi .= "x$moltiplica";
 } # fine if ($moltiplica)
 } # fine if ($dati_ca[$num_uc]['moltiplica'] == "c")
 else {
+if (empty($moltiplica)) $moltiplica = 0;
 if (!empty($aggiungi)) $moltiplica = $aggiungi + 1;
 for ($num1 = 1 ; $num1 <= $moltiplica ; $num1++) $id_costi .= ",".$ultimo_costo;
 if (substr($id_costi,0,1) == ",") $id_costi = substr($id_costi,1);
@@ -547,7 +547,7 @@ if ($dati_ca[$numca]['tipo_val'] == "t" or $dati_ca[$numca]['tipo_val'] == "r")
 if (!$calcolabile_js['nessuno']) {
 $calcolabile_js[$num_costo] = 1;
 if (!empty($errori_costi[$num_costo])) $calcolabile_js[$num_costo] = 0;
-if ($dati_ca[$numca]['tipo'] != "u" or $dati_ca[$num1]['tipo_val'] != "f") $calcolabile_js[$num_costo] = 0;
+if ($dati_ca[$numca]['tipo'] != "u" or $dati_ca[$numca]['tipo_val'] != "f") $calcolabile_js[$num_costo] = 0;
 if ($dati_ca[$numca]['letto'] == "s" or $dati_ca[$numca]['numlimite'] or !empty($dati_ca[$numca]['tipo_beniinv']) or $dati_ca[$numca]['periodipermessi'] or $dati_ca[$numca]['appincompatibili']) $calcolabile_js[$num_costo] = 0;
 if ($dati_ca[$numca]['moltiplica'] != "1" and $dati_ca[$numca]['moltiplica'] != "c") $calcolabile_js[$num_costo] = 0;
 if ($dati_ca[$numca]['moltiplica'] == "c") $moltiplicabile_js[$num_costo] = 1;
@@ -668,7 +668,7 @@ if ($dati_ca[$numca]['molt_max'] == "n") $errore_cassa = 1;
 for ($numca = 0 ; $numca < $dati_cap['num'] ; $numca++) {
 if ($dati_cap[$numca]['tipo_val'] != "t" and $dati_cap[$numca]['tipo_val'] != "r") {
 if ($dati_cap[$numca]['moltiplica'] == "t") {
-$n_prezzo_costo_agg[$numca] = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$n_moltiplica_costo[$numca],$d_costo_tariffa,$d_tariffesettimanali,1,$d_caparra,$d_num_persone,$dati_cap[$numca]['cat_pers'],0);
+$n_prezzo_costo_agg[$numca] = (float) calcola_prezzo_totale_costo($dati_cap,$numca,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$n_moltiplica_costo[$numca],$d_costo_tariffa,$d_tariffesettimanali,1,$d_caparra,$d_num_persone,$dati_cap[$numca]['cat_pers'],0);
 if ($n_prezzo_costo_agg[$numca] != $d_prezzo_costo_agg[$numca]) $val_costo[-1] += $n_prezzo_costo_agg[$numca] - $d_prezzo_costo_agg[$numca];
 } # fine if ($dati_cap[$numca]['moltiplica'] == "t")
 else $n_prezzo_costo_agg[$numca] = $d_prezzo_costo_agg[$numca];
@@ -683,7 +683,7 @@ $id_costo = $id_costo[0];
 $numca = $dati_ca['id'][$id_costo];
 if ($dati_ca[$numca]['tipo_val'] != "f" or $dati_ca[$numca]['tipo'] != "u" or $dati_ca[$numca]['moltiplica'] == "p" or $dati_ca[$numca]['moltiplica'] == "t") {
 if ($dati_ca[$numca]['tipo_val'] != "t" and $dati_ca[$numca]['tipo_val'] != "r") {
-$val_costo[$num1] = (double) calcola_prezzo_totale_costo($dati_ca,$numca,$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$moltiplica_costo[$num1],$d_costo_tariffa,$d_tariffesettimanali,1,$d_caparra,$d_num_persone,$dati_cat_pers,0);
+$val_costo[$num1] = (float) calcola_prezzo_totale_costo($dati_ca,$numca,$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$moltiplica_costo[$num1],$d_costo_tariffa,$d_tariffesettimanali,1,$d_caparra,$d_num_persone,$dati_cat_pers,0);
 $n_costo_agg_tot = $n_costo_agg_tot + $val_costo[$num1];
 $val_tot += $val_costo[$num1];
 } # fine if ($dati_ca[$numca]['tipo_val'] != "t" and $dati_ca[$numca]['tipo_val'] != "r")
@@ -696,7 +696,7 @@ for ($numca = 0 ; $numca < $dati_cap['num'] ; $numca++) {
 if ($dati_cap[$numca]['tipo_val'] == "r") {
 $calcolabile_js['nessuno'] = 1;
 $costo_totale_provvisorio = $d_costo_tariffa + $n_costo_agg_tot - $d_sconto;
-$n_prezzo_costo_agg[$numca] = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$n_moltiplica_costo[$numca],$d_costo_tariffa,$d_tariffesettimanali,$costo_totale_provvisorio,$d_caparra,$d_num_persone,"","");
+$n_prezzo_costo_agg[$numca] = (float) calcola_prezzo_totale_costo($dati_cap,$numca,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$n_moltiplica_costo[$numca],$d_costo_tariffa,$d_tariffesettimanali,$costo_totale_provvisorio,$d_caparra,$d_num_persone,"","");
 if ($d_prezzo_costo_agg[$numca] != $n_prezzo_costo_agg[$numca]) $val_costo[-1] += $n_prezzo_costo_agg[$numca] - $d_prezzo_costo_agg[$numca];
 $n_costo_agg_tot = $n_costo_agg_tot + $n_prezzo_costo_agg[$numca];
 } # fine if ($dati_cap[$numca][tipo_val] == "r")
@@ -708,7 +708,7 @@ $id_costo = $id_costo[0];
 $numca = $dati_ca['id'][$id_costo];
 if ($dati_ca[$numca]['tipo_val'] == "r") {
 $costo_totale_provvisorio = $d_costo_tariffa + $n_costo_agg_tot - $d_sconto;
-$val_costo[$num1] = (double) calcola_prezzo_totale_costo($dati_ca,$numca,$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$moltiplica_costo[$num1],$d_costo_tariffa,$d_tariffesettimanali,$costo_totale_provvisorio,$d_caparra,$d_num_persone,"","");
+$val_costo[$num1] = (float) calcola_prezzo_totale_costo($dati_ca,$numca,$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$moltiplica_costo[$num1],$d_costo_tariffa,$d_tariffesettimanali,$costo_totale_provvisorio,$d_caparra,$d_num_persone,"","");
 $n_costo_agg_tot = $n_costo_agg_tot + $val_costo[$num1];
 $val_tot += $val_costo[$num1];
 } # fine if ($dati_ca[$numca][tipo_val] == "r")
@@ -719,7 +719,7 @@ for ($numca = 0 ; $numca < $dati_cap['num'] ; $numca++) {
 if ($dati_cap[$numca]['tipo_val'] == "t") {
 $calcolabile_js['nessuno'] = 1;
 $costo_totale_provvisorio = $d_costo_tariffa + $n_costo_agg_tot - $d_sconto;
-$n_prezzo_costo_agg[$numca] = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$n_moltiplica_costo[$numca],$d_costo_tariffa,$d_tariffesettimanali,$costo_totale_provvisorio,$d_caparra,$d_num_persone,"","");
+$n_prezzo_costo_agg[$numca] = (float) calcola_prezzo_totale_costo($dati_cap,$numca,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$n_moltiplica_costo[$numca],$d_costo_tariffa,$d_tariffesettimanali,$costo_totale_provvisorio,$d_caparra,$d_num_persone,"","");
 if ($d_prezzo_costo_agg[$numca] != $n_prezzo_costo_agg[$numca]) $val_costo[-1] += $n_prezzo_costo_agg[$numca] - $d_prezzo_costo_agg[$numca];
 $n_costo_agg_tot = $n_costo_agg_tot + $n_prezzo_costo_agg[$numca];
 } # fine if ($dati_cap[$numca][tipo_val] == "t")
@@ -731,7 +731,7 @@ $id_costo = $id_costo[0];
 $numca = $dati_ca['id'][$id_costo];
 if ($dati_ca[$numca]['tipo_val'] == "t") {
 $costo_totale_provvisorio = $d_costo_tariffa + $n_costo_agg_tot - $d_sconto;
-$val_costo[$num1] = (double) calcola_prezzo_totale_costo($dati_ca,$numca,$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$moltiplica_costo[$num1],$d_costo_tariffa,$d_tariffesettimanali,$costo_totale_provvisorio,$d_caparra,$d_num_persone,"","");
+$val_costo[$num1] = (float) calcola_prezzo_totale_costo($dati_ca,$numca,$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$moltiplica_costo[$num1],$d_costo_tariffa,$d_tariffesettimanali,$costo_totale_provvisorio,$d_caparra,$d_num_persone,"","");
 $n_costo_agg_tot = $n_costo_agg_tot + $val_costo[$num1];
 $val_tot += $val_costo[$num1];
 } # fine if ($dati_ca[$numca][tipo_val] == "t")
@@ -764,14 +764,14 @@ unset($nomi_casse);
 $cassa_trovata = 0;
 for ($num1 = 0 ; $num1 < $num_casse ; $num1++) {
 $id_cassa = risul_query($casse,$num1,'idcasse');
-if ($attiva_casse_consentite == "n" or $casse_consentite_vett[$id_cassa] == "SI") {
+if ($attiva_casse_consentite == "n" or (isset($casse_consentite_vett[$id_cassa]) and $casse_consentite_vett[$id_cassa] == "SI")) {
 if ($id_cassa == 1) $nome_cassa = "";
 else $nome_cassa = risul_query($casse,$num1,'nome_cassa');
 $num_casse_attive++;
 $id_casse[$num_casse_attive] = $id_cassa;
 $nomi_casse[$id_cassa] = $nome_cassa;
 if (isset($id_cassa_sel) and $id_cassa_sel == $id_cassa) $cassa_trovata = 1;
-} # fine if ($attiva_casse_consentite == "n" or $casse_consentite_vett[$id_cassa] == "SI")
+} # fine if ($attiva_casse_consentite == "n" or (isset($casse_consentite_vett[$id_cassa]) and...
 } # fine for $num1
 if (!$num_casse_attive) {
 $errore_cassa = 1;
@@ -800,10 +800,10 @@ $testo_azione .= "<br>".mex("Valuta",$pag).":<br><br>
 <select name=\"valuta_pagamento_sel\" style=\"font-size: xx-large;\">
 <option value=\"\">".punti_in_num($val_entrata,$stile_soldi)." $Euro</option>";
 for ($num1 = 0 ; $num1 < $altre_valute['num'] ; $num1++) {
-$val_entrata_valuta = (double) $val_entrata * (double) $altre_valute[$num1]['cambio'];
-$val_entrata_valuta = $val_entrata_valuta / (double) $altre_valute[$num1]['arrotond'];
+$val_entrata_valuta = (float) $val_entrata * (float) $altre_valute[$num1]['cambio'];
+$val_entrata_valuta = $val_entrata_valuta / (float) $altre_valute[$num1]['arrotond'];
 $val_entrata_valuta = round($val_entrata_valuta);
-$val_entrata_valuta = $val_entrata_valuta * (double) $altre_valute[$num1]['arrotond'];
+$val_entrata_valuta = $val_entrata_valuta * (float) $altre_valute[$num1]['arrotond'];
 $val_entrata_valuta_p = punti_in_num($val_entrata_valuta,$stile_soldi);
 #if (substr($val_entrata_valuta_p,0,1) != "-") $val_entrata_valuta_p = "+".$val_entrata_valuta_p;
 $testo_azione .=  "<option value=\"".htmlspecialchars($altre_valute[$num1]['nome'])."\">$val_entrata_valuta_p ".$altre_valute[$num1]['nome']."</option>";
@@ -831,11 +831,9 @@ else {
 if ($num_casse_attive == 1) $id_cassa = $id_casse[1];
 else $id_cassa = $id_cassa_sel;
 $nome_cassa = $nomi_casse[$id_cassa];
-if (strcmp((string) $metodo_pagamento_sel,"")) {
 if (@get_magic_quotes_gpc()) $metodo_pagamento_sel = stripslashes($metodo_pagamento_sel);
-$metodo_pagamento_sel = htmlspecialchars($metodo_pagamento_sel);
-if (str_replace(",$metodo_pagamento_sel,",",",",$metodi_pagamento,") == ",$metodi_pagamento,") $metodo_pagamento_sel = "";
-} # fine if (strcmp((string) $metodo_pagamento_sel,""))
+$metodo_pagamento_sel = htmlspecialchars(fixstr($metodo_pagamento_sel),ENT_COMPAT);
+if (strcmp($metodo_pagamento_sel,"") and str_replace(",$metodo_pagamento_sel,",",",",$metodi_pagamento,") == ",$metodi_pagamento,") $metodo_pagamento_sel = "";
 $datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 $val_entrata = formatta_soldi($val_tot);
 $persona_costo = "";
@@ -849,10 +847,10 @@ $idcosti = risul_query($idcosti,0,0) + 1;
 esegui_query("insert into $tablecosti (idcosti,nome_costo,val_costo,tipo_costo,nome_cassa,persona_costo,provenienza_costo,metodo_pagamento,data_transazione,datainserimento,hostinserimento,utente_inserimento) values ('$idcosti','".aggslashdb($testo_costi)."','$val_entrata','e','".aggslashdb($nome_cassa)."','".aggslashdb($persona_costo)."','".aggslashdb($provenienza_costo)."','".aggslashdb($metodo_pagamento_sel)."','$datainserimento','$datainserimento','$HOSTNAME','$id_utente') ");
 if ($altre_valute['num'] and isset($altre_valute['id'][$valuta_pagamento_sel]) and strcmp((string) $altre_valute['id'][$valuta_pagamento_sel],"")) {
 $valuta_corr = $altre_valute['id'][$valuta_pagamento_sel];
-$val_entrata_valuta = (double) $val_entrata * (double) $altre_valute[$valuta_corr]['cambio'];
-$val_entrata_valuta = $val_entrata_valuta / (double) $altre_valute[$valuta_corr]['arrotond'];
+$val_entrata_valuta = (float) $val_entrata * (float) $altre_valute[$valuta_corr]['cambio'];
+$val_entrata_valuta = $val_entrata_valuta / (float) $altre_valute[$valuta_corr]['arrotond'];
 $val_entrata_valuta = round($val_entrata_valuta);
-$val_entrata_valuta = $val_entrata_valuta * (double) $altre_valute[$valuta_corr]['arrotond'];
+$val_entrata_valuta = $val_entrata_valuta * (float) $altre_valute[$valuta_corr]['arrotond'];
 $valuta = $altre_valute[$valuta_corr]['nome'].">".$altre_valute[$valuta_corr]['cambio'].">".$altre_valute[$valuta_corr]['arrotond'];
 esegui_query("update $tablecosti set valuta = '".aggslashdb($valuta)."', costo_valuta = '".aggslashdb($val_entrata_valuta)."' where idcosti = '$idcosti' ");
 $val_valuta_paga = $val_entrata_valuta;
@@ -1070,19 +1068,19 @@ $numca = $dati_ca['id'][$id_costo];
 if (!empty($moltiplica_max[$num1])) $molt_costo = $moltiplica_max[$num1];
 elseif ($dati_ca[$numca]['moltiplica'] == "p" or $dati_ca[$numca]['moltiplica'] == "t") $molt_costo = "?";
 $onclick = "";
-if ($calcolabile_js[$num1]) {
+if (!empty($calcolabile_js[$num1])) {
 $vett_js_id_c .= ",'$id_costo'";
 $vett_js_nomi_c .= ",'".str_replace("'","\\'",str_replace("\\","\\\\",$dati_ca[$numca]['nome']))."'";
 $vett_js_molt_c .= ",'$molt_costo'";
 $vett_js_val_c .= ",'".$val_costo[$num1]."'";
 if (!$calcolabile_js['nessuno']) $onclick = " onclick=\"return canc_cos_pv($num1);\"";
-} # fine if ($calcolabile_js[$num1])
+} # fine if (!empty($calcolabile_js[$num1]))
 else {
 $vett_js_id_c .= ",''";
 $vett_js_nomi_c .= ",''";
 $vett_js_molt_c .= ",''";
 $vett_js_val_c .= ",''";
-} # fine else if ($calcolabile_js[$num1])
+} # fine else if (!empty($calcolabile_js[$num1]))
 if ($molt_costo and $molt_costo != 1) $molt_costo = " <b>x$molt_costo</b>";
 else $molt_costo = "";
 if (!empty($errori_costi[$num1])) $redclass = " class=\"colred\" title=\"".substr($errori_costi[$num1],2)."\"";
@@ -1196,14 +1194,19 @@ $nome_contratto[$dati_nome_contratto[0]] = $dati_nome_contratto[1];
 } # fine for $num1
 $max_contr = esegui_query("select max(numero) from $tablecontratti where tipo $LIKE 'contr%'");
 $max_contr = risul_query($max_contr,0,0);
+$contr_escludi = array();
+$escludi_pag = esegui_query("select numero from $tablecontratti where tipo = 'pag_esc' and testo $LIKE '%,pos,%' ");
+for ($num1 = 0 ; $num1 < numlin_query($escludi_pag) ; $num1++) $contr_escludi[risul_query($escludi_pag,$num1,'numero')] = 1;
 for ($num_contratto = 1 ; $num_contratto <= $max_contr ; $num_contratto++) {
-if ($attiva_contratti_consentiti == "n" or $contratti_consentiti_vett[$num_contratto] == "SI") {
+if (empty($contr_escludi[$num_contratto])) {
+if ($attiva_contratti_consentiti == "n" or (isset($contratti_consentiti_vett[$num_contratto]) and $contratti_consentiti_vett[$num_contratto] == "SI")) {
 if (!empty($nome_contratto[$num_contratto])) $num_contratto_vedi = $nome_contratto[$num_contratto];
 else $num_contratto_vedi = mex("documento",$pag)." ".$num_contratto;
 echo "<div style=\"float: left; padding: 2px;\">
 <button class=\"pos\" type=\"submit\" name=\"numero_contratto\" value=\"$num_contratto\" style=\"min-height: 60px; min-width: 70px; max-width: 110px;\">$num_contratto_vedi</button>
 </div>";
 } # fine if ($attiva_contratti_consentiti == "n" or...
+} # fine if (empty($contr_escludi[$num_contratto]))
 } # fine for $num_contratto
 echo "</div></form>";
 } # fine if ($mostra_contr)
