@@ -97,6 +97,7 @@ $tariffe_consentite_vett = array();
 $costi_agg_consentiti_vett = array();
 
 if ($id_utente != 1) {
+$prendi_gruppi = "";
 $tableprivilegi = $PHPR_TAB_PRE."privilegi";
 $privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
 if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
@@ -174,7 +175,7 @@ $utenti_gruppo = esegui_query("select idutente from $tablerelgruppi where idgrup
 $num_utenti_gruppo = numlin_query($utenti_gruppo);
 for ($num2 = 0 ; $num2 < $num_utenti_gruppo ; $num2++) {
 $idutente_gruppo = risul_query($utenti_gruppo,$num2,'idutente');
-if ($idutente_gruppo != $id_utente and !$utenti_gruppi[$idutente_gruppo]) {
+if ($idutente_gruppo != $id_utente and empty($utenti_gruppi[$idutente_gruppo])) {
 $utenti_gruppi[$idutente_gruppo] = 1;
 unset($priv_anno_ut_gr);
 
@@ -217,7 +218,7 @@ for ($num3 = 0 ; $num3 < count($costi_agg_consentiti_tmp) ; $num3++) if ($costi_
 } # fine if (numlin_query($priv_anno_ut_gr) == 1)
 } # fine if ($priv_vedi_tab_periodi == "g")
 
-} # fine if ($idutente_gruppo != $id_utente)
+} # fine if ($idutente_gruppo != $id_utente and...
 } # fine for $num2
 } # fine for $num1
 } # fine if ($prendi_gruppi == "SI")
@@ -284,10 +285,10 @@ unlock_tabelle($tabelle_lock);
 $numero_tariffe = $dati_tariffe['num'];
 if (empty($num_tariffe_mostra) or controlla_num_pos($num_tariffe_mostra) != "SI") $num_tariffe_mostra = 1;
 for ($num1 = 1 ; $num1 <= $num_tariffe_mostra ; $num1++) {
-if (${"numtariffa".$num1} < 1 or ${"numtariffa".$num1} > $numero_tariffe or controlla_num_pos(${"numtariffa".$num1}) != "SI") {
+if (!isset(${"numtariffa".$num1}) or ${"numtariffa".$num1} < 1 or ${"numtariffa".$num1} > $numero_tariffe or controlla_num_pos(${"numtariffa".$num1}) != "SI") {
 if ($num1 == 1) ${"numtariffa".$num1} = 1;
 else $num_tariffe_mostra = 1;
-} # fine if (${"numtariffa".$num1} < 1 or ${"numtariffa".$num1} > $numero_tariffe or...
+} # fine if (!isset(${"numtariffa".$num1}) or ${"numtariffa".$num1} < 1 or ${"numtariffa".$num1} > $numero_tariffe or...
 } # fine for $num1
 
 $attiva_tariffe_consentite_ut = $attiva_tariffe_consentite;
@@ -319,20 +320,20 @@ $tabelle_lock = array($tabledescrizioni);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 if (strcmp((string) $n_descrizione_ita,"")) {
 if (@get_magic_quotes_gpc()) $n_descrizione_ita = stripslashes($n_descrizione_ita);
-$n_descrizione_ita = aggslashdb(htmlspecialchars($n_descrizione_ita));
+$n_descrizione_ita = aggslashdb(htmlspecialchars($n_descrizione_ita,ENT_COMPAT));
 $descr_esistente = esegui_query("select testo from $tabledescrizioni where nome = 'tariffa".$numtariffa1."' and tipo = 'tardescr' and lingua = 'ita' and numero = '1' ");
 if (numlin_query($descr_esistente)) esegui_query("update $tabledescrizioni set testo = '$n_descrizione_ita' where nome = 'tariffa".$numtariffa1."' and tipo = 'tardescr' and lingua = 'ita' and numero = '1' ");
 else esegui_query("insert into $tabledescrizioni (nome,tipo,lingua,numero,testo) values ('tariffa".$numtariffa1."','tardescr','ita','1','$n_descrizione_ita') ");
 } # fine if (strcmp((string) $n_descrizione_ita,""))
 else esegui_query("delete from $tabledescrizioni where nome = 'tariffa".$numtariffa1."' and tipo = 'tardescr' and lingua = 'ita' and numero = '1' ");
 $lang_dir = opendir("./includes/lang/");
-include(C_DATI_PATH."/lingua.php");
+#include(C_DATI_PATH."/lingua.php");
 while ($ini_lingua = readdir($lang_dir)) {
 if ($ini_lingua != "." && $ini_lingua != ".." and strlen($ini_lingua) <= 3 and preg_replace("/[a-z]/","",$ini_lingua) == "") {
 $n_descrizione = ${"n_descrizione_".$ini_lingua};
 if (strcmp((string) $n_descrizione,"")) {
 if (@get_magic_quotes_gpc()) $n_descrizione = stripslashes($n_descrizione);
-$n_descrizione = aggslashdb(htmlspecialchars($n_descrizione));
+$n_descrizione = aggslashdb(htmlspecialchars($n_descrizione,ENT_COMPAT));
 $descr_esistente = esegui_query("select testo from $tabledescrizioni where nome = 'tariffa".$numtariffa1."' and tipo = 'tardescr' and lingua = '$ini_lingua' and numero = '1' ");
 if (numlin_query($descr_esistente)) esegui_query("update $tabledescrizioni set testo = '$n_descrizione' where nome = 'tariffa".$numtariffa1."' and tipo = 'tardescr' and lingua = '$ini_lingua' and numero = '1' ");
 else esegui_query("insert into $tabledescrizioni (nome,tipo,lingua,numero,testo) values ('tariffa".$numtariffa1."','tardescr','$ini_lingua','1','$n_descrizione') ");
@@ -351,9 +352,11 @@ if (!empty($aggurlfoto) and $priv_mod_tariffe != "n" and (!defined('C_RESTRIZION
 $dest = "#aggfoto";
 $errore = "";
 if (@get_magic_quotes_gpc()) $n_urlfoto = stripslashes($n_urlfoto);
-$lowurl = strtolower(fixstr($n_urlfoto));
+$n_urlfoto = trim(fixstr($n_urlfoto));
+$lowurl = strtolower($n_urlfoto);
 if (substr($lowurl,-4) != ".jpg" and substr($lowurl,-5) != ".jpeg" and substr($lowurl,-4) != ".gif" and substr($lowurl,-4) != ".png" and substr($lowurl,-5) != ".webp") $errore = "SI";
 if (str_replace("<","",$n_urlfoto) != $n_urlfoto or str_replace(">","",$n_urlfoto) != $n_urlfoto or str_replace("\"","",$n_urlfoto) != $n_urlfoto) $errore = "SI";
+if (substr($lowurl,0,5) != "http:" and substr($lowurl,0,6) != "https:" and preg_match("/^[a-z ]+:/i",$n_urlfoto)) $errore = "SI";
 if ($errore != "SI") {
 $tabelle_lock = array($tabledescrizioni);
 $tabelle_lock = lock_tabelle($tabelle_lock);
@@ -379,20 +382,20 @@ $foto_esistente = esegui_query("select testo from $tabledescrizioni where nome =
 if (numlin_query($foto_esistente)) {
 if (strcmp((string) $n_commento_ita,"")) {
 if (@get_magic_quotes_gpc()) $n_commento_ita = stripslashes($n_commento_ita);
-$n_commento_ita = aggslashdb(htmlspecialchars($n_commento_ita));
+$n_commento_ita = aggslashdb(htmlspecialchars($n_commento_ita,ENT_COMPAT));
 $comm_esistente = esegui_query("select testo from $tabledescrizioni where nome = 'tariffa".$numtariffa1."' and tipo = 'tarcommfoto' and lingua = 'ita' and numero = '$numfoto' ");
 if (numlin_query($comm_esistente)) esegui_query("update $tabledescrizioni set testo = '$n_commento_ita' where nome = 'tariffa".$numtariffa1."' and tipo = 'tarcommfoto' and lingua = 'ita' and numero = '$numfoto' ");
 else esegui_query("insert into $tabledescrizioni (nome,tipo,lingua,numero,testo) values ('tariffa".$numtariffa1."','tarcommfoto','ita','$numfoto','$n_commento_ita') ");
 } # fine if (strcmp((string) $n_commento_ita,""))
 else esegui_query("delete from $tabledescrizioni where nome = 'tariffa".$numtariffa1."' and tipo = 'tarcommfoto' and lingua = 'ita' and numero = '$numfoto' ");
 $lang_dir = opendir("./includes/lang/");
-include(C_DATI_PATH."/lingua.php");
+#include(C_DATI_PATH."/lingua.php");
 while ($ini_lingua = readdir($lang_dir)) {
 if ($ini_lingua != "." && $ini_lingua != ".." and strlen($ini_lingua) <= 3 and preg_replace("/[a-z]/","",$ini_lingua) == "") {
 $n_commento = ${"n_commento_".$ini_lingua};
 if (strcmp((string) $n_commento,"")) {
 if (@get_magic_quotes_gpc()) $n_commento = stripslashes($n_commento);
-$n_commento = aggslashdb(htmlspecialchars($n_commento));
+$n_commento = aggslashdb(htmlspecialchars($n_commento,ENT_COMPAT));
 $comm_esistente = esegui_query("select testo from $tabledescrizioni where nome = 'tariffa".$numtariffa1."' and tipo = 'tarcommfoto' and lingua = '$ini_lingua' and numero = '$numfoto' ");
 if (numlin_query($comm_esistente)) esegui_query("update $tabledescrizioni set testo = '$n_commento' where nome = 'tariffa".$numtariffa1."' and tipo = 'tarcommfoto' and lingua = '$ini_lingua' and numero = '$numfoto' ");
 else esegui_query("insert into $tabledescrizioni (nome,tipo,lingua,numero,testo) values ('tariffa".$numtariffa1."','tarcommfoto','$ini_lingua','$numfoto','$n_commento') ");
@@ -521,10 +524,10 @@ if (num_caratteri_testo($nometariffa[$num1]) > 10) $nometariffa_vedi[$num1] = "<
 else $nometariffa_vedi[$num1] = $nometariffa[$num1];
 } # fine else if (!strcmp((string) $nometariffa[$num1],""))
 $nome_tariffa[${"numtariffa".$num1}] = $tariffa[$num1];
-if (($priv_vedi_tab_periodi == "s" and $priv_vedi_tab_regole == "s" and $priv_vedi_tab_mesi == "s") or $attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num1}] == "SI") {
+if (($priv_vedi_tab_periodi == "s" and $priv_vedi_tab_regole == "s" and $priv_vedi_tab_mesi == "s") or $attiva_tariffe_consentite == "n" or (isset($tariffe_consentite_vett[${"numtariffa".$num1}]) and $tariffe_consentite_vett[${"numtariffa".$num1}] == "SI")) {
 if (empty($dati_r2[$tariffa[$num1]])) $app_regola2_orig[${"numtariffa".$num1}] = substr($dati_app['lista'],1,-1);
 else $app_regola2_orig[${"numtariffa".$num1}] = $dati_r2[$tariffa[$num1]];
-} # fine if (($priv_vedi_tab_periodi == "s" and $priv_vedi_tab_regole == "s" and $priv_vedi_tab_mesi == "s") or $attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num1}] == "SI")
+} # fine if (($priv_vedi_tab_periodi == "s" and $priv_vedi_tab_regole == "s" and $priv_vedi_tab_mesi == "s") or $attiva_tariffe_consentite == "n" or...
 } # fine for $num1
 
 
@@ -631,20 +634,20 @@ $sett_in_per++;
 $datafine = risul_query($periodi,($sett_in_per - 1),'datafine');
 $idper_corr = risul_query($periodi,($sett_in_per - 1),'idperiodi');
 for ($num1 = 1 ; $num1 <= $num_tariffe_mostra ; $num1++) {
-if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num1}] == "SI") {
+if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or (isset($tariffe_consentite_vett[${"numtariffa".$num1}]) and $tariffe_consentite_vett[${"numtariffa".$num1}] == "SI")) {
 $tar_corr = (string) risul_query($periodi,($sett_in_per - 1),$tariffa[$num1]);
 if ($dati_tariffe[$tariffa[$num1]]['moltiplica'] != "p") $tarp_corr = "";
 else $tarp_corr = (string) risul_query($periodi,($sett_in_per - 1),$tariffa[$num1]."p");
 if (isset($dati_r2['napp'][$tariffa[$num1]]) and $dati_r2['napp'][$tariffa[$num1]] > 1) {
 $p_app[${"numtariffa".$num1}] = "*".$dati_r2['napp'][$tariffa[$num1]];
-if (empty($form_tabella)) $tar_corr = (string) ((double) $tar_corr * (double) $dati_r2['napp'][$tariffa[$num1]]);
-#$tarp_corr = (string) ((double) $tarp_corr * (double) $dati_r2['napp'][$tariffa[$num1]]);
+if (empty($form_tabella)) $tar_corr = (string) ((float) $tar_corr * (float) $dati_r2['napp'][$tariffa[$num1]]);
+#$tarp_corr = (string) ((float) $tarp_corr * (float) $dati_r2['napp'][$tariffa[$num1]]);
 } # fine if (isset($dati_r2['napp'][$tariffa[$num1]]) and $dati_r2['napp'][$tariffa[$num1]] > 1)
 if ($sett_in_per == 1 or (!strcmp((string) $tar_corr,"") and !strcmp((string) $tarp_corr,""))) {
 if ($sett_in_per == 1) {
 $chiusa_colonna_periodo[$num1][0] = "";
 $importata_colonna_periodo[$num1][0] = "";
-if ($mostra_disp == "s") $liberi_colonna_periodo[$num1][0] = $tab_liberi[$tariffa[$num1]][$idper_corr];
+if ($mostra_disp == "s") $liberi_colonna_periodo[$num1][0] = fixset($tab_liberi[$tariffa[$num1]][$idper_corr]);
 if ($mostra_pmm == "s") $pminima_colonna_periodo[$num1][0] = fixset($permanenza_minima[$tariffa[$num1]][$idper_corr]);
 if ($mostra_pmm == "s") $pmassima_colonna_periodo[$num1][0] = fixset($permanenza_massima[$tariffa[$num1]][$idper_corr]);
 } # fine if ($sett_in_per == 1)
@@ -654,14 +657,14 @@ $tariffap_colonna_periodo[$num1][0] = $tarp_corr;
 elseif (strcmp((string) $tariffa_colonna_periodo[$num1][0],"") or strcmp((string) $tariffap_colonna_periodo[$num1][0],"")) {
 if (!strcmp((string) $tariffa_colonna_periodo[$num1][0],"")) $tariffa_colonna_periodo[$num1][0] = 0;
 if (!strcmp((string) $tariffap_colonna_periodo[$num1][0],"")) $tariffap_colonna_periodo[$num1][0] = 0;
-$tariffa_colonna_periodo[$num1][0] += (double) $tar_corr;
-$tariffap_colonna_periodo[$num1][0] += (double) $tarp_corr;
+$tariffa_colonna_periodo[$num1][0] += (float) $tar_corr;
+$tariffap_colonna_periodo[$num1][0] += (float) $tarp_corr;
 } # fine elseif (strcmp((string) $tariffa_colonna_periodo[$num1][0],"") or strcmp((string) $tariffap_colonna_periodo[$num1][0],""))
 if (!empty($dati_tariffe[$tariffa[$num1]]['chiusa'][$idper_corr])) $chiusa_colonna_periodo[$num1][0] = 1;
 $tar_imp = periodo_importato_tar($tariffa[$num1],$idper_corr,$dati_tariffe);
 if (!$importata_colonna_periodo[$num1][0]) $importata_colonna_periodo[$num1][0] = $tar_imp;
 elseif ($tar_imp and $importata_colonna_periodo[$num1][0] != $tar_imp) $importata_colonna_periodo[$num1][0] = -1;
-if ($mostra_disp == "s" and $tab_liberi[$tariffa[$num1]][$idper_corr] < $liberi_colonna_periodo[$num1][0]) $liberi_colonna_periodo[$num1][0] = $tab_liberi[$tariffa[$num1]][$idper_corr];
+if ($mostra_disp == "s" and fixset($tab_liberi[$tariffa[$num1]][$idper_corr]) < $liberi_colonna_periodo[$num1][0]) $liberi_colonna_periodo[$num1][0] = $tab_liberi[$tariffa[$num1]][$idper_corr];
 if ($mostra_pmm == "s" and isset($permanenza_minima[$tariffa[$num1]][$idper_corr]) and $permanenza_minima[$tariffa[$num1]][$idper_corr] > $pminima_colonna_periodo[$num1][0]) $pminima_colonna_periodo[$num1][0] = $permanenza_minima[$tariffa[$num1]][$idper_corr];
 if ($mostra_pmm == "s" and isset($permanenza_massima[$tariffa[$num1]][$idper_corr]) and $permanenza_massima[$tariffa[$num1]][$idper_corr] < $pmassima_colonna_periodo[$num1][0]) $pmassima_colonna_periodo[$num1][0] = $permanenza_massima[$tariffa[$num1]][$idper_corr];
 } # fine if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or...
@@ -682,13 +685,13 @@ if ($sett_in_per > 1) $num1++;
 $datafine = risul_query($periodi,$num1,'datafine');
 $idper_corr = risul_query($periodi,$num1,'idperiodi');
 for ($num2 = 1 ; $num2 <= $num_tariffe_mostra ; $num2++) {
-if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num2}] == "SI") {
+if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or (isset($tariffe_consentite_vett[${"numtariffa".$num2}]) and $tariffe_consentite_vett[${"numtariffa".$num2}] == "SI")) {
 $tar_corr = (string) risul_query($periodi,$num1,$tariffa[$num2]);
 if ($dati_tariffe[$tariffa[$num2]]['moltiplica'] != "p") $tarp_corr = "";
 else $tarp_corr = (string) risul_query($periodi,$num1,$tariffa[$num2]."p");
 if (isset($dati_r2['napp'][$tariffa[$num2]]) and $dati_r2['napp'][$tariffa[$num2]] > 1) {
-if (empty($form_tabella)) $tar_corr = (string) ((double) $tar_corr * (double) $dati_r2['napp'][$tariffa[$num2]]);
-#$tarp_corr = (string) ((double) $tarp_corr * (double) $dati_r2['napp'][$tariffa[$num2]]);
+if (empty($form_tabella)) $tar_corr = (string) ((float) $tar_corr * (float) $dati_r2['napp'][$tariffa[$num2]]);
+#$tarp_corr = (string) ((float) $tarp_corr * (float) $dati_r2['napp'][$tariffa[$num2]]);
 } # fine if (isset($dati_r2['napp'][$tariffa[$num2]]) and $dati_r2['napp'][$tariffa[$num2]] > 1)
 if ($sett_in_per == 1 or (!strcmp((string) $tar_corr,"") and !strcmp((string) $tarp_corr,""))) {
 ${$tariffa[$num2]} = $tar_corr;
@@ -696,7 +699,7 @@ ${$tariffa[$num2]."p"} = $tarp_corr;
 if ($sett_in_per == 1) {
 ${$tariffa[$num2]."c"} = "";
 ${$tariffa[$num2]."i"} = "";
-if ($mostra_disp == "s") ${$tariffa[$num2]."l"} = $tab_liberi[$tariffa[$num2]][$idper_corr];
+if ($mostra_disp == "s") ${$tariffa[$num2]."l"} = fixset($tab_liberi[$tariffa[$num2]][$idper_corr]);
 if ($mostra_pmm == "s") ${$tariffa[$num2]."pmin"} = fixset($permanenza_minima[$tariffa[$num2]][$idper_corr]);
 if ($mostra_pmm == "s") ${$tariffa[$num2]."pmax"} = fixset($permanenza_massima[$tariffa[$num2]][$idper_corr]);
 } # fine if ($sett_in_per == 1)
@@ -704,14 +707,14 @@ if ($mostra_pmm == "s") ${$tariffa[$num2]."pmax"} = fixset($permanenza_massima[$
 elseif (strcmp((string) ${$tariffa[$num2]},"") or strcmp((string) ${$tariffa[$num2]."p"},"")) {
 if (!strcmp((string) ${$tariffa[$num2]},"")) ${$tariffa[$num2]} = 0;
 if (!strcmp((string) ${$tariffa[$num2]."p"},"")) ${$tariffa[$num2]."p"} = 0;
-${$tariffa[$num2]} += (double) $tar_corr;
-${$tariffa[$num2]."p"} += (double) $tarp_corr;
+${$tariffa[$num2]} += (float) $tar_corr;
+${$tariffa[$num2]."p"} += (float) $tarp_corr;
 } # fine elseif (strcmp((string) ${$tariffa[$num2]},"") or strcmp((string) ${$tariffa[$num2]."p"},""))
 if (!empty($dati_tariffe[$tariffa[$num2]]['chiusa'][$idper_corr])) ${$tariffa[$num2]."c"} = 1;
 $tar_imp = periodo_importato_tar($tariffa[$num2],$idper_corr,$dati_tariffe);
 if (!${$tariffa[$num2]."i"}) ${$tariffa[$num2]."i"} = $tar_imp;
 elseif ($tar_imp and ${$tariffa[$num2]."i"} != $tar_imp) ${$tariffa[$num2]."i"} = -1;
-if ($mostra_disp == "s" and $tab_liberi[$tariffa[$num2]][$idper_corr] < ${$tariffa[$num2]."l"}) ${$tariffa[$num2]."l"} = $tab_liberi[$tariffa[$num2]][$idper_corr];
+if ($mostra_disp == "s" and fixset($tab_liberi[$tariffa[$num2]][$idper_corr]) < ${$tariffa[$num2]."l"}) ${$tariffa[$num2]."l"} = $tab_liberi[$tariffa[$num2]][$idper_corr];
 if ($mostra_pmm == "s" and fixset($permanenza_minima[$tariffa[$num2]][$idper_corr]) > ${$tariffa[$num2]."pmin"}) ${$tariffa[$num2]."pmin"} = $permanenza_minima[$tariffa[$num2]][$idper_corr];
 if ($mostra_pmm == "s" and fixset($permanenza_massima[$tariffa[$num2]][$idper_corr]) > ${$tariffa[$num2]."pmax"}) ${$tariffa[$num2]."pmax"} = $permanenza_massima[$tariffa[$num2]][$idper_corr];
 } # fine if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or...
@@ -719,7 +722,7 @@ if ($mostra_pmm == "s" and fixset($permanenza_massima[$tariffa[$num2]][$idper_co
 } # fine while ($sett_in_per == 0 or...
 if ($sett_in_per != $sett_in_per_col[$num_colonne_periodi]) $nuova_colonna = "SI";
 for ($num2 = 1 ; $num2 <= $num_tariffe_mostra ; $num2++) {
-if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num2}] == "SI") {
+if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or (isset($tariffe_consentite_vett[${"numtariffa".$num2}]) and $tariffe_consentite_vett[${"numtariffa".$num2}] == "SI")) {
 if ((string) ${$tariffa[$num2]} != (string) $tariffa_colonna_periodo[$num2][$num_colonne_periodi]) $nuova_colonna = "SI";
 if ((string) ${$tariffa[$num2]."p"} != (string) $tariffap_colonna_periodo[$num2][$num_colonne_periodi]) $nuova_colonna = "SI";
 if (${$tariffa[$num2]."c"} != $chiusa_colonna_periodo[$num2][$num_colonne_periodi]) $nuova_colonna = "SI";
@@ -743,7 +746,7 @@ $ini_colonna_periodo[$num_colonne_periodi] = $datainizio;
 $per_colonna_periodo[$num_colonne_periodi] = $periodo1;
 $sett_in_per_col[$num_colonne_periodi] = $sett_in_per;
 for ($num2 = 1 ; $num2 <= $num_tariffe_mostra ; $num2++) {
-if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num2}] == "SI") {
+if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or (isset($tariffe_consentite_vett[${"numtariffa".$num2}]) and $tariffe_consentite_vett[${"numtariffa".$num2}] == "SI")) {
 $tariffa_colonna_periodo[$num2][$num_colonne_periodi] = ${$tariffa[$num2]};
 $tariffap_colonna_periodo[$num2][$num_colonne_periodi] = ${$tariffa[$num2]."p"};
 $chiusa_colonna_periodo[$num2][$num_colonne_periodi] = ${$tariffa[$num2]."c"};
@@ -751,7 +754,7 @@ $importata_colonna_periodo[$num2][$num_colonne_periodi] = ${$tariffa[$num2]."i"}
 if ($mostra_disp == "s") $liberi_colonna_periodo[$num2][$num_colonne_periodi] = ${$tariffa[$num2]."l"};
 if ($mostra_pmm == "s") $pminima_colonna_periodo[$num2][$num_colonne_periodi] = ${$tariffa[$num2]."pmin"};
 if ($mostra_pmm == "s") $pmassima_colonna_periodo[$num2][$num_colonne_periodi] = ${$tariffa[$num2]."pmax"};
-} # fine if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num2}] == "SI")
+} # fine if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or (isset($tariffe_consentite_vett[${"numtariffa".$num2}]) and...
 } # fine for $num2
 $nuova_colonna = "NO";
 } # fine if ($nuova_colonna == "SI")
@@ -837,8 +840,8 @@ if ($form_tabella) echo "<input type=\"hidden\" name=\"ins_form_tabella\" value=
 else echo "<input type=\"hidden\" name=\"solo_sel\" value=\"1\">";
 $tab_modificabile = 0;
 for ($num1 = 1 ; $num1 <= $num_tariffe_mostra ; $num1++) {
-if (empty($dati_tariffe[$tariffa[$num1]]['importa_prezzi'][0]) and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI")) $tab_modificabile = 1;
-if ($mostra_pmm == "s" and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and $priv_ins_costi_agg != "n" and $priv_mod_costo_agg != "n" and $priv_canc_costi_agg != "n") $tab_modificabile = 1;
+if (empty($dati_tariffe[$tariffa[$num1]]['importa_prezzi'][0]) and ($attiva_tariffe_consentite_ut == "n" or (isset($tariffe_consentite_vett_ut[${"numtariffa".$num1}]) and $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI"))) $tab_modificabile = 1;
+if ($mostra_pmm == "s" and ($attiva_tariffe_consentite_ut == "n" or (isset($tariffe_consentite_vett_ut[${"numtariffa".$num1}]) and $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI")) and $priv_ins_costi_agg != "n" and $priv_mod_costo_agg != "n" and $priv_canc_costi_agg != "n") $tab_modificabile = 1;
 echo "<input type=\"hidden\" name=\"numtariffa$num1\" value=\"".${"numtariffa".$num1}."\">
 <input type=\"hidden\" name=\"tariffa_sel".${"numtariffa".$num1}."\" value=\"SI\">";
 } # fine for $num1
@@ -875,17 +878,17 @@ echo "</small></td>";
 } # fine for $num1
 echo "</tr>";
 for ($num1 = 1 ; $num1 <= $num_tariffe_mostra ; $num1++) {
-if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num1}] == "SI") {
+if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or (isset($tariffe_consentite_vett[${"numtariffa".$num1}]) and $tariffe_consentite_vett[${"numtariffa".$num1}] == "SI")) {
 echo "<tr><td style=\"text-align: left;\">".$nometariffa_vedi[$num1];
 if (empty($form_tabella) and !empty($p_app[${"numtariffa".$num1}])) echo "<small><small> (".$p_app[${"numtariffa".$num1}].")</small></small>";
 if ($num_tariffe_mostra > 1 and !empty($dati_tariffe[$tariffa[$num1]]['importa_prezzi'][0])) echo "<small><small> (".mex("dalla tariffa",'visualizza_tabelle.php')." ".$dati_tariffe[$tariffa[$num1]]['importa_prezzi'][0].")</small></small>";
 echo "</td>";
 for ($num2 = 0 ; $num2 <= $num_colonne_periodi ; $num2++) {
 if (!empty($mostra_data[$num2])) {
-if (!empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and !$importata_colonna_periodo[$num1][$num2]) {
+if (!empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or (isset($tariffe_consentite_vett_ut[${"numtariffa".$num1}]) and $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI")) and !$importata_colonna_periodo[$num1][$num2]) {
 $tariffa_vedi = "<input type=\"text\" name=\"per".fixset($per_colonna_periodo[$num2])."tar".${"numtariffa".$num1}."\" value=\"".$tariffa_colonna_periodo[$num1][$num2]."\" size=\"8\">".fixset($p_app[${"numtariffa".$num1}]);
 if ($dati_tariffe[$tariffa[$num1]]['moltiplica'] == "p") $tariffa_vedi .= " + <input type=\"text\" name=\"per".$per_colonna_periodo[$num2]."tar".${"numtariffa".$num1}.""."p\" value=\"".$tariffap_colonna_periodo[$num1][$num2]."\" size=\"6\">*$p_pers";
-} # fine if (!empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and...
+} # fine if (!empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or (isset($tariffe_consentite_vett_ut[${"numtariffa".$num1}]) and...
 else {
 if (!strcmp((string) $tariffa_colonna_periodo[$num1][$num2],"") and !$tariffap_colonna_periodo[$num1][$num2]) $tariffa_vedi = "&nbsp;";
 else {
@@ -902,16 +905,16 @@ if ((string) $importata_colonna_periodo[$num1][$num2] == "-1") $tariffa_vedi .=
 else $tariffa_vedi .= str_replace(" ","&nbsp;","(".mex("dalla tariffa",'visualizza_tabelle.php')." ".$importata_colonna_periodo[$num1][$num2].")");
 $tariffa_vedi .= "</small></small>";
 } # fine if ($importata_colonna_periodo[$num1][$num2] and $importata_colonna_periodo[$num1][$num2] != $dati_tariffe[$tariffa[$num1]]['importa_prezzi'][0])
-} # fine else if (!empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and...
+} # fine else if (!empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or (isset($tariffe_consentite_vett_ut[${"numtariffa".$num1}]) and...
 if ($chiusa_colonna_periodo[$num1][$num2]) $style = " style=\"background-color: #777777;\"";
 else $style = "";
-if (empty($form_tabella) and empty($dati_tariffe[$tariffa[$num1]]['importa_prezzi'][0]) and empty($importata_colonna_periodo[$num1][$num2]) and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI")) $id_td = " id=\"per".$per_colonna_periodo[$num2]."tar".${"numtariffa".$num1}."\"";
+if (empty($form_tabella) and empty($dati_tariffe[$tariffa[$num1]]['importa_prezzi'][0]) and empty($importata_colonna_periodo[$num1][$num2]) and ($attiva_tariffe_consentite_ut == "n" or (isset($tariffe_consentite_vett_ut[${"numtariffa".$num1}]) and $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI"))) $id_td = " id=\"per".$per_colonna_periodo[$num2]."tar".${"numtariffa".$num1}."\"";
 else $id_td = "";
 echo "<td$id_td align=\"center\"$style>$tariffa_vedi</td>";
 } # fine if (!empty($mostra_data[$num2]))
 } # fine for $num2
 echo "</tr>";
-if ($mostra_disp == "s" and (($priv_vedi_tab_periodi == "s" and $priv_vedi_tab_regole == "s" and $priv_vedi_tab_mesi == "s") or $attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num1}] == "SI")) {
+if ($mostra_disp == "s" and (($priv_vedi_tab_periodi == "s" and $priv_vedi_tab_regole == "s" and $priv_vedi_tab_mesi == "s") or $attiva_tariffe_consentite == "n" or (isset($tariffe_consentite_vett[${"numtariffa".$num1}]) and $tariffe_consentite_vett[${"numtariffa".$num1}] == "SI"))) {
 echo "<tr><td style=\"text-align: left;\">&nbsp;&nbsp;<small><small><em>".mex("disponibilità",$pag)."</em></small></small></td>";
 for ($num2 = 0 ; $num2 <= $num_colonne_periodi ; $num2++) {
 if (!empty($mostra_data[$num2])) {
@@ -926,14 +929,14 @@ if ($mostra_pmm == "s") {
 echo "<tr><td style=\"text-align: left;\">&nbsp;&nbsp;<small><small><em>".mex("permanenza min.",$pag)."</em></small></small></td>";
 for ($num2 = 0 ; $num2 <= $num_colonne_periodi ; $num2++) {
 if (!empty($mostra_data[$num2])) {
-if (!empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and $priv_ins_costi_agg != "n" and $priv_mod_costo_agg != "n" and $priv_canc_costi_agg != "n") {
+if (!empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or (isset($tariffe_consentite_vett_ut[${"numtariffa".$num1}]) and $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI")) and $priv_ins_costi_agg != "n" and $priv_mod_costo_agg != "n" and $priv_canc_costi_agg != "n") {
 $p_min = "<input type=\"text\" name=\"per".$per_colonna_periodo[$num2]."tar".${"numtariffa".$num1}."pmin\" value=\"".$pminima_colonna_periodo[$num1][$num2]."\" size=\"3\"><small><small>".mex($parola_settimane,$pag)."</small></small>";
-} # fine if (!empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and...
+} # fine if (!empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or (isset($tariffe_consentite_vett_ut[${"numtariffa".$num1}]) and...
 else {
 if ($pminima_colonna_periodo[$num1][$num2]) $p_min = $pminima_colonna_periodo[$num1][$num2]."&nbsp;<small><small>".mex($parola_settimane,$pag)."</small></small>";
 else $p_min = "&nbsp;";
 } # fine else if (!empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and...
-if (empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI")) $id_td = " id=\"per".$per_colonna_periodo[$num2]."tar".${"numtariffa".$num1}."pmin\"";
+if (empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or (isset($tariffe_consentite_vett_ut[${"numtariffa".$num1}]) and $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI"))) $id_td = " id=\"per".$per_colonna_periodo[$num2]."tar".${"numtariffa".$num1}."pmin\"";
 else $id_td = "";
 echo "<td$id_td align=\"center\">$p_min</td>";
 } # fine if (!empty($mostra_data[$num2]))
@@ -942,11 +945,11 @@ echo "</tr>";
 if ($pmax_attiva) {
 echo "<tr><td style=\"text-align: left;\">&nbsp;&nbsp;<small><small><em>".mex("permanenza mass.",$pag)."</em></small></small></td>";
 for ($num2 = 0 ; $num2 <= $num_colonne_periodi ; $num2++) {
-if ($mostra_data[$num2]) {
+if (!empty($mostra_data[$num2])) {
 if ($pmassima_colonna_periodo[$num1][$num2]) $p_max = $pmassima_colonna_periodo[$num1][$num2]."&nbsp;<small><small>".mex($parola_settimane,$pag)."</small></small>";
 else $p_max = "&nbsp;";
 echo "<td align=\"center\">$p_max</td>";
-} # fine if ($mostra_data[$num2])
+} # fine if (!empty($mostra_data[$num2]))
 } # fine for $num2
 echo "</tr>";
 } # fine if ($pmax_attiva)
@@ -1061,7 +1064,7 @@ echo "<br><br>".mex("Numero di persone minimo per la tariffa",$pag)." \"".$nomet
 if ($priv_mod_reg2 == "s") echo " <a style=\"display: inline-block; margin-bottom: 2px;\" href=\"./crearegole.php?id_sessione=$id_sessione&amp;anno=$anno&amp;tipotariffa_regola3=".$tariffa[1]."&amp;nor3=1&amp;origine=tab_tariffa\">".mex("Modifica la regola di assegnazione",'interconnessioni.php')." 3</a>";
 echo "<br><br><br>";
 
-if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa1] == "SI") {
+if ($attiva_tariffe_consentite == "n" or (isset($tariffe_consentite_vett[$numtariffa1]) and $tariffe_consentite_vett[$numtariffa1] == "SI")) {
 $d_descrizione = esegui_query("select testo from $tabledescrizioni where nome = 'tariffa".$numtariffa1."' and tipo = 'tardescr' and lingua = 'ita' and numero = '1' ");
 if (numlin_query($d_descrizione)) $d_descrizione = risul_query($d_descrizione,0,'testo');
 else $d_descrizione = "";
@@ -1084,11 +1087,20 @@ $col = 0;
 $max_col = 2;
 unset($lingue_vett);
 $lang_dir = opendir("./includes/lang/");
-include(C_DATI_PATH."/lingua.php");
+#include(C_DATI_PATH."/lingua.php");
+if ($lingua_mex == "ita") include("./includes/locale.php");
+else {
+if ($locale_mex and is_file("./includes/lang/$lingua_mex/locales/$locale_mex/locale.php")) include("./includes/lang/$lingua_mex/locales/$locale_mex/locale.php");
+else include("./includes/lang/$lingua_mex/locale.php");
+} # fine else if ($lingua_mex == "ita")
 while ($ini_lingua = readdir($lang_dir)) {
 if ($ini_lingua != "." && $ini_lingua != ".." and strlen($ini_lingua) <= 3 and preg_replace("/[a-z]/","",$ini_lingua) == "") {
 $nome_lingua = file("./includes/lang/$ini_lingua/l_n");
 $nome_lingua = togli_acapo($nome_lingua[0]);
+if (!empty($locale['language_capitalization'])) {
+if (function_exists('mb_convert_case')) $nome_lingua = mb_convert_case($nome_lingua,MB_CASE_TITLE,'UTF-8');
+else $nome_lingua = ucwords($nome_lingua);
+} # fine if (!empty($locale['language_capitalization']))
 $lingue_vett[$ini_lingua] = $nome_lingua;
 $d_descrizione = esegui_query("select testo from $tabledescrizioni where nome = 'tariffa".$numtariffa1."' and tipo = 'tardescr' and lingua = '$ini_lingua' and numero = '1' ");
 if (numlin_query($d_descrizione)) $d_descrizione = risul_query($d_descrizione,0,'testo');
@@ -1167,12 +1179,12 @@ echo "<form id=\"aggfoto\" accept-charset=\"utf-8\" method=\"post\" action=\"$pa
 <input type=\"hidden\" name=\"azione\" value=\"SI\">
 <input type=\"hidden\" name=\"aggurlfoto\" value=\"SI\">
 ".ucfirst(mex("url di una nuova foto",$pag)).":
-<input id=\"n_urlf\" type=\"text\" name=\"n_urlfoto\" size=\"30\" value=\"http://\"$readonly>
+<input id=\"n_urlf\" type=\"text\" name=\"n_urlfoto\" size=\"30\" value=\"https://\"$readonly>
 <button class=\"apho\" type=\"submit\"><div>".ucfirst(mex("aggiungi",$pag))."</div></button><br>
 ".upload_hd_img_form('n_urlf',$tablepersonalizza)."</div></form><br>";
 } # fine if ($priv_mod_tariffe != "n")
 echo "</div></div>";
-} # fine if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa1] == "SI")
+} # fine if ($attiva_tariffe_consentite == "n" or (isset($tariffe_consentite_vett[$numtariffa1]) and...
 
 } # fine if ($num_tariffe_mostra == 1)
 
