@@ -49,8 +49,12 @@ $tableregole = $PHPR_TAB_PRE."regole".$anno;
 
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
 if ($id_utente) {
+$tariffe_consentite_vett = array();
+$costi_agg_consentiti_vett = array();
 
 if ($id_utente != 1) {
+$prendi_gruppi = "";
+$priv_app_gruppi = "NO";
 $tableprivilegi = $PHPR_TAB_PRE."privilegi";
 $tablerelgruppi = $PHPR_TAB_PRE."relgruppi";
 $privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
@@ -63,19 +67,30 @@ $vedi_clienti = "NO";
 if (substr($priv_ins_clienti,2,1) == "s") $vedi_clienti = "SI";
 if (substr($priv_ins_clienti,2,1) == "p") $vedi_clienti = "PROPRI";
 if (substr($priv_ins_clienti,2,1) == "g") { $vedi_clienti = "GRUPPI"; $prendi_gruppi = "SI"; }
+$priv_ins_prenota = risul_query($privilegi_annuali_utente,0,'priv_ins_prenota');
+$priv_ins_nuove_prenota = substr($priv_ins_prenota,0,1);
+$priv_ins_assegnazione_app = substr($priv_ins_prenota,1,1);
 $priv_mod_prenota = risul_query($privilegi_annuali_utente,0,'priv_mod_prenota');
 $priv_mod_prenotazioni = substr($priv_mod_prenota,0,1);
 if ($priv_mod_prenotazioni == "g") $prendi_gruppi = "SI";
+$priv_mod_assegnazione_app = substr($priv_mod_prenota,2,1);
 $priv_mod_prenota_iniziate = substr($priv_mod_prenota,11,1);
 $priv_mod_prenota_ore = substr($priv_mod_prenota,12,3);
 $priv_vedi_tab = risul_query($privilegi_annuali_utente,0,'priv_vedi_tab');
 $priv_vedi_tab_mesi = substr($priv_vedi_tab,0,1);
 $priv_prenota_gruppi = "NO";
-$priv_app_gruppi = "NO";
 if ($priv_vedi_tab_mesi == "q" or $priv_vedi_tab_mesi == "g") $priv_prenota_gruppi = "SI";
 if ($priv_vedi_tab_mesi == "r" or $priv_vedi_tab_mesi == "g") $priv_app_gruppi = "SI";
 if ($priv_vedi_tab_mesi == "q" or $priv_vedi_tab_mesi == "r" or $priv_vedi_tab_mesi == "g") { $priv_vedi_tab_mesi = "p"; $prendi_gruppi = "SI"; }
 
+if ($prendi_gruppi == "SI") {
+$costi_agg_consentiti = risul_query($privilegi_annuali_utente,0,'costi_agg_consentiti');
+$attiva_costi_agg_consentiti = substr($costi_agg_consentiti,0,1);
+if ($attiva_costi_agg_consentiti == "s") {
+$costi_agg_consentiti = explode(",",substr($costi_agg_consentiti,2));
+for ($num1 = 0 ; $num1 < count($costi_agg_consentiti) ; $num1++) if ($costi_agg_consentiti[$num1]) $costi_agg_consentiti_vett[$costi_agg_consentiti[$num1]] = "SI";
+} # fine if ($attiva_costi_agg_consentiti == "s")
+} # fine if ($prendi_gruppi == "SI")
 if ($priv_vedi_tab_mesi == "p") {
 $regole1_consentite = risul_query($privilegi_annuali_utente,0,'regole1_consentite');
 $attiva_regole1_consentite = substr($regole1_consentite,0,1);
@@ -84,31 +99,30 @@ $tariffe_consentite = risul_query($privilegi_annuali_utente,0,'tariffe_consentit
 $attiva_tariffe_consentite = substr($tariffe_consentite,0,1);
 if ($attiva_tariffe_consentite == "s") {
 $tariffe_consentite = explode(",",substr($tariffe_consentite,2));
-unset($tariffe_consentite_vett);
 for ($num1 = 0 ; $num1 < count($tariffe_consentite) ; $num1++) if ($tariffe_consentite[$num1]) $tariffe_consentite_vett[$tariffe_consentite[$num1]] = "SI";
 } # fine if ($attiva_tariffe_consentite == "s")
-$priv_ins_prenota = risul_query($privilegi_annuali_utente,0,'priv_ins_prenota');
-$priv_ins_nuove_prenota_v = substr($priv_ins_prenota,0,1);
-$priv_ins_assegnazione_app_v = substr($priv_ins_prenota,1,1);
-$priv_mod_assegnazione_app_v = substr($priv_mod_prenota,2,1);
+$priv_ins_nuove_prenota_v = $priv_ins_nuove_prenota;
+$priv_ins_assegnazione_app_v = $priv_ins_assegnazione_app;
+$priv_mod_assegnazione_app_v = $priv_mod_assegnazione_app;
 $priv_mod_prenotazioni_v = $priv_mod_prenotazioni;
 } # fine if ($priv_vedi_tab_mesi == "p")
 $priv_oscura_tab_mesi = substr($priv_vedi_tab,8,1);
 } # fine else if (numlin_query($privilegi_annuali_utente) == 0)
 
 if ($priv_app_gruppi == "SI") {
-$attiva_regole1_consentite_gr[$id_utente] = $attiva_regole1_consentite;
-$regole1_consentite_gr[$id_utente] = $regole1_consentite;
-$attiva_tariffe_consentite_gr[$id_utente] = $attiva_tariffe_consentite;
-$tariffe_consentite_vett_gr[$id_utente] = $tariffe_consentite_vett;
-$priv_ins_nuove_prenota_gr[$id_utente] = $priv_ins_nuove_prenota;
-$priv_ins_assegnazione_app_gr[$id_utente] = $priv_ins_assegnazione_app;
-$priv_mod_prenotazioni_gr[$id_utente] = $priv_mod_prenotazioni;
-$priv_mod_assegnazione_app_gr[$id_utente] = $priv_mod_assegnazione_app;
+$attiva_regole1_consentite_gr = array($id_utente => $attiva_regole1_consentite);
+$regole1_consentite_gr = array($id_utente => $regole1_consentite);
+$attiva_tariffe_consentite_gr = array($id_utente => $attiva_tariffe_consentite);
+$tariffe_consentite_vett_gr = array($id_utente => $tariffe_consentite_vett);
+$priv_ins_nuove_prenota_gr = array($id_utente => $priv_ins_nuove_prenota);
+$priv_ins_assegnazione_app_gr = array($id_utente => $priv_ins_assegnazione_app);
+$priv_mod_prenotazioni_gr = array($id_utente => $priv_mod_prenotazioni);
+$priv_mod_assegnazione_app_gr = array($id_utente => $priv_mod_assegnazione_app);
 } # fine if ($priv_app_gruppi == "SI")
-unset($utenti_gruppi);
-$utenti_gruppi[$id_utente] = 1;
+$utenti_gruppi = array($id_utente => 1);
 if ($prendi_gruppi == "SI") {
+$attiva_costi_agg_consentiti_gr = $attiva_costi_agg_consentiti;
+$costi_agg_consentiti_vett_gr = $costi_agg_consentiti_vett;
 $gruppi_utente = esegui_query("select idgruppo from $tablerelgruppi where idutente = '$id_utente' and idgruppo is not NULL ");
 $num_gruppi_utente = numlin_query($gruppi_utente);
 for ($num1 = 0 ; $num1 < $num_gruppi_utente ; $num1++) {
@@ -117,7 +131,7 @@ $utenti_gruppo = esegui_query("select idutente from $tablerelgruppi where idgrup
 $num_utenti_gruppo = numlin_query($utenti_gruppo);
 for ($num2 = 0 ; $num2 < $num_utenti_gruppo ; $num2++) {
 $idutente_gruppo = risul_query($utenti_gruppo,$num2,"idutente");
-if ($idutente_gruppo != $id_utente and !$utenti_gruppi[$idutente_gruppo]) {
+if ($idutente_gruppo != $id_utente and empty($utenti_gruppi[$idutente_gruppo])) {
 $utenti_gruppi[$idutente_gruppo] = 1;
 
 if ($priv_app_gruppi == "SI") {
@@ -130,7 +144,7 @@ $tariffe_consentite_tmp = risul_query($priv_anno_ut_gr,0,'tariffe_consentite');
 $attiva_tariffe_consentite_gr[$idutente_gruppo] = substr($tariffe_consentite_tmp,0,1);
 if ($attiva_tariffe_consentite_gr[$idutente_gruppo] == "s") {
 $tariffe_consentite_tmp = explode(",",substr($tariffe_consentite_tmp,2));
-$tariffe_consentite_vett_gr[$idutente_gruppo] = "";
+$tariffe_consentite_vett_gr[$idutente_gruppo] = array();
 for ($num3 = 0 ; $num3 < count($tariffe_consentite_tmp) ; $num3++) if ($tariffe_consentite_tmp[$num3]) $tariffe_consentite_vett_gr[$idutente_gruppo][$tariffe_consentite_tmp[$num3]] = "SI";
 } # fine if ($attiva_tariffe_consentite_gr[$idutente_gruppo] == "s")
 $costi_agg_consentiti_tmp = risul_query($priv_anno_ut_gr,0,"costi_agg_consentiti");
@@ -153,7 +167,7 @@ $priv_mod_prenotazioni_gr[$idutente_gruppo] = "n";
 } # fine else if (numlin_query($priv_anno_ut_gr) == 1)
 } # fine if ($priv_app_gruppi == "SI")
 
-} # fine if ($idutente_gruppo != $id_utente)
+} # fine if ($idutente_gruppo != $id_utente and...
 } # fine for $num2
 } # fine for $num1
 } # fine if ($prendi_gruppi == "SI")
@@ -166,6 +180,9 @@ $priv_mod_prenota_iniziate = "s";
 $priv_mod_prenota_ore = "000";
 $priv_vedi_tab_mesi = "s";
 $priv_oscura_tab_mesi = "";
+$attiva_tariffe_consentite = "n";
+$attiva_costi_agg_consentiti = "n";
+$attiva_regole1_consentite = "n";
 } # fine else if ($id_utente != 1)
 if ($anno_utente_attivato == "SI" and $priv_vedi_tab_mesi != "n") {
 
@@ -196,7 +213,7 @@ $oggi = date("j/n/Y",(time() + (C_DIFF_ORE * 3600)));
 $ora = date("H:i",(time() + (C_DIFF_ORE * 3600)));
 echo "<small><small>".mex("situazione alle",$pag)." $ora ".mex("del",$pag)." $oggi</small></small><br>";
 
-if (controlla_num_pos($mese) != "SI") $mese = 1;
+if (controlla_num_pos(fixset($mese)) != "SI") $mese = 1;
 if (isset($anno_succ) and $anno_succ == "SI") { $mese = $mese + 12; }
 
 $data_inizio_periodi = esegui_query("select * from $tableperiodi where idperiodi = 1");
@@ -415,7 +432,7 @@ $condizione_prenota_propria .= " )";
 } # fine if ($priv_vedi_tab_mesi == "p")
 else $condizione_prenota_propria = "";
 } # fine else if ($num1 < $num_appartamenti)
-if ($priv_vedi_tab_mesi != "p" or $appartamenti_consentiti[$id_appartamento] != "NO" or $num1 >= $num_appartamenti) {
+if ($priv_vedi_tab_mesi != "p" or $num1 >= $num_appartamenti or $appartamenti_consentiti[$id_appartamento] != "NO") {
 
 if ($num1 < $num_appartamenti) echo "<tr><td>";
 else echo "<tr><td style=\"color: red;\">";
@@ -447,9 +464,9 @@ else $esiste = 0;
 if ($esiste == 1) $utente_inserimento = risul_query($prenotazione_presente,$prenota_corr,'utente_inserimento');
 else $utente_inserimento = $id_utente;
 
-#if ($priv_vedi_tab_mesi == "p" and (($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gruppi[$utente_inserimento])) or ($periodo_consentito_app[$id_appartamento][$id_settimana] == "NO" and $esiste != 1))) {
-if ($priv_vedi_tab_mesi == "p" and (($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gruppi[$utente_inserimento])))) {
-if ($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gruppi[$utente_inserimento])) {
+#if ($priv_vedi_tab_mesi == "p" and (($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or empty($utenti_gruppi[$utente_inserimento]))) or ($periodo_consentito_app[$id_appartamento][$id_settimana] == "NO" and $esiste != 1))) {
+if ($priv_vedi_tab_mesi == "p" and ($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or empty($utenti_gruppi[$utente_inserimento])))) {
+if ($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or empty($utenti_gruppi[$utente_inserimento]))) {
 $id_inizio_prenota = risul_query($prenotazione_presente,$prenota_corr,'iddatainizio');
 $id_fine_prenota = risul_query($prenotazione_presente,$prenota_corr,'iddatafine');
 if ($id_inizio_prenota > $id_data_inizio_tab) $id_inizio = $id_inizio_prenota;
@@ -469,7 +486,7 @@ while ($fatto == "NO") {
 $id_inizio2 = $id_fine + 1;
 if ($id_inizio2 >= $ini_prenota_succ) {
 $utente_inserimento2 = risul_query($prenotazione_presente,$prenota_succ,'utente_inserimento');
-if ($utente_inserimento2 != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gruppi[$utente_inserimento2])) {
+if ($utente_inserimento2 != $id_utente and ($priv_prenota_gruppi != "SI" or empty($utenti_gruppi[$utente_inserimento2]))) {
 $id_fine_prenota = risul_query($prenotazione_presente,$prenota_succ,'iddatafine');
 if ($id_fine_prenota < $id_data_fine_tab) $id_fine = $id_fine_prenota;
 else {
@@ -523,16 +540,20 @@ if ($esiste == 1) {
 $id_prenota = risul_query($prenotazione_presente,$prenota_corr,'idprenota');
 $id_clienti = risul_query($prenotazione_presente,$prenota_corr,'idclienti');
 if ($id_clienti) {
-$cognome = esegui_query("select cognome,utente_inserimento from $tableclienti where idclienti = '$id_clienti'");
+$cognome = esegui_query("select cognome,cognome2,utente_inserimento from $tableclienti where idclienti = '$id_clienti'");
 $mostra_cliente = "SI";
 if ($vedi_clienti == "NO") $mostra_cliente = "NO";
 if ($vedi_clienti == "PROPRI" or $vedi_clienti == "GRUPPI") {
 $utente_inserimento_cli = risul_query($cognome,0,'utente_inserimento');
 if ($vedi_clienti == "PROPRI" and $utente_inserimento_cli != $id_utente) $mostra_cliente = "NO";
-if ($vedi_clienti == "GRUPPI" and !$utenti_gruppi[$utente_inserimento_cli]) $mostra_cliente = "NO";
+if ($vedi_clienti == "GRUPPI" and empty($utenti_gruppi[$utente_inserimento_cli])) $mostra_cliente = "NO";
 } # fine if ($vedi_clienti == "PROPRI" or $vedi_clienti == "GRUPPI")
 if ($mostra_cliente == "NO") $cognome = $id_prenota;
-else $cognome = risul_query($cognome,0,'cognome');
+else {
+$cognome2 = (string) risul_query($cognome,0,'cognome2');
+$cognome = risul_query($cognome,0,'cognome');
+if (strcmp($cognome2,"")) $cognome .= " $cognome2";
+} # fine else if ($mostra_cliente == "NO")
 } # fine if ($id_clienti)
 else $cognome = "?";
 
@@ -558,7 +579,7 @@ if ($priv_mod_prenotazioni == "n") $link_modifica = "NO";
 if ($priv_mod_prenotazioni == "p" or $priv_mod_prenotazioni == "g") {
 $utente_inserimento = risul_query($prenotazione_presente,$prenota_corr,'utente_inserimento');
 if ($priv_mod_prenotazioni == "p" and $utente_inserimento != $id_utente) $link_modifica = "NO";
-if ($priv_mod_prenotazioni == "g" and !$utenti_gruppi[$utente_inserimento]) $link_modifica = "NO";
+if ($priv_mod_prenotazioni == "g" and empty($utenti_gruppi[$utente_inserimento])) $link_modifica = "NO";
 } # fine if ($priv_mod_prenotazioni == "p" or $priv_mod_prenotazioni == "g")
 if ($priv_mod_prenota_iniziate != "s" and $id_periodo_corrente >= $id_inizio_prenota) $link_modifica = "NO";
 if ($priv_mod_prenota_ore != "000") {
@@ -572,8 +593,8 @@ $link_modifica_inizio = "<a href=\"modifica_prenota.php?id_prenota=$id_prenota&a
 $link_modifica_fine = "</a>";
 } # fine if ($link_modifica == "SI" and $id_clienti)
 else {
-unset($link_modifica_inizio);
-unset($link_modifica_fine);
+$link_modifica_inizio = "";
+$link_modifica_fine = "";
 } # fine else if ($link_modifica == "SI" and $id_clienti)
 
 $riduci_font = "";
@@ -626,7 +647,7 @@ echo $linea_date;
 $num_ripeti = 1;
 } # fine if ($num_ripeti == $linee_ripeti_date_tab_mesi)
 else $num_ripeti++;
-} # fine if ($priv_vedi_tab_mesi != "p" or $appartamenti_consentiti[$id_appartamento] != "NO")
+} # fine if ($priv_vedi_tab_mesi != "p" or $num1 >= $num_appartamenti or $appartamenti_consentiti[$id_appartamento] != "NO")
 } # fine for $num1
 
 echo "<tr class=\"ra_r\"><td style=\"height: 0; padding: 0; border: 0;\"></td>";
