@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2024 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -44,12 +44,12 @@ attiva_seleziona_icona_tab('');
 ";
 } # fine if ($pag == "inizio.php")
 
-if ($pag == "visualizza_tabelle.php" and $tipo_tabella == "prenotazioni") {
+if ($pag == "visualizza_tabelle.php" and isset($tipo_tabella) and $tipo_tabella == "prenotazioni") {
 echo "
 <script type=\"text/javascript\">
 <!--
-var lista_prenota_contr_orig = '$lista_prenota_contr';
-var lista_prenota_mod_orig = ',$lista_prenota_mod,';
+var lista_prenota_contr_orig = '".htmlspecialchars(fixstr($lista_prenota_contr))."';
+var lista_prenota_mod_orig = ',".htmlspecialchars(fixstr($lista_prenota_mod)).",';
 attiva_seleziona_uguali('');
 -->
 </script>
@@ -66,7 +66,7 @@ ridim_col_modres();
 ";
 } # fine if ($pag == "modifica_prenota.php" or $pag == "modifica_cliente.php")
 
-if (isset($mobile_device)) {
+if (!empty($mobile_device)) {
 echo "
 <script type=\"text/javascript\">
 <!--
@@ -74,18 +74,36 @@ tab_in_container();
 -->
 </script>
 ";
-} # fine if (isset($mobile_device))
+} # fine if (!empty($mobile_device))
 
 
 
 if (isset($start_time)) {
 $start_time = explode(" ",$start_time);
-$start_time = (double) $start_time[0] + (double) $start_time[1];
+$start_time = (float) $start_time[0] + (float) $start_time[1];
 $end_time = explode(" ",microtime());
-$end_time = (double) $end_time[0] + (double) $end_time[1];
+$end_time = (float) $end_time[0] + (float) $end_time[1];
 echo "<small><small>seconds: ".round(($end_time - $start_time),2)."</small></small>";
 } # fine if (isset($start_time))
 
+
+
+if (defined('C_FILE_JS_PERS') and C_FILE_JS_PERS != "" and @is_file(C_FILE_JS_PERS)) echo "
+<script type=\"text/javascript\" src=\"".C_FILE_JS_PERS."\">
+</script>
+";
+
+/*echo "<script type=\"text/javascript\">
+<!--
+if ('serviceWorker' in navigator && !navigator.serviceWorker.controller && typeof hide_def_worker === 'undefined') {
+navigator.serviceWorker.register('sw.js');
+}
+-->
+</script>
+";*/
+
+
+
 echo "
 </body>
 </html>";
@@ -93,5 +111,4 @@ echo "
 
 
 
-
-?>
\ No newline at end of file
+?>
