@@ -27,6 +27,13 @@ if ($pag != "visualizza_contratto.php") echo "
 </td></tr></table>";
 
 
+if (defined('C_FILE_JS_PERS') and C_FILE_JS_PERS != "" and @is_file(C_FILE_JS_PERS)) echo "
+<script type=\"text/javascript\" src=\"".C_FILE_JS_PERS."\">
+</script>
+";
+
+
+
 echo "
 </body>
 </html>";
