@@ -48,7 +48,7 @@ if (defined('C_NASCONDI_MARCA') and C_NASCONDI_MARCA == "SI") $titolo = "";
 if (defined('C_FILE_TITOLO_PERS') and C_FILE_TITOLO_PERS != "" and @is_file(C_FILE_TITOLO_PERS)) $titolo = trim(substr(implode("",file(C_FILE_TITOLO_PERS)),0,40))." - $titolo";
 echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"
         \"http://www.w3.org/TR/html4/strict.dtd\">
-<html lang=\"$lingua_mex\">
+<html lang=\"".substr($lingua_mex,0,2)."\">
 <head>
 <meta http-equiv=\"Content-Type\" content=\"text/html;charset=utf-8\" >
 <meta name=\"viewport\" content=\"initial-scale=$iscale\">
@@ -58,6 +58,8 @@ if (defined('C_URL_FAVICON') and C_URL_FAVICON != "" and @is_file(C_URL_FAVICON)
 ";
 elseif (!defined('C_NASCONDI_MARCA') or C_NASCONDI_MARCA != "SI") echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"./img/favicon.ico\">
 ";
+if (defined('C_URL_MANIFEST') and C_URL_MANIFEST != "" and @is_file(C_URL_MANIFEST)) echo "<link rel=\"manifest\" href=\"".C_URL_MANIFEST."\">
+";
 if (isset($base_js)) echo "<script type=\"text/javascript\" src=\"./base.js$vers_hinc\">
 </script>
 ";
