@@ -57,6 +57,7 @@ if (isset($_POST['num_ripeti'])) $num2 = (int) $_POST['num_ripeti'];
 elseif (isset($_GET['num_ripeti'])) $num2 = (int) $_GET['num_ripeti'];
 for ($num1 = 1 ; $num1 <= $num2 ; $num1++) {
 $var_pag[$n_var_pag++] = "cognome_$num1";
+$var_pag[$n_var_pag++] = "cognome2_$num1";
 $var_pag[$n_var_pag++] = "nome_$num1";
 $var_pag[$n_var_pag++] = "soprannome_$num1";
 $var_pag[$n_var_pag++] = "titolo_$num1";
@@ -242,8 +243,8 @@ include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
 $numconnessione = connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
 include("./includes/funzioni.php");
-include("./includes/funzioni_contratti.php");
 include("./includes/funzioni_testo.php");
+include("./includes/funzioni_contratti.php");
 include("./includes/funzioni_email.php");
 $tablecontratti = $PHPR_TAB_PRE."contratti";
 $tableprenota = $PHPR_TAB_PRE."prenota".$anno;
@@ -269,11 +270,17 @@ $tablerelclienti = $PHPR_TAB_PRE."relclienti";
 $tablecasse = $PHPR_TAB_PRE."casse";
 $tablecosti = $PHPR_TAB_PRE."costi".$anno;
 $tablecache = $PHPR_TAB_PRE."cache";
+$tablebeniinventario = $PHPR_TAB_PRE."beniinventario";
+$tablerelinventario = $PHPR_TAB_PRE."relinventario";
+$tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
+$tableregole = $PHPR_TAB_PRE."regole".$anno;
 
 
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
 if ($id_utente) {
+$tariffe_consentite_vett = array();
 
+$numero_contratto = fixstr($numero_contratto);
 if (str_replace("-","",$numero_contratto) != $numero_contratto) {
 $numero_contratto = explode("-",$numero_contratto);
 if (empty($num_ripeti) or controlla_num_pos($num_ripeti) == "NO") $num_ripeti = 1;
@@ -292,16 +299,26 @@ $anno_utente_attivato = "SI";
 $privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
 $priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
 if (substr($priv_mod_pers,0,1) != "s") $modifica_pers = "NO";
+$priv_inventario = risul_query($privilegi_globali_utente,0,'priv_inventario');
+$priv_vedi_beni_inv = substr($priv_inventario,0,1);
+$priv_vedi_inv_app = substr($priv_inventario,6,1);
+if ($priv_vedi_beni_inv == "g" or $priv_vedi_inv_app == "g") $prendi_gruppi = "SI";
 $priv_vedi_tab = risul_query($privilegi_annuali_utente,0,'priv_vedi_tab');
 $priv_vedi_tab_mesi = substr($priv_vedi_tab,0,1);
-if ($priv_vedi_tab_mesi == "q" or $priv_vedi_tab_mesi == "g") $prendi_gruppi = "SI";
+if ($priv_vedi_tab_mesi == "q" or $priv_vedi_tab_mesi == "r" or $priv_vedi_tab_mesi == "g") $prendi_gruppi = "SI";
 $priv_vedi_tab_costi = substr($priv_vedi_tab,2,1);
 $priv_vedi_tab_prenotazioni = substr($priv_vedi_tab,1,1);
 if ($priv_vedi_tab_prenotazioni == "g") $prendi_gruppi = "SI";
+$priv_vedi_tab_appartamenti = substr($priv_vedi_tab,5,1);
+if ($priv_vedi_tab_appartamenti == "g") $prendi_gruppi = "SI";
 $priv_vedi_tab_doc = substr($priv_vedi_tab,7,1);
+$priv_ins_prenota = risul_query($privilegi_annuali_utente,0,'priv_ins_prenota');
+$priv_ins_nuove_prenota = substr($priv_ins_prenota,0,1);
+$priv_ins_assegnazione_app = substr($priv_ins_prenota,1,1);
 $priv_mod_prenota = risul_query($privilegi_annuali_utente,0,'priv_mod_prenota');
 $priv_mod_prenotazioni = substr($priv_mod_prenota,0,1);
 if ($priv_mod_prenotazioni == "g") $prendi_gruppi = "SI";
+$priv_mod_assegnazione_app = substr($priv_mod_prenota,2,1);
 $priv_mod_tariffa = substr($priv_mod_prenota,3,1);
 $priv_mod_sconto = substr($priv_mod_prenota,6,1);
 $priv_mod_caparra = substr($priv_mod_prenota,7,1);
@@ -318,6 +335,16 @@ if (substr($priv_ins_clienti,2,1) == "p") $vedi_clienti = "PROPRI";
 if (substr($priv_ins_clienti,2,1) == "g") { $vedi_clienti = "GRUPPI"; $prendi_gruppi = "SI"; }
 $priv_vedi_telefoni = substr($priv_ins_clienti,3,1);
 $priv_vedi_indirizzo = substr($priv_ins_clienti,4,1);
+$regole1_consentite = risul_query($privilegi_annuali_utente,0,'regole1_consentite');
+$attiva_regole1_consentite = substr($regole1_consentite,0,1);
+if ($attiva_regole1_consentite != "n") $regole1_consentite = explode("#@^",substr($regole1_consentite,3));
+$tariffe_consentite = risul_query($privilegi_annuali_utente,0,'tariffe_consentite');
+$attiva_tariffe_consentite = substr($tariffe_consentite,0,1);
+if ($attiva_tariffe_consentite == "s") {
+$tariffe_consentite = explode(",",substr($tariffe_consentite,2));
+for ($num1 = 0 ; $num1 < count($tariffe_consentite) ; $num1++) if ($tariffe_consentite[$num1]) $tariffe_consentite_vett[$tariffe_consentite[$num1]] = "SI";
+} # fine if ($attiva_tariffe_consentite == "s")
+unset($tariffe_consentite);
 $casse_consentite = risul_query($privilegi_globali_utente,0,'casse_consentite');
 $attiva_casse_consentite = substr($casse_consentite,0,1);
 if ($attiva_casse_consentite == "s") {
@@ -332,11 +359,23 @@ if ($attiva_contratti_consentiti == "s") {
 $contratti_consentiti = explode(",",$contratti_consentiti);
 $contratti_consentiti_vett = array();
 for ($num1 = 1 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
-if ($contratti_consentiti_vett[$numero_contratto] != "SI") $anno_utente_attivato = "NO";
+if (!isset($contratti_consentiti_vett[$numero_contratto]) or $contratti_consentiti_vett[$numero_contratto] != "SI") $anno_utente_attivato = "NO";
 } # fine if ($attiva_contratti_consentiti == "s")
 } # fine else if (numlin_query($privilegi_annuali_utente) == 0)
-unset($utenti_gruppi);
-$utenti_gruppi[$id_utente] = 1;
+
+if ($priv_vedi_tab_appartamenti == "g" or $priv_vedi_tab_mesi == "r" or $priv_vedi_tab_mesi == "g" or $priv_vedi_inv_app == "g") {
+$priv_app_gruppi = "SI";
+$attiva_regole1_consentite_gr = array($id_utente => $attiva_regole1_consentite);
+$regole1_consentite_gr = array($id_utente => $regole1_consentite);
+$attiva_tariffe_consentite_gr = array($id_utente => $attiva_tariffe_consentite);
+$tariffe_consentite_vett_gr = array($id_utente => $tariffe_consentite_vett);
+$priv_ins_nuove_prenota_gr = array($id_utente => $priv_ins_nuove_prenota);
+$priv_ins_assegnazione_app_gr = array($id_utente => $priv_ins_assegnazione_app);
+$priv_mod_prenotazioni_gr = array($id_utente => $priv_mod_prenotazioni);
+$priv_mod_assegnazione_app_gr = array($id_utente => $priv_mod_assegnazione_app);
+} # fine if ($priv_vedi_tab_appartamenti == "g" or $priv_vedi_tab_mesi == "r" or $priv_vedi_tab_mesi == "g" or $priv_vedi_inv_app == "g")
+else $priv_app_gruppi = "NO";
+$utenti_gruppi = array($id_utente => 1);
 if ($prendi_gruppi == "SI") {
 $gruppi_utente = esegui_query("select idgruppo from $tablerelgruppi where idutente = '$id_utente' and idgruppo is not NULL ");
 $num_gruppi_utente = numlin_query($gruppi_utente);
@@ -344,18 +383,61 @@ for ($num1 = 0 ; $num1 < $num_gruppi_utente ; $num1++) {
 $idgruppo = risul_query($gruppi_utente,$num1,'idgruppo');
 $utenti_gruppo = esegui_query("select idutente from $tablerelgruppi where idgruppo = '$idgruppo' ");
 $num_utenti_gruppo = numlin_query($utenti_gruppo);
-for ($num2 = 0 ; $num2 < $num_utenti_gruppo ; $num2++) $utenti_gruppi[risul_query($utenti_gruppo,$num2,'idutente')] = 1;
+for ($num2 = 0 ; $num2 < $num_utenti_gruppo ; $num2++) {
+$idutente_gruppo = risul_query($utenti_gruppo,$num2,'idutente');
+if ($idutente_gruppo != $id_utente and !isset($utenti_gruppi[$idutente_gruppo])) {
+$utenti_gruppi[$idutente_gruppo] = 1;
+
+if ($priv_app_gruppi == "SI") {
+$priv_anno_ut_gr = esegui_query("select * from $tableprivilegi where idutente = '$idutente_gruppo' and anno = '$anno'");
+if (numlin_query($priv_anno_ut_gr) == 1) {
+$regole1_consentite_gr[$idutente_gruppo] = risul_query($priv_anno_ut_gr,0,'regole1_consentite');
+$attiva_regole1_consentite_gr[$idutente_gruppo] = substr($regole1_consentite_gr[$idutente_gruppo],0,1);
+if ($attiva_regole1_consentite_gr[$idutente_gruppo] != "n") $regole1_consentite_gr[$idutente_gruppo] = explode("#@^",substr($regole1_consentite_gr[$idutente_gruppo],3));
+$tariffe_consentite_tmp = risul_query($priv_anno_ut_gr,0,'tariffe_consentite');
+$attiva_tariffe_consentite_gr[$idutente_gruppo] = substr($tariffe_consentite_tmp,0,1);
+if ($attiva_tariffe_consentite_gr[$idutente_gruppo] == "s") {
+$tariffe_consentite_tmp = explode(",",substr($tariffe_consentite_tmp,2));
+$tariffe_consentite_vett_gr[$idutente_gruppo] = array();
+for ($num3 = 0 ; $num3 < count($tariffe_consentite_tmp) ; $num3++) if ($tariffe_consentite_tmp[$num3]) $tariffe_consentite_vett_gr[$idutente_gruppo][$tariffe_consentite_tmp[$num3]] = "SI";
+} # fine if ($attiva_tariffe_consentite_gr[$idutente_gruppo] == "s")
+$priv_ins_prenota_tmp = risul_query($priv_anno_ut_gr,0,'priv_ins_prenota');
+$priv_ins_nuove_prenota_gr[$idutente_gruppo] = substr($priv_ins_prenota_tmp,0,1);
+$priv_ins_assegnazione_app_gr[$idutente_gruppo] = substr($priv_ins_prenota_tmp,1,1);
+$priv_mod_prenota_tmp = risul_query($priv_anno_ut_gr,0,'priv_mod_prenota');
+$priv_mod_prenotazioni_gr[$idutente_gruppo] = substr($priv_mod_prenota_tmp,0,1);
+$priv_mod_assegnazione_app_gr[$idutente_gruppo] = substr($priv_mod_prenota_tmp,2,1);
+unset($tariffe_consentite_tmp);
+unset($priv_ins_prenota_tmp);
+unset($priv_mod_prenota_tmp);
+} # fine if (numlin_query($priv_anno_ut_gr) == 1)
+else {
+$priv_ins_nuove_prenota_gr[$idutente_gruppo] = "n";
+$priv_mod_prenotazioni_gr[$idutente_gruppo] = "n";
+} # fine else if (numlin_query($priv_anno_ut_gr) == 1)
+chiudi_query($priv_anno_ut_gr);
+} # fine if ($priv_app_gruppi == "SI")
+
+} # fine if ($idutente_gruppo != $id_utente and !isset($utenti_gruppi[$idutente_gruppo]))
+} # fine for $num2
 } # fine for $num1
 } # fine if ($prendi_gruppi == "SI")
+unset($priv_app_gruppi);
 } # fine if ($id_utente != 1)
 else {
 $anno_utente_attivato = "SI";
 $modifica_pers = "SI";
+$priv_vedi_beni_inv = "s";
+$priv_vedi_inv_app = "s";
 $priv_vedi_tab_mesi = "s";
 $priv_vedi_tab_costi = "s";
 $priv_vedi_tab_prenotazioni = "s";
+$priv_vedi_tab_appartamenti = "s";
 $priv_vedi_tab_doc = "s";
+$priv_ins_nuove_prenota = "s";
+$priv_ins_assegnazione_app = "s";
 $priv_mod_prenotazioni = "s";
+$priv_mod_assegnazione_app = "s";
 $priv_mod_tariffa = "s";
 $priv_mod_sconto = "s";
 $priv_mod_caparra = "s";
@@ -366,6 +448,8 @@ $priv_mod_codice = "s";
 $vedi_clienti = "SI";
 $priv_vedi_telefoni = "s";
 $priv_vedi_indirizzo = "s";
+$attiva_regole1_consentite = "n";
+$attiva_tariffe_consentite = "n";
 $attiva_casse_consentite = "n";
 $attiva_contratti_consentiti = "n";
 $priv_cancella_contratti = "s";
@@ -377,7 +461,7 @@ if ($anno_utente_attivato == "SI") {
 
 $numero_contratto = aggslashdb((int) $numero_contratto);
 $nomi_contratti = trova_nomi_contratti($max_contr,$id_utente,$tablecontratti,$tablepersonalizza,$LIKE,$pag);
-$nome_contratto = $nomi_contratti['salv'][$numero_contratto];
+$nome_contratto = fixstr($nomi_contratti['salv'][$numero_contratto]);
 
 
 
@@ -470,7 +554,7 @@ if (is_file($dir_salvato."/".$file_dat.".dat")) unlink($dir_salvato."/".$file_da
 echo "".mex("Il documento",$pag)." <b>".$nome_file_contr[$num1]."</b> ".mex("è stato <b style=\"font-weight: normal; color: blue;\">cancellato</b>",$pag).".<br>";
 } # fine for $num1
 } # fine if (isset($cancella) and $cancella == "SI" and $priv_cancella_contratti != "n")
-elseif ($n_file < 1 or $n_file > $num_file_salva or controlla_num_pos($n_file) != "SI") $n_file = 1;
+elseif (controlla_num_pos(fix_set($n_file)) != "SI" or $n_file < 1 or $n_file > $num_file_salva) $n_file = 1;
 } # fine else if ($tipo_transazione != "con_s")
 } # fine elseif (!empty($id_transazione))
 
@@ -495,7 +579,8 @@ if ($nome_mittente_email) $mittente_email = "$nome_mittente_email <$mittente_ema
 } # fine if ($modifica_pers == "NO")
 #$maschera_envelope = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'maschera_email' and idutente = '1'");
 #$maschera_envelope = risul_query($maschera_envelope,0,'valpersonalizza');
-$dati_allegato = array('num' => 0);
+
+$dati_allegato = array('num' => 0, 'num_iim' => 0);
 $allegati_email = esegui_query("select * from $tablecontratti where numero = '$numero_contratto' and tipo = 'allegato'");
 $allegati_email = risul_query($allegati_email,0,'testo');
 if ($allegati_email) {
@@ -529,11 +614,34 @@ $dati_allegato[$num1]['valo'] = substr($allegato_email,strlen($dati_allegato[$nu
 } # fine for $num2
 } # fine for $num1
 } # fine if ($allegati_email)
+
+$iimg_email = esegui_query("select * from $tablecontratti where numero = '$numero_contratto' and tipo = 'img_inln'");
+if (numlin_query($iimg_email)) $iimg_email = (string) risul_query($iimg_email,0,'testo');
+else $iimg_email = "";
+if ($iimg_email) {
+$iimg_email = explode(",",$iimg_email);
+$dati_allegato['num_iim'] = (count($iimg_email) - 2);
+for ($num1 = 1 ; $num1 <= $dati_allegato['num_iim'] ; $num1++) {
+$cid_iimg = substr(strstr($iimg_email[$num1],":"),1);
+$num_iimg = str_replace(":$cid_iimg","",$iimg_email[$num1]);
+$iim_email = esegui_query("select * from $tablecontratti where numero = '$num_iimg' and tipo = 'file_iim'");
+$iim_email = risul_query($iim_email,0,'testo');
+$iim_email_v = explode(",",$iim_email);
+$dati_allegato['iim'][$num1]['nome'] = $iim_email_v[0];
+$dati_allegato['iim'][$num1]['tipo'] = $iim_email_v[1];
+$dati_allegato['iim'][$num1]['cid'] = $cid_iimg;
+$dati_allegato['iim'][$num1]['valo'] = substr($iim_email,strlen($dati_allegato['iim'][$num1]['nome'].",".$dati_allegato['iim'][$num1]['tipo'].","));
+} # fine for $num1
+} # fine if ($iimg_email)
+
 $opz_eml = esegui_query("select * from $tablecontratti where numero = '$numero_contratto' and tipo = 'opzeml'");
 $opz_eml = risul_query($opz_eml,0,'testo');
 $opz_eml = explode(";",$opz_eml);
 $cont_type = "text/plain";
-if ($opz_eml[0] == "html") $cont_type = "text/html";
+if ($opz_eml[0] == "html") {
+if (!empty($opz_eml[3])) $cont_type = "multipart/alternative";
+else $cont_type = "text/html";
+} # fine if ($opz_eml[0] == "html")
 $bcc_mittente = $opz_eml[1];
 $bcc_indirizzo = $opz_eml[2];
 if (defined('C_MASSIMO_NUM_EMAIL_GIORNALIERE') and C_MASSIMO_NUM_EMAIL_GIORNALIERE > 0) {
@@ -541,6 +649,7 @@ $dati_manda_email['num_app'] = esegui_query("select idappartamenti from $tableap
 $dati_manda_email['num_app'] = numlin_query($dati_manda_email['num_app']);
 } # fine if (defined('C_MASSIMO_NUM_EMAIL_GIORNALIERE') and C_MASSIMO_NUM_EMAIL_GIORNALIERE > 0)
 
+
 for ($num1 = 1 ; $num1 <= $numero_email ; $num1++) {
 if (!empty(${"destinatario_email".$num1}) and strstr(${"destinatario_email".$num1},"@")) {
 if ($modifica_pers != "NO") $mittente_email = ${"mittente_email".$num1};
@@ -560,10 +669,10 @@ $allega[$num2] = "SI";
 else $allega[$num2] = "";
 } # fine if ($contr_multilingua and $allega[$num2])
 } # fine for $num2
+$inviato = array('ok' => 0);
 if (!defined('C_RESTRIZIONI_DEMO_ADMIN') or C_RESTRIZIONI_DEMO_ADMIN != "SI") {
 $inviato = manda_email($mittente_email,"","",$destinatario_email,"",$bcc_mittente,$bcc_indirizzo,${"oggetto_email".$num1},${"testo_email".$num1},$cont_type,$dati_allegato,$allega,$tablepersonalizza,$tablecache);
 } # fine if (!defined('C_RESTRIZIONI_DEMO_ADMIN') or C_RESTRIZIONI_DEMO_ADMIN != "SI")
-else $inviato = array('ok' => 0);
 if (!empty($inviato['err_spf'])) {
 echo "<br><small>&nbsp;".mex("Non si è potuto mascherare il mittente dell'email perchè attualmente <b class=\"colwarn\">SPF non è configurato correttamente</b> sul dominio della email",$pag)." <b>".htmlspecialchars($mittente_email)."</b>.
  ".mex("L'utente amministratore può cambiare questa inpostazione in",$pag)." \"";
@@ -601,11 +710,11 @@ $clienti = esegui_query("select * from $tableclienti where email $ILIKE '$destin
 for ($num4 = 0 ; $num4 < numlin_query($clienti) ; $num4++) {
 $idclienti = risul_query($clienti,$num4,'idclienti');
 $doc_inviati = (string) risul_query($clienti,$num4,'doc_inviati');
-if (str_replace("#@?".htmlspecialchars(${"oggetto_email".$num1})."#|?","",$doc_inviati) == $doc_inviati) {
+if (str_replace("#@?".htmlspecialchars(${"oggetto_email".$num1},ENT_COMPAT)."#|?","",$doc_inviati) == $doc_inviati) {
 if (!$doc_inviati) $doc_inviati = "#@?";
-$doc_inviati .= str_replace("#|?","",str_replace("#@?","",htmlspecialchars(${"oggetto_email".$num1})))."#|?".date("Y-m-d",(time() + (C_DIFF_ORE * 3600)))."#@?";
-} # fine if (str_replace("#@?".htmlspecialchars(${"oggetto_email".$num1})."#|?","",$doc_inviati) == $doc_inviati)
-else $doc_inviati = preg_replace("/#@\?".str_replace('$','\$',str_replace("^","\^",str_replace("{","\{",str_replace("[","\[",str_replace("|","\|",str_replace(")","\)",str_replace("(","\(",str_replace("?","\?",str_replace("+","\+",str_replace(".","\.",str_replace("*","\*",str_replace("/","\/",${"oggetto_email".$num1}))))))))))))."#\|\?[^#]*#@\?/","#@?".htmlspecialchars(${"oggetto_email".$num1})."#|?".date("Y-m-d",(time() + (C_DIFF_ORE * 3600)))."#@?",$doc_inviati);
+$doc_inviati .= str_replace("#|?","",str_replace("#@?","",htmlspecialchars(${"oggetto_email".$num1},ENT_COMPAT)))."#|?".date("Y-m-d",(time() + (C_DIFF_ORE * 3600)))."#@?";
+} # fine if (str_replace("#@?".htmlspecialchars(${"oggetto_email".$num1},ENT_COMPAT)."#|?","",$doc_inviati) == $doc_inviati)
+else $doc_inviati = preg_replace("/#@\?".str_replace('$','\$',str_replace("^","\^",str_replace("{","\{",str_replace("[","\[",str_replace("|","\|",str_replace(")","\)",str_replace("(","\(",str_replace("?","\?",str_replace("+","\+",str_replace(".","\.",str_replace("*","\*",str_replace("/","\/",${"oggetto_email".$num1}))))))))))))."#\|\?[^#]*#@\?/","#@?".htmlspecialchars(${"oggetto_email".$num1},ENT_COMPAT)."#|?".date("Y-m-d",(time() + (C_DIFF_ORE * 3600)))."#@?",$doc_inviati);
 esegui_query("update $tableclienti set doc_inviati = '".aggslashdb($doc_inviati)."' where idclienti = '$idclienti' ");
 } # fine for $num4
 } # fine if (str_replace("@","",$destinatario_email) != $destinatario_email)
@@ -620,6 +729,7 @@ echo "<br>&nbsp;".mex("Non si è potuto inviare l'email a",$pag)." <b class=\"co
 } # fine if (!empty(${"destinatario_email".$num1}) and strstr(${"destinatario_email".$num1},"@"))
 } # fine for $num1
 
+
 } # fine if ($tipo_contratto == "contreml")
 } # fine if (isset($manda_mail) and $manda_mail == "SI")
 
@@ -646,7 +756,7 @@ $num_campi_pers_cliente = count($campi_pers_cliente);
 else $num_campi_pers_cliente = 0;
 include_once("./includes/funzioni_tariffe.php");
 $dati_cat_pers = dati_cat_pers($id_utente,$tablepersonalizza,$lingua_mex,"v",0,1);
-$dati_allegato = array('num' => 0);
+$dati_allegato = array('num' => 0, 'num_iim' => 0);
 $allegati_email = esegui_query("select * from $tablecontratti where numero = '$numero_contratto' and tipo = 'allegato'");
 if (numlin_query($allegati_email)) {
 $allegati_email = risul_query($allegati_email,0,'testo');
